# frozen_string_literal: true

# Collection of pseudo-legal move tablebases.
module PseudoLegalMoveTablebase
  # Xiangqi99 chess variant.
  module Xiangqi99
    # Computerized database that contains precalculated exhaustive pseudo-legal
    # moves of Xiangqi99 positions.
    #
    # @see https://developer.sashite.com/specs/general-actor-notation
    DB = {"X:-G"=>{0=>[[{1=>:enemy}, 1, "X:-G", true], [{9=>:enemy}, 9, "X:-G", true], [{1=>nil}, 1, "X:-G", false], [{9=>nil}, 9, "X:-G", false]], 1=>[[{0=>:enemy}, 0, "X:-G", true], [{2=>:enemy}, 2, "X:-G", true], [{10=>:enemy}, 10, "X:-G", true], [{0=>nil}, 0, "X:-G", false], [{2=>nil}, 2, "X:-G", false], [{10=>nil}, 10, "X:-G", false]], 2=>[[{1=>:enemy}, 1, "X:-G", true], [{3=>:enemy}, 3, "X:-G", true], [{11=>:enemy}, 11, "X:-G", true], [{1=>nil}, 1, "X:-G", false], [{3=>nil}, 3, "X:-G", false], [{11=>nil}, 11, "X:-G", false]], 3=>[[{2=>:enemy}, 2, "X:-G", true], [{4=>:enemy}, 4, "X:-G", true], [{12=>:enemy}, 12, "X:-G", true], [{2=>nil}, 2, "X:-G", false], [{4=>nil}, 4, "X:-G", false], [{12=>nil}, 12, "X:-G", false]], 4=>[[{3=>:enemy}, 3, "X:-G", true], [{5=>:enemy}, 5, "X:-G", true], [{13=>:enemy}, 13, "X:-G", true], [{3=>nil}, 3, "X:-G", false], [{5=>nil}, 5, "X:-G", false], [{13=>nil}, 13, "X:-G", false]], 5=>[[{4=>:enemy}, 4, "X:-G", true], [{6=>:enemy}, 6, "X:-G", true], [{14=>:enemy}, 14, "X:-G", true], [{4=>nil}, 4, "X:-G", false], [{6=>nil}, 6, "X:-G", false], [{14=>nil}, 14, "X:-G", false]], 6=>[[{5=>:enemy}, 5, "X:-G", true], [{7=>:enemy}, 7, "X:-G", true], [{15=>:enemy}, 15, "X:-G", true], [{5=>nil}, 5, "X:-G", false], [{7=>nil}, 7, "X:-G", false], [{15=>nil}, 15, "X:-G", false]], 7=>[[{6=>:enemy}, 6, "X:-G", true], [{8=>:enemy}, 8, "X:-G", true], [{16=>:enemy}, 16, "X:-G", true], [{6=>nil}, 6, "X:-G", false], [{8=>nil}, 8, "X:-G", false], [{16=>nil}, 16, "X:-G", false]], 8=>[[{7=>:enemy}, 7, "X:-G", true], [{17=>:enemy}, 17, "X:-G", true], [{7=>nil}, 7, "X:-G", false], [{17=>nil}, 17, "X:-G", false]], 9=>[[{0=>:enemy}, 0, "X:-G", true], [{10=>:enemy}, 10, "X:-G", true], [{18=>:enemy}, 18, "X:-G", true], [{0=>nil}, 0, "X:-G", false], [{10=>nil}, 10, "X:-G", false], [{18=>nil}, 18, "X:-G", false]], 10=>[[{1=>:enemy}, 1, "X:-G", true], [{9=>:enemy}, 9, "X:-G", true], [{11=>:enemy}, 11, "X:-G", true], [{19=>:enemy}, 19, "X:-G", true], [{1=>nil}, 1, "X:-G", false], [{9=>nil}, 9, "X:-G", false], [{11=>nil}, 11, "X:-G", false], [{19=>nil}, 19, "X:-G", false]], 11=>[[{2=>:enemy}, 2, "X:-G", true], [{10=>:enemy}, 10, "X:-G", true], [{12=>:enemy}, 12, "X:-G", true], [{20=>:enemy}, 20, "X:-G", true], [{2=>nil}, 2, "X:-G", false], [{10=>nil}, 10, "X:-G", false], [{12=>nil}, 12, "X:-G", false], [{20=>nil}, 20, "X:-G", false]], 12=>[[{3=>:enemy}, 3, "X:-G", true], [{11=>:enemy}, 11, "X:-G", true], [{13=>:enemy}, 13, "X:-G", true], [{21=>:enemy}, 21, "X:-G", true], [{3=>nil}, 3, "X:-G", false], [{11=>nil}, 11, "X:-G", false], [{13=>nil}, 13, "X:-G", false], [{21=>nil}, 21, "X:-G", false]], 13=>[[{4=>:enemy}, 4, "X:-G", true], [{12=>:enemy}, 12, "X:-G", true], [{14=>:enemy}, 14, "X:-G", true], [{22=>:enemy}, 22, "X:-G", true], [{4=>nil}, 4, "X:-G", false], [{12=>nil}, 12, "X:-G", false], [{14=>nil}, 14, "X:-G", false], [{22=>nil}, 22, "X:-G", false]], 14=>[[{5=>:enemy}, 5, "X:-G", true], [{13=>:enemy}, 13, "X:-G", true], [{15=>:enemy}, 15, "X:-G", true], [{23=>:enemy}, 23, "X:-G", true], [{5=>nil}, 5, "X:-G", false], [{13=>nil}, 13, "X:-G", false], [{15=>nil}, 15, "X:-G", false], [{23=>nil}, 23, "X:-G", false]], 15=>[[{6=>:enemy}, 6, "X:-G", true], [{14=>:enemy}, 14, "X:-G", true], [{16=>:enemy}, 16, "X:-G", true], [{24=>:enemy}, 24, "X:-G", true], [{6=>nil}, 6, "X:-G", false], [{14=>nil}, 14, "X:-G", false], [{16=>nil}, 16, "X:-G", false], [{24=>nil}, 24, "X:-G", false]], 16=>[[{7=>:enemy}, 7, "X:-G", true], [{15=>:enemy}, 15, "X:-G", true], [{17=>:enemy}, 17, "X:-G", true], [{25=>:enemy}, 25, "X:-G", true], [{7=>nil}, 7, "X:-G", false], [{15=>nil}, 15, "X:-G", false], [{17=>nil}, 17, "X:-G", false], [{25=>nil}, 25, "X:-G", false]], 17=>[[{8=>:enemy}, 8, "X:-G", true], [{16=>:enemy}, 16, "X:-G", true], [{26=>:enemy}, 26, "X:-G", true], [{8=>nil}, 8, "X:-G", false], [{16=>nil}, 16, "X:-G", false], [{26=>nil}, 26, "X:-G", false]], 18=>[[{9=>:enemy}, 9, "X:-G", true], [{19=>:enemy}, 19, "X:-G", true], [{27=>:enemy}, 27, "X:-G", true], [{9=>nil}, 9, "X:-G", false], [{19=>nil}, 19, "X:-G", false], [{27=>nil}, 27, "X:-G", false]], 19=>[[{10=>:enemy}, 10, "X:-G", true], [{18=>:enemy}, 18, "X:-G", true], [{20=>:enemy}, 20, "X:-G", true], [{28=>:enemy}, 28, "X:-G", true], [{10=>nil}, 10, "X:-G", false], [{18=>nil}, 18, "X:-G", false], [{20=>nil}, 20, "X:-G", false], [{28=>nil}, 28, "X:-G", false]], 20=>[[{11=>:enemy}, 11, "X:-G", true], [{19=>:enemy}, 19, "X:-G", true], [{21=>:enemy}, 21, "X:-G", true], [{29=>:enemy}, 29, "X:-G", true], [{11=>nil}, 11, "X:-G", false], [{19=>nil}, 19, "X:-G", false], [{21=>nil}, 21, "X:-G", false], [{29=>nil}, 29, "X:-G", false]], 21=>[[{12=>:enemy}, 12, "X:-G", true], [{20=>:enemy}, 20, "X:-G", true], [{22=>:enemy}, 22, "X:-G", true], [{30=>:enemy}, 30, "X:-G", true], [{12=>nil}, 12, "X:-G", false], [{20=>nil}, 20, "X:-G", false], [{22=>nil}, 22, "X:-G", false], [{30=>nil}, 30, "X:-G", false]], 22=>[[{13=>:enemy}, 13, "X:-G", true], [{21=>:enemy}, 21, "X:-G", true], [{23=>:enemy}, 23, "X:-G", true], [{31=>:enemy}, 31, "X:-G", true], [{13=>nil}, 13, "X:-G", false], [{21=>nil}, 21, "X:-G", false], [{23=>nil}, 23, "X:-G", false], [{31=>nil}, 31, "X:-G", false]], 23=>[[{14=>:enemy}, 14, "X:-G", true], [{22=>:enemy}, 22, "X:-G", true], [{24=>:enemy}, 24, "X:-G", true], [{32=>:enemy}, 32, "X:-G", true], [{14=>nil}, 14, "X:-G", false], [{22=>nil}, 22, "X:-G", false], [{24=>nil}, 24, "X:-G", false], [{32=>nil}, 32, "X:-G", false]], 24=>[[{15=>:enemy}, 15, "X:-G", true], [{23=>:enemy}, 23, "X:-G", true], [{25=>:enemy}, 25, "X:-G", true], [{33=>:enemy}, 33, "X:-G", true], [{15=>nil}, 15, "X:-G", false], [{23=>nil}, 23, "X:-G", false], [{25=>nil}, 25, "X:-G", false], [{33=>nil}, 33, "X:-G", false]], 25=>[[{16=>:enemy}, 16, "X:-G", true], [{24=>:enemy}, 24, "X:-G", true], [{26=>:enemy}, 26, "X:-G", true], [{34=>:enemy}, 34, "X:-G", true], [{16=>nil}, 16, "X:-G", false], [{24=>nil}, 24, "X:-G", false], [{26=>nil}, 26, "X:-G", false], [{34=>nil}, 34, "X:-G", false]], 26=>[[{17=>:enemy}, 17, "X:-G", true], [{25=>:enemy}, 25, "X:-G", true], [{35=>:enemy}, 35, "X:-G", true], [{17=>nil}, 17, "X:-G", false], [{25=>nil}, 25, "X:-G", false], [{35=>nil}, 35, "X:-G", false]], 27=>[[{18=>:enemy}, 18, "X:-G", true], [{28=>:enemy}, 28, "X:-G", true], [{36=>:enemy}, 36, "X:-G", true], [{18=>nil}, 18, "X:-G", false], [{28=>nil}, 28, "X:-G", false], [{36=>nil}, 36, "X:-G", false]], 28=>[[{19=>:enemy}, 19, "X:-G", true], [{27=>:enemy}, 27, "X:-G", true], [{29=>:enemy}, 29, "X:-G", true], [{37=>:enemy}, 37, "X:-G", true], [{19=>nil}, 19, "X:-G", false], [{27=>nil}, 27, "X:-G", false], [{29=>nil}, 29, "X:-G", false], [{37=>nil}, 37, "X:-G", false]], 29=>[[{20=>:enemy}, 20, "X:-G", true], [{28=>:enemy}, 28, "X:-G", true], [{30=>:enemy}, 30, "X:-G", true], [{38=>:enemy}, 38, "X:-G", true], [{20=>nil}, 20, "X:-G", false], [{28=>nil}, 28, "X:-G", false], [{30=>nil}, 30, "X:-G", false], [{38=>nil}, 38, "X:-G", false]], 30=>[[{21=>:enemy}, 21, "X:-G", true], [{29=>:enemy}, 29, "X:-G", true], [{31=>:enemy}, 31, "X:-G", true], [{39=>:enemy}, 39, "X:-G", true], [{21=>nil}, 21, "X:-G", false], [{29=>nil}, 29, "X:-G", false], [{31=>nil}, 31, "X:-G", false], [{39=>nil}, 39, "X:-G", false]], 31=>[[{22=>:enemy}, 22, "X:-G", true], [{30=>:enemy}, 30, "X:-G", true], [{32=>:enemy}, 32, "X:-G", true], [{40=>:enemy}, 40, "X:-G", true], [{22=>nil}, 22, "X:-G", false], [{30=>nil}, 30, "X:-G", false], [{32=>nil}, 32, "X:-G", false], [{40=>nil}, 40, "X:-G", false]], 32=>[[{23=>:enemy}, 23, "X:-G", true], [{31=>:enemy}, 31, "X:-G", true], [{33=>:enemy}, 33, "X:-G", true], [{41=>:enemy}, 41, "X:-G", true], [{23=>nil}, 23, "X:-G", false], [{31=>nil}, 31, "X:-G", false], [{33=>nil}, 33, "X:-G", false], [{41=>nil}, 41, "X:-G", false]], 33=>[[{24=>:enemy}, 24, "X:-G", true], [{32=>:enemy}, 32, "X:-G", true], [{34=>:enemy}, 34, "X:-G", true], [{42=>:enemy}, 42, "X:-G", true], [{24=>nil}, 24, "X:-G", false], [{32=>nil}, 32, "X:-G", false], [{34=>nil}, 34, "X:-G", false], [{42=>nil}, 42, "X:-G", false]], 34=>[[{25=>:enemy}, 25, "X:-G", true], [{33=>:enemy}, 33, "X:-G", true], [{35=>:enemy}, 35, "X:-G", true], [{43=>:enemy}, 43, "X:-G", true], [{25=>nil}, 25, "X:-G", false], [{33=>nil}, 33, "X:-G", false], [{35=>nil}, 35, "X:-G", false], [{43=>nil}, 43, "X:-G", false]], 35=>[[{26=>:enemy}, 26, "X:-G", true], [{34=>:enemy}, 34, "X:-G", true], [{44=>:enemy}, 44, "X:-G", true], [{26=>nil}, 26, "X:-G", false], [{34=>nil}, 34, "X:-G", false], [{44=>nil}, 44, "X:-G", false]], 36=>[[{27=>:enemy}, 27, "X:-G", true], [{37=>:enemy}, 37, "X:-G", true], [{45=>:enemy}, 45, "X:-G", true], [{27=>nil}, 27, "X:-G", false], [{37=>nil}, 37, "X:-G", false], [{45=>nil}, 45, "X:-G", false]], 37=>[[{28=>:enemy}, 28, "X:-G", true], [{36=>:enemy}, 36, "X:-G", true], [{38=>:enemy}, 38, "X:-G", true], [{46=>:enemy}, 46, "X:-G", true], [{28=>nil}, 28, "X:-G", false], [{36=>nil}, 36, "X:-G", false], [{38=>nil}, 38, "X:-G", false], [{46=>nil}, 46, "X:-G", false]], 38=>[[{29=>:enemy}, 29, "X:-G", true], [{37=>:enemy}, 37, "X:-G", true], [{39=>:enemy}, 39, "X:-G", true], [{47=>:enemy}, 47, "X:-G", true], [{29=>nil}, 29, "X:-G", false], [{37=>nil}, 37, "X:-G", false], [{39=>nil}, 39, "X:-G", false], [{47=>nil}, 47, "X:-G", false]], 39=>[[{30=>:enemy}, 30, "X:-G", true], [{38=>:enemy}, 38, "X:-G", true], [{40=>:enemy}, 40, "X:-G", true], [{48=>:enemy}, 48, "X:-G", true], [{30=>nil}, 30, "X:-G", false], [{38=>nil}, 38, "X:-G", false], [{40=>nil}, 40, "X:-G", false], [{48=>nil}, 48, "X:-G", false]], 40=>[[{31=>:enemy}, 31, "X:-G", true], [{39=>:enemy}, 39, "X:-G", true], [{41=>:enemy}, 41, "X:-G", true], [{49=>:enemy}, 49, "X:-G", true], [{31=>nil}, 31, "X:-G", false], [{39=>nil}, 39, "X:-G", false], [{41=>nil}, 41, "X:-G", false], [{49=>nil}, 49, "X:-G", false]], 41=>[[{32=>:enemy}, 32, "X:-G", true], [{40=>:enemy}, 40, "X:-G", true], [{42=>:enemy}, 42, "X:-G", true], [{50=>:enemy}, 50, "X:-G", true], [{32=>nil}, 32, "X:-G", false], [{40=>nil}, 40, "X:-G", false], [{42=>nil}, 42, "X:-G", false], [{50=>nil}, 50, "X:-G", false]], 42=>[[{33=>:enemy}, 33, "X:-G", true], [{41=>:enemy}, 41, "X:-G", true], [{43=>:enemy}, 43, "X:-G", true], [{51=>:enemy}, 51, "X:-G", true], [{33=>nil}, 33, "X:-G", false], [{41=>nil}, 41, "X:-G", false], [{43=>nil}, 43, "X:-G", false], [{51=>nil}, 51, "X:-G", false]], 43=>[[{34=>:enemy}, 34, "X:-G", true], [{42=>:enemy}, 42, "X:-G", true], [{44=>:enemy}, 44, "X:-G", true], [{52=>:enemy}, 52, "X:-G", true], [{34=>nil}, 34, "X:-G", false], [{42=>nil}, 42, "X:-G", false], [{44=>nil}, 44, "X:-G", false], [{52=>nil}, 52, "X:-G", false]], 44=>[[{35=>:enemy}, 35, "X:-G", true], [{43=>:enemy}, 43, "X:-G", true], [{53=>:enemy}, 53, "X:-G", true], [{35=>nil}, 35, "X:-G", false], [{43=>nil}, 43, "X:-G", false], [{53=>nil}, 53, "X:-G", false]], 45=>[[{36=>:enemy}, 36, "X:-G", true], [{46=>:enemy}, 46, "X:-G", true], [{54=>:enemy}, 54, "X:-G", true], [{36=>nil}, 36, "X:-G", false], [{46=>nil}, 46, "X:-G", false], [{54=>nil}, 54, "X:-G", false]], 46=>[[{37=>:enemy}, 37, "X:-G", true], [{45=>:enemy}, 45, "X:-G", true], [{47=>:enemy}, 47, "X:-G", true], [{55=>:enemy}, 55, "X:-G", true], [{37=>nil}, 37, "X:-G", false], [{45=>nil}, 45, "X:-G", false], [{47=>nil}, 47, "X:-G", false], [{55=>nil}, 55, "X:-G", false]], 47=>[[{38=>:enemy}, 38, "X:-G", true], [{46=>:enemy}, 46, "X:-G", true], [{48=>:enemy}, 48, "X:-G", true], [{56=>:enemy}, 56, "X:-G", true], [{38=>nil}, 38, "X:-G", false], [{46=>nil}, 46, "X:-G", false], [{48=>nil}, 48, "X:-G", false], [{56=>nil}, 56, "X:-G", false]], 48=>[[{39=>:enemy}, 39, "X:-G", true], [{47=>:enemy}, 47, "X:-G", true], [{49=>:enemy}, 49, "X:-G", true], [{57=>:enemy}, 57, "X:-G", true], [{39=>nil}, 39, "X:-G", false], [{47=>nil}, 47, "X:-G", false], [{49=>nil}, 49, "X:-G", false], [{57=>nil}, 57, "X:-G", false]], 49=>[[{40=>:enemy}, 40, "X:-G", true], [{48=>:enemy}, 48, "X:-G", true], [{50=>:enemy}, 50, "X:-G", true], [{58=>:enemy}, 58, "X:-G", true], [{40=>nil}, 40, "X:-G", false], [{48=>nil}, 48, "X:-G", false], [{50=>nil}, 50, "X:-G", false], [{58=>nil}, 58, "X:-G", false]], 50=>[[{41=>:enemy}, 41, "X:-G", true], [{49=>:enemy}, 49, "X:-G", true], [{51=>:enemy}, 51, "X:-G", true], [{59=>:enemy}, 59, "X:-G", true], [{41=>nil}, 41, "X:-G", false], [{49=>nil}, 49, "X:-G", false], [{51=>nil}, 51, "X:-G", false], [{59=>nil}, 59, "X:-G", false]], 51=>[[{42=>:enemy}, 42, "X:-G", true], [{50=>:enemy}, 50, "X:-G", true], [{52=>:enemy}, 52, "X:-G", true], [{60=>:enemy}, 60, "X:-G", true], [{42=>nil}, 42, "X:-G", false], [{50=>nil}, 50, "X:-G", false], [{52=>nil}, 52, "X:-G", false], [{60=>nil}, 60, "X:-G", false]], 52=>[[{43=>:enemy}, 43, "X:-G", true], [{51=>:enemy}, 51, "X:-G", true], [{53=>:enemy}, 53, "X:-G", true], [{61=>:enemy}, 61, "X:-G", true], [{43=>nil}, 43, "X:-G", false], [{51=>nil}, 51, "X:-G", false], [{53=>nil}, 53, "X:-G", false], [{61=>nil}, 61, "X:-G", false]], 53=>[[{44=>:enemy}, 44, "X:-G", true], [{52=>:enemy}, 52, "X:-G", true], [{62=>:enemy}, 62, "X:-G", true], [{44=>nil}, 44, "X:-G", false], [{52=>nil}, 52, "X:-G", false], [{62=>nil}, 62, "X:-G", false]], 54=>[[{45=>:enemy}, 45, "X:-G", true], [{55=>:enemy}, 55, "X:-G", true], [{63=>:enemy}, 63, "X:-G", true], [{45=>nil}, 45, "X:-G", false], [{55=>nil}, 55, "X:-G", false], [{63=>nil}, 63, "X:-G", false]], 55=>[[{46=>:enemy}, 46, "X:-G", true], [{54=>:enemy}, 54, "X:-G", true], [{56=>:enemy}, 56, "X:-G", true], [{64=>:enemy}, 64, "X:-G", true], [{46=>nil}, 46, "X:-G", false], [{54=>nil}, 54, "X:-G", false], [{56=>nil}, 56, "X:-G", false], [{64=>nil}, 64, "X:-G", false]], 56=>[[{47=>:enemy}, 47, "X:-G", true], [{55=>:enemy}, 55, "X:-G", true], [{57=>:enemy}, 57, "X:-G", true], [{65=>:enemy}, 65, "X:-G", true], [{47=>nil}, 47, "X:-G", false], [{55=>nil}, 55, "X:-G", false], [{57=>nil}, 57, "X:-G", false], [{65=>nil}, 65, "X:-G", false]], 57=>[[{48=>:enemy}, 48, "X:-G", true], [{56=>:enemy}, 56, "X:-G", true], [{58=>:enemy}, 58, "X:-G", true], [{66=>:enemy}, 66, "X:-G", true], [{48=>nil}, 48, "X:-G", false], [{56=>nil}, 56, "X:-G", false], [{58=>nil}, 58, "X:-G", false], [{66=>nil}, 66, "X:-G", false]], 58=>[[{49=>:enemy}, 49, "X:-G", true], [{57=>:enemy}, 57, "X:-G", true], [{59=>:enemy}, 59, "X:-G", true], [{67=>:enemy}, 67, "X:-G", true], [{49=>nil}, 49, "X:-G", false], [{57=>nil}, 57, "X:-G", false], [{59=>nil}, 59, "X:-G", false], [{67=>nil}, 67, "X:-G", false]], 59=>[[{50=>:enemy}, 50, "X:-G", true], [{58=>:enemy}, 58, "X:-G", true], [{60=>:enemy}, 60, "X:-G", true], [{68=>:enemy}, 68, "X:-G", true], [{50=>nil}, 50, "X:-G", false], [{58=>nil}, 58, "X:-G", false], [{60=>nil}, 60, "X:-G", false], [{68=>nil}, 68, "X:-G", false]], 60=>[[{51=>:enemy}, 51, "X:-G", true], [{59=>:enemy}, 59, "X:-G", true], [{61=>:enemy}, 61, "X:-G", true], [{69=>:enemy}, 69, "X:-G", true], [{51=>nil}, 51, "X:-G", false], [{59=>nil}, 59, "X:-G", false], [{61=>nil}, 61, "X:-G", false], [{69=>nil}, 69, "X:-G", false]], 61=>[[{52=>:enemy}, 52, "X:-G", true], [{60=>:enemy}, 60, "X:-G", true], [{62=>:enemy}, 62, "X:-G", true], [{70=>:enemy}, 70, "X:-G", true], [{52=>nil}, 52, "X:-G", false], [{60=>nil}, 60, "X:-G", false], [{62=>nil}, 62, "X:-G", false], [{70=>nil}, 70, "X:-G", false]], 62=>[[{53=>:enemy}, 53, "X:-G", true], [{61=>:enemy}, 61, "X:-G", true], [{71=>:enemy}, 71, "X:-G", true], [{53=>nil}, 53, "X:-G", false], [{61=>nil}, 61, "X:-G", false], [{71=>nil}, 71, "X:-G", false]], 63=>[[{54=>:enemy}, 54, "X:-G", true], [{64=>:enemy}, 64, "X:-G", true], [{72=>:enemy}, 72, "X:-G", true], [{54=>nil}, 54, "X:-G", false], [{64=>nil}, 64, "X:-G", false], [{72=>nil}, 72, "X:-G", false]], 64=>[[{55=>:enemy}, 55, "X:-G", true], [{63=>:enemy}, 63, "X:-G", true], [{65=>:enemy}, 65, "X:-G", true], [{73=>:enemy}, 73, "X:-G", true], [{55=>nil}, 55, "X:-G", false], [{63=>nil}, 63, "X:-G", false], [{65=>nil}, 65, "X:-G", false], [{73=>nil}, 73, "X:-G", false]], 65=>[[{56=>:enemy}, 56, "X:-G", true], [{64=>:enemy}, 64, "X:-G", true], [{66=>:enemy}, 66, "X:-G", true], [{74=>:enemy}, 74, "X:-G", true], [{56=>nil}, 56, "X:-G", false], [{64=>nil}, 64, "X:-G", false], [{66=>nil}, 66, "X:-G", false], [{74=>nil}, 74, "X:-G", false]], 66=>[[{57=>:enemy}, 57, "X:-G", true], [{65=>:enemy}, 65, "X:-G", true], [{67=>:enemy}, 67, "X:-G", true], [{75=>:enemy}, 75, "X:-G", true], [{57=>nil}, 57, "X:-G", false], [{65=>nil}, 65, "X:-G", false], [{67=>nil}, 67, "X:-G", false], [{75=>nil}, 75, "X:-G", false]], 67=>[[{58=>:enemy}, 58, "X:-G", true], [{66=>:enemy}, 66, "X:-G", true], [{68=>:enemy}, 68, "X:-G", true], [{76=>:enemy}, 76, "X:-G", true], [{58=>nil}, 58, "X:-G", false], [{66=>nil}, 66, "X:-G", false], [{68=>nil}, 68, "X:-G", false], [{76=>nil}, 76, "X:-G", false]], 68=>[[{59=>:enemy}, 59, "X:-G", true], [{67=>:enemy}, 67, "X:-G", true], [{69=>:enemy}, 69, "X:-G", true], [{77=>:enemy}, 77, "X:-G", true], [{59=>nil}, 59, "X:-G", false], [{67=>nil}, 67, "X:-G", false], [{69=>nil}, 69, "X:-G", false], [{77=>nil}, 77, "X:-G", false]], 69=>[[{60=>:enemy}, 60, "X:-G", true], [{68=>:enemy}, 68, "X:-G", true], [{70=>:enemy}, 70, "X:-G", true], [{78=>:enemy}, 78, "X:-G", true], [{60=>nil}, 60, "X:-G", false], [{68=>nil}, 68, "X:-G", false], [{70=>nil}, 70, "X:-G", false], [{78=>nil}, 78, "X:-G", false]], 70=>[[{61=>:enemy}, 61, "X:-G", true], [{69=>:enemy}, 69, "X:-G", true], [{71=>:enemy}, 71, "X:-G", true], [{79=>:enemy}, 79, "X:-G", true], [{61=>nil}, 61, "X:-G", false], [{69=>nil}, 69, "X:-G", false], [{71=>nil}, 71, "X:-G", false], [{79=>nil}, 79, "X:-G", false]], 71=>[[{62=>:enemy}, 62, "X:-G", true], [{70=>:enemy}, 70, "X:-G", true], [{80=>:enemy}, 80, "X:-G", true], [{62=>nil}, 62, "X:-G", false], [{70=>nil}, 70, "X:-G", false], [{80=>nil}, 80, "X:-G", false]], 72=>[[{63=>:enemy}, 63, "X:-G", true], [{73=>:enemy}, 73, "X:-G", true], [{63=>nil}, 63, "X:-G", false], [{73=>nil}, 73, "X:-G", false]], 73=>[[{64=>:enemy}, 64, "X:-G", true], [{72=>:enemy}, 72, "X:-G", true], [{74=>:enemy}, 74, "X:-G", true], [{64=>nil}, 64, "X:-G", false], [{72=>nil}, 72, "X:-G", false], [{74=>nil}, 74, "X:-G", false]], 74=>[[{65=>:enemy}, 65, "X:-G", true], [{73=>:enemy}, 73, "X:-G", true], [{75=>:enemy}, 75, "X:-G", true], [{65=>nil}, 65, "X:-G", false], [{73=>nil}, 73, "X:-G", false], [{75=>nil}, 75, "X:-G", false]], 75=>[[{66=>:enemy}, 66, "X:-G", true], [{74=>:enemy}, 74, "X:-G", true], [{76=>:enemy}, 76, "X:-G", true], [{66=>nil}, 66, "X:-G", false], [{74=>nil}, 74, "X:-G", false], [{76=>nil}, 76, "X:-G", false]], 76=>[[{67=>:enemy}, 67, "X:-G", true], [{75=>:enemy}, 75, "X:-G", true], [{77=>:enemy}, 77, "X:-G", true], [{67=>nil}, 67, "X:-G", false], [{75=>nil}, 75, "X:-G", false], [{77=>nil}, 77, "X:-G", false]], 77=>[[{68=>:enemy}, 68, "X:-G", true], [{76=>:enemy}, 76, "X:-G", true], [{78=>:enemy}, 78, "X:-G", true], [{68=>nil}, 68, "X:-G", false], [{76=>nil}, 76, "X:-G", false], [{78=>nil}, 78, "X:-G", false]], 78=>[[{69=>:enemy}, 69, "X:-G", true], [{77=>:enemy}, 77, "X:-G", true], [{79=>:enemy}, 79, "X:-G", true], [{69=>nil}, 69, "X:-G", false], [{77=>nil}, 77, "X:-G", false], [{79=>nil}, 79, "X:-G", false]], 79=>[[{70=>:enemy}, 70, "X:-G", true], [{78=>:enemy}, 78, "X:-G", true], [{80=>:enemy}, 80, "X:-G", true], [{70=>nil}, 70, "X:-G", false], [{78=>nil}, 78, "X:-G", false], [{80=>nil}, 80, "X:-G", false]], 80=>[[{71=>:enemy}, 71, "X:-G", true], [{79=>:enemy}, 79, "X:-G", true], [{71=>nil}, 71, "X:-G", false], [{79=>nil}, 79, "X:-G", false]], nil=>[[{0=>nil}, 0, "X:-G", false], [{1=>nil}, 1, "X:-G", false], [{2=>nil}, 2, "X:-G", false], [{3=>nil}, 3, "X:-G", false], [{4=>nil}, 4, "X:-G", false], [{5=>nil}, 5, "X:-G", false], [{6=>nil}, 6, "X:-G", false], [{7=>nil}, 7, "X:-G", false], [{8=>nil}, 8, "X:-G", false], [{9=>nil}, 9, "X:-G", false], [{10=>nil}, 10, "X:-G", false], [{11=>nil}, 11, "X:-G", false], [{12=>nil}, 12, "X:-G", false], [{13=>nil}, 13, "X:-G", false], [{14=>nil}, 14, "X:-G", false], [{15=>nil}, 15, "X:-G", false], [{16=>nil}, 16, "X:-G", false], [{17=>nil}, 17, "X:-G", false], [{18=>nil}, 18, "X:-G", false], [{19=>nil}, 19, "X:-G", false], [{20=>nil}, 20, "X:-G", false], [{21=>nil}, 21, "X:-G", false], [{22=>nil}, 22, "X:-G", false], [{23=>nil}, 23, "X:-G", false], [{24=>nil}, 24, "X:-G", false], [{25=>nil}, 25, "X:-G", false], [{26=>nil}, 26, "X:-G", false], [{27=>nil}, 27, "X:-G", false], [{28=>nil}, 28, "X:-G", false], [{29=>nil}, 29, "X:-G", false], [{30=>nil}, 30, "X:-G", false], [{31=>nil}, 31, "X:-G", false], [{32=>nil}, 32, "X:-G", false], [{33=>nil}, 33, "X:-G", false], [{34=>nil}, 34, "X:-G", false], [{35=>nil}, 35, "X:-G", false], [{36=>nil}, 36, "X:-G", false], [{37=>nil}, 37, "X:-G", false], [{38=>nil}, 38, "X:-G", false], [{39=>nil}, 39, "X:-G", false], [{40=>nil}, 40, "X:-G", false], [{41=>nil}, 41, "X:-G", false], [{42=>nil}, 42, "X:-G", false], [{43=>nil}, 43, "X:-G", false], [{44=>nil}, 44, "X:-G", false], [{45=>nil}, 45, "X:-G", false], [{46=>nil}, 46, "X:-G", false], [{47=>nil}, 47, "X:-G", false], [{48=>nil}, 48, "X:-G", false], [{49=>nil}, 49, "X:-G", false], [{50=>nil}, 50, "X:-G", false], [{51=>nil}, 51, "X:-G", false], [{52=>nil}, 52, "X:-G", false], [{53=>nil}, 53, "X:-G", false], [{54=>nil}, 54, "X:-G", false], [{55=>nil}, 55, "X:-G", false], [{56=>nil}, 56, "X:-G", false], [{57=>nil}, 57, "X:-G", false], [{58=>nil}, 58, "X:-G", false], [{59=>nil}, 59, "X:-G", false], [{60=>nil}, 60, "X:-G", false], [{61=>nil}, 61, "X:-G", false], [{62=>nil}, 62, "X:-G", false], [{63=>nil}, 63, "X:-G", false], [{64=>nil}, 64, "X:-G", false], [{65=>nil}, 65, "X:-G", false], [{66=>nil}, 66, "X:-G", false], [{67=>nil}, 67, "X:-G", false], [{68=>nil}, 68, "X:-G", false], [{69=>nil}, 69, "X:-G", false], [{70=>nil}, 70, "X:-G", false], [{71=>nil}, 71, "X:-G", false], [{72=>nil}, 72, "X:-G", false], [{73=>nil}, 73, "X:-G", false], [{74=>nil}, 74, "X:-G", false], [{75=>nil}, 75, "X:-G", false], [{76=>nil}, 76, "X:-G", false], [{77=>nil}, 77, "X:-G", false], [{78=>nil}, 78, "X:-G", false], [{79=>nil}, 79, "X:-G", false], [{80=>nil}, 80, "X:-G", false]]}, "X:A"=>{0=>[[{10=>:enemy}, 10, "X:A", true], [{10=>nil}, 10, "X:A", false]], 1=>[[{9=>:enemy}, 9, "X:A", true], [{11=>:enemy}, 11, "X:A", true], [{9=>nil}, 9, "X:A", false], [{11=>nil}, 11, "X:A", false]], 2=>[[{10=>:enemy}, 10, "X:A", true], [{12=>:enemy}, 12, "X:A", true], [{10=>nil}, 10, "X:A", false], [{12=>nil}, 12, "X:A", false]], 3=>[[{11=>:enemy}, 11, "X:A", true], [{13=>:enemy}, 13, "X:A", true], [{11=>nil}, 11, "X:A", false], [{13=>nil}, 13, "X:A", false]], 4=>[[{12=>:enemy}, 12, "X:A", true], [{14=>:enemy}, 14, "X:A", true], [{12=>nil}, 12, "X:A", false], [{14=>nil}, 14, "X:A", false]], 5=>[[{13=>:enemy}, 13, "X:A", true], [{15=>:enemy}, 15, "X:A", true], [{13=>nil}, 13, "X:A", false], [{15=>nil}, 15, "X:A", false]], 6=>[[{14=>:enemy}, 14, "X:A", true], [{16=>:enemy}, 16, "X:A", true], [{14=>nil}, 14, "X:A", false], [{16=>nil}, 16, "X:A", false]], 7=>[[{15=>:enemy}, 15, "X:A", true], [{17=>:enemy}, 17, "X:A", true], [{15=>nil}, 15, "X:A", false], [{17=>nil}, 17, "X:A", false]], 8=>[[{16=>:enemy}, 16, "X:A", true], [{16=>nil}, 16, "X:A", false]], 9=>[[{1=>:enemy}, 1, "X:A", true], [{19=>:enemy}, 19, "X:A", true], [{1=>nil}, 1, "X:A", false], [{19=>nil}, 19, "X:A", false]], 10=>[[{0=>:enemy}, 0, "X:A", true], [{2=>:enemy}, 2, "X:A", true], [{18=>:enemy}, 18, "X:A", true], [{20=>:enemy}, 20, "X:A", true], [{0=>nil}, 0, "X:A", false], [{2=>nil}, 2, "X:A", false], [{18=>nil}, 18, "X:A", false], [{20=>nil}, 20, "X:A", false]], 11=>[[{1=>:enemy}, 1, "X:A", true], [{3=>:enemy}, 3, "X:A", true], [{19=>:enemy}, 19, "X:A", true], [{21=>:enemy}, 21, "X:A", true], [{1=>nil}, 1, "X:A", false], [{3=>nil}, 3, "X:A", false], [{19=>nil}, 19, "X:A", false], [{21=>nil}, 21, "X:A", false]], 12=>[[{2=>:enemy}, 2, "X:A", true], [{4=>:enemy}, 4, "X:A", true], [{20=>:enemy}, 20, "X:A", true], [{22=>:enemy}, 22, "X:A", true], [{2=>nil}, 2, "X:A", false], [{4=>nil}, 4, "X:A", false], [{20=>nil}, 20, "X:A", false], [{22=>nil}, 22, "X:A", false]], 13=>[[{3=>:enemy}, 3, "X:A", true], [{5=>:enemy}, 5, "X:A", true], [{21=>:enemy}, 21, "X:A", true], [{23=>:enemy}, 23, "X:A", true], [{3=>nil}, 3, "X:A", false], [{5=>nil}, 5, "X:A", false], [{21=>nil}, 21, "X:A", false], [{23=>nil}, 23, "X:A", false]], 14=>[[{4=>:enemy}, 4, "X:A", true], [{6=>:enemy}, 6, "X:A", true], [{22=>:enemy}, 22, "X:A", true], [{24=>:enemy}, 24, "X:A", true], [{4=>nil}, 4, "X:A", false], [{6=>nil}, 6, "X:A", false], [{22=>nil}, 22, "X:A", false], [{24=>nil}, 24, "X:A", false]], 15=>[[{5=>:enemy}, 5, "X:A", true], [{7=>:enemy}, 7, "X:A", true], [{23=>:enemy}, 23, "X:A", true], [{25=>:enemy}, 25, "X:A", true], [{5=>nil}, 5, "X:A", false], [{7=>nil}, 7, "X:A", false], [{23=>nil}, 23, "X:A", false], [{25=>nil}, 25, "X:A", false]], 16=>[[{6=>:enemy}, 6, "X:A", true], [{8=>:enemy}, 8, "X:A", true], [{24=>:enemy}, 24, "X:A", true], [{26=>:enemy}, 26, "X:A", true], [{6=>nil}, 6, "X:A", false], [{8=>nil}, 8, "X:A", false], [{24=>nil}, 24, "X:A", false], [{26=>nil}, 26, "X:A", false]], 17=>[[{7=>:enemy}, 7, "X:A", true], [{25=>:enemy}, 25, "X:A", true], [{7=>nil}, 7, "X:A", false], [{25=>nil}, 25, "X:A", false]], 18=>[[{10=>:enemy}, 10, "X:A", true], [{28=>:enemy}, 28, "X:A", true], [{10=>nil}, 10, "X:A", false], [{28=>nil}, 28, "X:A", false]], 19=>[[{9=>:enemy}, 9, "X:A", true], [{11=>:enemy}, 11, "X:A", true], [{27=>:enemy}, 27, "X:A", true], [{29=>:enemy}, 29, "X:A", true], [{9=>nil}, 9, "X:A", false], [{11=>nil}, 11, "X:A", false], [{27=>nil}, 27, "X:A", false], [{29=>nil}, 29, "X:A", false]], 20=>[[{10=>:enemy}, 10, "X:A", true], [{12=>:enemy}, 12, "X:A", true], [{28=>:enemy}, 28, "X:A", true], [{30=>:enemy}, 30, "X:A", true], [{10=>nil}, 10, "X:A", false], [{12=>nil}, 12, "X:A", false], [{28=>nil}, 28, "X:A", false], [{30=>nil}, 30, "X:A", false]], 21=>[[{11=>:enemy}, 11, "X:A", true], [{13=>:enemy}, 13, "X:A", true], [{29=>:enemy}, 29, "X:A", true], [{31=>:enemy}, 31, "X:A", true], [{11=>nil}, 11, "X:A", false], [{13=>nil}, 13, "X:A", false], [{29=>nil}, 29, "X:A", false], [{31=>nil}, 31, "X:A", false]], 22=>[[{12=>:enemy}, 12, "X:A", true], [{14=>:enemy}, 14, "X:A", true], [{30=>:enemy}, 30, "X:A", true], [{32=>:enemy}, 32, "X:A", true], [{12=>nil}, 12, "X:A", false], [{14=>nil}, 14, "X:A", false], [{30=>nil}, 30, "X:A", false], [{32=>nil}, 32, "X:A", false]], 23=>[[{13=>:enemy}, 13, "X:A", true], [{15=>:enemy}, 15, "X:A", true], [{31=>:enemy}, 31, "X:A", true], [{33=>:enemy}, 33, "X:A", true], [{13=>nil}, 13, "X:A", false], [{15=>nil}, 15, "X:A", false], [{31=>nil}, 31, "X:A", false], [{33=>nil}, 33, "X:A", false]], 24=>[[{14=>:enemy}, 14, "X:A", true], [{16=>:enemy}, 16, "X:A", true], [{32=>:enemy}, 32, "X:A", true], [{34=>:enemy}, 34, "X:A", true], [{14=>nil}, 14, "X:A", false], [{16=>nil}, 16, "X:A", false], [{32=>nil}, 32, "X:A", false], [{34=>nil}, 34, "X:A", false]], 25=>[[{15=>:enemy}, 15, "X:A", true], [{17=>:enemy}, 17, "X:A", true], [{33=>:enemy}, 33, "X:A", true], [{35=>:enemy}, 35, "X:A", true], [{15=>nil}, 15, "X:A", false], [{17=>nil}, 17, "X:A", false], [{33=>nil}, 33, "X:A", false], [{35=>nil}, 35, "X:A", false]], 26=>[[{16=>:enemy}, 16, "X:A", true], [{34=>:enemy}, 34, "X:A", true], [{16=>nil}, 16, "X:A", false], [{34=>nil}, 34, "X:A", false]], 27=>[[{19=>:enemy}, 19, "X:A", true], [{37=>:enemy}, 37, "X:A", true], [{19=>nil}, 19, "X:A", false], [{37=>nil}, 37, "X:A", false]], 28=>[[{18=>:enemy}, 18, "X:A", true], [{20=>:enemy}, 20, "X:A", true], [{36=>:enemy}, 36, "X:A", true], [{38=>:enemy}, 38, "X:A", true], [{18=>nil}, 18, "X:A", false], [{20=>nil}, 20, "X:A", false], [{36=>nil}, 36, "X:A", false], [{38=>nil}, 38, "X:A", false]], 29=>[[{19=>:enemy}, 19, "X:A", true], [{21=>:enemy}, 21, "X:A", true], [{37=>:enemy}, 37, "X:A", true], [{39=>:enemy}, 39, "X:A", true], [{19=>nil}, 19, "X:A", false], [{21=>nil}, 21, "X:A", false], [{37=>nil}, 37, "X:A", false], [{39=>nil}, 39, "X:A", false]], 30=>[[{20=>:enemy}, 20, "X:A", true], [{22=>:enemy}, 22, "X:A", true], [{38=>:enemy}, 38, "X:A", true], [{40=>:enemy}, 40, "X:A", true], [{20=>nil}, 20, "X:A", false], [{22=>nil}, 22, "X:A", false], [{38=>nil}, 38, "X:A", false], [{40=>nil}, 40, "X:A", false]], 31=>[[{21=>:enemy}, 21, "X:A", true], [{23=>:enemy}, 23, "X:A", true], [{39=>:enemy}, 39, "X:A", true], [{41=>:enemy}, 41, "X:A", true], [{21=>nil}, 21, "X:A", false], [{23=>nil}, 23, "X:A", false], [{39=>nil}, 39, "X:A", false], [{41=>nil}, 41, "X:A", false]], 32=>[[{22=>:enemy}, 22, "X:A", true], [{24=>:enemy}, 24, "X:A", true], [{40=>:enemy}, 40, "X:A", true], [{42=>:enemy}, 42, "X:A", true], [{22=>nil}, 22, "X:A", false], [{24=>nil}, 24, "X:A", false], [{40=>nil}, 40, "X:A", false], [{42=>nil}, 42, "X:A", false]], 33=>[[{23=>:enemy}, 23, "X:A", true], [{25=>:enemy}, 25, "X:A", true], [{41=>:enemy}, 41, "X:A", true], [{43=>:enemy}, 43, "X:A", true], [{23=>nil}, 23, "X:A", false], [{25=>nil}, 25, "X:A", false], [{41=>nil}, 41, "X:A", false], [{43=>nil}, 43, "X:A", false]], 34=>[[{24=>:enemy}, 24, "X:A", true], [{26=>:enemy}, 26, "X:A", true], [{42=>:enemy}, 42, "X:A", true], [{44=>:enemy}, 44, "X:A", true], [{24=>nil}, 24, "X:A", false], [{26=>nil}, 26, "X:A", false], [{42=>nil}, 42, "X:A", false], [{44=>nil}, 44, "X:A", false]], 35=>[[{25=>:enemy}, 25, "X:A", true], [{43=>:enemy}, 43, "X:A", true], [{25=>nil}, 25, "X:A", false], [{43=>nil}, 43, "X:A", false]], 36=>[[{28=>:enemy}, 28, "X:A", true], [{46=>:enemy}, 46, "X:A", true], [{28=>nil}, 28, "X:A", false], [{46=>nil}, 46, "X:A", false]], 37=>[[{27=>:enemy}, 27, "X:A", true], [{29=>:enemy}, 29, "X:A", true], [{45=>:enemy}, 45, "X:A", true], [{47=>:enemy}, 47, "X:A", true], [{27=>nil}, 27, "X:A", false], [{29=>nil}, 29, "X:A", false], [{45=>nil}, 45, "X:A", false], [{47=>nil}, 47, "X:A", false]], 38=>[[{28=>:enemy}, 28, "X:A", true], [{30=>:enemy}, 30, "X:A", true], [{46=>:enemy}, 46, "X:A", true], [{48=>:enemy}, 48, "X:A", true], [{28=>nil}, 28, "X:A", false], [{30=>nil}, 30, "X:A", false], [{46=>nil}, 46, "X:A", false], [{48=>nil}, 48, "X:A", false]], 39=>[[{29=>:enemy}, 29, "X:A", true], [{31=>:enemy}, 31, "X:A", true], [{47=>:enemy}, 47, "X:A", true], [{49=>:enemy}, 49, "X:A", true], [{29=>nil}, 29, "X:A", false], [{31=>nil}, 31, "X:A", false], [{47=>nil}, 47, "X:A", false], [{49=>nil}, 49, "X:A", false]], 40=>[[{30=>:enemy}, 30, "X:A", true], [{32=>:enemy}, 32, "X:A", true], [{48=>:enemy}, 48, "X:A", true], [{50=>:enemy}, 50, "X:A", true], [{30=>nil}, 30, "X:A", false], [{32=>nil}, 32, "X:A", false], [{48=>nil}, 48, "X:A", false], [{50=>nil}, 50, "X:A", false]], 41=>[[{31=>:enemy}, 31, "X:A", true], [{33=>:enemy}, 33, "X:A", true], [{49=>:enemy}, 49, "X:A", true], [{51=>:enemy}, 51, "X:A", true], [{31=>nil}, 31, "X:A", false], [{33=>nil}, 33, "X:A", false], [{49=>nil}, 49, "X:A", false], [{51=>nil}, 51, "X:A", false]], 42=>[[{32=>:enemy}, 32, "X:A", true], [{34=>:enemy}, 34, "X:A", true], [{50=>:enemy}, 50, "X:A", true], [{52=>:enemy}, 52, "X:A", true], [{32=>nil}, 32, "X:A", false], [{34=>nil}, 34, "X:A", false], [{50=>nil}, 50, "X:A", false], [{52=>nil}, 52, "X:A", false]], 43=>[[{33=>:enemy}, 33, "X:A", true], [{35=>:enemy}, 35, "X:A", true], [{51=>:enemy}, 51, "X:A", true], [{53=>:enemy}, 53, "X:A", true], [{33=>nil}, 33, "X:A", false], [{35=>nil}, 35, "X:A", false], [{51=>nil}, 51, "X:A", false], [{53=>nil}, 53, "X:A", false]], 44=>[[{34=>:enemy}, 34, "X:A", true], [{52=>:enemy}, 52, "X:A", true], [{34=>nil}, 34, "X:A", false], [{52=>nil}, 52, "X:A", false]], 45=>[[{37=>:enemy}, 37, "X:A", true], [{55=>:enemy}, 55, "X:A", true], [{37=>nil}, 37, "X:A", false], [{55=>nil}, 55, "X:A", false]], 46=>[[{36=>:enemy}, 36, "X:A", true], [{38=>:enemy}, 38, "X:A", true], [{54=>:enemy}, 54, "X:A", true], [{56=>:enemy}, 56, "X:A", true], [{36=>nil}, 36, "X:A", false], [{38=>nil}, 38, "X:A", false], [{54=>nil}, 54, "X:A", false], [{56=>nil}, 56, "X:A", false]], 47=>[[{37=>:enemy}, 37, "X:A", true], [{39=>:enemy}, 39, "X:A", true], [{55=>:enemy}, 55, "X:A", true], [{57=>:enemy}, 57, "X:A", true], [{37=>nil}, 37, "X:A", false], [{39=>nil}, 39, "X:A", false], [{55=>nil}, 55, "X:A", false], [{57=>nil}, 57, "X:A", false]], 48=>[[{38=>:enemy}, 38, "X:A", true], [{40=>:enemy}, 40, "X:A", true], [{56=>:enemy}, 56, "X:A", true], [{58=>:enemy}, 58, "X:A", true], [{38=>nil}, 38, "X:A", false], [{40=>nil}, 40, "X:A", false], [{56=>nil}, 56, "X:A", false], [{58=>nil}, 58, "X:A", false]], 49=>[[{39=>:enemy}, 39, "X:A", true], [{41=>:enemy}, 41, "X:A", true], [{57=>:enemy}, 57, "X:A", true], [{59=>:enemy}, 59, "X:A", true], [{39=>nil}, 39, "X:A", false], [{41=>nil}, 41, "X:A", false], [{57=>nil}, 57, "X:A", false], [{59=>nil}, 59, "X:A", false]], 50=>[[{40=>:enemy}, 40, "X:A", true], [{42=>:enemy}, 42, "X:A", true], [{58=>:enemy}, 58, "X:A", true], [{60=>:enemy}, 60, "X:A", true], [{40=>nil}, 40, "X:A", false], [{42=>nil}, 42, "X:A", false], [{58=>nil}, 58, "X:A", false], [{60=>nil}, 60, "X:A", false]], 51=>[[{41=>:enemy}, 41, "X:A", true], [{43=>:enemy}, 43, "X:A", true], [{59=>:enemy}, 59, "X:A", true], [{61=>:enemy}, 61, "X:A", true], [{41=>nil}, 41, "X:A", false], [{43=>nil}, 43, "X:A", false], [{59=>nil}, 59, "X:A", false], [{61=>nil}, 61, "X:A", false]], 52=>[[{42=>:enemy}, 42, "X:A", true], [{44=>:enemy}, 44, "X:A", true], [{60=>:enemy}, 60, "X:A", true], [{62=>:enemy}, 62, "X:A", true], [{42=>nil}, 42, "X:A", false], [{44=>nil}, 44, "X:A", false], [{60=>nil}, 60, "X:A", false], [{62=>nil}, 62, "X:A", false]], 53=>[[{43=>:enemy}, 43, "X:A", true], [{61=>:enemy}, 61, "X:A", true], [{43=>nil}, 43, "X:A", false], [{61=>nil}, 61, "X:A", false]], 54=>[[{46=>:enemy}, 46, "X:A", true], [{64=>:enemy}, 64, "X:A", true], [{46=>nil}, 46, "X:A", false], [{64=>nil}, 64, "X:A", false]], 55=>[[{45=>:enemy}, 45, "X:A", true], [{47=>:enemy}, 47, "X:A", true], [{63=>:enemy}, 63, "X:A", true], [{65=>:enemy}, 65, "X:A", true], [{45=>nil}, 45, "X:A", false], [{47=>nil}, 47, "X:A", false], [{63=>nil}, 63, "X:A", false], [{65=>nil}, 65, "X:A", false]], 56=>[[{46=>:enemy}, 46, "X:A", true], [{48=>:enemy}, 48, "X:A", true], [{64=>:enemy}, 64, "X:A", true], [{66=>:enemy}, 66, "X:A", true], [{46=>nil}, 46, "X:A", false], [{48=>nil}, 48, "X:A", false], [{64=>nil}, 64, "X:A", false], [{66=>nil}, 66, "X:A", false]], 57=>[[{47=>:enemy}, 47, "X:A", true], [{49=>:enemy}, 49, "X:A", true], [{65=>:enemy}, 65, "X:A", true], [{67=>:enemy}, 67, "X:A", true], [{47=>nil}, 47, "X:A", false], [{49=>nil}, 49, "X:A", false], [{65=>nil}, 65, "X:A", false], [{67=>nil}, 67, "X:A", false]], 58=>[[{48=>:enemy}, 48, "X:A", true], [{50=>:enemy}, 50, "X:A", true], [{66=>:enemy}, 66, "X:A", true], [{68=>:enemy}, 68, "X:A", true], [{48=>nil}, 48, "X:A", false], [{50=>nil}, 50, "X:A", false], [{66=>nil}, 66, "X:A", false], [{68=>nil}, 68, "X:A", false]], 59=>[[{49=>:enemy}, 49, "X:A", true], [{51=>:enemy}, 51, "X:A", true], [{67=>:enemy}, 67, "X:A", true], [{69=>:enemy}, 69, "X:A", true], [{49=>nil}, 49, "X:A", false], [{51=>nil}, 51, "X:A", false], [{67=>nil}, 67, "X:A", false], [{69=>nil}, 69, "X:A", false]], 60=>[[{50=>:enemy}, 50, "X:A", true], [{52=>:enemy}, 52, "X:A", true], [{68=>:enemy}, 68, "X:A", true], [{70=>:enemy}, 70, "X:A", true], [{50=>nil}, 50, "X:A", false], [{52=>nil}, 52, "X:A", false], [{68=>nil}, 68, "X:A", false], [{70=>nil}, 70, "X:A", false]], 61=>[[{51=>:enemy}, 51, "X:A", true], [{53=>:enemy}, 53, "X:A", true], [{69=>:enemy}, 69, "X:A", true], [{71=>:enemy}, 71, "X:A", true], [{51=>nil}, 51, "X:A", false], [{53=>nil}, 53, "X:A", false], [{69=>nil}, 69, "X:A", false], [{71=>nil}, 71, "X:A", false]], 62=>[[{52=>:enemy}, 52, "X:A", true], [{70=>:enemy}, 70, "X:A", true], [{52=>nil}, 52, "X:A", false], [{70=>nil}, 70, "X:A", false]], 63=>[[{55=>:enemy}, 55, "X:A", true], [{73=>:enemy}, 73, "X:A", true], [{55=>nil}, 55, "X:A", false], [{73=>nil}, 73, "X:A", false]], 64=>[[{54=>:enemy}, 54, "X:A", true], [{56=>:enemy}, 56, "X:A", true], [{72=>:enemy}, 72, "X:A", true], [{74=>:enemy}, 74, "X:A", true], [{54=>nil}, 54, "X:A", false], [{56=>nil}, 56, "X:A", false], [{72=>nil}, 72, "X:A", false], [{74=>nil}, 74, "X:A", false]], 65=>[[{55=>:enemy}, 55, "X:A", true], [{57=>:enemy}, 57, "X:A", true], [{73=>:enemy}, 73, "X:A", true], [{75=>:enemy}, 75, "X:A", true], [{55=>nil}, 55, "X:A", false], [{57=>nil}, 57, "X:A", false], [{73=>nil}, 73, "X:A", false], [{75=>nil}, 75, "X:A", false]], 66=>[[{56=>:enemy}, 56, "X:A", true], [{58=>:enemy}, 58, "X:A", true], [{74=>:enemy}, 74, "X:A", true], [{76=>:enemy}, 76, "X:A", true], [{56=>nil}, 56, "X:A", false], [{58=>nil}, 58, "X:A", false], [{74=>nil}, 74, "X:A", false], [{76=>nil}, 76, "X:A", false]], 67=>[[{57=>:enemy}, 57, "X:A", true], [{59=>:enemy}, 59, "X:A", true], [{75=>:enemy}, 75, "X:A", true], [{77=>:enemy}, 77, "X:A", true], [{57=>nil}, 57, "X:A", false], [{59=>nil}, 59, "X:A", false], [{75=>nil}, 75, "X:A", false], [{77=>nil}, 77, "X:A", false]], 68=>[[{58=>:enemy}, 58, "X:A", true], [{60=>:enemy}, 60, "X:A", true], [{76=>:enemy}, 76, "X:A", true], [{78=>:enemy}, 78, "X:A", true], [{58=>nil}, 58, "X:A", false], [{60=>nil}, 60, "X:A", false], [{76=>nil}, 76, "X:A", false], [{78=>nil}, 78, "X:A", false]], 69=>[[{59=>:enemy}, 59, "X:A", true], [{61=>:enemy}, 61, "X:A", true], [{77=>:enemy}, 77, "X:A", true], [{79=>:enemy}, 79, "X:A", true], [{59=>nil}, 59, "X:A", false], [{61=>nil}, 61, "X:A", false], [{77=>nil}, 77, "X:A", false], [{79=>nil}, 79, "X:A", false]], 70=>[[{60=>:enemy}, 60, "X:A", true], [{62=>:enemy}, 62, "X:A", true], [{78=>:enemy}, 78, "X:A", true], [{80=>:enemy}, 80, "X:A", true], [{60=>nil}, 60, "X:A", false], [{62=>nil}, 62, "X:A", false], [{78=>nil}, 78, "X:A", false], [{80=>nil}, 80, "X:A", false]], 71=>[[{61=>:enemy}, 61, "X:A", true], [{79=>:enemy}, 79, "X:A", true], [{61=>nil}, 61, "X:A", false], [{79=>nil}, 79, "X:A", false]], 72=>[[{64=>:enemy}, 64, "X:A", true], [{64=>nil}, 64, "X:A", false]], 73=>[[{63=>:enemy}, 63, "X:A", true], [{65=>:enemy}, 65, "X:A", true], [{63=>nil}, 63, "X:A", false], [{65=>nil}, 65, "X:A", false]], 74=>[[{64=>:enemy}, 64, "X:A", true], [{66=>:enemy}, 66, "X:A", true], [{64=>nil}, 64, "X:A", false], [{66=>nil}, 66, "X:A", false]], 75=>[[{65=>:enemy}, 65, "X:A", true], [{67=>:enemy}, 67, "X:A", true], [{65=>nil}, 65, "X:A", false], [{67=>nil}, 67, "X:A", false]], 76=>[[{66=>:enemy}, 66, "X:A", true], [{68=>:enemy}, 68, "X:A", true], [{66=>nil}, 66, "X:A", false], [{68=>nil}, 68, "X:A", false]], 77=>[[{67=>:enemy}, 67, "X:A", true], [{69=>:enemy}, 69, "X:A", true], [{67=>nil}, 67, "X:A", false], [{69=>nil}, 69, "X:A", false]], 78=>[[{68=>:enemy}, 68, "X:A", true], [{70=>:enemy}, 70, "X:A", true], [{68=>nil}, 68, "X:A", false], [{70=>nil}, 70, "X:A", false]], 79=>[[{69=>:enemy}, 69, "X:A", true], [{71=>:enemy}, 71, "X:A", true], [{69=>nil}, 69, "X:A", false], [{71=>nil}, 71, "X:A", false]], 80=>[[{70=>:enemy}, 70, "X:A", true], [{70=>nil}, 70, "X:A", false]], nil=>[[{0=>nil}, 0, "X:A", false], [{1=>nil}, 1, "X:A", false], [{2=>nil}, 2, "X:A", false], [{3=>nil}, 3, "X:A", false], [{4=>nil}, 4, "X:A", false], [{5=>nil}, 5, "X:A", false], [{6=>nil}, 6, "X:A", false], [{7=>nil}, 7, "X:A", false], [{8=>nil}, 8, "X:A", false], [{9=>nil}, 9, "X:A", false], [{10=>nil}, 10, "X:A", false], [{11=>nil}, 11, "X:A", false], [{12=>nil}, 12, "X:A", false], [{13=>nil}, 13, "X:A", false], [{14=>nil}, 14, "X:A", false], [{15=>nil}, 15, "X:A", false], [{16=>nil}, 16, "X:A", false], [{17=>nil}, 17, "X:A", false], [{18=>nil}, 18, "X:A", false], [{19=>nil}, 19, "X:A", false], [{20=>nil}, 20, "X:A", false], [{21=>nil}, 21, "X:A", false], [{22=>nil}, 22, "X:A", false], [{23=>nil}, 23, "X:A", false], [{24=>nil}, 24, "X:A", false], [{25=>nil}, 25, "X:A", false], [{26=>nil}, 26, "X:A", false], [{27=>nil}, 27, "X:A", false], [{28=>nil}, 28, "X:A", false], [{29=>nil}, 29, "X:A", false], [{30=>nil}, 30, "X:A", false], [{31=>nil}, 31, "X:A", false], [{32=>nil}, 32, "X:A", false], [{33=>nil}, 33, "X:A", false], [{34=>nil}, 34, "X:A", false], [{35=>nil}, 35, "X:A", false], [{36=>nil}, 36, "X:A", false], [{37=>nil}, 37, "X:A", false], [{38=>nil}, 38, "X:A", false], [{39=>nil}, 39, "X:A", false], [{40=>nil}, 40, "X:A", false], [{41=>nil}, 41, "X:A", false], [{42=>nil}, 42, "X:A", false], [{43=>nil}, 43, "X:A", false], [{44=>nil}, 44, "X:A", false], [{45=>nil}, 45, "X:A", false], [{46=>nil}, 46, "X:A", false], [{47=>nil}, 47, "X:A", false], [{48=>nil}, 48, "X:A", false], [{49=>nil}, 49, "X:A", false], [{50=>nil}, 50, "X:A", false], [{51=>nil}, 51, "X:A", false], [{52=>nil}, 52, "X:A", false], [{53=>nil}, 53, "X:A", false], [{54=>nil}, 54, "X:A", false], [{55=>nil}, 55, "X:A", false], [{56=>nil}, 56, "X:A", false], [{57=>nil}, 57, "X:A", false], [{58=>nil}, 58, "X:A", false], [{59=>nil}, 59, "X:A", false], [{60=>nil}, 60, "X:A", false], [{61=>nil}, 61, "X:A", false], [{62=>nil}, 62, "X:A", false], [{63=>nil}, 63, "X:A", false], [{64=>nil}, 64, "X:A", false], [{65=>nil}, 65, "X:A", false], [{66=>nil}, 66, "X:A", false], [{67=>nil}, 67, "X:A", false], [{68=>nil}, 68, "X:A", false], [{69=>nil}, 69, "X:A", false], [{70=>nil}, 70, "X:A", false], [{71=>nil}, 71, "X:A", false], [{72=>nil}, 72, "X:A", false], [{73=>nil}, 73, "X:A", false], [{74=>nil}, 74, "X:A", false], [{75=>nil}, 75, "X:A", false], [{76=>nil}, 76, "X:A", false], [{77=>nil}, 77, "X:A", false], [{78=>nil}, 78, "X:A", false], [{79=>nil}, 79, "X:A", false], [{80=>nil}, 80, "X:A", false]]}, "X:C"=>{0=>[[{1=>:occupied, 2=>nil, 3=>:enemy}, 3, "X:C", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>:enemy}, 4, "X:C", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "X:C", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{1=>:occupied, 2=>:enemy}, 2, "X:C", true], [{9=>:occupied, 18=>nil, 27=>:enemy}, 27, "X:C", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>:enemy}, 36, "X:C", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "X:C", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{9=>:occupied, 18=>:enemy}, 18, "X:C", true], [{1=>nil}, 1, "X:C", false], [{1=>nil, 2=>:occupied, 3=>nil, 4=>:enemy}, 4, "X:C", true], [{1=>nil, 2=>:occupied, 3=>nil, 4=>nil, 5=>:enemy}, 5, "X:C", true], [{1=>nil, 2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{1=>nil, 2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{1=>nil, 2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{1=>nil, 2=>:occupied, 3=>:enemy}, 3, "X:C", true], [{1=>nil, 2=>nil}, 2, "X:C", false], [{1=>nil, 2=>nil, 3=>:occupied, 4=>nil, 5=>:enemy}, 5, "X:C", true], [{1=>nil, 2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{1=>nil, 2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{1=>nil, 2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{1=>nil, 2=>nil, 3=>:occupied, 4=>:enemy}, 4, "X:C", true], [{1=>nil, 2=>nil, 3=>nil}, 3, "X:C", false], [{1=>nil, 2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>:occupied, 5=>:enemy}, 5, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil}, 4, "X:C", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>:enemy}, 6, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "X:C", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>:enemy}, 7, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "X:C", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "X:C", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "X:C", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:C", false], [{9=>nil}, 9, "X:C", false], [{9=>nil, 18=>:occupied, 27=>nil, 36=>:enemy}, 36, "X:C", true], [{9=>nil, 18=>:occupied, 27=>nil, 36=>nil, 45=>:enemy}, 45, "X:C", true], [{9=>nil, 18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{9=>nil, 18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{9=>nil, 18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{9=>nil, 18=>:occupied, 27=>:enemy}, 27, "X:C", true], [{9=>nil, 18=>nil}, 18, "X:C", false], [{9=>nil, 18=>nil, 27=>:occupied, 36=>nil, 45=>:enemy}, 45, "X:C", true], [{9=>nil, 18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{9=>nil, 18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{9=>nil, 18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{9=>nil, 18=>nil, 27=>:occupied, 36=>:enemy}, 36, "X:C", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "X:C", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>:occupied, 45=>:enemy}, 45, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "X:C", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>:enemy}, 54, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "X:C", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>:enemy}, 63, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "X:C", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "X:C", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "X:C", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:C", false]], 1=>[[{2=>:occupied, 3=>nil, 4=>:enemy}, 4, "X:C", true], [{2=>:occupied, 3=>nil, 4=>nil, 5=>:enemy}, 5, "X:C", true], [{2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{2=>:occupied, 3=>:enemy}, 3, "X:C", true], [{10=>:occupied, 19=>nil, 28=>:enemy}, 28, "X:C", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>:enemy}, 37, "X:C", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "X:C", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{10=>:occupied, 19=>:enemy}, 19, "X:C", true], [{0=>nil}, 0, "X:C", false], [{2=>nil}, 2, "X:C", false], [{2=>nil, 3=>:occupied, 4=>nil, 5=>:enemy}, 5, "X:C", true], [{2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{2=>nil, 3=>:occupied, 4=>:enemy}, 4, "X:C", true], [{2=>nil, 3=>nil}, 3, "X:C", false], [{2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{2=>nil, 3=>nil, 4=>:occupied, 5=>:enemy}, 5, "X:C", true], [{2=>nil, 3=>nil, 4=>nil}, 4, "X:C", false], [{2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>:enemy}, 6, "X:C", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "X:C", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>:enemy}, 7, "X:C", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "X:C", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "X:C", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "X:C", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:C", false], [{10=>nil}, 10, "X:C", false], [{10=>nil, 19=>:occupied, 28=>nil, 37=>:enemy}, 37, "X:C", true], [{10=>nil, 19=>:occupied, 28=>nil, 37=>nil, 46=>:enemy}, 46, "X:C", true], [{10=>nil, 19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{10=>nil, 19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{10=>nil, 19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{10=>nil, 19=>:occupied, 28=>:enemy}, 28, "X:C", true], [{10=>nil, 19=>nil}, 19, "X:C", false], [{10=>nil, 19=>nil, 28=>:occupied, 37=>nil, 46=>:enemy}, 46, "X:C", true], [{10=>nil, 19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{10=>nil, 19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{10=>nil, 19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{10=>nil, 19=>nil, 28=>:occupied, 37=>:enemy}, 37, "X:C", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "X:C", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>:occupied, 46=>:enemy}, 46, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "X:C", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>:enemy}, 55, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "X:C", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>:enemy}, 64, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "X:C", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "X:C", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "X:C", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:C", false]], 2=>[[{1=>:occupied, 0=>:enemy}, 0, "X:C", true], [{3=>:occupied, 4=>nil, 5=>:enemy}, 5, "X:C", true], [{3=>:occupied, 4=>nil, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{3=>:occupied, 4=>:enemy}, 4, "X:C", true], [{11=>:occupied, 20=>nil, 29=>:enemy}, 29, "X:C", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>:enemy}, 38, "X:C", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "X:C", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{11=>:occupied, 20=>:enemy}, 20, "X:C", true], [{1=>nil}, 1, "X:C", false], [{1=>nil, 0=>nil}, 0, "X:C", false], [{3=>nil}, 3, "X:C", false], [{3=>nil, 4=>:occupied, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{3=>nil, 4=>:occupied, 5=>:enemy}, 5, "X:C", true], [{3=>nil, 4=>nil}, 4, "X:C", false], [{3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{3=>nil, 4=>nil, 5=>:occupied, 6=>:enemy}, 6, "X:C", true], [{3=>nil, 4=>nil, 5=>nil}, 5, "X:C", false], [{3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>:enemy}, 7, "X:C", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "X:C", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "X:C", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "X:C", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:C", false], [{11=>nil}, 11, "X:C", false], [{11=>nil, 20=>:occupied, 29=>nil, 38=>:enemy}, 38, "X:C", true], [{11=>nil, 20=>:occupied, 29=>nil, 38=>nil, 47=>:enemy}, 47, "X:C", true], [{11=>nil, 20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{11=>nil, 20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{11=>nil, 20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{11=>nil, 20=>:occupied, 29=>:enemy}, 29, "X:C", true], [{11=>nil, 20=>nil}, 20, "X:C", false], [{11=>nil, 20=>nil, 29=>:occupied, 38=>nil, 47=>:enemy}, 47, "X:C", true], [{11=>nil, 20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{11=>nil, 20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{11=>nil, 20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{11=>nil, 20=>nil, 29=>:occupied, 38=>:enemy}, 38, "X:C", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "X:C", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>:occupied, 47=>:enemy}, 47, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "X:C", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>:enemy}, 56, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "X:C", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>:enemy}, 65, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "X:C", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "X:C", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "X:C", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:C", false]], 3=>[[{2=>:occupied, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{2=>:occupied, 1=>:enemy}, 1, "X:C", true], [{4=>:occupied, 5=>nil, 6=>:enemy}, 6, "X:C", true], [{4=>:occupied, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{4=>:occupied, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{4=>:occupied, 5=>:enemy}, 5, "X:C", true], [{12=>:occupied, 21=>nil, 30=>:enemy}, 30, "X:C", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>:enemy}, 39, "X:C", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "X:C", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{12=>:occupied, 21=>:enemy}, 21, "X:C", true], [{2=>nil}, 2, "X:C", false], [{2=>nil, 1=>:occupied, 0=>:enemy}, 0, "X:C", true], [{2=>nil, 1=>nil}, 1, "X:C", false], [{2=>nil, 1=>nil, 0=>nil}, 0, "X:C", false], [{4=>nil}, 4, "X:C", false], [{4=>nil, 5=>:occupied, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{4=>nil, 5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{4=>nil, 5=>:occupied, 6=>:enemy}, 6, "X:C", true], [{4=>nil, 5=>nil}, 5, "X:C", false], [{4=>nil, 5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{4=>nil, 5=>nil, 6=>:occupied, 7=>:enemy}, 7, "X:C", true], [{4=>nil, 5=>nil, 6=>nil}, 6, "X:C", false], [{4=>nil, 5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "X:C", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "X:C", false], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:C", false], [{12=>nil}, 12, "X:C", false], [{12=>nil, 21=>:occupied, 30=>nil, 39=>:enemy}, 39, "X:C", true], [{12=>nil, 21=>:occupied, 30=>nil, 39=>nil, 48=>:enemy}, 48, "X:C", true], [{12=>nil, 21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{12=>nil, 21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{12=>nil, 21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{12=>nil, 21=>:occupied, 30=>:enemy}, 30, "X:C", true], [{12=>nil, 21=>nil}, 21, "X:C", false], [{12=>nil, 21=>nil, 30=>:occupied, 39=>nil, 48=>:enemy}, 48, "X:C", true], [{12=>nil, 21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{12=>nil, 21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{12=>nil, 21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{12=>nil, 21=>nil, 30=>:occupied, 39=>:enemy}, 39, "X:C", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "X:C", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>:occupied, 48=>:enemy}, 48, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "X:C", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>:enemy}, 57, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "X:C", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>:enemy}, 66, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "X:C", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "X:C", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "X:C", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:C", false]], 4=>[[{3=>:occupied, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{3=>:occupied, 2=>:enemy}, 2, "X:C", true], [{5=>:occupied, 6=>nil, 7=>:enemy}, 7, "X:C", true], [{5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{5=>:occupied, 6=>:enemy}, 6, "X:C", true], [{13=>:occupied, 22=>nil, 31=>:enemy}, 31, "X:C", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>:enemy}, 40, "X:C", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "X:C", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{13=>:occupied, 22=>:enemy}, 22, "X:C", true], [{3=>nil}, 3, "X:C", false], [{3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{3=>nil, 2=>:occupied, 1=>:enemy}, 1, "X:C", true], [{3=>nil, 2=>nil}, 2, "X:C", false], [{3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "X:C", true], [{3=>nil, 2=>nil, 1=>nil}, 1, "X:C", false], [{3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:C", false], [{5=>nil}, 5, "X:C", false], [{5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{5=>nil, 6=>:occupied, 7=>:enemy}, 7, "X:C", true], [{5=>nil, 6=>nil}, 6, "X:C", false], [{5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "X:C", true], [{5=>nil, 6=>nil, 7=>nil}, 7, "X:C", false], [{5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:C", false], [{13=>nil}, 13, "X:C", false], [{13=>nil, 22=>:occupied, 31=>nil, 40=>:enemy}, 40, "X:C", true], [{13=>nil, 22=>:occupied, 31=>nil, 40=>nil, 49=>:enemy}, 49, "X:C", true], [{13=>nil, 22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{13=>nil, 22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{13=>nil, 22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{13=>nil, 22=>:occupied, 31=>:enemy}, 31, "X:C", true], [{13=>nil, 22=>nil}, 22, "X:C", false], [{13=>nil, 22=>nil, 31=>:occupied, 40=>nil, 49=>:enemy}, 49, "X:C", true], [{13=>nil, 22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{13=>nil, 22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{13=>nil, 22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{13=>nil, 22=>nil, 31=>:occupied, 40=>:enemy}, 40, "X:C", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "X:C", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>:occupied, 49=>:enemy}, 49, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "X:C", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>:enemy}, 58, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "X:C", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>:enemy}, 67, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "X:C", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "X:C", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "X:C", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:C", false]], 5=>[[{4=>:occupied, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{4=>:occupied, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{4=>:occupied, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{4=>:occupied, 3=>:enemy}, 3, "X:C", true], [{6=>:occupied, 7=>nil, 8=>:enemy}, 8, "X:C", true], [{6=>:occupied, 7=>:enemy}, 7, "X:C", true], [{14=>:occupied, 23=>nil, 32=>:enemy}, 32, "X:C", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>:enemy}, 41, "X:C", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "X:C", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{14=>:occupied, 23=>:enemy}, 23, "X:C", true], [{4=>nil}, 4, "X:C", false], [{4=>nil, 3=>:occupied, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{4=>nil, 3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{4=>nil, 3=>:occupied, 2=>:enemy}, 2, "X:C", true], [{4=>nil, 3=>nil}, 3, "X:C", false], [{4=>nil, 3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{4=>nil, 3=>nil, 2=>:occupied, 1=>:enemy}, 1, "X:C", true], [{4=>nil, 3=>nil, 2=>nil}, 2, "X:C", false], [{4=>nil, 3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "X:C", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "X:C", false], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:C", false], [{6=>nil}, 6, "X:C", false], [{6=>nil, 7=>:occupied, 8=>:enemy}, 8, "X:C", true], [{6=>nil, 7=>nil}, 7, "X:C", false], [{6=>nil, 7=>nil, 8=>nil}, 8, "X:C", false], [{14=>nil}, 14, "X:C", false], [{14=>nil, 23=>:occupied, 32=>nil, 41=>:enemy}, 41, "X:C", true], [{14=>nil, 23=>:occupied, 32=>nil, 41=>nil, 50=>:enemy}, 50, "X:C", true], [{14=>nil, 23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{14=>nil, 23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{14=>nil, 23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{14=>nil, 23=>:occupied, 32=>:enemy}, 32, "X:C", true], [{14=>nil, 23=>nil}, 23, "X:C", false], [{14=>nil, 23=>nil, 32=>:occupied, 41=>nil, 50=>:enemy}, 50, "X:C", true], [{14=>nil, 23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{14=>nil, 23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{14=>nil, 23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{14=>nil, 23=>nil, 32=>:occupied, 41=>:enemy}, 41, "X:C", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "X:C", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>:occupied, 50=>:enemy}, 50, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "X:C", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>:enemy}, 59, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "X:C", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>:enemy}, 68, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "X:C", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "X:C", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "X:C", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:C", false]], 6=>[[{5=>:occupied, 4=>nil, 3=>:enemy}, 3, "X:C", true], [{5=>:occupied, 4=>nil, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{5=>:occupied, 4=>:enemy}, 4, "X:C", true], [{7=>:occupied, 8=>:enemy}, 8, "X:C", true], [{15=>:occupied, 24=>nil, 33=>:enemy}, 33, "X:C", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>:enemy}, 42, "X:C", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "X:C", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{15=>:occupied, 24=>:enemy}, 24, "X:C", true], [{5=>nil}, 5, "X:C", false], [{5=>nil, 4=>:occupied, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{5=>nil, 4=>:occupied, 3=>:enemy}, 3, "X:C", true], [{5=>nil, 4=>nil}, 4, "X:C", false], [{5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{5=>nil, 4=>nil, 3=>:occupied, 2=>:enemy}, 2, "X:C", true], [{5=>nil, 4=>nil, 3=>nil}, 3, "X:C", false], [{5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>:enemy}, 1, "X:C", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "X:C", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "X:C", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "X:C", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:C", false], [{7=>nil}, 7, "X:C", false], [{7=>nil, 8=>nil}, 8, "X:C", false], [{15=>nil}, 15, "X:C", false], [{15=>nil, 24=>:occupied, 33=>nil, 42=>:enemy}, 42, "X:C", true], [{15=>nil, 24=>:occupied, 33=>nil, 42=>nil, 51=>:enemy}, 51, "X:C", true], [{15=>nil, 24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{15=>nil, 24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{15=>nil, 24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{15=>nil, 24=>:occupied, 33=>:enemy}, 33, "X:C", true], [{15=>nil, 24=>nil}, 24, "X:C", false], [{15=>nil, 24=>nil, 33=>:occupied, 42=>nil, 51=>:enemy}, 51, "X:C", true], [{15=>nil, 24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{15=>nil, 24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{15=>nil, 24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{15=>nil, 24=>nil, 33=>:occupied, 42=>:enemy}, 42, "X:C", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "X:C", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>:occupied, 51=>:enemy}, 51, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "X:C", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>:enemy}, 60, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "X:C", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>:enemy}, 69, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "X:C", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "X:C", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "X:C", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:C", false]], 7=>[[{6=>:occupied, 5=>nil, 4=>:enemy}, 4, "X:C", true], [{6=>:occupied, 5=>nil, 4=>nil, 3=>:enemy}, 3, "X:C", true], [{6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{6=>:occupied, 5=>:enemy}, 5, "X:C", true], [{16=>:occupied, 25=>nil, 34=>:enemy}, 34, "X:C", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>:enemy}, 43, "X:C", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "X:C", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{16=>:occupied, 25=>:enemy}, 25, "X:C", true], [{6=>nil}, 6, "X:C", false], [{6=>nil, 5=>:occupied, 4=>nil, 3=>:enemy}, 3, "X:C", true], [{6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{6=>nil, 5=>:occupied, 4=>:enemy}, 4, "X:C", true], [{6=>nil, 5=>nil}, 5, "X:C", false], [{6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{6=>nil, 5=>nil, 4=>:occupied, 3=>:enemy}, 3, "X:C", true], [{6=>nil, 5=>nil, 4=>nil}, 4, "X:C", false], [{6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>:enemy}, 2, "X:C", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "X:C", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>:enemy}, 1, "X:C", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "X:C", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "X:C", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "X:C", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:C", false], [{8=>nil}, 8, "X:C", false], [{16=>nil}, 16, "X:C", false], [{16=>nil, 25=>:occupied, 34=>nil, 43=>:enemy}, 43, "X:C", true], [{16=>nil, 25=>:occupied, 34=>nil, 43=>nil, 52=>:enemy}, 52, "X:C", true], [{16=>nil, 25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{16=>nil, 25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{16=>nil, 25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{16=>nil, 25=>:occupied, 34=>:enemy}, 34, "X:C", true], [{16=>nil, 25=>nil}, 25, "X:C", false], [{16=>nil, 25=>nil, 34=>:occupied, 43=>nil, 52=>:enemy}, 52, "X:C", true], [{16=>nil, 25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{16=>nil, 25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{16=>nil, 25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{16=>nil, 25=>nil, 34=>:occupied, 43=>:enemy}, 43, "X:C", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "X:C", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>:occupied, 52=>:enemy}, 52, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "X:C", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>:enemy}, 61, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "X:C", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>:enemy}, 70, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "X:C", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "X:C", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "X:C", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:C", false]], 8=>[[{7=>:occupied, 6=>nil, 5=>:enemy}, 5, "X:C", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>:enemy}, 4, "X:C", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "X:C", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{7=>:occupied, 6=>:enemy}, 6, "X:C", true], [{17=>:occupied, 26=>nil, 35=>:enemy}, 35, "X:C", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>:enemy}, 44, "X:C", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "X:C", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{17=>:occupied, 26=>:enemy}, 26, "X:C", true], [{7=>nil}, 7, "X:C", false], [{7=>nil, 6=>:occupied, 5=>nil, 4=>:enemy}, 4, "X:C", true], [{7=>nil, 6=>:occupied, 5=>nil, 4=>nil, 3=>:enemy}, 3, "X:C", true], [{7=>nil, 6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{7=>nil, 6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{7=>nil, 6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{7=>nil, 6=>:occupied, 5=>:enemy}, 5, "X:C", true], [{7=>nil, 6=>nil}, 6, "X:C", false], [{7=>nil, 6=>nil, 5=>:occupied, 4=>nil, 3=>:enemy}, 3, "X:C", true], [{7=>nil, 6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{7=>nil, 6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{7=>nil, 6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{7=>nil, 6=>nil, 5=>:occupied, 4=>:enemy}, 4, "X:C", true], [{7=>nil, 6=>nil, 5=>nil}, 5, "X:C", false], [{7=>nil, 6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>:enemy}, 2, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>:occupied, 3=>:enemy}, 3, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil}, 4, "X:C", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>:enemy}, 1, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>:enemy}, 2, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "X:C", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>:enemy}, 1, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "X:C", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "X:C", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "X:C", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:C", false], [{17=>nil}, 17, "X:C", false], [{17=>nil, 26=>:occupied, 35=>nil, 44=>:enemy}, 44, "X:C", true], [{17=>nil, 26=>:occupied, 35=>nil, 44=>nil, 53=>:enemy}, 53, "X:C", true], [{17=>nil, 26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{17=>nil, 26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{17=>nil, 26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{17=>nil, 26=>:occupied, 35=>:enemy}, 35, "X:C", true], [{17=>nil, 26=>nil}, 26, "X:C", false], [{17=>nil, 26=>nil, 35=>:occupied, 44=>nil, 53=>:enemy}, 53, "X:C", true], [{17=>nil, 26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{17=>nil, 26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{17=>nil, 26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{17=>nil, 26=>nil, 35=>:occupied, 44=>:enemy}, 44, "X:C", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "X:C", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>:occupied, 53=>:enemy}, 53, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "X:C", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>:enemy}, 62, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "X:C", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>:enemy}, 71, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "X:C", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "X:C", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "X:C", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:C", false]], 9=>[[{10=>:occupied, 11=>nil, 12=>:enemy}, 12, "X:C", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>:enemy}, 13, "X:C", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "X:C", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{10=>:occupied, 11=>:enemy}, 11, "X:C", true], [{18=>:occupied, 27=>nil, 36=>:enemy}, 36, "X:C", true], [{18=>:occupied, 27=>nil, 36=>nil, 45=>:enemy}, 45, "X:C", true], [{18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{18=>:occupied, 27=>:enemy}, 27, "X:C", true], [{0=>nil}, 0, "X:C", false], [{10=>nil}, 10, "X:C", false], [{10=>nil, 11=>:occupied, 12=>nil, 13=>:enemy}, 13, "X:C", true], [{10=>nil, 11=>:occupied, 12=>nil, 13=>nil, 14=>:enemy}, 14, "X:C", true], [{10=>nil, 11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{10=>nil, 11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{10=>nil, 11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{10=>nil, 11=>:occupied, 12=>:enemy}, 12, "X:C", true], [{10=>nil, 11=>nil}, 11, "X:C", false], [{10=>nil, 11=>nil, 12=>:occupied, 13=>nil, 14=>:enemy}, 14, "X:C", true], [{10=>nil, 11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{10=>nil, 11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{10=>nil, 11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{10=>nil, 11=>nil, 12=>:occupied, 13=>:enemy}, 13, "X:C", true], [{10=>nil, 11=>nil, 12=>nil}, 12, "X:C", false], [{10=>nil, 11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>:occupied, 14=>:enemy}, 14, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil}, 13, "X:C", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>:enemy}, 15, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "X:C", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>:enemy}, 16, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "X:C", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "X:C", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "X:C", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:C", false], [{18=>nil}, 18, "X:C", false], [{18=>nil, 27=>:occupied, 36=>nil, 45=>:enemy}, 45, "X:C", true], [{18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{18=>nil, 27=>:occupied, 36=>:enemy}, 36, "X:C", true], [{18=>nil, 27=>nil}, 27, "X:C", false], [{18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{18=>nil, 27=>nil, 36=>:occupied, 45=>:enemy}, 45, "X:C", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "X:C", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>:enemy}, 54, "X:C", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "X:C", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>:enemy}, 63, "X:C", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "X:C", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "X:C", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "X:C", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:C", false]], 10=>[[{11=>:occupied, 12=>nil, 13=>:enemy}, 13, "X:C", true], [{11=>:occupied, 12=>nil, 13=>nil, 14=>:enemy}, 14, "X:C", true], [{11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{11=>:occupied, 12=>:enemy}, 12, "X:C", true], [{19=>:occupied, 28=>nil, 37=>:enemy}, 37, "X:C", true], [{19=>:occupied, 28=>nil, 37=>nil, 46=>:enemy}, 46, "X:C", true], [{19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{19=>:occupied, 28=>:enemy}, 28, "X:C", true], [{1=>nil}, 1, "X:C", false], [{9=>nil}, 9, "X:C", false], [{11=>nil}, 11, "X:C", false], [{11=>nil, 12=>:occupied, 13=>nil, 14=>:enemy}, 14, "X:C", true], [{11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{11=>nil, 12=>:occupied, 13=>:enemy}, 13, "X:C", true], [{11=>nil, 12=>nil}, 12, "X:C", false], [{11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{11=>nil, 12=>nil, 13=>:occupied, 14=>:enemy}, 14, "X:C", true], [{11=>nil, 12=>nil, 13=>nil}, 13, "X:C", false], [{11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>:enemy}, 15, "X:C", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "X:C", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>:enemy}, 16, "X:C", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "X:C", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "X:C", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "X:C", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:C", false], [{19=>nil}, 19, "X:C", false], [{19=>nil, 28=>:occupied, 37=>nil, 46=>:enemy}, 46, "X:C", true], [{19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{19=>nil, 28=>:occupied, 37=>:enemy}, 37, "X:C", true], [{19=>nil, 28=>nil}, 28, "X:C", false], [{19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{19=>nil, 28=>nil, 37=>:occupied, 46=>:enemy}, 46, "X:C", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "X:C", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>:enemy}, 55, "X:C", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "X:C", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>:enemy}, 64, "X:C", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "X:C", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "X:C", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "X:C", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:C", false]], 11=>[[{10=>:occupied, 9=>:enemy}, 9, "X:C", true], [{12=>:occupied, 13=>nil, 14=>:enemy}, 14, "X:C", true], [{12=>:occupied, 13=>nil, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{12=>:occupied, 13=>:enemy}, 13, "X:C", true], [{20=>:occupied, 29=>nil, 38=>:enemy}, 38, "X:C", true], [{20=>:occupied, 29=>nil, 38=>nil, 47=>:enemy}, 47, "X:C", true], [{20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{20=>:occupied, 29=>:enemy}, 29, "X:C", true], [{2=>nil}, 2, "X:C", false], [{10=>nil}, 10, "X:C", false], [{10=>nil, 9=>nil}, 9, "X:C", false], [{12=>nil}, 12, "X:C", false], [{12=>nil, 13=>:occupied, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{12=>nil, 13=>:occupied, 14=>:enemy}, 14, "X:C", true], [{12=>nil, 13=>nil}, 13, "X:C", false], [{12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{12=>nil, 13=>nil, 14=>:occupied, 15=>:enemy}, 15, "X:C", true], [{12=>nil, 13=>nil, 14=>nil}, 14, "X:C", false], [{12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>:enemy}, 16, "X:C", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "X:C", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "X:C", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "X:C", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:C", false], [{20=>nil}, 20, "X:C", false], [{20=>nil, 29=>:occupied, 38=>nil, 47=>:enemy}, 47, "X:C", true], [{20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{20=>nil, 29=>:occupied, 38=>:enemy}, 38, "X:C", true], [{20=>nil, 29=>nil}, 29, "X:C", false], [{20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{20=>nil, 29=>nil, 38=>:occupied, 47=>:enemy}, 47, "X:C", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "X:C", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>:enemy}, 56, "X:C", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "X:C", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>:enemy}, 65, "X:C", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "X:C", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "X:C", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "X:C", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:C", false]], 12=>[[{11=>:occupied, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{11=>:occupied, 10=>:enemy}, 10, "X:C", true], [{13=>:occupied, 14=>nil, 15=>:enemy}, 15, "X:C", true], [{13=>:occupied, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{13=>:occupied, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{13=>:occupied, 14=>:enemy}, 14, "X:C", true], [{21=>:occupied, 30=>nil, 39=>:enemy}, 39, "X:C", true], [{21=>:occupied, 30=>nil, 39=>nil, 48=>:enemy}, 48, "X:C", true], [{21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{21=>:occupied, 30=>:enemy}, 30, "X:C", true], [{3=>nil}, 3, "X:C", false], [{11=>nil}, 11, "X:C", false], [{11=>nil, 10=>:occupied, 9=>:enemy}, 9, "X:C", true], [{11=>nil, 10=>nil}, 10, "X:C", false], [{11=>nil, 10=>nil, 9=>nil}, 9, "X:C", false], [{13=>nil}, 13, "X:C", false], [{13=>nil, 14=>:occupied, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{13=>nil, 14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{13=>nil, 14=>:occupied, 15=>:enemy}, 15, "X:C", true], [{13=>nil, 14=>nil}, 14, "X:C", false], [{13=>nil, 14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{13=>nil, 14=>nil, 15=>:occupied, 16=>:enemy}, 16, "X:C", true], [{13=>nil, 14=>nil, 15=>nil}, 15, "X:C", false], [{13=>nil, 14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "X:C", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "X:C", false], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:C", false], [{21=>nil}, 21, "X:C", false], [{21=>nil, 30=>:occupied, 39=>nil, 48=>:enemy}, 48, "X:C", true], [{21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{21=>nil, 30=>:occupied, 39=>:enemy}, 39, "X:C", true], [{21=>nil, 30=>nil}, 30, "X:C", false], [{21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{21=>nil, 30=>nil, 39=>:occupied, 48=>:enemy}, 48, "X:C", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "X:C", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>:enemy}, 57, "X:C", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "X:C", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>:enemy}, 66, "X:C", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "X:C", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "X:C", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "X:C", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:C", false]], 13=>[[{12=>:occupied, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{12=>:occupied, 11=>:enemy}, 11, "X:C", true], [{14=>:occupied, 15=>nil, 16=>:enemy}, 16, "X:C", true], [{14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{14=>:occupied, 15=>:enemy}, 15, "X:C", true], [{22=>:occupied, 31=>nil, 40=>:enemy}, 40, "X:C", true], [{22=>:occupied, 31=>nil, 40=>nil, 49=>:enemy}, 49, "X:C", true], [{22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{22=>:occupied, 31=>:enemy}, 31, "X:C", true], [{4=>nil}, 4, "X:C", false], [{12=>nil}, 12, "X:C", false], [{12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{12=>nil, 11=>:occupied, 10=>:enemy}, 10, "X:C", true], [{12=>nil, 11=>nil}, 11, "X:C", false], [{12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "X:C", true], [{12=>nil, 11=>nil, 10=>nil}, 10, "X:C", false], [{12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:C", false], [{14=>nil}, 14, "X:C", false], [{14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{14=>nil, 15=>:occupied, 16=>:enemy}, 16, "X:C", true], [{14=>nil, 15=>nil}, 15, "X:C", false], [{14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "X:C", true], [{14=>nil, 15=>nil, 16=>nil}, 16, "X:C", false], [{14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:C", false], [{22=>nil}, 22, "X:C", false], [{22=>nil, 31=>:occupied, 40=>nil, 49=>:enemy}, 49, "X:C", true], [{22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{22=>nil, 31=>:occupied, 40=>:enemy}, 40, "X:C", true], [{22=>nil, 31=>nil}, 31, "X:C", false], [{22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{22=>nil, 31=>nil, 40=>:occupied, 49=>:enemy}, 49, "X:C", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "X:C", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>:enemy}, 58, "X:C", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "X:C", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>:enemy}, 67, "X:C", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "X:C", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "X:C", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "X:C", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:C", false]], 14=>[[{13=>:occupied, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{13=>:occupied, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{13=>:occupied, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{13=>:occupied, 12=>:enemy}, 12, "X:C", true], [{15=>:occupied, 16=>nil, 17=>:enemy}, 17, "X:C", true], [{15=>:occupied, 16=>:enemy}, 16, "X:C", true], [{23=>:occupied, 32=>nil, 41=>:enemy}, 41, "X:C", true], [{23=>:occupied, 32=>nil, 41=>nil, 50=>:enemy}, 50, "X:C", true], [{23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{23=>:occupied, 32=>:enemy}, 32, "X:C", true], [{5=>nil}, 5, "X:C", false], [{13=>nil}, 13, "X:C", false], [{13=>nil, 12=>:occupied, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{13=>nil, 12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{13=>nil, 12=>:occupied, 11=>:enemy}, 11, "X:C", true], [{13=>nil, 12=>nil}, 12, "X:C", false], [{13=>nil, 12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{13=>nil, 12=>nil, 11=>:occupied, 10=>:enemy}, 10, "X:C", true], [{13=>nil, 12=>nil, 11=>nil}, 11, "X:C", false], [{13=>nil, 12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "X:C", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "X:C", false], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:C", false], [{15=>nil}, 15, "X:C", false], [{15=>nil, 16=>:occupied, 17=>:enemy}, 17, "X:C", true], [{15=>nil, 16=>nil}, 16, "X:C", false], [{15=>nil, 16=>nil, 17=>nil}, 17, "X:C", false], [{23=>nil}, 23, "X:C", false], [{23=>nil, 32=>:occupied, 41=>nil, 50=>:enemy}, 50, "X:C", true], [{23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{23=>nil, 32=>:occupied, 41=>:enemy}, 41, "X:C", true], [{23=>nil, 32=>nil}, 32, "X:C", false], [{23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{23=>nil, 32=>nil, 41=>:occupied, 50=>:enemy}, 50, "X:C", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "X:C", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>:enemy}, 59, "X:C", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "X:C", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>:enemy}, 68, "X:C", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "X:C", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "X:C", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "X:C", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:C", false]], 15=>[[{14=>:occupied, 13=>nil, 12=>:enemy}, 12, "X:C", true], [{14=>:occupied, 13=>nil, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{14=>:occupied, 13=>:enemy}, 13, "X:C", true], [{16=>:occupied, 17=>:enemy}, 17, "X:C", true], [{24=>:occupied, 33=>nil, 42=>:enemy}, 42, "X:C", true], [{24=>:occupied, 33=>nil, 42=>nil, 51=>:enemy}, 51, "X:C", true], [{24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{24=>:occupied, 33=>:enemy}, 33, "X:C", true], [{6=>nil}, 6, "X:C", false], [{14=>nil}, 14, "X:C", false], [{14=>nil, 13=>:occupied, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{14=>nil, 13=>:occupied, 12=>:enemy}, 12, "X:C", true], [{14=>nil, 13=>nil}, 13, "X:C", false], [{14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{14=>nil, 13=>nil, 12=>:occupied, 11=>:enemy}, 11, "X:C", true], [{14=>nil, 13=>nil, 12=>nil}, 12, "X:C", false], [{14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>:enemy}, 10, "X:C", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "X:C", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "X:C", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "X:C", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:C", false], [{16=>nil}, 16, "X:C", false], [{16=>nil, 17=>nil}, 17, "X:C", false], [{24=>nil}, 24, "X:C", false], [{24=>nil, 33=>:occupied, 42=>nil, 51=>:enemy}, 51, "X:C", true], [{24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{24=>nil, 33=>:occupied, 42=>:enemy}, 42, "X:C", true], [{24=>nil, 33=>nil}, 33, "X:C", false], [{24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{24=>nil, 33=>nil, 42=>:occupied, 51=>:enemy}, 51, "X:C", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "X:C", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>:enemy}, 60, "X:C", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "X:C", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>:enemy}, 69, "X:C", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "X:C", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "X:C", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "X:C", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:C", false]], 16=>[[{15=>:occupied, 14=>nil, 13=>:enemy}, 13, "X:C", true], [{15=>:occupied, 14=>nil, 13=>nil, 12=>:enemy}, 12, "X:C", true], [{15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{15=>:occupied, 14=>:enemy}, 14, "X:C", true], [{25=>:occupied, 34=>nil, 43=>:enemy}, 43, "X:C", true], [{25=>:occupied, 34=>nil, 43=>nil, 52=>:enemy}, 52, "X:C", true], [{25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{25=>:occupied, 34=>:enemy}, 34, "X:C", true], [{7=>nil}, 7, "X:C", false], [{15=>nil}, 15, "X:C", false], [{15=>nil, 14=>:occupied, 13=>nil, 12=>:enemy}, 12, "X:C", true], [{15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{15=>nil, 14=>:occupied, 13=>:enemy}, 13, "X:C", true], [{15=>nil, 14=>nil}, 14, "X:C", false], [{15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{15=>nil, 14=>nil, 13=>:occupied, 12=>:enemy}, 12, "X:C", true], [{15=>nil, 14=>nil, 13=>nil}, 13, "X:C", false], [{15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>:enemy}, 11, "X:C", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "X:C", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>:enemy}, 10, "X:C", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "X:C", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "X:C", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "X:C", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:C", false], [{17=>nil}, 17, "X:C", false], [{25=>nil}, 25, "X:C", false], [{25=>nil, 34=>:occupied, 43=>nil, 52=>:enemy}, 52, "X:C", true], [{25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{25=>nil, 34=>:occupied, 43=>:enemy}, 43, "X:C", true], [{25=>nil, 34=>nil}, 34, "X:C", false], [{25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{25=>nil, 34=>nil, 43=>:occupied, 52=>:enemy}, 52, "X:C", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "X:C", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>:enemy}, 61, "X:C", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "X:C", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>:enemy}, 70, "X:C", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "X:C", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "X:C", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "X:C", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:C", false]], 17=>[[{16=>:occupied, 15=>nil, 14=>:enemy}, 14, "X:C", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>:enemy}, 13, "X:C", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "X:C", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{16=>:occupied, 15=>:enemy}, 15, "X:C", true], [{26=>:occupied, 35=>nil, 44=>:enemy}, 44, "X:C", true], [{26=>:occupied, 35=>nil, 44=>nil, 53=>:enemy}, 53, "X:C", true], [{26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{26=>:occupied, 35=>:enemy}, 35, "X:C", true], [{8=>nil}, 8, "X:C", false], [{16=>nil}, 16, "X:C", false], [{16=>nil, 15=>:occupied, 14=>nil, 13=>:enemy}, 13, "X:C", true], [{16=>nil, 15=>:occupied, 14=>nil, 13=>nil, 12=>:enemy}, 12, "X:C", true], [{16=>nil, 15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{16=>nil, 15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{16=>nil, 15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{16=>nil, 15=>:occupied, 14=>:enemy}, 14, "X:C", true], [{16=>nil, 15=>nil}, 15, "X:C", false], [{16=>nil, 15=>nil, 14=>:occupied, 13=>nil, 12=>:enemy}, 12, "X:C", true], [{16=>nil, 15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{16=>nil, 15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{16=>nil, 15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{16=>nil, 15=>nil, 14=>:occupied, 13=>:enemy}, 13, "X:C", true], [{16=>nil, 15=>nil, 14=>nil}, 14, "X:C", false], [{16=>nil, 15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>:enemy}, 11, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>:occupied, 12=>:enemy}, 12, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil}, 13, "X:C", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>:enemy}, 10, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>:enemy}, 11, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "X:C", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>:enemy}, 10, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "X:C", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "X:C", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "X:C", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:C", false], [{26=>nil}, 26, "X:C", false], [{26=>nil, 35=>:occupied, 44=>nil, 53=>:enemy}, 53, "X:C", true], [{26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{26=>nil, 35=>:occupied, 44=>:enemy}, 44, "X:C", true], [{26=>nil, 35=>nil}, 35, "X:C", false], [{26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{26=>nil, 35=>nil, 44=>:occupied, 53=>:enemy}, 53, "X:C", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "X:C", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>:enemy}, 62, "X:C", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "X:C", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>:enemy}, 71, "X:C", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "X:C", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "X:C", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "X:C", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:C", false]], 18=>[[{9=>:occupied, 0=>:enemy}, 0, "X:C", true], [{19=>:occupied, 20=>nil, 21=>:enemy}, 21, "X:C", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>:enemy}, 22, "X:C", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "X:C", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{19=>:occupied, 20=>:enemy}, 20, "X:C", true], [{27=>:occupied, 36=>nil, 45=>:enemy}, 45, "X:C", true], [{27=>:occupied, 36=>nil, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{27=>:occupied, 36=>:enemy}, 36, "X:C", true], [{9=>nil}, 9, "X:C", false], [{9=>nil, 0=>nil}, 0, "X:C", false], [{19=>nil}, 19, "X:C", false], [{19=>nil, 20=>:occupied, 21=>nil, 22=>:enemy}, 22, "X:C", true], [{19=>nil, 20=>:occupied, 21=>nil, 22=>nil, 23=>:enemy}, 23, "X:C", true], [{19=>nil, 20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{19=>nil, 20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{19=>nil, 20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{19=>nil, 20=>:occupied, 21=>:enemy}, 21, "X:C", true], [{19=>nil, 20=>nil}, 20, "X:C", false], [{19=>nil, 20=>nil, 21=>:occupied, 22=>nil, 23=>:enemy}, 23, "X:C", true], [{19=>nil, 20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{19=>nil, 20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{19=>nil, 20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{19=>nil, 20=>nil, 21=>:occupied, 22=>:enemy}, 22, "X:C", true], [{19=>nil, 20=>nil, 21=>nil}, 21, "X:C", false], [{19=>nil, 20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>:occupied, 23=>:enemy}, 23, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil}, 22, "X:C", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>:enemy}, 24, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "X:C", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>:enemy}, 25, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "X:C", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "X:C", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "X:C", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:C", false], [{27=>nil}, 27, "X:C", false], [{27=>nil, 36=>:occupied, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{27=>nil, 36=>:occupied, 45=>:enemy}, 45, "X:C", true], [{27=>nil, 36=>nil}, 36, "X:C", false], [{27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{27=>nil, 36=>nil, 45=>:occupied, 54=>:enemy}, 54, "X:C", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "X:C", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>:enemy}, 63, "X:C", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "X:C", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "X:C", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "X:C", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:C", false]], 19=>[[{10=>:occupied, 1=>:enemy}, 1, "X:C", true], [{20=>:occupied, 21=>nil, 22=>:enemy}, 22, "X:C", true], [{20=>:occupied, 21=>nil, 22=>nil, 23=>:enemy}, 23, "X:C", true], [{20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{20=>:occupied, 21=>:enemy}, 21, "X:C", true], [{28=>:occupied, 37=>nil, 46=>:enemy}, 46, "X:C", true], [{28=>:occupied, 37=>nil, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{28=>:occupied, 37=>:enemy}, 37, "X:C", true], [{10=>nil}, 10, "X:C", false], [{10=>nil, 1=>nil}, 1, "X:C", false], [{18=>nil}, 18, "X:C", false], [{20=>nil}, 20, "X:C", false], [{20=>nil, 21=>:occupied, 22=>nil, 23=>:enemy}, 23, "X:C", true], [{20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{20=>nil, 21=>:occupied, 22=>:enemy}, 22, "X:C", true], [{20=>nil, 21=>nil}, 21, "X:C", false], [{20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{20=>nil, 21=>nil, 22=>:occupied, 23=>:enemy}, 23, "X:C", true], [{20=>nil, 21=>nil, 22=>nil}, 22, "X:C", false], [{20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>:enemy}, 24, "X:C", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "X:C", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>:enemy}, 25, "X:C", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "X:C", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "X:C", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "X:C", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:C", false], [{28=>nil}, 28, "X:C", false], [{28=>nil, 37=>:occupied, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{28=>nil, 37=>:occupied, 46=>:enemy}, 46, "X:C", true], [{28=>nil, 37=>nil}, 37, "X:C", false], [{28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{28=>nil, 37=>nil, 46=>:occupied, 55=>:enemy}, 55, "X:C", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "X:C", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>:enemy}, 64, "X:C", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "X:C", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "X:C", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "X:C", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:C", false]], 20=>[[{11=>:occupied, 2=>:enemy}, 2, "X:C", true], [{19=>:occupied, 18=>:enemy}, 18, "X:C", true], [{21=>:occupied, 22=>nil, 23=>:enemy}, 23, "X:C", true], [{21=>:occupied, 22=>nil, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{21=>:occupied, 22=>:enemy}, 22, "X:C", true], [{29=>:occupied, 38=>nil, 47=>:enemy}, 47, "X:C", true], [{29=>:occupied, 38=>nil, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{29=>:occupied, 38=>:enemy}, 38, "X:C", true], [{11=>nil}, 11, "X:C", false], [{11=>nil, 2=>nil}, 2, "X:C", false], [{19=>nil}, 19, "X:C", false], [{19=>nil, 18=>nil}, 18, "X:C", false], [{21=>nil}, 21, "X:C", false], [{21=>nil, 22=>:occupied, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{21=>nil, 22=>:occupied, 23=>:enemy}, 23, "X:C", true], [{21=>nil, 22=>nil}, 22, "X:C", false], [{21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{21=>nil, 22=>nil, 23=>:occupied, 24=>:enemy}, 24, "X:C", true], [{21=>nil, 22=>nil, 23=>nil}, 23, "X:C", false], [{21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>:enemy}, 25, "X:C", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "X:C", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "X:C", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "X:C", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:C", false], [{29=>nil}, 29, "X:C", false], [{29=>nil, 38=>:occupied, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{29=>nil, 38=>:occupied, 47=>:enemy}, 47, "X:C", true], [{29=>nil, 38=>nil}, 38, "X:C", false], [{29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{29=>nil, 38=>nil, 47=>:occupied, 56=>:enemy}, 56, "X:C", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "X:C", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>:enemy}, 65, "X:C", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "X:C", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "X:C", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "X:C", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:C", false]], 21=>[[{12=>:occupied, 3=>:enemy}, 3, "X:C", true], [{20=>:occupied, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{20=>:occupied, 19=>:enemy}, 19, "X:C", true], [{22=>:occupied, 23=>nil, 24=>:enemy}, 24, "X:C", true], [{22=>:occupied, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{22=>:occupied, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{22=>:occupied, 23=>:enemy}, 23, "X:C", true], [{30=>:occupied, 39=>nil, 48=>:enemy}, 48, "X:C", true], [{30=>:occupied, 39=>nil, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{30=>:occupied, 39=>:enemy}, 39, "X:C", true], [{12=>nil}, 12, "X:C", false], [{12=>nil, 3=>nil}, 3, "X:C", false], [{20=>nil}, 20, "X:C", false], [{20=>nil, 19=>:occupied, 18=>:enemy}, 18, "X:C", true], [{20=>nil, 19=>nil}, 19, "X:C", false], [{20=>nil, 19=>nil, 18=>nil}, 18, "X:C", false], [{22=>nil}, 22, "X:C", false], [{22=>nil, 23=>:occupied, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{22=>nil, 23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{22=>nil, 23=>:occupied, 24=>:enemy}, 24, "X:C", true], [{22=>nil, 23=>nil}, 23, "X:C", false], [{22=>nil, 23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{22=>nil, 23=>nil, 24=>:occupied, 25=>:enemy}, 25, "X:C", true], [{22=>nil, 23=>nil, 24=>nil}, 24, "X:C", false], [{22=>nil, 23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "X:C", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "X:C", false], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:C", false], [{30=>nil}, 30, "X:C", false], [{30=>nil, 39=>:occupied, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{30=>nil, 39=>:occupied, 48=>:enemy}, 48, "X:C", true], [{30=>nil, 39=>nil}, 39, "X:C", false], [{30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{30=>nil, 39=>nil, 48=>:occupied, 57=>:enemy}, 57, "X:C", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "X:C", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>:enemy}, 66, "X:C", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "X:C", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "X:C", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "X:C", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:C", false]], 22=>[[{13=>:occupied, 4=>:enemy}, 4, "X:C", true], [{21=>:occupied, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{21=>:occupied, 20=>:enemy}, 20, "X:C", true], [{23=>:occupied, 24=>nil, 25=>:enemy}, 25, "X:C", true], [{23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{23=>:occupied, 24=>:enemy}, 24, "X:C", true], [{31=>:occupied, 40=>nil, 49=>:enemy}, 49, "X:C", true], [{31=>:occupied, 40=>nil, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{31=>:occupied, 40=>:enemy}, 40, "X:C", true], [{13=>nil}, 13, "X:C", false], [{13=>nil, 4=>nil}, 4, "X:C", false], [{21=>nil}, 21, "X:C", false], [{21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{21=>nil, 20=>:occupied, 19=>:enemy}, 19, "X:C", true], [{21=>nil, 20=>nil}, 20, "X:C", false], [{21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "X:C", true], [{21=>nil, 20=>nil, 19=>nil}, 19, "X:C", false], [{21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:C", false], [{23=>nil}, 23, "X:C", false], [{23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{23=>nil, 24=>:occupied, 25=>:enemy}, 25, "X:C", true], [{23=>nil, 24=>nil}, 24, "X:C", false], [{23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "X:C", true], [{23=>nil, 24=>nil, 25=>nil}, 25, "X:C", false], [{23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:C", false], [{31=>nil}, 31, "X:C", false], [{31=>nil, 40=>:occupied, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{31=>nil, 40=>:occupied, 49=>:enemy}, 49, "X:C", true], [{31=>nil, 40=>nil}, 40, "X:C", false], [{31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{31=>nil, 40=>nil, 49=>:occupied, 58=>:enemy}, 58, "X:C", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "X:C", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>:enemy}, 67, "X:C", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "X:C", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "X:C", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "X:C", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:C", false]], 23=>[[{14=>:occupied, 5=>:enemy}, 5, "X:C", true], [{22=>:occupied, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{22=>:occupied, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{22=>:occupied, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{22=>:occupied, 21=>:enemy}, 21, "X:C", true], [{24=>:occupied, 25=>nil, 26=>:enemy}, 26, "X:C", true], [{24=>:occupied, 25=>:enemy}, 25, "X:C", true], [{32=>:occupied, 41=>nil, 50=>:enemy}, 50, "X:C", true], [{32=>:occupied, 41=>nil, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{32=>:occupied, 41=>:enemy}, 41, "X:C", true], [{14=>nil}, 14, "X:C", false], [{14=>nil, 5=>nil}, 5, "X:C", false], [{22=>nil}, 22, "X:C", false], [{22=>nil, 21=>:occupied, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{22=>nil, 21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{22=>nil, 21=>:occupied, 20=>:enemy}, 20, "X:C", true], [{22=>nil, 21=>nil}, 21, "X:C", false], [{22=>nil, 21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{22=>nil, 21=>nil, 20=>:occupied, 19=>:enemy}, 19, "X:C", true], [{22=>nil, 21=>nil, 20=>nil}, 20, "X:C", false], [{22=>nil, 21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "X:C", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "X:C", false], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:C", false], [{24=>nil}, 24, "X:C", false], [{24=>nil, 25=>:occupied, 26=>:enemy}, 26, "X:C", true], [{24=>nil, 25=>nil}, 25, "X:C", false], [{24=>nil, 25=>nil, 26=>nil}, 26, "X:C", false], [{32=>nil}, 32, "X:C", false], [{32=>nil, 41=>:occupied, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{32=>nil, 41=>:occupied, 50=>:enemy}, 50, "X:C", true], [{32=>nil, 41=>nil}, 41, "X:C", false], [{32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{32=>nil, 41=>nil, 50=>:occupied, 59=>:enemy}, 59, "X:C", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "X:C", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>:enemy}, 68, "X:C", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "X:C", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "X:C", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "X:C", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:C", false]], 24=>[[{15=>:occupied, 6=>:enemy}, 6, "X:C", true], [{23=>:occupied, 22=>nil, 21=>:enemy}, 21, "X:C", true], [{23=>:occupied, 22=>nil, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{23=>:occupied, 22=>:enemy}, 22, "X:C", true], [{25=>:occupied, 26=>:enemy}, 26, "X:C", true], [{33=>:occupied, 42=>nil, 51=>:enemy}, 51, "X:C", true], [{33=>:occupied, 42=>nil, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{33=>:occupied, 42=>:enemy}, 42, "X:C", true], [{15=>nil}, 15, "X:C", false], [{15=>nil, 6=>nil}, 6, "X:C", false], [{23=>nil}, 23, "X:C", false], [{23=>nil, 22=>:occupied, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{23=>nil, 22=>:occupied, 21=>:enemy}, 21, "X:C", true], [{23=>nil, 22=>nil}, 22, "X:C", false], [{23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{23=>nil, 22=>nil, 21=>:occupied, 20=>:enemy}, 20, "X:C", true], [{23=>nil, 22=>nil, 21=>nil}, 21, "X:C", false], [{23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>:enemy}, 19, "X:C", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "X:C", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "X:C", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "X:C", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:C", false], [{25=>nil}, 25, "X:C", false], [{25=>nil, 26=>nil}, 26, "X:C", false], [{33=>nil}, 33, "X:C", false], [{33=>nil, 42=>:occupied, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{33=>nil, 42=>:occupied, 51=>:enemy}, 51, "X:C", true], [{33=>nil, 42=>nil}, 42, "X:C", false], [{33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{33=>nil, 42=>nil, 51=>:occupied, 60=>:enemy}, 60, "X:C", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "X:C", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>:enemy}, 69, "X:C", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "X:C", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "X:C", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "X:C", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:C", false]], 25=>[[{16=>:occupied, 7=>:enemy}, 7, "X:C", true], [{24=>:occupied, 23=>nil, 22=>:enemy}, 22, "X:C", true], [{24=>:occupied, 23=>nil, 22=>nil, 21=>:enemy}, 21, "X:C", true], [{24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{24=>:occupied, 23=>:enemy}, 23, "X:C", true], [{34=>:occupied, 43=>nil, 52=>:enemy}, 52, "X:C", true], [{34=>:occupied, 43=>nil, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{34=>:occupied, 43=>:enemy}, 43, "X:C", true], [{16=>nil}, 16, "X:C", false], [{16=>nil, 7=>nil}, 7, "X:C", false], [{24=>nil}, 24, "X:C", false], [{24=>nil, 23=>:occupied, 22=>nil, 21=>:enemy}, 21, "X:C", true], [{24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{24=>nil, 23=>:occupied, 22=>:enemy}, 22, "X:C", true], [{24=>nil, 23=>nil}, 23, "X:C", false], [{24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{24=>nil, 23=>nil, 22=>:occupied, 21=>:enemy}, 21, "X:C", true], [{24=>nil, 23=>nil, 22=>nil}, 22, "X:C", false], [{24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>:enemy}, 20, "X:C", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "X:C", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>:enemy}, 19, "X:C", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "X:C", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "X:C", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "X:C", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:C", false], [{26=>nil}, 26, "X:C", false], [{34=>nil}, 34, "X:C", false], [{34=>nil, 43=>:occupied, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{34=>nil, 43=>:occupied, 52=>:enemy}, 52, "X:C", true], [{34=>nil, 43=>nil}, 43, "X:C", false], [{34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{34=>nil, 43=>nil, 52=>:occupied, 61=>:enemy}, 61, "X:C", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "X:C", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>:enemy}, 70, "X:C", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "X:C", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "X:C", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "X:C", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:C", false]], 26=>[[{17=>:occupied, 8=>:enemy}, 8, "X:C", true], [{25=>:occupied, 24=>nil, 23=>:enemy}, 23, "X:C", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>:enemy}, 22, "X:C", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "X:C", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{25=>:occupied, 24=>:enemy}, 24, "X:C", true], [{35=>:occupied, 44=>nil, 53=>:enemy}, 53, "X:C", true], [{35=>:occupied, 44=>nil, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{35=>:occupied, 44=>:enemy}, 44, "X:C", true], [{17=>nil}, 17, "X:C", false], [{17=>nil, 8=>nil}, 8, "X:C", false], [{25=>nil}, 25, "X:C", false], [{25=>nil, 24=>:occupied, 23=>nil, 22=>:enemy}, 22, "X:C", true], [{25=>nil, 24=>:occupied, 23=>nil, 22=>nil, 21=>:enemy}, 21, "X:C", true], [{25=>nil, 24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{25=>nil, 24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{25=>nil, 24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{25=>nil, 24=>:occupied, 23=>:enemy}, 23, "X:C", true], [{25=>nil, 24=>nil}, 24, "X:C", false], [{25=>nil, 24=>nil, 23=>:occupied, 22=>nil, 21=>:enemy}, 21, "X:C", true], [{25=>nil, 24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{25=>nil, 24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{25=>nil, 24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{25=>nil, 24=>nil, 23=>:occupied, 22=>:enemy}, 22, "X:C", true], [{25=>nil, 24=>nil, 23=>nil}, 23, "X:C", false], [{25=>nil, 24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>:enemy}, 20, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>:occupied, 21=>:enemy}, 21, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil}, 22, "X:C", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>:enemy}, 19, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>:enemy}, 20, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "X:C", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>:enemy}, 19, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "X:C", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "X:C", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "X:C", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:C", false], [{35=>nil}, 35, "X:C", false], [{35=>nil, 44=>:occupied, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{35=>nil, 44=>:occupied, 53=>:enemy}, 53, "X:C", true], [{35=>nil, 44=>nil}, 44, "X:C", false], [{35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{35=>nil, 44=>nil, 53=>:occupied, 62=>:enemy}, 62, "X:C", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "X:C", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>:enemy}, 71, "X:C", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "X:C", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "X:C", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "X:C", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:C", false]], 27=>[[{18=>:occupied, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{18=>:occupied, 9=>:enemy}, 9, "X:C", true], [{28=>:occupied, 29=>nil, 30=>:enemy}, 30, "X:C", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>:enemy}, 31, "X:C", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "X:C", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{28=>:occupied, 29=>:enemy}, 29, "X:C", true], [{36=>:occupied, 45=>nil, 54=>:enemy}, 54, "X:C", true], [{36=>:occupied, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{36=>:occupied, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{36=>:occupied, 45=>:enemy}, 45, "X:C", true], [{18=>nil}, 18, "X:C", false], [{18=>nil, 9=>:occupied, 0=>:enemy}, 0, "X:C", true], [{18=>nil, 9=>nil}, 9, "X:C", false], [{18=>nil, 9=>nil, 0=>nil}, 0, "X:C", false], [{28=>nil}, 28, "X:C", false], [{28=>nil, 29=>:occupied, 30=>nil, 31=>:enemy}, 31, "X:C", true], [{28=>nil, 29=>:occupied, 30=>nil, 31=>nil, 32=>:enemy}, 32, "X:C", true], [{28=>nil, 29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{28=>nil, 29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{28=>nil, 29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{28=>nil, 29=>:occupied, 30=>:enemy}, 30, "X:C", true], [{28=>nil, 29=>nil}, 29, "X:C", false], [{28=>nil, 29=>nil, 30=>:occupied, 31=>nil, 32=>:enemy}, 32, "X:C", true], [{28=>nil, 29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{28=>nil, 29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{28=>nil, 29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{28=>nil, 29=>nil, 30=>:occupied, 31=>:enemy}, 31, "X:C", true], [{28=>nil, 29=>nil, 30=>nil}, 30, "X:C", false], [{28=>nil, 29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>:occupied, 32=>:enemy}, 32, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil}, 31, "X:C", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>:enemy}, 33, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "X:C", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>:enemy}, 34, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "X:C", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "X:C", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "X:C", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:C", false], [{36=>nil}, 36, "X:C", false], [{36=>nil, 45=>:occupied, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{36=>nil, 45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{36=>nil, 45=>:occupied, 54=>:enemy}, 54, "X:C", true], [{36=>nil, 45=>nil}, 45, "X:C", false], [{36=>nil, 45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{36=>nil, 45=>nil, 54=>:occupied, 63=>:enemy}, 63, "X:C", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "X:C", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "X:C", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "X:C", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:C", false]], 28=>[[{19=>:occupied, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{19=>:occupied, 10=>:enemy}, 10, "X:C", true], [{29=>:occupied, 30=>nil, 31=>:enemy}, 31, "X:C", true], [{29=>:occupied, 30=>nil, 31=>nil, 32=>:enemy}, 32, "X:C", true], [{29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{29=>:occupied, 30=>:enemy}, 30, "X:C", true], [{37=>:occupied, 46=>nil, 55=>:enemy}, 55, "X:C", true], [{37=>:occupied, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{37=>:occupied, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{37=>:occupied, 46=>:enemy}, 46, "X:C", true], [{19=>nil}, 19, "X:C", false], [{19=>nil, 10=>:occupied, 1=>:enemy}, 1, "X:C", true], [{19=>nil, 10=>nil}, 10, "X:C", false], [{19=>nil, 10=>nil, 1=>nil}, 1, "X:C", false], [{27=>nil}, 27, "X:C", false], [{29=>nil}, 29, "X:C", false], [{29=>nil, 30=>:occupied, 31=>nil, 32=>:enemy}, 32, "X:C", true], [{29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{29=>nil, 30=>:occupied, 31=>:enemy}, 31, "X:C", true], [{29=>nil, 30=>nil}, 30, "X:C", false], [{29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{29=>nil, 30=>nil, 31=>:occupied, 32=>:enemy}, 32, "X:C", true], [{29=>nil, 30=>nil, 31=>nil}, 31, "X:C", false], [{29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>:enemy}, 33, "X:C", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "X:C", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>:enemy}, 34, "X:C", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "X:C", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "X:C", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "X:C", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:C", false], [{37=>nil}, 37, "X:C", false], [{37=>nil, 46=>:occupied, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{37=>nil, 46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{37=>nil, 46=>:occupied, 55=>:enemy}, 55, "X:C", true], [{37=>nil, 46=>nil}, 46, "X:C", false], [{37=>nil, 46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{37=>nil, 46=>nil, 55=>:occupied, 64=>:enemy}, 64, "X:C", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "X:C", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "X:C", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "X:C", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:C", false]], 29=>[[{20=>:occupied, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{20=>:occupied, 11=>:enemy}, 11, "X:C", true], [{28=>:occupied, 27=>:enemy}, 27, "X:C", true], [{30=>:occupied, 31=>nil, 32=>:enemy}, 32, "X:C", true], [{30=>:occupied, 31=>nil, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{30=>:occupied, 31=>:enemy}, 31, "X:C", true], [{38=>:occupied, 47=>nil, 56=>:enemy}, 56, "X:C", true], [{38=>:occupied, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{38=>:occupied, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{38=>:occupied, 47=>:enemy}, 47, "X:C", true], [{20=>nil}, 20, "X:C", false], [{20=>nil, 11=>:occupied, 2=>:enemy}, 2, "X:C", true], [{20=>nil, 11=>nil}, 11, "X:C", false], [{20=>nil, 11=>nil, 2=>nil}, 2, "X:C", false], [{28=>nil}, 28, "X:C", false], [{28=>nil, 27=>nil}, 27, "X:C", false], [{30=>nil}, 30, "X:C", false], [{30=>nil, 31=>:occupied, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{30=>nil, 31=>:occupied, 32=>:enemy}, 32, "X:C", true], [{30=>nil, 31=>nil}, 31, "X:C", false], [{30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{30=>nil, 31=>nil, 32=>:occupied, 33=>:enemy}, 33, "X:C", true], [{30=>nil, 31=>nil, 32=>nil}, 32, "X:C", false], [{30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>:enemy}, 34, "X:C", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "X:C", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "X:C", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "X:C", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:C", false], [{38=>nil}, 38, "X:C", false], [{38=>nil, 47=>:occupied, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{38=>nil, 47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{38=>nil, 47=>:occupied, 56=>:enemy}, 56, "X:C", true], [{38=>nil, 47=>nil}, 47, "X:C", false], [{38=>nil, 47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{38=>nil, 47=>nil, 56=>:occupied, 65=>:enemy}, 65, "X:C", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "X:C", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "X:C", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "X:C", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:C", false]], 30=>[[{21=>:occupied, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{21=>:occupied, 12=>:enemy}, 12, "X:C", true], [{29=>:occupied, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{29=>:occupied, 28=>:enemy}, 28, "X:C", true], [{31=>:occupied, 32=>nil, 33=>:enemy}, 33, "X:C", true], [{31=>:occupied, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{31=>:occupied, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{31=>:occupied, 32=>:enemy}, 32, "X:C", true], [{39=>:occupied, 48=>nil, 57=>:enemy}, 57, "X:C", true], [{39=>:occupied, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{39=>:occupied, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{39=>:occupied, 48=>:enemy}, 48, "X:C", true], [{21=>nil}, 21, "X:C", false], [{21=>nil, 12=>:occupied, 3=>:enemy}, 3, "X:C", true], [{21=>nil, 12=>nil}, 12, "X:C", false], [{21=>nil, 12=>nil, 3=>nil}, 3, "X:C", false], [{29=>nil}, 29, "X:C", false], [{29=>nil, 28=>:occupied, 27=>:enemy}, 27, "X:C", true], [{29=>nil, 28=>nil}, 28, "X:C", false], [{29=>nil, 28=>nil, 27=>nil}, 27, "X:C", false], [{31=>nil}, 31, "X:C", false], [{31=>nil, 32=>:occupied, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{31=>nil, 32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{31=>nil, 32=>:occupied, 33=>:enemy}, 33, "X:C", true], [{31=>nil, 32=>nil}, 32, "X:C", false], [{31=>nil, 32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{31=>nil, 32=>nil, 33=>:occupied, 34=>:enemy}, 34, "X:C", true], [{31=>nil, 32=>nil, 33=>nil}, 33, "X:C", false], [{31=>nil, 32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "X:C", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "X:C", false], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:C", false], [{39=>nil}, 39, "X:C", false], [{39=>nil, 48=>:occupied, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{39=>nil, 48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{39=>nil, 48=>:occupied, 57=>:enemy}, 57, "X:C", true], [{39=>nil, 48=>nil}, 48, "X:C", false], [{39=>nil, 48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{39=>nil, 48=>nil, 57=>:occupied, 66=>:enemy}, 66, "X:C", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "X:C", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "X:C", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "X:C", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:C", false]], 31=>[[{22=>:occupied, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{22=>:occupied, 13=>:enemy}, 13, "X:C", true], [{30=>:occupied, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{30=>:occupied, 29=>:enemy}, 29, "X:C", true], [{32=>:occupied, 33=>nil, 34=>:enemy}, 34, "X:C", true], [{32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{32=>:occupied, 33=>:enemy}, 33, "X:C", true], [{40=>:occupied, 49=>nil, 58=>:enemy}, 58, "X:C", true], [{40=>:occupied, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{40=>:occupied, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{40=>:occupied, 49=>:enemy}, 49, "X:C", true], [{22=>nil}, 22, "X:C", false], [{22=>nil, 13=>:occupied, 4=>:enemy}, 4, "X:C", true], [{22=>nil, 13=>nil}, 13, "X:C", false], [{22=>nil, 13=>nil, 4=>nil}, 4, "X:C", false], [{30=>nil}, 30, "X:C", false], [{30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{30=>nil, 29=>:occupied, 28=>:enemy}, 28, "X:C", true], [{30=>nil, 29=>nil}, 29, "X:C", false], [{30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "X:C", true], [{30=>nil, 29=>nil, 28=>nil}, 28, "X:C", false], [{30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:C", false], [{32=>nil}, 32, "X:C", false], [{32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{32=>nil, 33=>:occupied, 34=>:enemy}, 34, "X:C", true], [{32=>nil, 33=>nil}, 33, "X:C", false], [{32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "X:C", true], [{32=>nil, 33=>nil, 34=>nil}, 34, "X:C", false], [{32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:C", false], [{40=>nil}, 40, "X:C", false], [{40=>nil, 49=>:occupied, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{40=>nil, 49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{40=>nil, 49=>:occupied, 58=>:enemy}, 58, "X:C", true], [{40=>nil, 49=>nil}, 49, "X:C", false], [{40=>nil, 49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{40=>nil, 49=>nil, 58=>:occupied, 67=>:enemy}, 67, "X:C", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "X:C", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "X:C", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "X:C", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:C", false]], 32=>[[{23=>:occupied, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{23=>:occupied, 14=>:enemy}, 14, "X:C", true], [{31=>:occupied, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{31=>:occupied, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{31=>:occupied, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{31=>:occupied, 30=>:enemy}, 30, "X:C", true], [{33=>:occupied, 34=>nil, 35=>:enemy}, 35, "X:C", true], [{33=>:occupied, 34=>:enemy}, 34, "X:C", true], [{41=>:occupied, 50=>nil, 59=>:enemy}, 59, "X:C", true], [{41=>:occupied, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{41=>:occupied, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{41=>:occupied, 50=>:enemy}, 50, "X:C", true], [{23=>nil}, 23, "X:C", false], [{23=>nil, 14=>:occupied, 5=>:enemy}, 5, "X:C", true], [{23=>nil, 14=>nil}, 14, "X:C", false], [{23=>nil, 14=>nil, 5=>nil}, 5, "X:C", false], [{31=>nil}, 31, "X:C", false], [{31=>nil, 30=>:occupied, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{31=>nil, 30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{31=>nil, 30=>:occupied, 29=>:enemy}, 29, "X:C", true], [{31=>nil, 30=>nil}, 30, "X:C", false], [{31=>nil, 30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{31=>nil, 30=>nil, 29=>:occupied, 28=>:enemy}, 28, "X:C", true], [{31=>nil, 30=>nil, 29=>nil}, 29, "X:C", false], [{31=>nil, 30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "X:C", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "X:C", false], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:C", false], [{33=>nil}, 33, "X:C", false], [{33=>nil, 34=>:occupied, 35=>:enemy}, 35, "X:C", true], [{33=>nil, 34=>nil}, 34, "X:C", false], [{33=>nil, 34=>nil, 35=>nil}, 35, "X:C", false], [{41=>nil}, 41, "X:C", false], [{41=>nil, 50=>:occupied, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{41=>nil, 50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{41=>nil, 50=>:occupied, 59=>:enemy}, 59, "X:C", true], [{41=>nil, 50=>nil}, 50, "X:C", false], [{41=>nil, 50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{41=>nil, 50=>nil, 59=>:occupied, 68=>:enemy}, 68, "X:C", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "X:C", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "X:C", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "X:C", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:C", false]], 33=>[[{24=>:occupied, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{24=>:occupied, 15=>:enemy}, 15, "X:C", true], [{32=>:occupied, 31=>nil, 30=>:enemy}, 30, "X:C", true], [{32=>:occupied, 31=>nil, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{32=>:occupied, 31=>:enemy}, 31, "X:C", true], [{34=>:occupied, 35=>:enemy}, 35, "X:C", true], [{42=>:occupied, 51=>nil, 60=>:enemy}, 60, "X:C", true], [{42=>:occupied, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{42=>:occupied, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{42=>:occupied, 51=>:enemy}, 51, "X:C", true], [{24=>nil}, 24, "X:C", false], [{24=>nil, 15=>:occupied, 6=>:enemy}, 6, "X:C", true], [{24=>nil, 15=>nil}, 15, "X:C", false], [{24=>nil, 15=>nil, 6=>nil}, 6, "X:C", false], [{32=>nil}, 32, "X:C", false], [{32=>nil, 31=>:occupied, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{32=>nil, 31=>:occupied, 30=>:enemy}, 30, "X:C", true], [{32=>nil, 31=>nil}, 31, "X:C", false], [{32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{32=>nil, 31=>nil, 30=>:occupied, 29=>:enemy}, 29, "X:C", true], [{32=>nil, 31=>nil, 30=>nil}, 30, "X:C", false], [{32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>:enemy}, 28, "X:C", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "X:C", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "X:C", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "X:C", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:C", false], [{34=>nil}, 34, "X:C", false], [{34=>nil, 35=>nil}, 35, "X:C", false], [{42=>nil}, 42, "X:C", false], [{42=>nil, 51=>:occupied, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{42=>nil, 51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{42=>nil, 51=>:occupied, 60=>:enemy}, 60, "X:C", true], [{42=>nil, 51=>nil}, 51, "X:C", false], [{42=>nil, 51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{42=>nil, 51=>nil, 60=>:occupied, 69=>:enemy}, 69, "X:C", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "X:C", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "X:C", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "X:C", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:C", false]], 34=>[[{25=>:occupied, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{25=>:occupied, 16=>:enemy}, 16, "X:C", true], [{33=>:occupied, 32=>nil, 31=>:enemy}, 31, "X:C", true], [{33=>:occupied, 32=>nil, 31=>nil, 30=>:enemy}, 30, "X:C", true], [{33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{33=>:occupied, 32=>:enemy}, 32, "X:C", true], [{43=>:occupied, 52=>nil, 61=>:enemy}, 61, "X:C", true], [{43=>:occupied, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{43=>:occupied, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{43=>:occupied, 52=>:enemy}, 52, "X:C", true], [{25=>nil}, 25, "X:C", false], [{25=>nil, 16=>:occupied, 7=>:enemy}, 7, "X:C", true], [{25=>nil, 16=>nil}, 16, "X:C", false], [{25=>nil, 16=>nil, 7=>nil}, 7, "X:C", false], [{33=>nil}, 33, "X:C", false], [{33=>nil, 32=>:occupied, 31=>nil, 30=>:enemy}, 30, "X:C", true], [{33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{33=>nil, 32=>:occupied, 31=>:enemy}, 31, "X:C", true], [{33=>nil, 32=>nil}, 32, "X:C", false], [{33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{33=>nil, 32=>nil, 31=>:occupied, 30=>:enemy}, 30, "X:C", true], [{33=>nil, 32=>nil, 31=>nil}, 31, "X:C", false], [{33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>:enemy}, 29, "X:C", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "X:C", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>:enemy}, 28, "X:C", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "X:C", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "X:C", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "X:C", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:C", false], [{35=>nil}, 35, "X:C", false], [{43=>nil}, 43, "X:C", false], [{43=>nil, 52=>:occupied, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{43=>nil, 52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{43=>nil, 52=>:occupied, 61=>:enemy}, 61, "X:C", true], [{43=>nil, 52=>nil}, 52, "X:C", false], [{43=>nil, 52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{43=>nil, 52=>nil, 61=>:occupied, 70=>:enemy}, 70, "X:C", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "X:C", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "X:C", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "X:C", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:C", false]], 35=>[[{26=>:occupied, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{26=>:occupied, 17=>:enemy}, 17, "X:C", true], [{34=>:occupied, 33=>nil, 32=>:enemy}, 32, "X:C", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>:enemy}, 31, "X:C", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "X:C", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{34=>:occupied, 33=>:enemy}, 33, "X:C", true], [{44=>:occupied, 53=>nil, 62=>:enemy}, 62, "X:C", true], [{44=>:occupied, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{44=>:occupied, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{44=>:occupied, 53=>:enemy}, 53, "X:C", true], [{26=>nil}, 26, "X:C", false], [{26=>nil, 17=>:occupied, 8=>:enemy}, 8, "X:C", true], [{26=>nil, 17=>nil}, 17, "X:C", false], [{26=>nil, 17=>nil, 8=>nil}, 8, "X:C", false], [{34=>nil}, 34, "X:C", false], [{34=>nil, 33=>:occupied, 32=>nil, 31=>:enemy}, 31, "X:C", true], [{34=>nil, 33=>:occupied, 32=>nil, 31=>nil, 30=>:enemy}, 30, "X:C", true], [{34=>nil, 33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{34=>nil, 33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{34=>nil, 33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{34=>nil, 33=>:occupied, 32=>:enemy}, 32, "X:C", true], [{34=>nil, 33=>nil}, 33, "X:C", false], [{34=>nil, 33=>nil, 32=>:occupied, 31=>nil, 30=>:enemy}, 30, "X:C", true], [{34=>nil, 33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{34=>nil, 33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{34=>nil, 33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{34=>nil, 33=>nil, 32=>:occupied, 31=>:enemy}, 31, "X:C", true], [{34=>nil, 33=>nil, 32=>nil}, 32, "X:C", false], [{34=>nil, 33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>:enemy}, 29, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>:occupied, 30=>:enemy}, 30, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil}, 31, "X:C", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>:enemy}, 28, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>:enemy}, 29, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "X:C", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>:enemy}, 28, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "X:C", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "X:C", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "X:C", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:C", false], [{44=>nil}, 44, "X:C", false], [{44=>nil, 53=>:occupied, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{44=>nil, 53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{44=>nil, 53=>:occupied, 62=>:enemy}, 62, "X:C", true], [{44=>nil, 53=>nil}, 53, "X:C", false], [{44=>nil, 53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{44=>nil, 53=>nil, 62=>:occupied, 71=>:enemy}, 71, "X:C", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "X:C", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "X:C", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "X:C", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:C", false]], 36=>[[{27=>:occupied, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{27=>:occupied, 18=>:enemy}, 18, "X:C", true], [{37=>:occupied, 38=>nil, 39=>:enemy}, 39, "X:C", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>:enemy}, 40, "X:C", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "X:C", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{37=>:occupied, 38=>:enemy}, 38, "X:C", true], [{45=>:occupied, 54=>nil, 63=>:enemy}, 63, "X:C", true], [{45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{45=>:occupied, 54=>:enemy}, 54, "X:C", true], [{27=>nil}, 27, "X:C", false], [{27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{27=>nil, 18=>:occupied, 9=>:enemy}, 9, "X:C", true], [{27=>nil, 18=>nil}, 18, "X:C", false], [{27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "X:C", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "X:C", false], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:C", false], [{37=>nil}, 37, "X:C", false], [{37=>nil, 38=>:occupied, 39=>nil, 40=>:enemy}, 40, "X:C", true], [{37=>nil, 38=>:occupied, 39=>nil, 40=>nil, 41=>:enemy}, 41, "X:C", true], [{37=>nil, 38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{37=>nil, 38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{37=>nil, 38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{37=>nil, 38=>:occupied, 39=>:enemy}, 39, "X:C", true], [{37=>nil, 38=>nil}, 38, "X:C", false], [{37=>nil, 38=>nil, 39=>:occupied, 40=>nil, 41=>:enemy}, 41, "X:C", true], [{37=>nil, 38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{37=>nil, 38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{37=>nil, 38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{37=>nil, 38=>nil, 39=>:occupied, 40=>:enemy}, 40, "X:C", true], [{37=>nil, 38=>nil, 39=>nil}, 39, "X:C", false], [{37=>nil, 38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>:occupied, 41=>:enemy}, 41, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil}, 40, "X:C", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>:enemy}, 42, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "X:C", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>:enemy}, 43, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "X:C", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "X:C", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "X:C", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:C", false], [{45=>nil}, 45, "X:C", false], [{45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{45=>nil, 54=>:occupied, 63=>:enemy}, 63, "X:C", true], [{45=>nil, 54=>nil}, 54, "X:C", false], [{45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "X:C", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "X:C", false], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:C", false]], 37=>[[{28=>:occupied, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{28=>:occupied, 19=>:enemy}, 19, "X:C", true], [{38=>:occupied, 39=>nil, 40=>:enemy}, 40, "X:C", true], [{38=>:occupied, 39=>nil, 40=>nil, 41=>:enemy}, 41, "X:C", true], [{38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{38=>:occupied, 39=>:enemy}, 39, "X:C", true], [{46=>:occupied, 55=>nil, 64=>:enemy}, 64, "X:C", true], [{46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{46=>:occupied, 55=>:enemy}, 55, "X:C", true], [{28=>nil}, 28, "X:C", false], [{28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{28=>nil, 19=>:occupied, 10=>:enemy}, 10, "X:C", true], [{28=>nil, 19=>nil}, 19, "X:C", false], [{28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "X:C", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "X:C", false], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:C", false], [{36=>nil}, 36, "X:C", false], [{38=>nil}, 38, "X:C", false], [{38=>nil, 39=>:occupied, 40=>nil, 41=>:enemy}, 41, "X:C", true], [{38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{38=>nil, 39=>:occupied, 40=>:enemy}, 40, "X:C", true], [{38=>nil, 39=>nil}, 39, "X:C", false], [{38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{38=>nil, 39=>nil, 40=>:occupied, 41=>:enemy}, 41, "X:C", true], [{38=>nil, 39=>nil, 40=>nil}, 40, "X:C", false], [{38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>:enemy}, 42, "X:C", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "X:C", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>:enemy}, 43, "X:C", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "X:C", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "X:C", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "X:C", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:C", false], [{46=>nil}, 46, "X:C", false], [{46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{46=>nil, 55=>:occupied, 64=>:enemy}, 64, "X:C", true], [{46=>nil, 55=>nil}, 55, "X:C", false], [{46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "X:C", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "X:C", false], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:C", false]], 38=>[[{29=>:occupied, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{29=>:occupied, 20=>:enemy}, 20, "X:C", true], [{37=>:occupied, 36=>:enemy}, 36, "X:C", true], [{39=>:occupied, 40=>nil, 41=>:enemy}, 41, "X:C", true], [{39=>:occupied, 40=>nil, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{39=>:occupied, 40=>:enemy}, 40, "X:C", true], [{47=>:occupied, 56=>nil, 65=>:enemy}, 65, "X:C", true], [{47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{47=>:occupied, 56=>:enemy}, 56, "X:C", true], [{29=>nil}, 29, "X:C", false], [{29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{29=>nil, 20=>:occupied, 11=>:enemy}, 11, "X:C", true], [{29=>nil, 20=>nil}, 20, "X:C", false], [{29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "X:C", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "X:C", false], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:C", false], [{37=>nil}, 37, "X:C", false], [{37=>nil, 36=>nil}, 36, "X:C", false], [{39=>nil}, 39, "X:C", false], [{39=>nil, 40=>:occupied, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{39=>nil, 40=>:occupied, 41=>:enemy}, 41, "X:C", true], [{39=>nil, 40=>nil}, 40, "X:C", false], [{39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{39=>nil, 40=>nil, 41=>:occupied, 42=>:enemy}, 42, "X:C", true], [{39=>nil, 40=>nil, 41=>nil}, 41, "X:C", false], [{39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>:enemy}, 43, "X:C", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "X:C", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "X:C", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "X:C", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:C", false], [{47=>nil}, 47, "X:C", false], [{47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{47=>nil, 56=>:occupied, 65=>:enemy}, 65, "X:C", true], [{47=>nil, 56=>nil}, 56, "X:C", false], [{47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "X:C", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "X:C", false], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:C", false]], 39=>[[{30=>:occupied, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{30=>:occupied, 21=>:enemy}, 21, "X:C", true], [{38=>:occupied, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{38=>:occupied, 37=>:enemy}, 37, "X:C", true], [{40=>:occupied, 41=>nil, 42=>:enemy}, 42, "X:C", true], [{40=>:occupied, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{40=>:occupied, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{40=>:occupied, 41=>:enemy}, 41, "X:C", true], [{48=>:occupied, 57=>nil, 66=>:enemy}, 66, "X:C", true], [{48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{48=>:occupied, 57=>:enemy}, 57, "X:C", true], [{30=>nil}, 30, "X:C", false], [{30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{30=>nil, 21=>:occupied, 12=>:enemy}, 12, "X:C", true], [{30=>nil, 21=>nil}, 21, "X:C", false], [{30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "X:C", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "X:C", false], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:C", false], [{38=>nil}, 38, "X:C", false], [{38=>nil, 37=>:occupied, 36=>:enemy}, 36, "X:C", true], [{38=>nil, 37=>nil}, 37, "X:C", false], [{38=>nil, 37=>nil, 36=>nil}, 36, "X:C", false], [{40=>nil}, 40, "X:C", false], [{40=>nil, 41=>:occupied, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{40=>nil, 41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{40=>nil, 41=>:occupied, 42=>:enemy}, 42, "X:C", true], [{40=>nil, 41=>nil}, 41, "X:C", false], [{40=>nil, 41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{40=>nil, 41=>nil, 42=>:occupied, 43=>:enemy}, 43, "X:C", true], [{40=>nil, 41=>nil, 42=>nil}, 42, "X:C", false], [{40=>nil, 41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "X:C", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "X:C", false], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:C", false], [{48=>nil}, 48, "X:C", false], [{48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{48=>nil, 57=>:occupied, 66=>:enemy}, 66, "X:C", true], [{48=>nil, 57=>nil}, 57, "X:C", false], [{48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "X:C", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "X:C", false], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:C", false]], 40=>[[{31=>:occupied, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{31=>:occupied, 22=>:enemy}, 22, "X:C", true], [{39=>:occupied, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{39=>:occupied, 38=>:enemy}, 38, "X:C", true], [{41=>:occupied, 42=>nil, 43=>:enemy}, 43, "X:C", true], [{41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{41=>:occupied, 42=>:enemy}, 42, "X:C", true], [{49=>:occupied, 58=>nil, 67=>:enemy}, 67, "X:C", true], [{49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{49=>:occupied, 58=>:enemy}, 58, "X:C", true], [{31=>nil}, 31, "X:C", false], [{31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{31=>nil, 22=>:occupied, 13=>:enemy}, 13, "X:C", true], [{31=>nil, 22=>nil}, 22, "X:C", false], [{31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "X:C", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "X:C", false], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:C", false], [{39=>nil}, 39, "X:C", false], [{39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{39=>nil, 38=>:occupied, 37=>:enemy}, 37, "X:C", true], [{39=>nil, 38=>nil}, 38, "X:C", false], [{39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "X:C", true], [{39=>nil, 38=>nil, 37=>nil}, 37, "X:C", false], [{39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:C", false], [{41=>nil}, 41, "X:C", false], [{41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{41=>nil, 42=>:occupied, 43=>:enemy}, 43, "X:C", true], [{41=>nil, 42=>nil}, 42, "X:C", false], [{41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "X:C", true], [{41=>nil, 42=>nil, 43=>nil}, 43, "X:C", false], [{41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:C", false], [{49=>nil}, 49, "X:C", false], [{49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{49=>nil, 58=>:occupied, 67=>:enemy}, 67, "X:C", true], [{49=>nil, 58=>nil}, 58, "X:C", false], [{49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "X:C", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "X:C", false], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:C", false]], 41=>[[{32=>:occupied, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{32=>:occupied, 23=>:enemy}, 23, "X:C", true], [{40=>:occupied, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{40=>:occupied, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{40=>:occupied, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{40=>:occupied, 39=>:enemy}, 39, "X:C", true], [{42=>:occupied, 43=>nil, 44=>:enemy}, 44, "X:C", true], [{42=>:occupied, 43=>:enemy}, 43, "X:C", true], [{50=>:occupied, 59=>nil, 68=>:enemy}, 68, "X:C", true], [{50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{50=>:occupied, 59=>:enemy}, 59, "X:C", true], [{32=>nil}, 32, "X:C", false], [{32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{32=>nil, 23=>:occupied, 14=>:enemy}, 14, "X:C", true], [{32=>nil, 23=>nil}, 23, "X:C", false], [{32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "X:C", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "X:C", false], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:C", false], [{40=>nil}, 40, "X:C", false], [{40=>nil, 39=>:occupied, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{40=>nil, 39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{40=>nil, 39=>:occupied, 38=>:enemy}, 38, "X:C", true], [{40=>nil, 39=>nil}, 39, "X:C", false], [{40=>nil, 39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{40=>nil, 39=>nil, 38=>:occupied, 37=>:enemy}, 37, "X:C", true], [{40=>nil, 39=>nil, 38=>nil}, 38, "X:C", false], [{40=>nil, 39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "X:C", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "X:C", false], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:C", false], [{42=>nil}, 42, "X:C", false], [{42=>nil, 43=>:occupied, 44=>:enemy}, 44, "X:C", true], [{42=>nil, 43=>nil}, 43, "X:C", false], [{42=>nil, 43=>nil, 44=>nil}, 44, "X:C", false], [{50=>nil}, 50, "X:C", false], [{50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{50=>nil, 59=>:occupied, 68=>:enemy}, 68, "X:C", true], [{50=>nil, 59=>nil}, 59, "X:C", false], [{50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "X:C", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "X:C", false], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:C", false]], 42=>[[{33=>:occupied, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{33=>:occupied, 24=>:enemy}, 24, "X:C", true], [{41=>:occupied, 40=>nil, 39=>:enemy}, 39, "X:C", true], [{41=>:occupied, 40=>nil, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{41=>:occupied, 40=>:enemy}, 40, "X:C", true], [{43=>:occupied, 44=>:enemy}, 44, "X:C", true], [{51=>:occupied, 60=>nil, 69=>:enemy}, 69, "X:C", true], [{51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{51=>:occupied, 60=>:enemy}, 60, "X:C", true], [{33=>nil}, 33, "X:C", false], [{33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{33=>nil, 24=>:occupied, 15=>:enemy}, 15, "X:C", true], [{33=>nil, 24=>nil}, 24, "X:C", false], [{33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "X:C", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "X:C", false], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:C", false], [{41=>nil}, 41, "X:C", false], [{41=>nil, 40=>:occupied, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{41=>nil, 40=>:occupied, 39=>:enemy}, 39, "X:C", true], [{41=>nil, 40=>nil}, 40, "X:C", false], [{41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{41=>nil, 40=>nil, 39=>:occupied, 38=>:enemy}, 38, "X:C", true], [{41=>nil, 40=>nil, 39=>nil}, 39, "X:C", false], [{41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>:enemy}, 37, "X:C", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "X:C", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "X:C", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "X:C", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:C", false], [{43=>nil}, 43, "X:C", false], [{43=>nil, 44=>nil}, 44, "X:C", false], [{51=>nil}, 51, "X:C", false], [{51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{51=>nil, 60=>:occupied, 69=>:enemy}, 69, "X:C", true], [{51=>nil, 60=>nil}, 60, "X:C", false], [{51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "X:C", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "X:C", false], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:C", false]], 43=>[[{34=>:occupied, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{34=>:occupied, 25=>:enemy}, 25, "X:C", true], [{42=>:occupied, 41=>nil, 40=>:enemy}, 40, "X:C", true], [{42=>:occupied, 41=>nil, 40=>nil, 39=>:enemy}, 39, "X:C", true], [{42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{42=>:occupied, 41=>:enemy}, 41, "X:C", true], [{52=>:occupied, 61=>nil, 70=>:enemy}, 70, "X:C", true], [{52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{52=>:occupied, 61=>:enemy}, 61, "X:C", true], [{34=>nil}, 34, "X:C", false], [{34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{34=>nil, 25=>:occupied, 16=>:enemy}, 16, "X:C", true], [{34=>nil, 25=>nil}, 25, "X:C", false], [{34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "X:C", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "X:C", false], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:C", false], [{42=>nil}, 42, "X:C", false], [{42=>nil, 41=>:occupied, 40=>nil, 39=>:enemy}, 39, "X:C", true], [{42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{42=>nil, 41=>:occupied, 40=>:enemy}, 40, "X:C", true], [{42=>nil, 41=>nil}, 41, "X:C", false], [{42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{42=>nil, 41=>nil, 40=>:occupied, 39=>:enemy}, 39, "X:C", true], [{42=>nil, 41=>nil, 40=>nil}, 40, "X:C", false], [{42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>:enemy}, 38, "X:C", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "X:C", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>:enemy}, 37, "X:C", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "X:C", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "X:C", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "X:C", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:C", false], [{44=>nil}, 44, "X:C", false], [{52=>nil}, 52, "X:C", false], [{52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{52=>nil, 61=>:occupied, 70=>:enemy}, 70, "X:C", true], [{52=>nil, 61=>nil}, 61, "X:C", false], [{52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "X:C", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "X:C", false], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:C", false]], 44=>[[{35=>:occupied, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{35=>:occupied, 26=>:enemy}, 26, "X:C", true], [{43=>:occupied, 42=>nil, 41=>:enemy}, 41, "X:C", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>:enemy}, 40, "X:C", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "X:C", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{43=>:occupied, 42=>:enemy}, 42, "X:C", true], [{53=>:occupied, 62=>nil, 71=>:enemy}, 71, "X:C", true], [{53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{53=>:occupied, 62=>:enemy}, 62, "X:C", true], [{35=>nil}, 35, "X:C", false], [{35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{35=>nil, 26=>:occupied, 17=>:enemy}, 17, "X:C", true], [{35=>nil, 26=>nil}, 26, "X:C", false], [{35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "X:C", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "X:C", false], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:C", false], [{43=>nil}, 43, "X:C", false], [{43=>nil, 42=>:occupied, 41=>nil, 40=>:enemy}, 40, "X:C", true], [{43=>nil, 42=>:occupied, 41=>nil, 40=>nil, 39=>:enemy}, 39, "X:C", true], [{43=>nil, 42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{43=>nil, 42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{43=>nil, 42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{43=>nil, 42=>:occupied, 41=>:enemy}, 41, "X:C", true], [{43=>nil, 42=>nil}, 42, "X:C", false], [{43=>nil, 42=>nil, 41=>:occupied, 40=>nil, 39=>:enemy}, 39, "X:C", true], [{43=>nil, 42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{43=>nil, 42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{43=>nil, 42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{43=>nil, 42=>nil, 41=>:occupied, 40=>:enemy}, 40, "X:C", true], [{43=>nil, 42=>nil, 41=>nil}, 41, "X:C", false], [{43=>nil, 42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>:enemy}, 38, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>:occupied, 39=>:enemy}, 39, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil}, 40, "X:C", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>:enemy}, 37, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>:enemy}, 38, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "X:C", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>:enemy}, 37, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "X:C", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "X:C", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "X:C", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:C", false], [{53=>nil}, 53, "X:C", false], [{53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{53=>nil, 62=>:occupied, 71=>:enemy}, 71, "X:C", true], [{53=>nil, 62=>nil}, 62, "X:C", false], [{53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "X:C", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "X:C", false], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:C", false]], 45=>[[{36=>:occupied, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{36=>:occupied, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{36=>:occupied, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{36=>:occupied, 27=>:enemy}, 27, "X:C", true], [{46=>:occupied, 47=>nil, 48=>:enemy}, 48, "X:C", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>:enemy}, 49, "X:C", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "X:C", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{46=>:occupied, 47=>:enemy}, 47, "X:C", true], [{54=>:occupied, 63=>nil, 72=>:enemy}, 72, "X:C", true], [{54=>:occupied, 63=>:enemy}, 63, "X:C", true], [{36=>nil}, 36, "X:C", false], [{36=>nil, 27=>:occupied, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{36=>nil, 27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{36=>nil, 27=>:occupied, 18=>:enemy}, 18, "X:C", true], [{36=>nil, 27=>nil}, 27, "X:C", false], [{36=>nil, 27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{36=>nil, 27=>nil, 18=>:occupied, 9=>:enemy}, 9, "X:C", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "X:C", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "X:C", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "X:C", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:C", false], [{46=>nil}, 46, "X:C", false], [{46=>nil, 47=>:occupied, 48=>nil, 49=>:enemy}, 49, "X:C", true], [{46=>nil, 47=>:occupied, 48=>nil, 49=>nil, 50=>:enemy}, 50, "X:C", true], [{46=>nil, 47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{46=>nil, 47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{46=>nil, 47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{46=>nil, 47=>:occupied, 48=>:enemy}, 48, "X:C", true], [{46=>nil, 47=>nil}, 47, "X:C", false], [{46=>nil, 47=>nil, 48=>:occupied, 49=>nil, 50=>:enemy}, 50, "X:C", true], [{46=>nil, 47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{46=>nil, 47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{46=>nil, 47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{46=>nil, 47=>nil, 48=>:occupied, 49=>:enemy}, 49, "X:C", true], [{46=>nil, 47=>nil, 48=>nil}, 48, "X:C", false], [{46=>nil, 47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>:occupied, 50=>:enemy}, 50, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil}, 49, "X:C", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>:enemy}, 51, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "X:C", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>:enemy}, 52, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "X:C", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "X:C", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "X:C", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:C", false], [{54=>nil}, 54, "X:C", false], [{54=>nil, 63=>:occupied, 72=>:enemy}, 72, "X:C", true], [{54=>nil, 63=>nil}, 63, "X:C", false], [{54=>nil, 63=>nil, 72=>nil}, 72, "X:C", false]], 46=>[[{37=>:occupied, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{37=>:occupied, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{37=>:occupied, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{37=>:occupied, 28=>:enemy}, 28, "X:C", true], [{47=>:occupied, 48=>nil, 49=>:enemy}, 49, "X:C", true], [{47=>:occupied, 48=>nil, 49=>nil, 50=>:enemy}, 50, "X:C", true], [{47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{47=>:occupied, 48=>:enemy}, 48, "X:C", true], [{55=>:occupied, 64=>nil, 73=>:enemy}, 73, "X:C", true], [{55=>:occupied, 64=>:enemy}, 64, "X:C", true], [{37=>nil}, 37, "X:C", false], [{37=>nil, 28=>:occupied, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{37=>nil, 28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{37=>nil, 28=>:occupied, 19=>:enemy}, 19, "X:C", true], [{37=>nil, 28=>nil}, 28, "X:C", false], [{37=>nil, 28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{37=>nil, 28=>nil, 19=>:occupied, 10=>:enemy}, 10, "X:C", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "X:C", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "X:C", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "X:C", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:C", false], [{45=>nil}, 45, "X:C", false], [{47=>nil}, 47, "X:C", false], [{47=>nil, 48=>:occupied, 49=>nil, 50=>:enemy}, 50, "X:C", true], [{47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{47=>nil, 48=>:occupied, 49=>:enemy}, 49, "X:C", true], [{47=>nil, 48=>nil}, 48, "X:C", false], [{47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{47=>nil, 48=>nil, 49=>:occupied, 50=>:enemy}, 50, "X:C", true], [{47=>nil, 48=>nil, 49=>nil}, 49, "X:C", false], [{47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>:enemy}, 51, "X:C", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "X:C", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>:enemy}, 52, "X:C", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "X:C", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "X:C", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "X:C", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:C", false], [{55=>nil}, 55, "X:C", false], [{55=>nil, 64=>:occupied, 73=>:enemy}, 73, "X:C", true], [{55=>nil, 64=>nil}, 64, "X:C", false], [{55=>nil, 64=>nil, 73=>nil}, 73, "X:C", false]], 47=>[[{38=>:occupied, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{38=>:occupied, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{38=>:occupied, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{38=>:occupied, 29=>:enemy}, 29, "X:C", true], [{46=>:occupied, 45=>:enemy}, 45, "X:C", true], [{48=>:occupied, 49=>nil, 50=>:enemy}, 50, "X:C", true], [{48=>:occupied, 49=>nil, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{48=>:occupied, 49=>:enemy}, 49, "X:C", true], [{56=>:occupied, 65=>nil, 74=>:enemy}, 74, "X:C", true], [{56=>:occupied, 65=>:enemy}, 65, "X:C", true], [{38=>nil}, 38, "X:C", false], [{38=>nil, 29=>:occupied, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{38=>nil, 29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{38=>nil, 29=>:occupied, 20=>:enemy}, 20, "X:C", true], [{38=>nil, 29=>nil}, 29, "X:C", false], [{38=>nil, 29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{38=>nil, 29=>nil, 20=>:occupied, 11=>:enemy}, 11, "X:C", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "X:C", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "X:C", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "X:C", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:C", false], [{46=>nil}, 46, "X:C", false], [{46=>nil, 45=>nil}, 45, "X:C", false], [{48=>nil}, 48, "X:C", false], [{48=>nil, 49=>:occupied, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{48=>nil, 49=>:occupied, 50=>:enemy}, 50, "X:C", true], [{48=>nil, 49=>nil}, 49, "X:C", false], [{48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{48=>nil, 49=>nil, 50=>:occupied, 51=>:enemy}, 51, "X:C", true], [{48=>nil, 49=>nil, 50=>nil}, 50, "X:C", false], [{48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>:enemy}, 52, "X:C", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "X:C", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "X:C", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "X:C", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:C", false], [{56=>nil}, 56, "X:C", false], [{56=>nil, 65=>:occupied, 74=>:enemy}, 74, "X:C", true], [{56=>nil, 65=>nil}, 65, "X:C", false], [{56=>nil, 65=>nil, 74=>nil}, 74, "X:C", false]], 48=>[[{39=>:occupied, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{39=>:occupied, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{39=>:occupied, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{39=>:occupied, 30=>:enemy}, 30, "X:C", true], [{47=>:occupied, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{47=>:occupied, 46=>:enemy}, 46, "X:C", true], [{49=>:occupied, 50=>nil, 51=>:enemy}, 51, "X:C", true], [{49=>:occupied, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{49=>:occupied, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{49=>:occupied, 50=>:enemy}, 50, "X:C", true], [{57=>:occupied, 66=>nil, 75=>:enemy}, 75, "X:C", true], [{57=>:occupied, 66=>:enemy}, 66, "X:C", true], [{39=>nil}, 39, "X:C", false], [{39=>nil, 30=>:occupied, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{39=>nil, 30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{39=>nil, 30=>:occupied, 21=>:enemy}, 21, "X:C", true], [{39=>nil, 30=>nil}, 30, "X:C", false], [{39=>nil, 30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{39=>nil, 30=>nil, 21=>:occupied, 12=>:enemy}, 12, "X:C", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "X:C", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "X:C", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "X:C", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:C", false], [{47=>nil}, 47, "X:C", false], [{47=>nil, 46=>:occupied, 45=>:enemy}, 45, "X:C", true], [{47=>nil, 46=>nil}, 46, "X:C", false], [{47=>nil, 46=>nil, 45=>nil}, 45, "X:C", false], [{49=>nil}, 49, "X:C", false], [{49=>nil, 50=>:occupied, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{49=>nil, 50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{49=>nil, 50=>:occupied, 51=>:enemy}, 51, "X:C", true], [{49=>nil, 50=>nil}, 50, "X:C", false], [{49=>nil, 50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{49=>nil, 50=>nil, 51=>:occupied, 52=>:enemy}, 52, "X:C", true], [{49=>nil, 50=>nil, 51=>nil}, 51, "X:C", false], [{49=>nil, 50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "X:C", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "X:C", false], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:C", false], [{57=>nil}, 57, "X:C", false], [{57=>nil, 66=>:occupied, 75=>:enemy}, 75, "X:C", true], [{57=>nil, 66=>nil}, 66, "X:C", false], [{57=>nil, 66=>nil, 75=>nil}, 75, "X:C", false]], 49=>[[{40=>:occupied, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{40=>:occupied, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{40=>:occupied, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{40=>:occupied, 31=>:enemy}, 31, "X:C", true], [{48=>:occupied, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{48=>:occupied, 47=>:enemy}, 47, "X:C", true], [{50=>:occupied, 51=>nil, 52=>:enemy}, 52, "X:C", true], [{50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{50=>:occupied, 51=>:enemy}, 51, "X:C", true], [{58=>:occupied, 67=>nil, 76=>:enemy}, 76, "X:C", true], [{58=>:occupied, 67=>:enemy}, 67, "X:C", true], [{40=>nil}, 40, "X:C", false], [{40=>nil, 31=>:occupied, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{40=>nil, 31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{40=>nil, 31=>:occupied, 22=>:enemy}, 22, "X:C", true], [{40=>nil, 31=>nil}, 31, "X:C", false], [{40=>nil, 31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{40=>nil, 31=>nil, 22=>:occupied, 13=>:enemy}, 13, "X:C", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "X:C", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "X:C", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "X:C", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:C", false], [{48=>nil}, 48, "X:C", false], [{48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{48=>nil, 47=>:occupied, 46=>:enemy}, 46, "X:C", true], [{48=>nil, 47=>nil}, 47, "X:C", false], [{48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "X:C", true], [{48=>nil, 47=>nil, 46=>nil}, 46, "X:C", false], [{48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:C", false], [{50=>nil}, 50, "X:C", false], [{50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{50=>nil, 51=>:occupied, 52=>:enemy}, 52, "X:C", true], [{50=>nil, 51=>nil}, 51, "X:C", false], [{50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "X:C", true], [{50=>nil, 51=>nil, 52=>nil}, 52, "X:C", false], [{50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:C", false], [{58=>nil}, 58, "X:C", false], [{58=>nil, 67=>:occupied, 76=>:enemy}, 76, "X:C", true], [{58=>nil, 67=>nil}, 67, "X:C", false], [{58=>nil, 67=>nil, 76=>nil}, 76, "X:C", false]], 50=>[[{41=>:occupied, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{41=>:occupied, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{41=>:occupied, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{41=>:occupied, 32=>:enemy}, 32, "X:C", true], [{49=>:occupied, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{49=>:occupied, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{49=>:occupied, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{49=>:occupied, 48=>:enemy}, 48, "X:C", true], [{51=>:occupied, 52=>nil, 53=>:enemy}, 53, "X:C", true], [{51=>:occupied, 52=>:enemy}, 52, "X:C", true], [{59=>:occupied, 68=>nil, 77=>:enemy}, 77, "X:C", true], [{59=>:occupied, 68=>:enemy}, 68, "X:C", true], [{41=>nil}, 41, "X:C", false], [{41=>nil, 32=>:occupied, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{41=>nil, 32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{41=>nil, 32=>:occupied, 23=>:enemy}, 23, "X:C", true], [{41=>nil, 32=>nil}, 32, "X:C", false], [{41=>nil, 32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{41=>nil, 32=>nil, 23=>:occupied, 14=>:enemy}, 14, "X:C", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "X:C", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "X:C", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "X:C", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:C", false], [{49=>nil}, 49, "X:C", false], [{49=>nil, 48=>:occupied, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{49=>nil, 48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{49=>nil, 48=>:occupied, 47=>:enemy}, 47, "X:C", true], [{49=>nil, 48=>nil}, 48, "X:C", false], [{49=>nil, 48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{49=>nil, 48=>nil, 47=>:occupied, 46=>:enemy}, 46, "X:C", true], [{49=>nil, 48=>nil, 47=>nil}, 47, "X:C", false], [{49=>nil, 48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "X:C", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "X:C", false], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:C", false], [{51=>nil}, 51, "X:C", false], [{51=>nil, 52=>:occupied, 53=>:enemy}, 53, "X:C", true], [{51=>nil, 52=>nil}, 52, "X:C", false], [{51=>nil, 52=>nil, 53=>nil}, 53, "X:C", false], [{59=>nil}, 59, "X:C", false], [{59=>nil, 68=>:occupied, 77=>:enemy}, 77, "X:C", true], [{59=>nil, 68=>nil}, 68, "X:C", false], [{59=>nil, 68=>nil, 77=>nil}, 77, "X:C", false]], 51=>[[{42=>:occupied, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{42=>:occupied, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{42=>:occupied, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{42=>:occupied, 33=>:enemy}, 33, "X:C", true], [{50=>:occupied, 49=>nil, 48=>:enemy}, 48, "X:C", true], [{50=>:occupied, 49=>nil, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{50=>:occupied, 49=>:enemy}, 49, "X:C", true], [{52=>:occupied, 53=>:enemy}, 53, "X:C", true], [{60=>:occupied, 69=>nil, 78=>:enemy}, 78, "X:C", true], [{60=>:occupied, 69=>:enemy}, 69, "X:C", true], [{42=>nil}, 42, "X:C", false], [{42=>nil, 33=>:occupied, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{42=>nil, 33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{42=>nil, 33=>:occupied, 24=>:enemy}, 24, "X:C", true], [{42=>nil, 33=>nil}, 33, "X:C", false], [{42=>nil, 33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{42=>nil, 33=>nil, 24=>:occupied, 15=>:enemy}, 15, "X:C", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "X:C", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "X:C", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "X:C", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:C", false], [{50=>nil}, 50, "X:C", false], [{50=>nil, 49=>:occupied, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{50=>nil, 49=>:occupied, 48=>:enemy}, 48, "X:C", true], [{50=>nil, 49=>nil}, 49, "X:C", false], [{50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{50=>nil, 49=>nil, 48=>:occupied, 47=>:enemy}, 47, "X:C", true], [{50=>nil, 49=>nil, 48=>nil}, 48, "X:C", false], [{50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>:enemy}, 46, "X:C", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "X:C", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "X:C", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "X:C", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:C", false], [{52=>nil}, 52, "X:C", false], [{52=>nil, 53=>nil}, 53, "X:C", false], [{60=>nil}, 60, "X:C", false], [{60=>nil, 69=>:occupied, 78=>:enemy}, 78, "X:C", true], [{60=>nil, 69=>nil}, 69, "X:C", false], [{60=>nil, 69=>nil, 78=>nil}, 78, "X:C", false]], 52=>[[{43=>:occupied, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{43=>:occupied, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{43=>:occupied, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{43=>:occupied, 34=>:enemy}, 34, "X:C", true], [{51=>:occupied, 50=>nil, 49=>:enemy}, 49, "X:C", true], [{51=>:occupied, 50=>nil, 49=>nil, 48=>:enemy}, 48, "X:C", true], [{51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{51=>:occupied, 50=>:enemy}, 50, "X:C", true], [{61=>:occupied, 70=>nil, 79=>:enemy}, 79, "X:C", true], [{61=>:occupied, 70=>:enemy}, 70, "X:C", true], [{43=>nil}, 43, "X:C", false], [{43=>nil, 34=>:occupied, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{43=>nil, 34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{43=>nil, 34=>:occupied, 25=>:enemy}, 25, "X:C", true], [{43=>nil, 34=>nil}, 34, "X:C", false], [{43=>nil, 34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{43=>nil, 34=>nil, 25=>:occupied, 16=>:enemy}, 16, "X:C", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "X:C", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "X:C", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "X:C", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:C", false], [{51=>nil}, 51, "X:C", false], [{51=>nil, 50=>:occupied, 49=>nil, 48=>:enemy}, 48, "X:C", true], [{51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{51=>nil, 50=>:occupied, 49=>:enemy}, 49, "X:C", true], [{51=>nil, 50=>nil}, 50, "X:C", false], [{51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{51=>nil, 50=>nil, 49=>:occupied, 48=>:enemy}, 48, "X:C", true], [{51=>nil, 50=>nil, 49=>nil}, 49, "X:C", false], [{51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>:enemy}, 47, "X:C", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "X:C", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>:enemy}, 46, "X:C", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "X:C", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "X:C", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "X:C", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:C", false], [{53=>nil}, 53, "X:C", false], [{61=>nil}, 61, "X:C", false], [{61=>nil, 70=>:occupied, 79=>:enemy}, 79, "X:C", true], [{61=>nil, 70=>nil}, 70, "X:C", false], [{61=>nil, 70=>nil, 79=>nil}, 79, "X:C", false]], 53=>[[{44=>:occupied, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{44=>:occupied, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{44=>:occupied, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{44=>:occupied, 35=>:enemy}, 35, "X:C", true], [{52=>:occupied, 51=>nil, 50=>:enemy}, 50, "X:C", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>:enemy}, 49, "X:C", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "X:C", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{52=>:occupied, 51=>:enemy}, 51, "X:C", true], [{62=>:occupied, 71=>nil, 80=>:enemy}, 80, "X:C", true], [{62=>:occupied, 71=>:enemy}, 71, "X:C", true], [{44=>nil}, 44, "X:C", false], [{44=>nil, 35=>:occupied, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{44=>nil, 35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{44=>nil, 35=>:occupied, 26=>:enemy}, 26, "X:C", true], [{44=>nil, 35=>nil}, 35, "X:C", false], [{44=>nil, 35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{44=>nil, 35=>nil, 26=>:occupied, 17=>:enemy}, 17, "X:C", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "X:C", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "X:C", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "X:C", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:C", false], [{52=>nil}, 52, "X:C", false], [{52=>nil, 51=>:occupied, 50=>nil, 49=>:enemy}, 49, "X:C", true], [{52=>nil, 51=>:occupied, 50=>nil, 49=>nil, 48=>:enemy}, 48, "X:C", true], [{52=>nil, 51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{52=>nil, 51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{52=>nil, 51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{52=>nil, 51=>:occupied, 50=>:enemy}, 50, "X:C", true], [{52=>nil, 51=>nil}, 51, "X:C", false], [{52=>nil, 51=>nil, 50=>:occupied, 49=>nil, 48=>:enemy}, 48, "X:C", true], [{52=>nil, 51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{52=>nil, 51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{52=>nil, 51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{52=>nil, 51=>nil, 50=>:occupied, 49=>:enemy}, 49, "X:C", true], [{52=>nil, 51=>nil, 50=>nil}, 50, "X:C", false], [{52=>nil, 51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>:enemy}, 47, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>:occupied, 48=>:enemy}, 48, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil}, 49, "X:C", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>:enemy}, 46, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>:enemy}, 47, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "X:C", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>:enemy}, 46, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "X:C", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "X:C", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "X:C", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:C", false], [{62=>nil}, 62, "X:C", false], [{62=>nil, 71=>:occupied, 80=>:enemy}, 80, "X:C", true], [{62=>nil, 71=>nil}, 71, "X:C", false], [{62=>nil, 71=>nil, 80=>nil}, 80, "X:C", false]], 54=>[[{45=>:occupied, 36=>nil, 27=>:enemy}, 27, "X:C", true], [{45=>:occupied, 36=>nil, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{45=>:occupied, 36=>:enemy}, 36, "X:C", true], [{55=>:occupied, 56=>nil, 57=>:enemy}, 57, "X:C", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>:enemy}, 58, "X:C", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "X:C", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{55=>:occupied, 56=>:enemy}, 56, "X:C", true], [{63=>:occupied, 72=>:enemy}, 72, "X:C", true], [{45=>nil}, 45, "X:C", false], [{45=>nil, 36=>:occupied, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{45=>nil, 36=>:occupied, 27=>:enemy}, 27, "X:C", true], [{45=>nil, 36=>nil}, 36, "X:C", false], [{45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{45=>nil, 36=>nil, 27=>:occupied, 18=>:enemy}, 18, "X:C", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "X:C", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>:enemy}, 9, "X:C", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "X:C", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "X:C", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "X:C", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:C", false], [{55=>nil}, 55, "X:C", false], [{55=>nil, 56=>:occupied, 57=>nil, 58=>:enemy}, 58, "X:C", true], [{55=>nil, 56=>:occupied, 57=>nil, 58=>nil, 59=>:enemy}, 59, "X:C", true], [{55=>nil, 56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{55=>nil, 56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{55=>nil, 56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{55=>nil, 56=>:occupied, 57=>:enemy}, 57, "X:C", true], [{55=>nil, 56=>nil}, 56, "X:C", false], [{55=>nil, 56=>nil, 57=>:occupied, 58=>nil, 59=>:enemy}, 59, "X:C", true], [{55=>nil, 56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{55=>nil, 56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{55=>nil, 56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{55=>nil, 56=>nil, 57=>:occupied, 58=>:enemy}, 58, "X:C", true], [{55=>nil, 56=>nil, 57=>nil}, 57, "X:C", false], [{55=>nil, 56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>:occupied, 59=>:enemy}, 59, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil}, 58, "X:C", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>:enemy}, 60, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "X:C", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>:enemy}, 61, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "X:C", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "X:C", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "X:C", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:C", false], [{63=>nil}, 63, "X:C", false], [{63=>nil, 72=>nil}, 72, "X:C", false]], 55=>[[{46=>:occupied, 37=>nil, 28=>:enemy}, 28, "X:C", true], [{46=>:occupied, 37=>nil, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{46=>:occupied, 37=>:enemy}, 37, "X:C", true], [{56=>:occupied, 57=>nil, 58=>:enemy}, 58, "X:C", true], [{56=>:occupied, 57=>nil, 58=>nil, 59=>:enemy}, 59, "X:C", true], [{56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{56=>:occupied, 57=>:enemy}, 57, "X:C", true], [{64=>:occupied, 73=>:enemy}, 73, "X:C", true], [{46=>nil}, 46, "X:C", false], [{46=>nil, 37=>:occupied, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{46=>nil, 37=>:occupied, 28=>:enemy}, 28, "X:C", true], [{46=>nil, 37=>nil}, 37, "X:C", false], [{46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{46=>nil, 37=>nil, 28=>:occupied, 19=>:enemy}, 19, "X:C", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "X:C", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>:enemy}, 10, "X:C", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "X:C", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "X:C", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "X:C", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:C", false], [{54=>nil}, 54, "X:C", false], [{56=>nil}, 56, "X:C", false], [{56=>nil, 57=>:occupied, 58=>nil, 59=>:enemy}, 59, "X:C", true], [{56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{56=>nil, 57=>:occupied, 58=>:enemy}, 58, "X:C", true], [{56=>nil, 57=>nil}, 57, "X:C", false], [{56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{56=>nil, 57=>nil, 58=>:occupied, 59=>:enemy}, 59, "X:C", true], [{56=>nil, 57=>nil, 58=>nil}, 58, "X:C", false], [{56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>:enemy}, 60, "X:C", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "X:C", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>:enemy}, 61, "X:C", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "X:C", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "X:C", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "X:C", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:C", false], [{64=>nil}, 64, "X:C", false], [{64=>nil, 73=>nil}, 73, "X:C", false]], 56=>[[{47=>:occupied, 38=>nil, 29=>:enemy}, 29, "X:C", true], [{47=>:occupied, 38=>nil, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{47=>:occupied, 38=>:enemy}, 38, "X:C", true], [{55=>:occupied, 54=>:enemy}, 54, "X:C", true], [{57=>:occupied, 58=>nil, 59=>:enemy}, 59, "X:C", true], [{57=>:occupied, 58=>nil, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{57=>:occupied, 58=>:enemy}, 58, "X:C", true], [{65=>:occupied, 74=>:enemy}, 74, "X:C", true], [{47=>nil}, 47, "X:C", false], [{47=>nil, 38=>:occupied, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{47=>nil, 38=>:occupied, 29=>:enemy}, 29, "X:C", true], [{47=>nil, 38=>nil}, 38, "X:C", false], [{47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{47=>nil, 38=>nil, 29=>:occupied, 20=>:enemy}, 20, "X:C", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "X:C", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>:enemy}, 11, "X:C", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "X:C", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "X:C", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "X:C", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:C", false], [{55=>nil}, 55, "X:C", false], [{55=>nil, 54=>nil}, 54, "X:C", false], [{57=>nil}, 57, "X:C", false], [{57=>nil, 58=>:occupied, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{57=>nil, 58=>:occupied, 59=>:enemy}, 59, "X:C", true], [{57=>nil, 58=>nil}, 58, "X:C", false], [{57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{57=>nil, 58=>nil, 59=>:occupied, 60=>:enemy}, 60, "X:C", true], [{57=>nil, 58=>nil, 59=>nil}, 59, "X:C", false], [{57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>:enemy}, 61, "X:C", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "X:C", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "X:C", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "X:C", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:C", false], [{65=>nil}, 65, "X:C", false], [{65=>nil, 74=>nil}, 74, "X:C", false]], 57=>[[{48=>:occupied, 39=>nil, 30=>:enemy}, 30, "X:C", true], [{48=>:occupied, 39=>nil, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{48=>:occupied, 39=>:enemy}, 39, "X:C", true], [{56=>:occupied, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{56=>:occupied, 55=>:enemy}, 55, "X:C", true], [{58=>:occupied, 59=>nil, 60=>:enemy}, 60, "X:C", true], [{58=>:occupied, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{58=>:occupied, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{58=>:occupied, 59=>:enemy}, 59, "X:C", true], [{66=>:occupied, 75=>:enemy}, 75, "X:C", true], [{48=>nil}, 48, "X:C", false], [{48=>nil, 39=>:occupied, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{48=>nil, 39=>:occupied, 30=>:enemy}, 30, "X:C", true], [{48=>nil, 39=>nil}, 39, "X:C", false], [{48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{48=>nil, 39=>nil, 30=>:occupied, 21=>:enemy}, 21, "X:C", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "X:C", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>:enemy}, 12, "X:C", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "X:C", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "X:C", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "X:C", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:C", false], [{56=>nil}, 56, "X:C", false], [{56=>nil, 55=>:occupied, 54=>:enemy}, 54, "X:C", true], [{56=>nil, 55=>nil}, 55, "X:C", false], [{56=>nil, 55=>nil, 54=>nil}, 54, "X:C", false], [{58=>nil}, 58, "X:C", false], [{58=>nil, 59=>:occupied, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{58=>nil, 59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{58=>nil, 59=>:occupied, 60=>:enemy}, 60, "X:C", true], [{58=>nil, 59=>nil}, 59, "X:C", false], [{58=>nil, 59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{58=>nil, 59=>nil, 60=>:occupied, 61=>:enemy}, 61, "X:C", true], [{58=>nil, 59=>nil, 60=>nil}, 60, "X:C", false], [{58=>nil, 59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "X:C", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "X:C", false], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:C", false], [{66=>nil}, 66, "X:C", false], [{66=>nil, 75=>nil}, 75, "X:C", false]], 58=>[[{49=>:occupied, 40=>nil, 31=>:enemy}, 31, "X:C", true], [{49=>:occupied, 40=>nil, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{49=>:occupied, 40=>:enemy}, 40, "X:C", true], [{57=>:occupied, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{57=>:occupied, 56=>:enemy}, 56, "X:C", true], [{59=>:occupied, 60=>nil, 61=>:enemy}, 61, "X:C", true], [{59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{59=>:occupied, 60=>:enemy}, 60, "X:C", true], [{67=>:occupied, 76=>:enemy}, 76, "X:C", true], [{49=>nil}, 49, "X:C", false], [{49=>nil, 40=>:occupied, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{49=>nil, 40=>:occupied, 31=>:enemy}, 31, "X:C", true], [{49=>nil, 40=>nil}, 40, "X:C", false], [{49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{49=>nil, 40=>nil, 31=>:occupied, 22=>:enemy}, 22, "X:C", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "X:C", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>:enemy}, 13, "X:C", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "X:C", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "X:C", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "X:C", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:C", false], [{57=>nil}, 57, "X:C", false], [{57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{57=>nil, 56=>:occupied, 55=>:enemy}, 55, "X:C", true], [{57=>nil, 56=>nil}, 56, "X:C", false], [{57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "X:C", true], [{57=>nil, 56=>nil, 55=>nil}, 55, "X:C", false], [{57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:C", false], [{59=>nil}, 59, "X:C", false], [{59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{59=>nil, 60=>:occupied, 61=>:enemy}, 61, "X:C", true], [{59=>nil, 60=>nil}, 60, "X:C", false], [{59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "X:C", true], [{59=>nil, 60=>nil, 61=>nil}, 61, "X:C", false], [{59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:C", false], [{67=>nil}, 67, "X:C", false], [{67=>nil, 76=>nil}, 76, "X:C", false]], 59=>[[{50=>:occupied, 41=>nil, 32=>:enemy}, 32, "X:C", true], [{50=>:occupied, 41=>nil, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{50=>:occupied, 41=>:enemy}, 41, "X:C", true], [{58=>:occupied, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{58=>:occupied, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{58=>:occupied, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{58=>:occupied, 57=>:enemy}, 57, "X:C", true], [{60=>:occupied, 61=>nil, 62=>:enemy}, 62, "X:C", true], [{60=>:occupied, 61=>:enemy}, 61, "X:C", true], [{68=>:occupied, 77=>:enemy}, 77, "X:C", true], [{50=>nil}, 50, "X:C", false], [{50=>nil, 41=>:occupied, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{50=>nil, 41=>:occupied, 32=>:enemy}, 32, "X:C", true], [{50=>nil, 41=>nil}, 41, "X:C", false], [{50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{50=>nil, 41=>nil, 32=>:occupied, 23=>:enemy}, 23, "X:C", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "X:C", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>:enemy}, 14, "X:C", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "X:C", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "X:C", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "X:C", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:C", false], [{58=>nil}, 58, "X:C", false], [{58=>nil, 57=>:occupied, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{58=>nil, 57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{58=>nil, 57=>:occupied, 56=>:enemy}, 56, "X:C", true], [{58=>nil, 57=>nil}, 57, "X:C", false], [{58=>nil, 57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{58=>nil, 57=>nil, 56=>:occupied, 55=>:enemy}, 55, "X:C", true], [{58=>nil, 57=>nil, 56=>nil}, 56, "X:C", false], [{58=>nil, 57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "X:C", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "X:C", false], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:C", false], [{60=>nil}, 60, "X:C", false], [{60=>nil, 61=>:occupied, 62=>:enemy}, 62, "X:C", true], [{60=>nil, 61=>nil}, 61, "X:C", false], [{60=>nil, 61=>nil, 62=>nil}, 62, "X:C", false], [{68=>nil}, 68, "X:C", false], [{68=>nil, 77=>nil}, 77, "X:C", false]], 60=>[[{51=>:occupied, 42=>nil, 33=>:enemy}, 33, "X:C", true], [{51=>:occupied, 42=>nil, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{51=>:occupied, 42=>:enemy}, 42, "X:C", true], [{59=>:occupied, 58=>nil, 57=>:enemy}, 57, "X:C", true], [{59=>:occupied, 58=>nil, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{59=>:occupied, 58=>:enemy}, 58, "X:C", true], [{61=>:occupied, 62=>:enemy}, 62, "X:C", true], [{69=>:occupied, 78=>:enemy}, 78, "X:C", true], [{51=>nil}, 51, "X:C", false], [{51=>nil, 42=>:occupied, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{51=>nil, 42=>:occupied, 33=>:enemy}, 33, "X:C", true], [{51=>nil, 42=>nil}, 42, "X:C", false], [{51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{51=>nil, 42=>nil, 33=>:occupied, 24=>:enemy}, 24, "X:C", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "X:C", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>:enemy}, 15, "X:C", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "X:C", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "X:C", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "X:C", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:C", false], [{59=>nil}, 59, "X:C", false], [{59=>nil, 58=>:occupied, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{59=>nil, 58=>:occupied, 57=>:enemy}, 57, "X:C", true], [{59=>nil, 58=>nil}, 58, "X:C", false], [{59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{59=>nil, 58=>nil, 57=>:occupied, 56=>:enemy}, 56, "X:C", true], [{59=>nil, 58=>nil, 57=>nil}, 57, "X:C", false], [{59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>:enemy}, 55, "X:C", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "X:C", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "X:C", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "X:C", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:C", false], [{61=>nil}, 61, "X:C", false], [{61=>nil, 62=>nil}, 62, "X:C", false], [{69=>nil}, 69, "X:C", false], [{69=>nil, 78=>nil}, 78, "X:C", false]], 61=>[[{52=>:occupied, 43=>nil, 34=>:enemy}, 34, "X:C", true], [{52=>:occupied, 43=>nil, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{52=>:occupied, 43=>:enemy}, 43, "X:C", true], [{60=>:occupied, 59=>nil, 58=>:enemy}, 58, "X:C", true], [{60=>:occupied, 59=>nil, 58=>nil, 57=>:enemy}, 57, "X:C", true], [{60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{60=>:occupied, 59=>:enemy}, 59, "X:C", true], [{70=>:occupied, 79=>:enemy}, 79, "X:C", true], [{52=>nil}, 52, "X:C", false], [{52=>nil, 43=>:occupied, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{52=>nil, 43=>:occupied, 34=>:enemy}, 34, "X:C", true], [{52=>nil, 43=>nil}, 43, "X:C", false], [{52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{52=>nil, 43=>nil, 34=>:occupied, 25=>:enemy}, 25, "X:C", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "X:C", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>:enemy}, 16, "X:C", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "X:C", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "X:C", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "X:C", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:C", false], [{60=>nil}, 60, "X:C", false], [{60=>nil, 59=>:occupied, 58=>nil, 57=>:enemy}, 57, "X:C", true], [{60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{60=>nil, 59=>:occupied, 58=>:enemy}, 58, "X:C", true], [{60=>nil, 59=>nil}, 59, "X:C", false], [{60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{60=>nil, 59=>nil, 58=>:occupied, 57=>:enemy}, 57, "X:C", true], [{60=>nil, 59=>nil, 58=>nil}, 58, "X:C", false], [{60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>:enemy}, 56, "X:C", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "X:C", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>:enemy}, 55, "X:C", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "X:C", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "X:C", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "X:C", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:C", false], [{62=>nil}, 62, "X:C", false], [{70=>nil}, 70, "X:C", false], [{70=>nil, 79=>nil}, 79, "X:C", false]], 62=>[[{53=>:occupied, 44=>nil, 35=>:enemy}, 35, "X:C", true], [{53=>:occupied, 44=>nil, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{53=>:occupied, 44=>:enemy}, 44, "X:C", true], [{61=>:occupied, 60=>nil, 59=>:enemy}, 59, "X:C", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>:enemy}, 58, "X:C", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "X:C", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{61=>:occupied, 60=>:enemy}, 60, "X:C", true], [{71=>:occupied, 80=>:enemy}, 80, "X:C", true], [{53=>nil}, 53, "X:C", false], [{53=>nil, 44=>:occupied, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{53=>nil, 44=>:occupied, 35=>:enemy}, 35, "X:C", true], [{53=>nil, 44=>nil}, 44, "X:C", false], [{53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{53=>nil, 44=>nil, 35=>:occupied, 26=>:enemy}, 26, "X:C", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "X:C", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>:enemy}, 17, "X:C", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "X:C", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "X:C", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "X:C", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:C", false], [{61=>nil}, 61, "X:C", false], [{61=>nil, 60=>:occupied, 59=>nil, 58=>:enemy}, 58, "X:C", true], [{61=>nil, 60=>:occupied, 59=>nil, 58=>nil, 57=>:enemy}, 57, "X:C", true], [{61=>nil, 60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{61=>nil, 60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{61=>nil, 60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{61=>nil, 60=>:occupied, 59=>:enemy}, 59, "X:C", true], [{61=>nil, 60=>nil}, 60, "X:C", false], [{61=>nil, 60=>nil, 59=>:occupied, 58=>nil, 57=>:enemy}, 57, "X:C", true], [{61=>nil, 60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{61=>nil, 60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{61=>nil, 60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{61=>nil, 60=>nil, 59=>:occupied, 58=>:enemy}, 58, "X:C", true], [{61=>nil, 60=>nil, 59=>nil}, 59, "X:C", false], [{61=>nil, 60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>:enemy}, 56, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>:occupied, 57=>:enemy}, 57, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil}, 58, "X:C", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>:enemy}, 55, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>:enemy}, 56, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "X:C", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>:enemy}, 55, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "X:C", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "X:C", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "X:C", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:C", false], [{71=>nil}, 71, "X:C", false], [{71=>nil, 80=>nil}, 80, "X:C", false]], 63=>[[{54=>:occupied, 45=>nil, 36=>:enemy}, 36, "X:C", true], [{54=>:occupied, 45=>nil, 36=>nil, 27=>:enemy}, 27, "X:C", true], [{54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{54=>:occupied, 45=>:enemy}, 45, "X:C", true], [{64=>:occupied, 65=>nil, 66=>:enemy}, 66, "X:C", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>:enemy}, 67, "X:C", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "X:C", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{64=>:occupied, 65=>:enemy}, 65, "X:C", true], [{54=>nil}, 54, "X:C", false], [{54=>nil, 45=>:occupied, 36=>nil, 27=>:enemy}, 27, "X:C", true], [{54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{54=>nil, 45=>:occupied, 36=>:enemy}, 36, "X:C", true], [{54=>nil, 45=>nil}, 45, "X:C", false], [{54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{54=>nil, 45=>nil, 36=>:occupied, 27=>:enemy}, 27, "X:C", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "X:C", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>:enemy}, 18, "X:C", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "X:C", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>:enemy}, 9, "X:C", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "X:C", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "X:C", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "X:C", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:C", false], [{64=>nil}, 64, "X:C", false], [{64=>nil, 65=>:occupied, 66=>nil, 67=>:enemy}, 67, "X:C", true], [{64=>nil, 65=>:occupied, 66=>nil, 67=>nil, 68=>:enemy}, 68, "X:C", true], [{64=>nil, 65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{64=>nil, 65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{64=>nil, 65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{64=>nil, 65=>:occupied, 66=>:enemy}, 66, "X:C", true], [{64=>nil, 65=>nil}, 65, "X:C", false], [{64=>nil, 65=>nil, 66=>:occupied, 67=>nil, 68=>:enemy}, 68, "X:C", true], [{64=>nil, 65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{64=>nil, 65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{64=>nil, 65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{64=>nil, 65=>nil, 66=>:occupied, 67=>:enemy}, 67, "X:C", true], [{64=>nil, 65=>nil, 66=>nil}, 66, "X:C", false], [{64=>nil, 65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>:occupied, 68=>:enemy}, 68, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil}, 67, "X:C", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>:enemy}, 69, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "X:C", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>:enemy}, 70, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "X:C", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "X:C", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "X:C", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:C", false], [{72=>nil}, 72, "X:C", false]], 64=>[[{55=>:occupied, 46=>nil, 37=>:enemy}, 37, "X:C", true], [{55=>:occupied, 46=>nil, 37=>nil, 28=>:enemy}, 28, "X:C", true], [{55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{55=>:occupied, 46=>:enemy}, 46, "X:C", true], [{65=>:occupied, 66=>nil, 67=>:enemy}, 67, "X:C", true], [{65=>:occupied, 66=>nil, 67=>nil, 68=>:enemy}, 68, "X:C", true], [{65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{65=>:occupied, 66=>:enemy}, 66, "X:C", true], [{55=>nil}, 55, "X:C", false], [{55=>nil, 46=>:occupied, 37=>nil, 28=>:enemy}, 28, "X:C", true], [{55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{55=>nil, 46=>:occupied, 37=>:enemy}, 37, "X:C", true], [{55=>nil, 46=>nil}, 46, "X:C", false], [{55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{55=>nil, 46=>nil, 37=>:occupied, 28=>:enemy}, 28, "X:C", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "X:C", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>:enemy}, 19, "X:C", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "X:C", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>:enemy}, 10, "X:C", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "X:C", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "X:C", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "X:C", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:C", false], [{63=>nil}, 63, "X:C", false], [{65=>nil}, 65, "X:C", false], [{65=>nil, 66=>:occupied, 67=>nil, 68=>:enemy}, 68, "X:C", true], [{65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{65=>nil, 66=>:occupied, 67=>:enemy}, 67, "X:C", true], [{65=>nil, 66=>nil}, 66, "X:C", false], [{65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{65=>nil, 66=>nil, 67=>:occupied, 68=>:enemy}, 68, "X:C", true], [{65=>nil, 66=>nil, 67=>nil}, 67, "X:C", false], [{65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>:enemy}, 69, "X:C", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "X:C", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>:enemy}, 70, "X:C", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "X:C", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "X:C", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "X:C", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:C", false], [{73=>nil}, 73, "X:C", false]], 65=>[[{56=>:occupied, 47=>nil, 38=>:enemy}, 38, "X:C", true], [{56=>:occupied, 47=>nil, 38=>nil, 29=>:enemy}, 29, "X:C", true], [{56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{56=>:occupied, 47=>:enemy}, 47, "X:C", true], [{64=>:occupied, 63=>:enemy}, 63, "X:C", true], [{66=>:occupied, 67=>nil, 68=>:enemy}, 68, "X:C", true], [{66=>:occupied, 67=>nil, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{66=>:occupied, 67=>:enemy}, 67, "X:C", true], [{56=>nil}, 56, "X:C", false], [{56=>nil, 47=>:occupied, 38=>nil, 29=>:enemy}, 29, "X:C", true], [{56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{56=>nil, 47=>:occupied, 38=>:enemy}, 38, "X:C", true], [{56=>nil, 47=>nil}, 47, "X:C", false], [{56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{56=>nil, 47=>nil, 38=>:occupied, 29=>:enemy}, 29, "X:C", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "X:C", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>:enemy}, 20, "X:C", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "X:C", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>:enemy}, 11, "X:C", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "X:C", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "X:C", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "X:C", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:C", false], [{64=>nil}, 64, "X:C", false], [{64=>nil, 63=>nil}, 63, "X:C", false], [{66=>nil}, 66, "X:C", false], [{66=>nil, 67=>:occupied, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{66=>nil, 67=>:occupied, 68=>:enemy}, 68, "X:C", true], [{66=>nil, 67=>nil}, 67, "X:C", false], [{66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{66=>nil, 67=>nil, 68=>:occupied, 69=>:enemy}, 69, "X:C", true], [{66=>nil, 67=>nil, 68=>nil}, 68, "X:C", false], [{66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>:enemy}, 70, "X:C", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "X:C", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "X:C", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "X:C", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:C", false], [{74=>nil}, 74, "X:C", false]], 66=>[[{57=>:occupied, 48=>nil, 39=>:enemy}, 39, "X:C", true], [{57=>:occupied, 48=>nil, 39=>nil, 30=>:enemy}, 30, "X:C", true], [{57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{57=>:occupied, 48=>:enemy}, 48, "X:C", true], [{65=>:occupied, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{65=>:occupied, 64=>:enemy}, 64, "X:C", true], [{67=>:occupied, 68=>nil, 69=>:enemy}, 69, "X:C", true], [{67=>:occupied, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{67=>:occupied, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{67=>:occupied, 68=>:enemy}, 68, "X:C", true], [{57=>nil}, 57, "X:C", false], [{57=>nil, 48=>:occupied, 39=>nil, 30=>:enemy}, 30, "X:C", true], [{57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{57=>nil, 48=>:occupied, 39=>:enemy}, 39, "X:C", true], [{57=>nil, 48=>nil}, 48, "X:C", false], [{57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{57=>nil, 48=>nil, 39=>:occupied, 30=>:enemy}, 30, "X:C", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "X:C", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>:enemy}, 21, "X:C", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "X:C", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>:enemy}, 12, "X:C", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "X:C", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "X:C", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "X:C", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:C", false], [{65=>nil}, 65, "X:C", false], [{65=>nil, 64=>:occupied, 63=>:enemy}, 63, "X:C", true], [{65=>nil, 64=>nil}, 64, "X:C", false], [{65=>nil, 64=>nil, 63=>nil}, 63, "X:C", false], [{67=>nil}, 67, "X:C", false], [{67=>nil, 68=>:occupied, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{67=>nil, 68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{67=>nil, 68=>:occupied, 69=>:enemy}, 69, "X:C", true], [{67=>nil, 68=>nil}, 68, "X:C", false], [{67=>nil, 68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{67=>nil, 68=>nil, 69=>:occupied, 70=>:enemy}, 70, "X:C", true], [{67=>nil, 68=>nil, 69=>nil}, 69, "X:C", false], [{67=>nil, 68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "X:C", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "X:C", false], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:C", false], [{75=>nil}, 75, "X:C", false]], 67=>[[{58=>:occupied, 49=>nil, 40=>:enemy}, 40, "X:C", true], [{58=>:occupied, 49=>nil, 40=>nil, 31=>:enemy}, 31, "X:C", true], [{58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{58=>:occupied, 49=>:enemy}, 49, "X:C", true], [{66=>:occupied, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{66=>:occupied, 65=>:enemy}, 65, "X:C", true], [{68=>:occupied, 69=>nil, 70=>:enemy}, 70, "X:C", true], [{68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{68=>:occupied, 69=>:enemy}, 69, "X:C", true], [{58=>nil}, 58, "X:C", false], [{58=>nil, 49=>:occupied, 40=>nil, 31=>:enemy}, 31, "X:C", true], [{58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{58=>nil, 49=>:occupied, 40=>:enemy}, 40, "X:C", true], [{58=>nil, 49=>nil}, 49, "X:C", false], [{58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{58=>nil, 49=>nil, 40=>:occupied, 31=>:enemy}, 31, "X:C", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "X:C", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>:enemy}, 22, "X:C", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "X:C", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>:enemy}, 13, "X:C", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "X:C", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "X:C", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "X:C", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:C", false], [{66=>nil}, 66, "X:C", false], [{66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{66=>nil, 65=>:occupied, 64=>:enemy}, 64, "X:C", true], [{66=>nil, 65=>nil}, 65, "X:C", false], [{66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "X:C", true], [{66=>nil, 65=>nil, 64=>nil}, 64, "X:C", false], [{66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:C", false], [{68=>nil}, 68, "X:C", false], [{68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{68=>nil, 69=>:occupied, 70=>:enemy}, 70, "X:C", true], [{68=>nil, 69=>nil}, 69, "X:C", false], [{68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "X:C", true], [{68=>nil, 69=>nil, 70=>nil}, 70, "X:C", false], [{68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:C", false], [{76=>nil}, 76, "X:C", false]], 68=>[[{59=>:occupied, 50=>nil, 41=>:enemy}, 41, "X:C", true], [{59=>:occupied, 50=>nil, 41=>nil, 32=>:enemy}, 32, "X:C", true], [{59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{59=>:occupied, 50=>:enemy}, 50, "X:C", true], [{67=>:occupied, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{67=>:occupied, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{67=>:occupied, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{67=>:occupied, 66=>:enemy}, 66, "X:C", true], [{69=>:occupied, 70=>nil, 71=>:enemy}, 71, "X:C", true], [{69=>:occupied, 70=>:enemy}, 70, "X:C", true], [{59=>nil}, 59, "X:C", false], [{59=>nil, 50=>:occupied, 41=>nil, 32=>:enemy}, 32, "X:C", true], [{59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{59=>nil, 50=>:occupied, 41=>:enemy}, 41, "X:C", true], [{59=>nil, 50=>nil}, 50, "X:C", false], [{59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{59=>nil, 50=>nil, 41=>:occupied, 32=>:enemy}, 32, "X:C", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "X:C", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>:enemy}, 23, "X:C", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "X:C", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>:enemy}, 14, "X:C", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "X:C", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "X:C", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "X:C", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:C", false], [{67=>nil}, 67, "X:C", false], [{67=>nil, 66=>:occupied, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{67=>nil, 66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{67=>nil, 66=>:occupied, 65=>:enemy}, 65, "X:C", true], [{67=>nil, 66=>nil}, 66, "X:C", false], [{67=>nil, 66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{67=>nil, 66=>nil, 65=>:occupied, 64=>:enemy}, 64, "X:C", true], [{67=>nil, 66=>nil, 65=>nil}, 65, "X:C", false], [{67=>nil, 66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "X:C", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "X:C", false], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:C", false], [{69=>nil}, 69, "X:C", false], [{69=>nil, 70=>:occupied, 71=>:enemy}, 71, "X:C", true], [{69=>nil, 70=>nil}, 70, "X:C", false], [{69=>nil, 70=>nil, 71=>nil}, 71, "X:C", false], [{77=>nil}, 77, "X:C", false]], 69=>[[{60=>:occupied, 51=>nil, 42=>:enemy}, 42, "X:C", true], [{60=>:occupied, 51=>nil, 42=>nil, 33=>:enemy}, 33, "X:C", true], [{60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{60=>:occupied, 51=>:enemy}, 51, "X:C", true], [{68=>:occupied, 67=>nil, 66=>:enemy}, 66, "X:C", true], [{68=>:occupied, 67=>nil, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{68=>:occupied, 67=>:enemy}, 67, "X:C", true], [{70=>:occupied, 71=>:enemy}, 71, "X:C", true], [{60=>nil}, 60, "X:C", false], [{60=>nil, 51=>:occupied, 42=>nil, 33=>:enemy}, 33, "X:C", true], [{60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{60=>nil, 51=>:occupied, 42=>:enemy}, 42, "X:C", true], [{60=>nil, 51=>nil}, 51, "X:C", false], [{60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{60=>nil, 51=>nil, 42=>:occupied, 33=>:enemy}, 33, "X:C", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "X:C", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>:enemy}, 24, "X:C", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "X:C", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>:enemy}, 15, "X:C", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "X:C", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "X:C", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "X:C", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:C", false], [{68=>nil}, 68, "X:C", false], [{68=>nil, 67=>:occupied, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{68=>nil, 67=>:occupied, 66=>:enemy}, 66, "X:C", true], [{68=>nil, 67=>nil}, 67, "X:C", false], [{68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{68=>nil, 67=>nil, 66=>:occupied, 65=>:enemy}, 65, "X:C", true], [{68=>nil, 67=>nil, 66=>nil}, 66, "X:C", false], [{68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>:enemy}, 64, "X:C", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "X:C", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "X:C", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "X:C", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:C", false], [{70=>nil}, 70, "X:C", false], [{70=>nil, 71=>nil}, 71, "X:C", false], [{78=>nil}, 78, "X:C", false]], 70=>[[{61=>:occupied, 52=>nil, 43=>:enemy}, 43, "X:C", true], [{61=>:occupied, 52=>nil, 43=>nil, 34=>:enemy}, 34, "X:C", true], [{61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{61=>:occupied, 52=>:enemy}, 52, "X:C", true], [{69=>:occupied, 68=>nil, 67=>:enemy}, 67, "X:C", true], [{69=>:occupied, 68=>nil, 67=>nil, 66=>:enemy}, 66, "X:C", true], [{69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{69=>:occupied, 68=>:enemy}, 68, "X:C", true], [{61=>nil}, 61, "X:C", false], [{61=>nil, 52=>:occupied, 43=>nil, 34=>:enemy}, 34, "X:C", true], [{61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{61=>nil, 52=>:occupied, 43=>:enemy}, 43, "X:C", true], [{61=>nil, 52=>nil}, 52, "X:C", false], [{61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{61=>nil, 52=>nil, 43=>:occupied, 34=>:enemy}, 34, "X:C", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "X:C", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>:enemy}, 25, "X:C", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "X:C", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>:enemy}, 16, "X:C", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "X:C", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "X:C", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "X:C", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:C", false], [{69=>nil}, 69, "X:C", false], [{69=>nil, 68=>:occupied, 67=>nil, 66=>:enemy}, 66, "X:C", true], [{69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{69=>nil, 68=>:occupied, 67=>:enemy}, 67, "X:C", true], [{69=>nil, 68=>nil}, 68, "X:C", false], [{69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{69=>nil, 68=>nil, 67=>:occupied, 66=>:enemy}, 66, "X:C", true], [{69=>nil, 68=>nil, 67=>nil}, 67, "X:C", false], [{69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>:enemy}, 65, "X:C", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "X:C", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>:enemy}, 64, "X:C", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "X:C", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "X:C", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "X:C", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:C", false], [{71=>nil}, 71, "X:C", false], [{79=>nil}, 79, "X:C", false]], 71=>[[{62=>:occupied, 53=>nil, 44=>:enemy}, 44, "X:C", true], [{62=>:occupied, 53=>nil, 44=>nil, 35=>:enemy}, 35, "X:C", true], [{62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{62=>:occupied, 53=>:enemy}, 53, "X:C", true], [{70=>:occupied, 69=>nil, 68=>:enemy}, 68, "X:C", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>:enemy}, 67, "X:C", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "X:C", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{70=>:occupied, 69=>:enemy}, 69, "X:C", true], [{62=>nil}, 62, "X:C", false], [{62=>nil, 53=>:occupied, 44=>nil, 35=>:enemy}, 35, "X:C", true], [{62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{62=>nil, 53=>:occupied, 44=>:enemy}, 44, "X:C", true], [{62=>nil, 53=>nil}, 53, "X:C", false], [{62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{62=>nil, 53=>nil, 44=>:occupied, 35=>:enemy}, 35, "X:C", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "X:C", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>:enemy}, 26, "X:C", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "X:C", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>:enemy}, 17, "X:C", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "X:C", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "X:C", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "X:C", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:C", false], [{70=>nil}, 70, "X:C", false], [{70=>nil, 69=>:occupied, 68=>nil, 67=>:enemy}, 67, "X:C", true], [{70=>nil, 69=>:occupied, 68=>nil, 67=>nil, 66=>:enemy}, 66, "X:C", true], [{70=>nil, 69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{70=>nil, 69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{70=>nil, 69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{70=>nil, 69=>:occupied, 68=>:enemy}, 68, "X:C", true], [{70=>nil, 69=>nil}, 69, "X:C", false], [{70=>nil, 69=>nil, 68=>:occupied, 67=>nil, 66=>:enemy}, 66, "X:C", true], [{70=>nil, 69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{70=>nil, 69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{70=>nil, 69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{70=>nil, 69=>nil, 68=>:occupied, 67=>:enemy}, 67, "X:C", true], [{70=>nil, 69=>nil, 68=>nil}, 68, "X:C", false], [{70=>nil, 69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>:enemy}, 65, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>:occupied, 66=>:enemy}, 66, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil}, 67, "X:C", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>:enemy}, 64, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>:enemy}, 65, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "X:C", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>:enemy}, 64, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "X:C", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "X:C", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "X:C", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:C", false], [{80=>nil}, 80, "X:C", false]], 72=>[[{63=>:occupied, 54=>nil, 45=>:enemy}, 45, "X:C", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>:enemy}, 36, "X:C", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "X:C", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{63=>:occupied, 54=>:enemy}, 54, "X:C", true], [{73=>:occupied, 74=>nil, 75=>:enemy}, 75, "X:C", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>:enemy}, 76, "X:C", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "X:C", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{73=>:occupied, 74=>:enemy}, 74, "X:C", true], [{63=>nil}, 63, "X:C", false], [{63=>nil, 54=>:occupied, 45=>nil, 36=>:enemy}, 36, "X:C", true], [{63=>nil, 54=>:occupied, 45=>nil, 36=>nil, 27=>:enemy}, 27, "X:C", true], [{63=>nil, 54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{63=>nil, 54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{63=>nil, 54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{63=>nil, 54=>:occupied, 45=>:enemy}, 45, "X:C", true], [{63=>nil, 54=>nil}, 54, "X:C", false], [{63=>nil, 54=>nil, 45=>:occupied, 36=>nil, 27=>:enemy}, 27, "X:C", true], [{63=>nil, 54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{63=>nil, 54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{63=>nil, 54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{63=>nil, 54=>nil, 45=>:occupied, 36=>:enemy}, 36, "X:C", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "X:C", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>:enemy}, 18, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>:occupied, 27=>:enemy}, 27, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "X:C", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>:enemy}, 9, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>:enemy}, 18, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "X:C", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>:enemy}, 9, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "X:C", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "X:C", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "X:C", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:C", false], [{73=>nil}, 73, "X:C", false], [{73=>nil, 74=>:occupied, 75=>nil, 76=>:enemy}, 76, "X:C", true], [{73=>nil, 74=>:occupied, 75=>nil, 76=>nil, 77=>:enemy}, 77, "X:C", true], [{73=>nil, 74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{73=>nil, 74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{73=>nil, 74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{73=>nil, 74=>:occupied, 75=>:enemy}, 75, "X:C", true], [{73=>nil, 74=>nil}, 74, "X:C", false], [{73=>nil, 74=>nil, 75=>:occupied, 76=>nil, 77=>:enemy}, 77, "X:C", true], [{73=>nil, 74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{73=>nil, 74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{73=>nil, 74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{73=>nil, 74=>nil, 75=>:occupied, 76=>:enemy}, 76, "X:C", true], [{73=>nil, 74=>nil, 75=>nil}, 75, "X:C", false], [{73=>nil, 74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>:occupied, 77=>:enemy}, 77, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil}, 76, "X:C", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>:enemy}, 78, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "X:C", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>:enemy}, 79, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "X:C", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "X:C", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "X:C", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:C", false]], 73=>[[{64=>:occupied, 55=>nil, 46=>:enemy}, 46, "X:C", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>:enemy}, 37, "X:C", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "X:C", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{64=>:occupied, 55=>:enemy}, 55, "X:C", true], [{74=>:occupied, 75=>nil, 76=>:enemy}, 76, "X:C", true], [{74=>:occupied, 75=>nil, 76=>nil, 77=>:enemy}, 77, "X:C", true], [{74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{74=>:occupied, 75=>:enemy}, 75, "X:C", true], [{64=>nil}, 64, "X:C", false], [{64=>nil, 55=>:occupied, 46=>nil, 37=>:enemy}, 37, "X:C", true], [{64=>nil, 55=>:occupied, 46=>nil, 37=>nil, 28=>:enemy}, 28, "X:C", true], [{64=>nil, 55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{64=>nil, 55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{64=>nil, 55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{64=>nil, 55=>:occupied, 46=>:enemy}, 46, "X:C", true], [{64=>nil, 55=>nil}, 55, "X:C", false], [{64=>nil, 55=>nil, 46=>:occupied, 37=>nil, 28=>:enemy}, 28, "X:C", true], [{64=>nil, 55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{64=>nil, 55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{64=>nil, 55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{64=>nil, 55=>nil, 46=>:occupied, 37=>:enemy}, 37, "X:C", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "X:C", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>:enemy}, 19, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>:occupied, 28=>:enemy}, 28, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "X:C", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>:enemy}, 10, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>:enemy}, 19, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "X:C", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>:enemy}, 10, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "X:C", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "X:C", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "X:C", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:C", false], [{72=>nil}, 72, "X:C", false], [{74=>nil}, 74, "X:C", false], [{74=>nil, 75=>:occupied, 76=>nil, 77=>:enemy}, 77, "X:C", true], [{74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{74=>nil, 75=>:occupied, 76=>:enemy}, 76, "X:C", true], [{74=>nil, 75=>nil}, 75, "X:C", false], [{74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{74=>nil, 75=>nil, 76=>:occupied, 77=>:enemy}, 77, "X:C", true], [{74=>nil, 75=>nil, 76=>nil}, 76, "X:C", false], [{74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>:enemy}, 78, "X:C", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "X:C", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>:enemy}, 79, "X:C", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "X:C", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "X:C", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "X:C", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:C", false]], 74=>[[{65=>:occupied, 56=>nil, 47=>:enemy}, 47, "X:C", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>:enemy}, 38, "X:C", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "X:C", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{65=>:occupied, 56=>:enemy}, 56, "X:C", true], [{73=>:occupied, 72=>:enemy}, 72, "X:C", true], [{75=>:occupied, 76=>nil, 77=>:enemy}, 77, "X:C", true], [{75=>:occupied, 76=>nil, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{75=>:occupied, 76=>:enemy}, 76, "X:C", true], [{65=>nil}, 65, "X:C", false], [{65=>nil, 56=>:occupied, 47=>nil, 38=>:enemy}, 38, "X:C", true], [{65=>nil, 56=>:occupied, 47=>nil, 38=>nil, 29=>:enemy}, 29, "X:C", true], [{65=>nil, 56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{65=>nil, 56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{65=>nil, 56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{65=>nil, 56=>:occupied, 47=>:enemy}, 47, "X:C", true], [{65=>nil, 56=>nil}, 56, "X:C", false], [{65=>nil, 56=>nil, 47=>:occupied, 38=>nil, 29=>:enemy}, 29, "X:C", true], [{65=>nil, 56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{65=>nil, 56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{65=>nil, 56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{65=>nil, 56=>nil, 47=>:occupied, 38=>:enemy}, 38, "X:C", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "X:C", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>:enemy}, 20, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>:occupied, 29=>:enemy}, 29, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "X:C", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>:enemy}, 11, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>:enemy}, 20, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "X:C", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>:enemy}, 11, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "X:C", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "X:C", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "X:C", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:C", false], [{73=>nil}, 73, "X:C", false], [{73=>nil, 72=>nil}, 72, "X:C", false], [{75=>nil}, 75, "X:C", false], [{75=>nil, 76=>:occupied, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{75=>nil, 76=>:occupied, 77=>:enemy}, 77, "X:C", true], [{75=>nil, 76=>nil}, 76, "X:C", false], [{75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{75=>nil, 76=>nil, 77=>:occupied, 78=>:enemy}, 78, "X:C", true], [{75=>nil, 76=>nil, 77=>nil}, 77, "X:C", false], [{75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>:enemy}, 79, "X:C", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "X:C", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "X:C", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "X:C", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:C", false]], 75=>[[{66=>:occupied, 57=>nil, 48=>:enemy}, 48, "X:C", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>:enemy}, 39, "X:C", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "X:C", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{66=>:occupied, 57=>:enemy}, 57, "X:C", true], [{74=>:occupied, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{74=>:occupied, 73=>:enemy}, 73, "X:C", true], [{76=>:occupied, 77=>nil, 78=>:enemy}, 78, "X:C", true], [{76=>:occupied, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{76=>:occupied, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{76=>:occupied, 77=>:enemy}, 77, "X:C", true], [{66=>nil}, 66, "X:C", false], [{66=>nil, 57=>:occupied, 48=>nil, 39=>:enemy}, 39, "X:C", true], [{66=>nil, 57=>:occupied, 48=>nil, 39=>nil, 30=>:enemy}, 30, "X:C", true], [{66=>nil, 57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{66=>nil, 57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{66=>nil, 57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{66=>nil, 57=>:occupied, 48=>:enemy}, 48, "X:C", true], [{66=>nil, 57=>nil}, 57, "X:C", false], [{66=>nil, 57=>nil, 48=>:occupied, 39=>nil, 30=>:enemy}, 30, "X:C", true], [{66=>nil, 57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{66=>nil, 57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{66=>nil, 57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{66=>nil, 57=>nil, 48=>:occupied, 39=>:enemy}, 39, "X:C", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "X:C", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>:enemy}, 21, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>:occupied, 30=>:enemy}, 30, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "X:C", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>:enemy}, 12, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>:enemy}, 21, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "X:C", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>:enemy}, 12, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "X:C", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "X:C", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "X:C", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:C", false], [{74=>nil}, 74, "X:C", false], [{74=>nil, 73=>:occupied, 72=>:enemy}, 72, "X:C", true], [{74=>nil, 73=>nil}, 73, "X:C", false], [{74=>nil, 73=>nil, 72=>nil}, 72, "X:C", false], [{76=>nil}, 76, "X:C", false], [{76=>nil, 77=>:occupied, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{76=>nil, 77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{76=>nil, 77=>:occupied, 78=>:enemy}, 78, "X:C", true], [{76=>nil, 77=>nil}, 77, "X:C", false], [{76=>nil, 77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{76=>nil, 77=>nil, 78=>:occupied, 79=>:enemy}, 79, "X:C", true], [{76=>nil, 77=>nil, 78=>nil}, 78, "X:C", false], [{76=>nil, 77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "X:C", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "X:C", false], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:C", false]], 76=>[[{67=>:occupied, 58=>nil, 49=>:enemy}, 49, "X:C", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>:enemy}, 40, "X:C", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "X:C", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{67=>:occupied, 58=>:enemy}, 58, "X:C", true], [{75=>:occupied, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{75=>:occupied, 74=>:enemy}, 74, "X:C", true], [{77=>:occupied, 78=>nil, 79=>:enemy}, 79, "X:C", true], [{77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{77=>:occupied, 78=>:enemy}, 78, "X:C", true], [{67=>nil}, 67, "X:C", false], [{67=>nil, 58=>:occupied, 49=>nil, 40=>:enemy}, 40, "X:C", true], [{67=>nil, 58=>:occupied, 49=>nil, 40=>nil, 31=>:enemy}, 31, "X:C", true], [{67=>nil, 58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{67=>nil, 58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{67=>nil, 58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{67=>nil, 58=>:occupied, 49=>:enemy}, 49, "X:C", true], [{67=>nil, 58=>nil}, 58, "X:C", false], [{67=>nil, 58=>nil, 49=>:occupied, 40=>nil, 31=>:enemy}, 31, "X:C", true], [{67=>nil, 58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{67=>nil, 58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{67=>nil, 58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{67=>nil, 58=>nil, 49=>:occupied, 40=>:enemy}, 40, "X:C", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "X:C", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>:enemy}, 22, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>:occupied, 31=>:enemy}, 31, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "X:C", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>:enemy}, 13, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>:enemy}, 22, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "X:C", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>:enemy}, 13, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "X:C", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "X:C", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "X:C", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:C", false], [{75=>nil}, 75, "X:C", false], [{75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{75=>nil, 74=>:occupied, 73=>:enemy}, 73, "X:C", true], [{75=>nil, 74=>nil}, 74, "X:C", false], [{75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "X:C", true], [{75=>nil, 74=>nil, 73=>nil}, 73, "X:C", false], [{75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:C", false], [{77=>nil}, 77, "X:C", false], [{77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{77=>nil, 78=>:occupied, 79=>:enemy}, 79, "X:C", true], [{77=>nil, 78=>nil}, 78, "X:C", false], [{77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "X:C", true], [{77=>nil, 78=>nil, 79=>nil}, 79, "X:C", false], [{77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:C", false]], 77=>[[{68=>:occupied, 59=>nil, 50=>:enemy}, 50, "X:C", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>:enemy}, 41, "X:C", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "X:C", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{68=>:occupied, 59=>:enemy}, 59, "X:C", true], [{76=>:occupied, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{76=>:occupied, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{76=>:occupied, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{76=>:occupied, 75=>:enemy}, 75, "X:C", true], [{78=>:occupied, 79=>nil, 80=>:enemy}, 80, "X:C", true], [{78=>:occupied, 79=>:enemy}, 79, "X:C", true], [{68=>nil}, 68, "X:C", false], [{68=>nil, 59=>:occupied, 50=>nil, 41=>:enemy}, 41, "X:C", true], [{68=>nil, 59=>:occupied, 50=>nil, 41=>nil, 32=>:enemy}, 32, "X:C", true], [{68=>nil, 59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{68=>nil, 59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{68=>nil, 59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{68=>nil, 59=>:occupied, 50=>:enemy}, 50, "X:C", true], [{68=>nil, 59=>nil}, 59, "X:C", false], [{68=>nil, 59=>nil, 50=>:occupied, 41=>nil, 32=>:enemy}, 32, "X:C", true], [{68=>nil, 59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{68=>nil, 59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{68=>nil, 59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{68=>nil, 59=>nil, 50=>:occupied, 41=>:enemy}, 41, "X:C", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "X:C", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>:enemy}, 23, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>:occupied, 32=>:enemy}, 32, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "X:C", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>:enemy}, 14, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>:enemy}, 23, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "X:C", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>:enemy}, 14, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "X:C", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "X:C", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "X:C", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:C", false], [{76=>nil}, 76, "X:C", false], [{76=>nil, 75=>:occupied, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{76=>nil, 75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{76=>nil, 75=>:occupied, 74=>:enemy}, 74, "X:C", true], [{76=>nil, 75=>nil}, 75, "X:C", false], [{76=>nil, 75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{76=>nil, 75=>nil, 74=>:occupied, 73=>:enemy}, 73, "X:C", true], [{76=>nil, 75=>nil, 74=>nil}, 74, "X:C", false], [{76=>nil, 75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "X:C", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "X:C", false], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:C", false], [{78=>nil}, 78, "X:C", false], [{78=>nil, 79=>:occupied, 80=>:enemy}, 80, "X:C", true], [{78=>nil, 79=>nil}, 79, "X:C", false], [{78=>nil, 79=>nil, 80=>nil}, 80, "X:C", false]], 78=>[[{69=>:occupied, 60=>nil, 51=>:enemy}, 51, "X:C", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>:enemy}, 42, "X:C", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "X:C", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{69=>:occupied, 60=>:enemy}, 60, "X:C", true], [{77=>:occupied, 76=>nil, 75=>:enemy}, 75, "X:C", true], [{77=>:occupied, 76=>nil, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{77=>:occupied, 76=>:enemy}, 76, "X:C", true], [{79=>:occupied, 80=>:enemy}, 80, "X:C", true], [{69=>nil}, 69, "X:C", false], [{69=>nil, 60=>:occupied, 51=>nil, 42=>:enemy}, 42, "X:C", true], [{69=>nil, 60=>:occupied, 51=>nil, 42=>nil, 33=>:enemy}, 33, "X:C", true], [{69=>nil, 60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{69=>nil, 60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{69=>nil, 60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{69=>nil, 60=>:occupied, 51=>:enemy}, 51, "X:C", true], [{69=>nil, 60=>nil}, 60, "X:C", false], [{69=>nil, 60=>nil, 51=>:occupied, 42=>nil, 33=>:enemy}, 33, "X:C", true], [{69=>nil, 60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{69=>nil, 60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{69=>nil, 60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{69=>nil, 60=>nil, 51=>:occupied, 42=>:enemy}, 42, "X:C", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "X:C", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>:enemy}, 24, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>:occupied, 33=>:enemy}, 33, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "X:C", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>:enemy}, 15, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>:enemy}, 24, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "X:C", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>:enemy}, 15, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "X:C", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "X:C", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "X:C", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:C", false], [{77=>nil}, 77, "X:C", false], [{77=>nil, 76=>:occupied, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{77=>nil, 76=>:occupied, 75=>:enemy}, 75, "X:C", true], [{77=>nil, 76=>nil}, 76, "X:C", false], [{77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{77=>nil, 76=>nil, 75=>:occupied, 74=>:enemy}, 74, "X:C", true], [{77=>nil, 76=>nil, 75=>nil}, 75, "X:C", false], [{77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>:enemy}, 73, "X:C", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "X:C", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "X:C", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "X:C", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:C", false], [{79=>nil}, 79, "X:C", false], [{79=>nil, 80=>nil}, 80, "X:C", false]], 79=>[[{70=>:occupied, 61=>nil, 52=>:enemy}, 52, "X:C", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>:enemy}, 43, "X:C", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "X:C", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{70=>:occupied, 61=>:enemy}, 61, "X:C", true], [{78=>:occupied, 77=>nil, 76=>:enemy}, 76, "X:C", true], [{78=>:occupied, 77=>nil, 76=>nil, 75=>:enemy}, 75, "X:C", true], [{78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{78=>:occupied, 77=>:enemy}, 77, "X:C", true], [{70=>nil}, 70, "X:C", false], [{70=>nil, 61=>:occupied, 52=>nil, 43=>:enemy}, 43, "X:C", true], [{70=>nil, 61=>:occupied, 52=>nil, 43=>nil, 34=>:enemy}, 34, "X:C", true], [{70=>nil, 61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{70=>nil, 61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{70=>nil, 61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{70=>nil, 61=>:occupied, 52=>:enemy}, 52, "X:C", true], [{70=>nil, 61=>nil}, 61, "X:C", false], [{70=>nil, 61=>nil, 52=>:occupied, 43=>nil, 34=>:enemy}, 34, "X:C", true], [{70=>nil, 61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{70=>nil, 61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{70=>nil, 61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{70=>nil, 61=>nil, 52=>:occupied, 43=>:enemy}, 43, "X:C", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "X:C", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>:enemy}, 25, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>:occupied, 34=>:enemy}, 34, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "X:C", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>:enemy}, 16, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>:enemy}, 25, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "X:C", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>:enemy}, 16, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "X:C", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "X:C", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "X:C", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:C", false], [{78=>nil}, 78, "X:C", false], [{78=>nil, 77=>:occupied, 76=>nil, 75=>:enemy}, 75, "X:C", true], [{78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{78=>nil, 77=>:occupied, 76=>:enemy}, 76, "X:C", true], [{78=>nil, 77=>nil}, 77, "X:C", false], [{78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{78=>nil, 77=>nil, 76=>:occupied, 75=>:enemy}, 75, "X:C", true], [{78=>nil, 77=>nil, 76=>nil}, 76, "X:C", false], [{78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>:enemy}, 74, "X:C", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "X:C", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>:enemy}, 73, "X:C", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "X:C", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "X:C", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "X:C", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:C", false], [{80=>nil}, 80, "X:C", false]], 80=>[[{71=>:occupied, 62=>nil, 53=>:enemy}, 53, "X:C", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>:enemy}, 44, "X:C", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "X:C", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{71=>:occupied, 62=>:enemy}, 62, "X:C", true], [{79=>:occupied, 78=>nil, 77=>:enemy}, 77, "X:C", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>:enemy}, 76, "X:C", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "X:C", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{79=>:occupied, 78=>:enemy}, 78, "X:C", true], [{71=>nil}, 71, "X:C", false], [{71=>nil, 62=>:occupied, 53=>nil, 44=>:enemy}, 44, "X:C", true], [{71=>nil, 62=>:occupied, 53=>nil, 44=>nil, 35=>:enemy}, 35, "X:C", true], [{71=>nil, 62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{71=>nil, 62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{71=>nil, 62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{71=>nil, 62=>:occupied, 53=>:enemy}, 53, "X:C", true], [{71=>nil, 62=>nil}, 62, "X:C", false], [{71=>nil, 62=>nil, 53=>:occupied, 44=>nil, 35=>:enemy}, 35, "X:C", true], [{71=>nil, 62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{71=>nil, 62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{71=>nil, 62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{71=>nil, 62=>nil, 53=>:occupied, 44=>:enemy}, 44, "X:C", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "X:C", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>:enemy}, 26, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>:occupied, 35=>:enemy}, 35, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "X:C", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>:enemy}, 17, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>:enemy}, 26, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "X:C", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>:enemy}, 17, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "X:C", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "X:C", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "X:C", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:C", false], [{79=>nil}, 79, "X:C", false], [{79=>nil, 78=>:occupied, 77=>nil, 76=>:enemy}, 76, "X:C", true], [{79=>nil, 78=>:occupied, 77=>nil, 76=>nil, 75=>:enemy}, 75, "X:C", true], [{79=>nil, 78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{79=>nil, 78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{79=>nil, 78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{79=>nil, 78=>:occupied, 77=>:enemy}, 77, "X:C", true], [{79=>nil, 78=>nil}, 78, "X:C", false], [{79=>nil, 78=>nil, 77=>:occupied, 76=>nil, 75=>:enemy}, 75, "X:C", true], [{79=>nil, 78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{79=>nil, 78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{79=>nil, 78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{79=>nil, 78=>nil, 77=>:occupied, 76=>:enemy}, 76, "X:C", true], [{79=>nil, 78=>nil, 77=>nil}, 77, "X:C", false], [{79=>nil, 78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>:enemy}, 74, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>:occupied, 75=>:enemy}, 75, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil}, 76, "X:C", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>:enemy}, 73, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>:enemy}, 74, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "X:C", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>:enemy}, 73, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "X:C", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "X:C", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "X:C", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:C", false]], nil=>[[{0=>nil}, 0, "X:C", false], [{1=>nil}, 1, "X:C", false], [{2=>nil}, 2, "X:C", false], [{3=>nil}, 3, "X:C", false], [{4=>nil}, 4, "X:C", false], [{5=>nil}, 5, "X:C", false], [{6=>nil}, 6, "X:C", false], [{7=>nil}, 7, "X:C", false], [{8=>nil}, 8, "X:C", false], [{9=>nil}, 9, "X:C", false], [{10=>nil}, 10, "X:C", false], [{11=>nil}, 11, "X:C", false], [{12=>nil}, 12, "X:C", false], [{13=>nil}, 13, "X:C", false], [{14=>nil}, 14, "X:C", false], [{15=>nil}, 15, "X:C", false], [{16=>nil}, 16, "X:C", false], [{17=>nil}, 17, "X:C", false], [{18=>nil}, 18, "X:C", false], [{19=>nil}, 19, "X:C", false], [{20=>nil}, 20, "X:C", false], [{21=>nil}, 21, "X:C", false], [{22=>nil}, 22, "X:C", false], [{23=>nil}, 23, "X:C", false], [{24=>nil}, 24, "X:C", false], [{25=>nil}, 25, "X:C", false], [{26=>nil}, 26, "X:C", false], [{27=>nil}, 27, "X:C", false], [{28=>nil}, 28, "X:C", false], [{29=>nil}, 29, "X:C", false], [{30=>nil}, 30, "X:C", false], [{31=>nil}, 31, "X:C", false], [{32=>nil}, 32, "X:C", false], [{33=>nil}, 33, "X:C", false], [{34=>nil}, 34, "X:C", false], [{35=>nil}, 35, "X:C", false], [{36=>nil}, 36, "X:C", false], [{37=>nil}, 37, "X:C", false], [{38=>nil}, 38, "X:C", false], [{39=>nil}, 39, "X:C", false], [{40=>nil}, 40, "X:C", false], [{41=>nil}, 41, "X:C", false], [{42=>nil}, 42, "X:C", false], [{43=>nil}, 43, "X:C", false], [{44=>nil}, 44, "X:C", false], [{45=>nil}, 45, "X:C", false], [{46=>nil}, 46, "X:C", false], [{47=>nil}, 47, "X:C", false], [{48=>nil}, 48, "X:C", false], [{49=>nil}, 49, "X:C", false], [{50=>nil}, 50, "X:C", false], [{51=>nil}, 51, "X:C", false], [{52=>nil}, 52, "X:C", false], [{53=>nil}, 53, "X:C", false], [{54=>nil}, 54, "X:C", false], [{55=>nil}, 55, "X:C", false], [{56=>nil}, 56, "X:C", false], [{57=>nil}, 57, "X:C", false], [{58=>nil}, 58, "X:C", false], [{59=>nil}, 59, "X:C", false], [{60=>nil}, 60, "X:C", false], [{61=>nil}, 61, "X:C", false], [{62=>nil}, 62, "X:C", false], [{63=>nil}, 63, "X:C", false], [{64=>nil}, 64, "X:C", false], [{65=>nil}, 65, "X:C", false], [{66=>nil}, 66, "X:C", false], [{67=>nil}, 67, "X:C", false], [{68=>nil}, 68, "X:C", false], [{69=>nil}, 69, "X:C", false], [{70=>nil}, 70, "X:C", false], [{71=>nil}, 71, "X:C", false], [{72=>nil}, 72, "X:C", false], [{73=>nil}, 73, "X:C", false], [{74=>nil}, 74, "X:C", false], [{75=>nil}, 75, "X:C", false], [{76=>nil}, 76, "X:C", false], [{77=>nil}, 77, "X:C", false], [{78=>nil}, 78, "X:C", false], [{79=>nil}, 79, "X:C", false], [{80=>nil}, 80, "X:C", false]]}, "X:E"=>{0=>[[{10=>nil, 20=>:enemy}, 20, "X:E", true], [{10=>nil, 20=>nil}, 20, "X:E", false]], 1=>[[{11=>nil, 21=>:enemy}, 21, "X:E", true], [{11=>nil, 21=>nil}, 21, "X:E", false]], 2=>[[{10=>nil, 18=>:enemy}, 18, "X:E", true], [{10=>nil, 18=>nil}, 18, "X:E", false], [{12=>nil, 22=>:enemy}, 22, "X:E", true], [{12=>nil, 22=>nil}, 22, "X:E", false]], 3=>[[{11=>nil, 19=>:enemy}, 19, "X:E", true], [{11=>nil, 19=>nil}, 19, "X:E", false], [{13=>nil, 23=>:enemy}, 23, "X:E", true], [{13=>nil, 23=>nil}, 23, "X:E", false]], 4=>[[{12=>nil, 20=>:enemy}, 20, "X:E", true], [{12=>nil, 20=>nil}, 20, "X:E", false], [{14=>nil, 24=>:enemy}, 24, "X:E", true], [{14=>nil, 24=>nil}, 24, "X:E", false]], 5=>[[{13=>nil, 21=>:enemy}, 21, "X:E", true], [{13=>nil, 21=>nil}, 21, "X:E", false], [{15=>nil, 25=>:enemy}, 25, "X:E", true], [{15=>nil, 25=>nil}, 25, "X:E", false]], 6=>[[{14=>nil, 22=>:enemy}, 22, "X:E", true], [{14=>nil, 22=>nil}, 22, "X:E", false], [{16=>nil, 26=>:enemy}, 26, "X:E", true], [{16=>nil, 26=>nil}, 26, "X:E", false]], 7=>[[{15=>nil, 23=>:enemy}, 23, "X:E", true], [{15=>nil, 23=>nil}, 23, "X:E", false]], 8=>[[{16=>nil, 24=>:enemy}, 24, "X:E", true], [{16=>nil, 24=>nil}, 24, "X:E", false]], 9=>[[{19=>nil, 29=>:enemy}, 29, "X:E", true], [{19=>nil, 29=>nil}, 29, "X:E", false]], 10=>[[{20=>nil, 30=>:enemy}, 30, "X:E", true], [{20=>nil, 30=>nil}, 30, "X:E", false]], 11=>[[{19=>nil, 27=>:enemy}, 27, "X:E", true], [{19=>nil, 27=>nil}, 27, "X:E", false], [{21=>nil, 31=>:enemy}, 31, "X:E", true], [{21=>nil, 31=>nil}, 31, "X:E", false]], 12=>[[{20=>nil, 28=>:enemy}, 28, "X:E", true], [{20=>nil, 28=>nil}, 28, "X:E", false], [{22=>nil, 32=>:enemy}, 32, "X:E", true], [{22=>nil, 32=>nil}, 32, "X:E", false]], 13=>[[{21=>nil, 29=>:enemy}, 29, "X:E", true], [{21=>nil, 29=>nil}, 29, "X:E", false], [{23=>nil, 33=>:enemy}, 33, "X:E", true], [{23=>nil, 33=>nil}, 33, "X:E", false]], 14=>[[{22=>nil, 30=>:enemy}, 30, "X:E", true], [{22=>nil, 30=>nil}, 30, "X:E", false], [{24=>nil, 34=>:enemy}, 34, "X:E", true], [{24=>nil, 34=>nil}, 34, "X:E", false]], 15=>[[{23=>nil, 31=>:enemy}, 31, "X:E", true], [{23=>nil, 31=>nil}, 31, "X:E", false], [{25=>nil, 35=>:enemy}, 35, "X:E", true], [{25=>nil, 35=>nil}, 35, "X:E", false]], 16=>[[{24=>nil, 32=>:enemy}, 32, "X:E", true], [{24=>nil, 32=>nil}, 32, "X:E", false]], 17=>[[{25=>nil, 33=>:enemy}, 33, "X:E", true], [{25=>nil, 33=>nil}, 33, "X:E", false]], 18=>[[{10=>nil, 2=>:enemy}, 2, "X:E", true], [{10=>nil, 2=>nil}, 2, "X:E", false], [{28=>nil, 38=>:enemy}, 38, "X:E", true], [{28=>nil, 38=>nil}, 38, "X:E", false]], 19=>[[{11=>nil, 3=>:enemy}, 3, "X:E", true], [{11=>nil, 3=>nil}, 3, "X:E", false], [{29=>nil, 39=>:enemy}, 39, "X:E", true], [{29=>nil, 39=>nil}, 39, "X:E", false]], 20=>[[{10=>nil, 0=>:enemy}, 0, "X:E", true], [{10=>nil, 0=>nil}, 0, "X:E", false], [{12=>nil, 4=>:enemy}, 4, "X:E", true], [{12=>nil, 4=>nil}, 4, "X:E", false], [{28=>nil, 36=>:enemy}, 36, "X:E", true], [{28=>nil, 36=>nil}, 36, "X:E", false], [{30=>nil, 40=>:enemy}, 40, "X:E", true], [{30=>nil, 40=>nil}, 40, "X:E", false]], 21=>[[{11=>nil, 1=>:enemy}, 1, "X:E", true], [{11=>nil, 1=>nil}, 1, "X:E", false], [{13=>nil, 5=>:enemy}, 5, "X:E", true], [{13=>nil, 5=>nil}, 5, "X:E", false], [{29=>nil, 37=>:enemy}, 37, "X:E", true], [{29=>nil, 37=>nil}, 37, "X:E", false], [{31=>nil, 41=>:enemy}, 41, "X:E", true], [{31=>nil, 41=>nil}, 41, "X:E", false]], 22=>[[{12=>nil, 2=>:enemy}, 2, "X:E", true], [{12=>nil, 2=>nil}, 2, "X:E", false], [{14=>nil, 6=>:enemy}, 6, "X:E", true], [{14=>nil, 6=>nil}, 6, "X:E", false], [{30=>nil, 38=>:enemy}, 38, "X:E", true], [{30=>nil, 38=>nil}, 38, "X:E", false], [{32=>nil, 42=>:enemy}, 42, "X:E", true], [{32=>nil, 42=>nil}, 42, "X:E", false]], 23=>[[{13=>nil, 3=>:enemy}, 3, "X:E", true], [{13=>nil, 3=>nil}, 3, "X:E", false], [{15=>nil, 7=>:enemy}, 7, "X:E", true], [{15=>nil, 7=>nil}, 7, "X:E", false], [{31=>nil, 39=>:enemy}, 39, "X:E", true], [{31=>nil, 39=>nil}, 39, "X:E", false], [{33=>nil, 43=>:enemy}, 43, "X:E", true], [{33=>nil, 43=>nil}, 43, "X:E", false]], 24=>[[{14=>nil, 4=>:enemy}, 4, "X:E", true], [{14=>nil, 4=>nil}, 4, "X:E", false], [{16=>nil, 8=>:enemy}, 8, "X:E", true], [{16=>nil, 8=>nil}, 8, "X:E", false], [{32=>nil, 40=>:enemy}, 40, "X:E", true], [{32=>nil, 40=>nil}, 40, "X:E", false], [{34=>nil, 44=>:enemy}, 44, "X:E", true], [{34=>nil, 44=>nil}, 44, "X:E", false]], 25=>[[{15=>nil, 5=>:enemy}, 5, "X:E", true], [{15=>nil, 5=>nil}, 5, "X:E", false], [{33=>nil, 41=>:enemy}, 41, "X:E", true], [{33=>nil, 41=>nil}, 41, "X:E", false]], 26=>[[{16=>nil, 6=>:enemy}, 6, "X:E", true], [{16=>nil, 6=>nil}, 6, "X:E", false], [{34=>nil, 42=>:enemy}, 42, "X:E", true], [{34=>nil, 42=>nil}, 42, "X:E", false]], 27=>[[{19=>nil, 11=>:enemy}, 11, "X:E", true], [{19=>nil, 11=>nil}, 11, "X:E", false], [{37=>nil, 47=>:enemy}, 47, "X:E", true], [{37=>nil, 47=>nil}, 47, "X:E", false]], 28=>[[{20=>nil, 12=>:enemy}, 12, "X:E", true], [{20=>nil, 12=>nil}, 12, "X:E", false], [{38=>nil, 48=>:enemy}, 48, "X:E", true], [{38=>nil, 48=>nil}, 48, "X:E", false]], 29=>[[{19=>nil, 9=>:enemy}, 9, "X:E", true], [{19=>nil, 9=>nil}, 9, "X:E", false], [{21=>nil, 13=>:enemy}, 13, "X:E", true], [{21=>nil, 13=>nil}, 13, "X:E", false], [{37=>nil, 45=>:enemy}, 45, "X:E", true], [{37=>nil, 45=>nil}, 45, "X:E", false], [{39=>nil, 49=>:enemy}, 49, "X:E", true], [{39=>nil, 49=>nil}, 49, "X:E", false]], 30=>[[{20=>nil, 10=>:enemy}, 10, "X:E", true], [{20=>nil, 10=>nil}, 10, "X:E", false], [{22=>nil, 14=>:enemy}, 14, "X:E", true], [{22=>nil, 14=>nil}, 14, "X:E", false], [{38=>nil, 46=>:enemy}, 46, "X:E", true], [{38=>nil, 46=>nil}, 46, "X:E", false], [{40=>nil, 50=>:enemy}, 50, "X:E", true], [{40=>nil, 50=>nil}, 50, "X:E", false]], 31=>[[{21=>nil, 11=>:enemy}, 11, "X:E", true], [{21=>nil, 11=>nil}, 11, "X:E", false], [{23=>nil, 15=>:enemy}, 15, "X:E", true], [{23=>nil, 15=>nil}, 15, "X:E", false], [{39=>nil, 47=>:enemy}, 47, "X:E", true], [{39=>nil, 47=>nil}, 47, "X:E", false], [{41=>nil, 51=>:enemy}, 51, "X:E", true], [{41=>nil, 51=>nil}, 51, "X:E", false]], 32=>[[{22=>nil, 12=>:enemy}, 12, "X:E", true], [{22=>nil, 12=>nil}, 12, "X:E", false], [{24=>nil, 16=>:enemy}, 16, "X:E", true], [{24=>nil, 16=>nil}, 16, "X:E", false], [{40=>nil, 48=>:enemy}, 48, "X:E", true], [{40=>nil, 48=>nil}, 48, "X:E", false], [{42=>nil, 52=>:enemy}, 52, "X:E", true], [{42=>nil, 52=>nil}, 52, "X:E", false]], 33=>[[{23=>nil, 13=>:enemy}, 13, "X:E", true], [{23=>nil, 13=>nil}, 13, "X:E", false], [{25=>nil, 17=>:enemy}, 17, "X:E", true], [{25=>nil, 17=>nil}, 17, "X:E", false], [{41=>nil, 49=>:enemy}, 49, "X:E", true], [{41=>nil, 49=>nil}, 49, "X:E", false], [{43=>nil, 53=>:enemy}, 53, "X:E", true], [{43=>nil, 53=>nil}, 53, "X:E", false]], 34=>[[{24=>nil, 14=>:enemy}, 14, "X:E", true], [{24=>nil, 14=>nil}, 14, "X:E", false], [{42=>nil, 50=>:enemy}, 50, "X:E", true], [{42=>nil, 50=>nil}, 50, "X:E", false]], 35=>[[{25=>nil, 15=>:enemy}, 15, "X:E", true], [{25=>nil, 15=>nil}, 15, "X:E", false], [{43=>nil, 51=>:enemy}, 51, "X:E", true], [{43=>nil, 51=>nil}, 51, "X:E", false]], 36=>[[{28=>nil, 20=>:enemy}, 20, "X:E", true], [{28=>nil, 20=>nil}, 20, "X:E", false], [{46=>nil, 56=>:enemy}, 56, "X:E", true], [{46=>nil, 56=>nil}, 56, "X:E", false]], 37=>[[{29=>nil, 21=>:enemy}, 21, "X:E", true], [{29=>nil, 21=>nil}, 21, "X:E", false], [{47=>nil, 57=>:enemy}, 57, "X:E", true], [{47=>nil, 57=>nil}, 57, "X:E", false]], 38=>[[{28=>nil, 18=>:enemy}, 18, "X:E", true], [{28=>nil, 18=>nil}, 18, "X:E", false], [{30=>nil, 22=>:enemy}, 22, "X:E", true], [{30=>nil, 22=>nil}, 22, "X:E", false], [{46=>nil, 54=>:enemy}, 54, "X:E", true], [{46=>nil, 54=>nil}, 54, "X:E", false], [{48=>nil, 58=>:enemy}, 58, "X:E", true], [{48=>nil, 58=>nil}, 58, "X:E", false]], 39=>[[{29=>nil, 19=>:enemy}, 19, "X:E", true], [{29=>nil, 19=>nil}, 19, "X:E", false], [{31=>nil, 23=>:enemy}, 23, "X:E", true], [{31=>nil, 23=>nil}, 23, "X:E", false], [{47=>nil, 55=>:enemy}, 55, "X:E", true], [{47=>nil, 55=>nil}, 55, "X:E", false], [{49=>nil, 59=>:enemy}, 59, "X:E", true], [{49=>nil, 59=>nil}, 59, "X:E", false]], 40=>[[{30=>nil, 20=>:enemy}, 20, "X:E", true], [{30=>nil, 20=>nil}, 20, "X:E", false], [{32=>nil, 24=>:enemy}, 24, "X:E", true], [{32=>nil, 24=>nil}, 24, "X:E", false], [{48=>nil, 56=>:enemy}, 56, "X:E", true], [{48=>nil, 56=>nil}, 56, "X:E", false], [{50=>nil, 60=>:enemy}, 60, "X:E", true], [{50=>nil, 60=>nil}, 60, "X:E", false]], 41=>[[{31=>nil, 21=>:enemy}, 21, "X:E", true], [{31=>nil, 21=>nil}, 21, "X:E", false], [{33=>nil, 25=>:enemy}, 25, "X:E", true], [{33=>nil, 25=>nil}, 25, "X:E", false], [{49=>nil, 57=>:enemy}, 57, "X:E", true], [{49=>nil, 57=>nil}, 57, "X:E", false], [{51=>nil, 61=>:enemy}, 61, "X:E", true], [{51=>nil, 61=>nil}, 61, "X:E", false]], 42=>[[{32=>nil, 22=>:enemy}, 22, "X:E", true], [{32=>nil, 22=>nil}, 22, "X:E", false], [{34=>nil, 26=>:enemy}, 26, "X:E", true], [{34=>nil, 26=>nil}, 26, "X:E", false], [{50=>nil, 58=>:enemy}, 58, "X:E", true], [{50=>nil, 58=>nil}, 58, "X:E", false], [{52=>nil, 62=>:enemy}, 62, "X:E", true], [{52=>nil, 62=>nil}, 62, "X:E", false]], 43=>[[{33=>nil, 23=>:enemy}, 23, "X:E", true], [{33=>nil, 23=>nil}, 23, "X:E", false], [{51=>nil, 59=>:enemy}, 59, "X:E", true], [{51=>nil, 59=>nil}, 59, "X:E", false]], 44=>[[{34=>nil, 24=>:enemy}, 24, "X:E", true], [{34=>nil, 24=>nil}, 24, "X:E", false], [{52=>nil, 60=>:enemy}, 60, "X:E", true], [{52=>nil, 60=>nil}, 60, "X:E", false]], 45=>[[{37=>nil, 29=>:enemy}, 29, "X:E", true], [{37=>nil, 29=>nil}, 29, "X:E", false], [{55=>nil, 65=>:enemy}, 65, "X:E", true], [{55=>nil, 65=>nil}, 65, "X:E", false]], 46=>[[{38=>nil, 30=>:enemy}, 30, "X:E", true], [{38=>nil, 30=>nil}, 30, "X:E", false], [{56=>nil, 66=>:enemy}, 66, "X:E", true], [{56=>nil, 66=>nil}, 66, "X:E", false]], 47=>[[{37=>nil, 27=>:enemy}, 27, "X:E", true], [{37=>nil, 27=>nil}, 27, "X:E", false], [{39=>nil, 31=>:enemy}, 31, "X:E", true], [{39=>nil, 31=>nil}, 31, "X:E", false], [{55=>nil, 63=>:enemy}, 63, "X:E", true], [{55=>nil, 63=>nil}, 63, "X:E", false], [{57=>nil, 67=>:enemy}, 67, "X:E", true], [{57=>nil, 67=>nil}, 67, "X:E", false]], 48=>[[{38=>nil, 28=>:enemy}, 28, "X:E", true], [{38=>nil, 28=>nil}, 28, "X:E", false], [{40=>nil, 32=>:enemy}, 32, "X:E", true], [{40=>nil, 32=>nil}, 32, "X:E", false], [{56=>nil, 64=>:enemy}, 64, "X:E", true], [{56=>nil, 64=>nil}, 64, "X:E", false], [{58=>nil, 68=>:enemy}, 68, "X:E", true], [{58=>nil, 68=>nil}, 68, "X:E", false]], 49=>[[{39=>nil, 29=>:enemy}, 29, "X:E", true], [{39=>nil, 29=>nil}, 29, "X:E", false], [{41=>nil, 33=>:enemy}, 33, "X:E", true], [{41=>nil, 33=>nil}, 33, "X:E", false], [{57=>nil, 65=>:enemy}, 65, "X:E", true], [{57=>nil, 65=>nil}, 65, "X:E", false], [{59=>nil, 69=>:enemy}, 69, "X:E", true], [{59=>nil, 69=>nil}, 69, "X:E", false]], 50=>[[{40=>nil, 30=>:enemy}, 30, "X:E", true], [{40=>nil, 30=>nil}, 30, "X:E", false], [{42=>nil, 34=>:enemy}, 34, "X:E", true], [{42=>nil, 34=>nil}, 34, "X:E", false], [{58=>nil, 66=>:enemy}, 66, "X:E", true], [{58=>nil, 66=>nil}, 66, "X:E", false], [{60=>nil, 70=>:enemy}, 70, "X:E", true], [{60=>nil, 70=>nil}, 70, "X:E", false]], 51=>[[{41=>nil, 31=>:enemy}, 31, "X:E", true], [{41=>nil, 31=>nil}, 31, "X:E", false], [{43=>nil, 35=>:enemy}, 35, "X:E", true], [{43=>nil, 35=>nil}, 35, "X:E", false], [{59=>nil, 67=>:enemy}, 67, "X:E", true], [{59=>nil, 67=>nil}, 67, "X:E", false], [{61=>nil, 71=>:enemy}, 71, "X:E", true], [{61=>nil, 71=>nil}, 71, "X:E", false]], 52=>[[{42=>nil, 32=>:enemy}, 32, "X:E", true], [{42=>nil, 32=>nil}, 32, "X:E", false], [{60=>nil, 68=>:enemy}, 68, "X:E", true], [{60=>nil, 68=>nil}, 68, "X:E", false]], 53=>[[{43=>nil, 33=>:enemy}, 33, "X:E", true], [{43=>nil, 33=>nil}, 33, "X:E", false], [{61=>nil, 69=>:enemy}, 69, "X:E", true], [{61=>nil, 69=>nil}, 69, "X:E", false]], 54=>[[{46=>nil, 38=>:enemy}, 38, "X:E", true], [{46=>nil, 38=>nil}, 38, "X:E", false], [{64=>nil, 74=>:enemy}, 74, "X:E", true], [{64=>nil, 74=>nil}, 74, "X:E", false]], 55=>[[{47=>nil, 39=>:enemy}, 39, "X:E", true], [{47=>nil, 39=>nil}, 39, "X:E", false], [{65=>nil, 75=>:enemy}, 75, "X:E", true], [{65=>nil, 75=>nil}, 75, "X:E", false]], 56=>[[{46=>nil, 36=>:enemy}, 36, "X:E", true], [{46=>nil, 36=>nil}, 36, "X:E", false], [{48=>nil, 40=>:enemy}, 40, "X:E", true], [{48=>nil, 40=>nil}, 40, "X:E", false], [{64=>nil, 72=>:enemy}, 72, "X:E", true], [{64=>nil, 72=>nil}, 72, "X:E", false], [{66=>nil, 76=>:enemy}, 76, "X:E", true], [{66=>nil, 76=>nil}, 76, "X:E", false]], 57=>[[{47=>nil, 37=>:enemy}, 37, "X:E", true], [{47=>nil, 37=>nil}, 37, "X:E", false], [{49=>nil, 41=>:enemy}, 41, "X:E", true], [{49=>nil, 41=>nil}, 41, "X:E", false], [{65=>nil, 73=>:enemy}, 73, "X:E", true], [{65=>nil, 73=>nil}, 73, "X:E", false], [{67=>nil, 77=>:enemy}, 77, "X:E", true], [{67=>nil, 77=>nil}, 77, "X:E", false]], 58=>[[{48=>nil, 38=>:enemy}, 38, "X:E", true], [{48=>nil, 38=>nil}, 38, "X:E", false], [{50=>nil, 42=>:enemy}, 42, "X:E", true], [{50=>nil, 42=>nil}, 42, "X:E", false], [{66=>nil, 74=>:enemy}, 74, "X:E", true], [{66=>nil, 74=>nil}, 74, "X:E", false], [{68=>nil, 78=>:enemy}, 78, "X:E", true], [{68=>nil, 78=>nil}, 78, "X:E", false]], 59=>[[{49=>nil, 39=>:enemy}, 39, "X:E", true], [{49=>nil, 39=>nil}, 39, "X:E", false], [{51=>nil, 43=>:enemy}, 43, "X:E", true], [{51=>nil, 43=>nil}, 43, "X:E", false], [{67=>nil, 75=>:enemy}, 75, "X:E", true], [{67=>nil, 75=>nil}, 75, "X:E", false], [{69=>nil, 79=>:enemy}, 79, "X:E", true], [{69=>nil, 79=>nil}, 79, "X:E", false]], 60=>[[{50=>nil, 40=>:enemy}, 40, "X:E", true], [{50=>nil, 40=>nil}, 40, "X:E", false], [{52=>nil, 44=>:enemy}, 44, "X:E", true], [{52=>nil, 44=>nil}, 44, "X:E", false], [{68=>nil, 76=>:enemy}, 76, "X:E", true], [{68=>nil, 76=>nil}, 76, "X:E", false], [{70=>nil, 80=>:enemy}, 80, "X:E", true], [{70=>nil, 80=>nil}, 80, "X:E", false]], 61=>[[{51=>nil, 41=>:enemy}, 41, "X:E", true], [{51=>nil, 41=>nil}, 41, "X:E", false], [{69=>nil, 77=>:enemy}, 77, "X:E", true], [{69=>nil, 77=>nil}, 77, "X:E", false]], 62=>[[{52=>nil, 42=>:enemy}, 42, "X:E", true], [{52=>nil, 42=>nil}, 42, "X:E", false], [{70=>nil, 78=>:enemy}, 78, "X:E", true], [{70=>nil, 78=>nil}, 78, "X:E", false]], 63=>[[{55=>nil, 47=>:enemy}, 47, "X:E", true], [{55=>nil, 47=>nil}, 47, "X:E", false]], 64=>[[{56=>nil, 48=>:enemy}, 48, "X:E", true], [{56=>nil, 48=>nil}, 48, "X:E", false]], 65=>[[{55=>nil, 45=>:enemy}, 45, "X:E", true], [{55=>nil, 45=>nil}, 45, "X:E", false], [{57=>nil, 49=>:enemy}, 49, "X:E", true], [{57=>nil, 49=>nil}, 49, "X:E", false]], 66=>[[{56=>nil, 46=>:enemy}, 46, "X:E", true], [{56=>nil, 46=>nil}, 46, "X:E", false], [{58=>nil, 50=>:enemy}, 50, "X:E", true], [{58=>nil, 50=>nil}, 50, "X:E", false]], 67=>[[{57=>nil, 47=>:enemy}, 47, "X:E", true], [{57=>nil, 47=>nil}, 47, "X:E", false], [{59=>nil, 51=>:enemy}, 51, "X:E", true], [{59=>nil, 51=>nil}, 51, "X:E", false]], 68=>[[{58=>nil, 48=>:enemy}, 48, "X:E", true], [{58=>nil, 48=>nil}, 48, "X:E", false], [{60=>nil, 52=>:enemy}, 52, "X:E", true], [{60=>nil, 52=>nil}, 52, "X:E", false]], 69=>[[{59=>nil, 49=>:enemy}, 49, "X:E", true], [{59=>nil, 49=>nil}, 49, "X:E", false], [{61=>nil, 53=>:enemy}, 53, "X:E", true], [{61=>nil, 53=>nil}, 53, "X:E", false]], 70=>[[{60=>nil, 50=>:enemy}, 50, "X:E", true], [{60=>nil, 50=>nil}, 50, "X:E", false]], 71=>[[{61=>nil, 51=>:enemy}, 51, "X:E", true], [{61=>nil, 51=>nil}, 51, "X:E", false]], 72=>[[{64=>nil, 56=>:enemy}, 56, "X:E", true], [{64=>nil, 56=>nil}, 56, "X:E", false]], 73=>[[{65=>nil, 57=>:enemy}, 57, "X:E", true], [{65=>nil, 57=>nil}, 57, "X:E", false]], 74=>[[{64=>nil, 54=>:enemy}, 54, "X:E", true], [{64=>nil, 54=>nil}, 54, "X:E", false], [{66=>nil, 58=>:enemy}, 58, "X:E", true], [{66=>nil, 58=>nil}, 58, "X:E", false]], 75=>[[{65=>nil, 55=>:enemy}, 55, "X:E", true], [{65=>nil, 55=>nil}, 55, "X:E", false], [{67=>nil, 59=>:enemy}, 59, "X:E", true], [{67=>nil, 59=>nil}, 59, "X:E", false]], 76=>[[{66=>nil, 56=>:enemy}, 56, "X:E", true], [{66=>nil, 56=>nil}, 56, "X:E", false], [{68=>nil, 60=>:enemy}, 60, "X:E", true], [{68=>nil, 60=>nil}, 60, "X:E", false]], 77=>[[{67=>nil, 57=>:enemy}, 57, "X:E", true], [{67=>nil, 57=>nil}, 57, "X:E", false], [{69=>nil, 61=>:enemy}, 61, "X:E", true], [{69=>nil, 61=>nil}, 61, "X:E", false]], 78=>[[{68=>nil, 58=>:enemy}, 58, "X:E", true], [{68=>nil, 58=>nil}, 58, "X:E", false], [{70=>nil, 62=>:enemy}, 62, "X:E", true], [{70=>nil, 62=>nil}, 62, "X:E", false]], 79=>[[{69=>nil, 59=>:enemy}, 59, "X:E", true], [{69=>nil, 59=>nil}, 59, "X:E", false]], 80=>[[{70=>nil, 60=>:enemy}, 60, "X:E", true], [{70=>nil, 60=>nil}, 60, "X:E", false]], nil=>[[{0=>nil}, 0, "X:E", false], [{1=>nil}, 1, "X:E", false], [{2=>nil}, 2, "X:E", false], [{3=>nil}, 3, "X:E", false], [{4=>nil}, 4, "X:E", false], [{5=>nil}, 5, "X:E", false], [{6=>nil}, 6, "X:E", false], [{7=>nil}, 7, "X:E", false], [{8=>nil}, 8, "X:E", false], [{9=>nil}, 9, "X:E", false], [{10=>nil}, 10, "X:E", false], [{11=>nil}, 11, "X:E", false], [{12=>nil}, 12, "X:E", false], [{13=>nil}, 13, "X:E", false], [{14=>nil}, 14, "X:E", false], [{15=>nil}, 15, "X:E", false], [{16=>nil}, 16, "X:E", false], [{17=>nil}, 17, "X:E", false], [{18=>nil}, 18, "X:E", false], [{19=>nil}, 19, "X:E", false], [{20=>nil}, 20, "X:E", false], [{21=>nil}, 21, "X:E", false], [{22=>nil}, 22, "X:E", false], [{23=>nil}, 23, "X:E", false], [{24=>nil}, 24, "X:E", false], [{25=>nil}, 25, "X:E", false], [{26=>nil}, 26, "X:E", false], [{27=>nil}, 27, "X:E", false], [{28=>nil}, 28, "X:E", false], [{29=>nil}, 29, "X:E", false], [{30=>nil}, 30, "X:E", false], [{31=>nil}, 31, "X:E", false], [{32=>nil}, 32, "X:E", false], [{33=>nil}, 33, "X:E", false], [{34=>nil}, 34, "X:E", false], [{35=>nil}, 35, "X:E", false], [{36=>nil}, 36, "X:E", false], [{37=>nil}, 37, "X:E", false], [{38=>nil}, 38, "X:E", false], [{39=>nil}, 39, "X:E", false], [{40=>nil}, 40, "X:E", false], [{41=>nil}, 41, "X:E", false], [{42=>nil}, 42, "X:E", false], [{43=>nil}, 43, "X:E", false], [{44=>nil}, 44, "X:E", false], [{45=>nil}, 45, "X:E", false], [{46=>nil}, 46, "X:E", false], [{47=>nil}, 47, "X:E", false], [{48=>nil}, 48, "X:E", false], [{49=>nil}, 49, "X:E", false], [{50=>nil}, 50, "X:E", false], [{51=>nil}, 51, "X:E", false], [{52=>nil}, 52, "X:E", false], [{53=>nil}, 53, "X:E", false], [{54=>nil}, 54, "X:E", false], [{55=>nil}, 55, "X:E", false], [{56=>nil}, 56, "X:E", false], [{57=>nil}, 57, "X:E", false], [{58=>nil}, 58, "X:E", false], [{59=>nil}, 59, "X:E", false], [{60=>nil}, 60, "X:E", false], [{61=>nil}, 61, "X:E", false], [{62=>nil}, 62, "X:E", false], [{63=>nil}, 63, "X:E", false], [{64=>nil}, 64, "X:E", false], [{65=>nil}, 65, "X:E", false], [{66=>nil}, 66, "X:E", false], [{67=>nil}, 67, "X:E", false], [{68=>nil}, 68, "X:E", false], [{69=>nil}, 69, "X:E", false], [{70=>nil}, 70, "X:E", false], [{71=>nil}, 71, "X:E", false], [{72=>nil}, 72, "X:E", false], [{73=>nil}, 73, "X:E", false], [{74=>nil}, 74, "X:E", false], [{75=>nil}, 75, "X:E", false], [{76=>nil}, 76, "X:E", false], [{77=>nil}, 77, "X:E", false], [{78=>nil}, 78, "X:E", false], [{79=>nil}, 79, "X:E", false], [{80=>nil}, 80, "X:E", false]]}, "X:H"=>{0=>[[{1=>nil, 11=>:enemy}, 11, "X:H", true], [{1=>nil, 11=>nil}, 11, "X:H", false], [{9=>nil, 19=>:enemy}, 19, "X:H", true], [{9=>nil, 19=>nil}, 19, "X:H", false]], 1=>[[{2=>nil, 12=>:enemy}, 12, "X:H", true], [{2=>nil, 12=>nil}, 12, "X:H", false], [{10=>nil, 18=>:enemy}, 18, "X:H", true], [{10=>nil, 20=>:enemy}, 20, "X:H", true], [{10=>nil, 18=>nil}, 18, "X:H", false], [{10=>nil, 20=>nil}, 20, "X:H", false]], 2=>[[{1=>nil, 9=>:enemy}, 9, "X:H", true], [{1=>nil, 9=>nil}, 9, "X:H", false], [{3=>nil, 13=>:enemy}, 13, "X:H", true], [{3=>nil, 13=>nil}, 13, "X:H", false], [{11=>nil, 19=>:enemy}, 19, "X:H", true], [{11=>nil, 21=>:enemy}, 21, "X:H", true], [{11=>nil, 19=>nil}, 19, "X:H", false], [{11=>nil, 21=>nil}, 21, "X:H", false]], 3=>[[{2=>nil, 10=>:enemy}, 10, "X:H", true], [{2=>nil, 10=>nil}, 10, "X:H", false], [{4=>nil, 14=>:enemy}, 14, "X:H", true], [{4=>nil, 14=>nil}, 14, "X:H", false], [{12=>nil, 20=>:enemy}, 20, "X:H", true], [{12=>nil, 22=>:enemy}, 22, "X:H", true], [{12=>nil, 20=>nil}, 20, "X:H", false], [{12=>nil, 22=>nil}, 22, "X:H", false]], 4=>[[{3=>nil, 11=>:enemy}, 11, "X:H", true], [{3=>nil, 11=>nil}, 11, "X:H", false], [{5=>nil, 15=>:enemy}, 15, "X:H", true], [{5=>nil, 15=>nil}, 15, "X:H", false], [{13=>nil, 21=>:enemy}, 21, "X:H", true], [{13=>nil, 23=>:enemy}, 23, "X:H", true], [{13=>nil, 21=>nil}, 21, "X:H", false], [{13=>nil, 23=>nil}, 23, "X:H", false]], 5=>[[{4=>nil, 12=>:enemy}, 12, "X:H", true], [{4=>nil, 12=>nil}, 12, "X:H", false], [{6=>nil, 16=>:enemy}, 16, "X:H", true], [{6=>nil, 16=>nil}, 16, "X:H", false], [{14=>nil, 22=>:enemy}, 22, "X:H", true], [{14=>nil, 24=>:enemy}, 24, "X:H", true], [{14=>nil, 22=>nil}, 22, "X:H", false], [{14=>nil, 24=>nil}, 24, "X:H", false]], 6=>[[{5=>nil, 13=>:enemy}, 13, "X:H", true], [{5=>nil, 13=>nil}, 13, "X:H", false], [{7=>nil, 17=>:enemy}, 17, "X:H", true], [{7=>nil, 17=>nil}, 17, "X:H", false], [{15=>nil, 23=>:enemy}, 23, "X:H", true], [{15=>nil, 25=>:enemy}, 25, "X:H", true], [{15=>nil, 23=>nil}, 23, "X:H", false], [{15=>nil, 25=>nil}, 25, "X:H", false]], 7=>[[{6=>nil, 14=>:enemy}, 14, "X:H", true], [{6=>nil, 14=>nil}, 14, "X:H", false], [{16=>nil, 24=>:enemy}, 24, "X:H", true], [{16=>nil, 26=>:enemy}, 26, "X:H", true], [{16=>nil, 24=>nil}, 24, "X:H", false], [{16=>nil, 26=>nil}, 26, "X:H", false]], 8=>[[{7=>nil, 15=>:enemy}, 15, "X:H", true], [{7=>nil, 15=>nil}, 15, "X:H", false], [{17=>nil, 25=>:enemy}, 25, "X:H", true], [{17=>nil, 25=>nil}, 25, "X:H", false]], 9=>[[{10=>nil, 2=>:enemy}, 2, "X:H", true], [{10=>nil, 20=>:enemy}, 20, "X:H", true], [{10=>nil, 2=>nil}, 2, "X:H", false], [{10=>nil, 20=>nil}, 20, "X:H", false], [{18=>nil, 28=>:enemy}, 28, "X:H", true], [{18=>nil, 28=>nil}, 28, "X:H", false]], 10=>[[{11=>nil, 3=>:enemy}, 3, "X:H", true], [{11=>nil, 21=>:enemy}, 21, "X:H", true], [{11=>nil, 3=>nil}, 3, "X:H", false], [{11=>nil, 21=>nil}, 21, "X:H", false], [{19=>nil, 27=>:enemy}, 27, "X:H", true], [{19=>nil, 29=>:enemy}, 29, "X:H", true], [{19=>nil, 27=>nil}, 27, "X:H", false], [{19=>nil, 29=>nil}, 29, "X:H", false]], 11=>[[{10=>nil, 0=>:enemy}, 0, "X:H", true], [{10=>nil, 18=>:enemy}, 18, "X:H", true], [{10=>nil, 0=>nil}, 0, "X:H", false], [{10=>nil, 18=>nil}, 18, "X:H", false], [{12=>nil, 4=>:enemy}, 4, "X:H", true], [{12=>nil, 22=>:enemy}, 22, "X:H", true], [{12=>nil, 4=>nil}, 4, "X:H", false], [{12=>nil, 22=>nil}, 22, "X:H", false], [{20=>nil, 28=>:enemy}, 28, "X:H", true], [{20=>nil, 30=>:enemy}, 30, "X:H", true], [{20=>nil, 28=>nil}, 28, "X:H", false], [{20=>nil, 30=>nil}, 30, "X:H", false]], 12=>[[{11=>nil, 1=>:enemy}, 1, "X:H", true], [{11=>nil, 19=>:enemy}, 19, "X:H", true], [{11=>nil, 1=>nil}, 1, "X:H", false], [{11=>nil, 19=>nil}, 19, "X:H", false], [{13=>nil, 5=>:enemy}, 5, "X:H", true], [{13=>nil, 23=>:enemy}, 23, "X:H", true], [{13=>nil, 5=>nil}, 5, "X:H", false], [{13=>nil, 23=>nil}, 23, "X:H", false], [{21=>nil, 29=>:enemy}, 29, "X:H", true], [{21=>nil, 31=>:enemy}, 31, "X:H", true], [{21=>nil, 29=>nil}, 29, "X:H", false], [{21=>nil, 31=>nil}, 31, "X:H", false]], 13=>[[{12=>nil, 2=>:enemy}, 2, "X:H", true], [{12=>nil, 20=>:enemy}, 20, "X:H", true], [{12=>nil, 2=>nil}, 2, "X:H", false], [{12=>nil, 20=>nil}, 20, "X:H", false], [{14=>nil, 6=>:enemy}, 6, "X:H", true], [{14=>nil, 24=>:enemy}, 24, "X:H", true], [{14=>nil, 6=>nil}, 6, "X:H", false], [{14=>nil, 24=>nil}, 24, "X:H", false], [{22=>nil, 30=>:enemy}, 30, "X:H", true], [{22=>nil, 32=>:enemy}, 32, "X:H", true], [{22=>nil, 30=>nil}, 30, "X:H", false], [{22=>nil, 32=>nil}, 32, "X:H", false]], 14=>[[{13=>nil, 3=>:enemy}, 3, "X:H", true], [{13=>nil, 21=>:enemy}, 21, "X:H", true], [{13=>nil, 3=>nil}, 3, "X:H", false], [{13=>nil, 21=>nil}, 21, "X:H", false], [{15=>nil, 7=>:enemy}, 7, "X:H", true], [{15=>nil, 25=>:enemy}, 25, "X:H", true], [{15=>nil, 7=>nil}, 7, "X:H", false], [{15=>nil, 25=>nil}, 25, "X:H", false], [{23=>nil, 31=>:enemy}, 31, "X:H", true], [{23=>nil, 33=>:enemy}, 33, "X:H", true], [{23=>nil, 31=>nil}, 31, "X:H", false], [{23=>nil, 33=>nil}, 33, "X:H", false]], 15=>[[{14=>nil, 4=>:enemy}, 4, "X:H", true], [{14=>nil, 22=>:enemy}, 22, "X:H", true], [{14=>nil, 4=>nil}, 4, "X:H", false], [{14=>nil, 22=>nil}, 22, "X:H", false], [{16=>nil, 8=>:enemy}, 8, "X:H", true], [{16=>nil, 26=>:enemy}, 26, "X:H", true], [{16=>nil, 8=>nil}, 8, "X:H", false], [{16=>nil, 26=>nil}, 26, "X:H", false], [{24=>nil, 32=>:enemy}, 32, "X:H", true], [{24=>nil, 34=>:enemy}, 34, "X:H", true], [{24=>nil, 32=>nil}, 32, "X:H", false], [{24=>nil, 34=>nil}, 34, "X:H", false]], 16=>[[{15=>nil, 5=>:enemy}, 5, "X:H", true], [{15=>nil, 23=>:enemy}, 23, "X:H", true], [{15=>nil, 5=>nil}, 5, "X:H", false], [{15=>nil, 23=>nil}, 23, "X:H", false], [{25=>nil, 33=>:enemy}, 33, "X:H", true], [{25=>nil, 35=>:enemy}, 35, "X:H", true], [{25=>nil, 33=>nil}, 33, "X:H", false], [{25=>nil, 35=>nil}, 35, "X:H", false]], 17=>[[{16=>nil, 6=>:enemy}, 6, "X:H", true], [{16=>nil, 24=>:enemy}, 24, "X:H", true], [{16=>nil, 6=>nil}, 6, "X:H", false], [{16=>nil, 24=>nil}, 24, "X:H", false], [{26=>nil, 34=>:enemy}, 34, "X:H", true], [{26=>nil, 34=>nil}, 34, "X:H", false]], 18=>[[{9=>nil, 1=>:enemy}, 1, "X:H", true], [{9=>nil, 1=>nil}, 1, "X:H", false], [{19=>nil, 11=>:enemy}, 11, "X:H", true], [{19=>nil, 29=>:enemy}, 29, "X:H", true], [{19=>nil, 11=>nil}, 11, "X:H", false], [{19=>nil, 29=>nil}, 29, "X:H", false], [{27=>nil, 37=>:enemy}, 37, "X:H", true], [{27=>nil, 37=>nil}, 37, "X:H", false]], 19=>[[{10=>nil, 0=>:enemy}, 0, "X:H", true], [{10=>nil, 2=>:enemy}, 2, "X:H", true], [{10=>nil, 0=>nil}, 0, "X:H", false], [{10=>nil, 2=>nil}, 2, "X:H", false], [{20=>nil, 12=>:enemy}, 12, "X:H", true], [{20=>nil, 30=>:enemy}, 30, "X:H", true], [{20=>nil, 12=>nil}, 12, "X:H", false], [{20=>nil, 30=>nil}, 30, "X:H", false], [{28=>nil, 36=>:enemy}, 36, "X:H", true], [{28=>nil, 38=>:enemy}, 38, "X:H", true], [{28=>nil, 36=>nil}, 36, "X:H", false], [{28=>nil, 38=>nil}, 38, "X:H", false]], 20=>[[{11=>nil, 1=>:enemy}, 1, "X:H", true], [{11=>nil, 3=>:enemy}, 3, "X:H", true], [{11=>nil, 1=>nil}, 1, "X:H", false], [{11=>nil, 3=>nil}, 3, "X:H", false], [{19=>nil, 9=>:enemy}, 9, "X:H", true], [{19=>nil, 27=>:enemy}, 27, "X:H", true], [{19=>nil, 9=>nil}, 9, "X:H", false], [{19=>nil, 27=>nil}, 27, "X:H", false], [{21=>nil, 13=>:enemy}, 13, "X:H", true], [{21=>nil, 31=>:enemy}, 31, "X:H", true], [{21=>nil, 13=>nil}, 13, "X:H", false], [{21=>nil, 31=>nil}, 31, "X:H", false], [{29=>nil, 37=>:enemy}, 37, "X:H", true], [{29=>nil, 39=>:enemy}, 39, "X:H", true], [{29=>nil, 37=>nil}, 37, "X:H", false], [{29=>nil, 39=>nil}, 39, "X:H", false]], 21=>[[{12=>nil, 2=>:enemy}, 2, "X:H", true], [{12=>nil, 4=>:enemy}, 4, "X:H", true], [{12=>nil, 2=>nil}, 2, "X:H", false], [{12=>nil, 4=>nil}, 4, "X:H", false], [{20=>nil, 10=>:enemy}, 10, "X:H", true], [{20=>nil, 28=>:enemy}, 28, "X:H", true], [{20=>nil, 10=>nil}, 10, "X:H", false], [{20=>nil, 28=>nil}, 28, "X:H", false], [{22=>nil, 14=>:enemy}, 14, "X:H", true], [{22=>nil, 32=>:enemy}, 32, "X:H", true], [{22=>nil, 14=>nil}, 14, "X:H", false], [{22=>nil, 32=>nil}, 32, "X:H", false], [{30=>nil, 38=>:enemy}, 38, "X:H", true], [{30=>nil, 40=>:enemy}, 40, "X:H", true], [{30=>nil, 38=>nil}, 38, "X:H", false], [{30=>nil, 40=>nil}, 40, "X:H", false]], 22=>[[{13=>nil, 3=>:enemy}, 3, "X:H", true], [{13=>nil, 5=>:enemy}, 5, "X:H", true], [{13=>nil, 3=>nil}, 3, "X:H", false], [{13=>nil, 5=>nil}, 5, "X:H", false], [{21=>nil, 11=>:enemy}, 11, "X:H", true], [{21=>nil, 29=>:enemy}, 29, "X:H", true], [{21=>nil, 11=>nil}, 11, "X:H", false], [{21=>nil, 29=>nil}, 29, "X:H", false], [{23=>nil, 15=>:enemy}, 15, "X:H", true], [{23=>nil, 33=>:enemy}, 33, "X:H", true], [{23=>nil, 15=>nil}, 15, "X:H", false], [{23=>nil, 33=>nil}, 33, "X:H", false], [{31=>nil, 39=>:enemy}, 39, "X:H", true], [{31=>nil, 41=>:enemy}, 41, "X:H", true], [{31=>nil, 39=>nil}, 39, "X:H", false], [{31=>nil, 41=>nil}, 41, "X:H", false]], 23=>[[{14=>nil, 4=>:enemy}, 4, "X:H", true], [{14=>nil, 6=>:enemy}, 6, "X:H", true], [{14=>nil, 4=>nil}, 4, "X:H", false], [{14=>nil, 6=>nil}, 6, "X:H", false], [{22=>nil, 12=>:enemy}, 12, "X:H", true], [{22=>nil, 30=>:enemy}, 30, "X:H", true], [{22=>nil, 12=>nil}, 12, "X:H", false], [{22=>nil, 30=>nil}, 30, "X:H", false], [{24=>nil, 16=>:enemy}, 16, "X:H", true], [{24=>nil, 34=>:enemy}, 34, "X:H", true], [{24=>nil, 16=>nil}, 16, "X:H", false], [{24=>nil, 34=>nil}, 34, "X:H", false], [{32=>nil, 40=>:enemy}, 40, "X:H", true], [{32=>nil, 42=>:enemy}, 42, "X:H", true], [{32=>nil, 40=>nil}, 40, "X:H", false], [{32=>nil, 42=>nil}, 42, "X:H", false]], 24=>[[{15=>nil, 5=>:enemy}, 5, "X:H", true], [{15=>nil, 7=>:enemy}, 7, "X:H", true], [{15=>nil, 5=>nil}, 5, "X:H", false], [{15=>nil, 7=>nil}, 7, "X:H", false], [{23=>nil, 13=>:enemy}, 13, "X:H", true], [{23=>nil, 31=>:enemy}, 31, "X:H", true], [{23=>nil, 13=>nil}, 13, "X:H", false], [{23=>nil, 31=>nil}, 31, "X:H", false], [{25=>nil, 17=>:enemy}, 17, "X:H", true], [{25=>nil, 35=>:enemy}, 35, "X:H", true], [{25=>nil, 17=>nil}, 17, "X:H", false], [{25=>nil, 35=>nil}, 35, "X:H", false], [{33=>nil, 41=>:enemy}, 41, "X:H", true], [{33=>nil, 43=>:enemy}, 43, "X:H", true], [{33=>nil, 41=>nil}, 41, "X:H", false], [{33=>nil, 43=>nil}, 43, "X:H", false]], 25=>[[{16=>nil, 6=>:enemy}, 6, "X:H", true], [{16=>nil, 8=>:enemy}, 8, "X:H", true], [{16=>nil, 6=>nil}, 6, "X:H", false], [{16=>nil, 8=>nil}, 8, "X:H", false], [{24=>nil, 14=>:enemy}, 14, "X:H", true], [{24=>nil, 32=>:enemy}, 32, "X:H", true], [{24=>nil, 14=>nil}, 14, "X:H", false], [{24=>nil, 32=>nil}, 32, "X:H", false], [{34=>nil, 42=>:enemy}, 42, "X:H", true], [{34=>nil, 44=>:enemy}, 44, "X:H", true], [{34=>nil, 42=>nil}, 42, "X:H", false], [{34=>nil, 44=>nil}, 44, "X:H", false]], 26=>[[{17=>nil, 7=>:enemy}, 7, "X:H", true], [{17=>nil, 7=>nil}, 7, "X:H", false], [{25=>nil, 15=>:enemy}, 15, "X:H", true], [{25=>nil, 33=>:enemy}, 33, "X:H", true], [{25=>nil, 15=>nil}, 15, "X:H", false], [{25=>nil, 33=>nil}, 33, "X:H", false], [{35=>nil, 43=>:enemy}, 43, "X:H", true], [{35=>nil, 43=>nil}, 43, "X:H", false]], 27=>[[{18=>nil, 10=>:enemy}, 10, "X:H", true], [{18=>nil, 10=>nil}, 10, "X:H", false], [{28=>nil, 20=>:enemy}, 20, "X:H", true], [{28=>nil, 38=>:enemy}, 38, "X:H", true], [{28=>nil, 20=>nil}, 20, "X:H", false], [{28=>nil, 38=>nil}, 38, "X:H", false], [{36=>nil, 46=>:enemy}, 46, "X:H", true], [{36=>nil, 46=>nil}, 46, "X:H", false]], 28=>[[{19=>nil, 9=>:enemy}, 9, "X:H", true], [{19=>nil, 11=>:enemy}, 11, "X:H", true], [{19=>nil, 9=>nil}, 9, "X:H", false], [{19=>nil, 11=>nil}, 11, "X:H", false], [{29=>nil, 21=>:enemy}, 21, "X:H", true], [{29=>nil, 39=>:enemy}, 39, "X:H", true], [{29=>nil, 21=>nil}, 21, "X:H", false], [{29=>nil, 39=>nil}, 39, "X:H", false], [{37=>nil, 45=>:enemy}, 45, "X:H", true], [{37=>nil, 47=>:enemy}, 47, "X:H", true], [{37=>nil, 45=>nil}, 45, "X:H", false], [{37=>nil, 47=>nil}, 47, "X:H", false]], 29=>[[{20=>nil, 10=>:enemy}, 10, "X:H", true], [{20=>nil, 12=>:enemy}, 12, "X:H", true], [{20=>nil, 10=>nil}, 10, "X:H", false], [{20=>nil, 12=>nil}, 12, "X:H", false], [{28=>nil, 18=>:enemy}, 18, "X:H", true], [{28=>nil, 36=>:enemy}, 36, "X:H", true], [{28=>nil, 18=>nil}, 18, "X:H", false], [{28=>nil, 36=>nil}, 36, "X:H", false], [{30=>nil, 22=>:enemy}, 22, "X:H", true], [{30=>nil, 40=>:enemy}, 40, "X:H", true], [{30=>nil, 22=>nil}, 22, "X:H", false], [{30=>nil, 40=>nil}, 40, "X:H", false], [{38=>nil, 46=>:enemy}, 46, "X:H", true], [{38=>nil, 48=>:enemy}, 48, "X:H", true], [{38=>nil, 46=>nil}, 46, "X:H", false], [{38=>nil, 48=>nil}, 48, "X:H", false]], 30=>[[{21=>nil, 11=>:enemy}, 11, "X:H", true], [{21=>nil, 13=>:enemy}, 13, "X:H", true], [{21=>nil, 11=>nil}, 11, "X:H", false], [{21=>nil, 13=>nil}, 13, "X:H", false], [{29=>nil, 19=>:enemy}, 19, "X:H", true], [{29=>nil, 37=>:enemy}, 37, "X:H", true], [{29=>nil, 19=>nil}, 19, "X:H", false], [{29=>nil, 37=>nil}, 37, "X:H", false], [{31=>nil, 23=>:enemy}, 23, "X:H", true], [{31=>nil, 41=>:enemy}, 41, "X:H", true], [{31=>nil, 23=>nil}, 23, "X:H", false], [{31=>nil, 41=>nil}, 41, "X:H", false], [{39=>nil, 47=>:enemy}, 47, "X:H", true], [{39=>nil, 49=>:enemy}, 49, "X:H", true], [{39=>nil, 47=>nil}, 47, "X:H", false], [{39=>nil, 49=>nil}, 49, "X:H", false]], 31=>[[{22=>nil, 12=>:enemy}, 12, "X:H", true], [{22=>nil, 14=>:enemy}, 14, "X:H", true], [{22=>nil, 12=>nil}, 12, "X:H", false], [{22=>nil, 14=>nil}, 14, "X:H", false], [{30=>nil, 20=>:enemy}, 20, "X:H", true], [{30=>nil, 38=>:enemy}, 38, "X:H", true], [{30=>nil, 20=>nil}, 20, "X:H", false], [{30=>nil, 38=>nil}, 38, "X:H", false], [{32=>nil, 24=>:enemy}, 24, "X:H", true], [{32=>nil, 42=>:enemy}, 42, "X:H", true], [{32=>nil, 24=>nil}, 24, "X:H", false], [{32=>nil, 42=>nil}, 42, "X:H", false], [{40=>nil, 48=>:enemy}, 48, "X:H", true], [{40=>nil, 50=>:enemy}, 50, "X:H", true], [{40=>nil, 48=>nil}, 48, "X:H", false], [{40=>nil, 50=>nil}, 50, "X:H", false]], 32=>[[{23=>nil, 13=>:enemy}, 13, "X:H", true], [{23=>nil, 15=>:enemy}, 15, "X:H", true], [{23=>nil, 13=>nil}, 13, "X:H", false], [{23=>nil, 15=>nil}, 15, "X:H", false], [{31=>nil, 21=>:enemy}, 21, "X:H", true], [{31=>nil, 39=>:enemy}, 39, "X:H", true], [{31=>nil, 21=>nil}, 21, "X:H", false], [{31=>nil, 39=>nil}, 39, "X:H", false], [{33=>nil, 25=>:enemy}, 25, "X:H", true], [{33=>nil, 43=>:enemy}, 43, "X:H", true], [{33=>nil, 25=>nil}, 25, "X:H", false], [{33=>nil, 43=>nil}, 43, "X:H", false], [{41=>nil, 49=>:enemy}, 49, "X:H", true], [{41=>nil, 51=>:enemy}, 51, "X:H", true], [{41=>nil, 49=>nil}, 49, "X:H", false], [{41=>nil, 51=>nil}, 51, "X:H", false]], 33=>[[{24=>nil, 14=>:enemy}, 14, "X:H", true], [{24=>nil, 16=>:enemy}, 16, "X:H", true], [{24=>nil, 14=>nil}, 14, "X:H", false], [{24=>nil, 16=>nil}, 16, "X:H", false], [{32=>nil, 22=>:enemy}, 22, "X:H", true], [{32=>nil, 40=>:enemy}, 40, "X:H", true], [{32=>nil, 22=>nil}, 22, "X:H", false], [{32=>nil, 40=>nil}, 40, "X:H", false], [{34=>nil, 26=>:enemy}, 26, "X:H", true], [{34=>nil, 44=>:enemy}, 44, "X:H", true], [{34=>nil, 26=>nil}, 26, "X:H", false], [{34=>nil, 44=>nil}, 44, "X:H", false], [{42=>nil, 50=>:enemy}, 50, "X:H", true], [{42=>nil, 52=>:enemy}, 52, "X:H", true], [{42=>nil, 50=>nil}, 50, "X:H", false], [{42=>nil, 52=>nil}, 52, "X:H", false]], 34=>[[{25=>nil, 15=>:enemy}, 15, "X:H", true], [{25=>nil, 17=>:enemy}, 17, "X:H", true], [{25=>nil, 15=>nil}, 15, "X:H", false], [{25=>nil, 17=>nil}, 17, "X:H", false], [{33=>nil, 23=>:enemy}, 23, "X:H", true], [{33=>nil, 41=>:enemy}, 41, "X:H", true], [{33=>nil, 23=>nil}, 23, "X:H", false], [{33=>nil, 41=>nil}, 41, "X:H", false], [{43=>nil, 51=>:enemy}, 51, "X:H", true], [{43=>nil, 53=>:enemy}, 53, "X:H", true], [{43=>nil, 51=>nil}, 51, "X:H", false], [{43=>nil, 53=>nil}, 53, "X:H", false]], 35=>[[{26=>nil, 16=>:enemy}, 16, "X:H", true], [{26=>nil, 16=>nil}, 16, "X:H", false], [{34=>nil, 24=>:enemy}, 24, "X:H", true], [{34=>nil, 42=>:enemy}, 42, "X:H", true], [{34=>nil, 24=>nil}, 24, "X:H", false], [{34=>nil, 42=>nil}, 42, "X:H", false], [{44=>nil, 52=>:enemy}, 52, "X:H", true], [{44=>nil, 52=>nil}, 52, "X:H", false]], 36=>[[{27=>nil, 19=>:enemy}, 19, "X:H", true], [{27=>nil, 19=>nil}, 19, "X:H", false], [{37=>nil, 29=>:enemy}, 29, "X:H", true], [{37=>nil, 47=>:enemy}, 47, "X:H", true], [{37=>nil, 29=>nil}, 29, "X:H", false], [{37=>nil, 47=>nil}, 47, "X:H", false], [{45=>nil, 55=>:enemy}, 55, "X:H", true], [{45=>nil, 55=>nil}, 55, "X:H", false]], 37=>[[{28=>nil, 18=>:enemy}, 18, "X:H", true], [{28=>nil, 20=>:enemy}, 20, "X:H", true], [{28=>nil, 18=>nil}, 18, "X:H", false], [{28=>nil, 20=>nil}, 20, "X:H", false], [{38=>nil, 30=>:enemy}, 30, "X:H", true], [{38=>nil, 48=>:enemy}, 48, "X:H", true], [{38=>nil, 30=>nil}, 30, "X:H", false], [{38=>nil, 48=>nil}, 48, "X:H", false], [{46=>nil, 54=>:enemy}, 54, "X:H", true], [{46=>nil, 56=>:enemy}, 56, "X:H", true], [{46=>nil, 54=>nil}, 54, "X:H", false], [{46=>nil, 56=>nil}, 56, "X:H", false]], 38=>[[{29=>nil, 19=>:enemy}, 19, "X:H", true], [{29=>nil, 21=>:enemy}, 21, "X:H", true], [{29=>nil, 19=>nil}, 19, "X:H", false], [{29=>nil, 21=>nil}, 21, "X:H", false], [{37=>nil, 27=>:enemy}, 27, "X:H", true], [{37=>nil, 45=>:enemy}, 45, "X:H", true], [{37=>nil, 27=>nil}, 27, "X:H", false], [{37=>nil, 45=>nil}, 45, "X:H", false], [{39=>nil, 31=>:enemy}, 31, "X:H", true], [{39=>nil, 49=>:enemy}, 49, "X:H", true], [{39=>nil, 31=>nil}, 31, "X:H", false], [{39=>nil, 49=>nil}, 49, "X:H", false], [{47=>nil, 55=>:enemy}, 55, "X:H", true], [{47=>nil, 57=>:enemy}, 57, "X:H", true], [{47=>nil, 55=>nil}, 55, "X:H", false], [{47=>nil, 57=>nil}, 57, "X:H", false]], 39=>[[{30=>nil, 20=>:enemy}, 20, "X:H", true], [{30=>nil, 22=>:enemy}, 22, "X:H", true], [{30=>nil, 20=>nil}, 20, "X:H", false], [{30=>nil, 22=>nil}, 22, "X:H", false], [{38=>nil, 28=>:enemy}, 28, "X:H", true], [{38=>nil, 46=>:enemy}, 46, "X:H", true], [{38=>nil, 28=>nil}, 28, "X:H", false], [{38=>nil, 46=>nil}, 46, "X:H", false], [{40=>nil, 32=>:enemy}, 32, "X:H", true], [{40=>nil, 50=>:enemy}, 50, "X:H", true], [{40=>nil, 32=>nil}, 32, "X:H", false], [{40=>nil, 50=>nil}, 50, "X:H", false], [{48=>nil, 56=>:enemy}, 56, "X:H", true], [{48=>nil, 58=>:enemy}, 58, "X:H", true], [{48=>nil, 56=>nil}, 56, "X:H", false], [{48=>nil, 58=>nil}, 58, "X:H", false]], 40=>[[{31=>nil, 21=>:enemy}, 21, "X:H", true], [{31=>nil, 23=>:enemy}, 23, "X:H", true], [{31=>nil, 21=>nil}, 21, "X:H", false], [{31=>nil, 23=>nil}, 23, "X:H", false], [{39=>nil, 29=>:enemy}, 29, "X:H", true], [{39=>nil, 47=>:enemy}, 47, "X:H", true], [{39=>nil, 29=>nil}, 29, "X:H", false], [{39=>nil, 47=>nil}, 47, "X:H", false], [{41=>nil, 33=>:enemy}, 33, "X:H", true], [{41=>nil, 51=>:enemy}, 51, "X:H", true], [{41=>nil, 33=>nil}, 33, "X:H", false], [{41=>nil, 51=>nil}, 51, "X:H", false], [{49=>nil, 57=>:enemy}, 57, "X:H", true], [{49=>nil, 59=>:enemy}, 59, "X:H", true], [{49=>nil, 57=>nil}, 57, "X:H", false], [{49=>nil, 59=>nil}, 59, "X:H", false]], 41=>[[{32=>nil, 22=>:enemy}, 22, "X:H", true], [{32=>nil, 24=>:enemy}, 24, "X:H", true], [{32=>nil, 22=>nil}, 22, "X:H", false], [{32=>nil, 24=>nil}, 24, "X:H", false], [{40=>nil, 30=>:enemy}, 30, "X:H", true], [{40=>nil, 48=>:enemy}, 48, "X:H", true], [{40=>nil, 30=>nil}, 30, "X:H", false], [{40=>nil, 48=>nil}, 48, "X:H", false], [{42=>nil, 34=>:enemy}, 34, "X:H", true], [{42=>nil, 52=>:enemy}, 52, "X:H", true], [{42=>nil, 34=>nil}, 34, "X:H", false], [{42=>nil, 52=>nil}, 52, "X:H", false], [{50=>nil, 58=>:enemy}, 58, "X:H", true], [{50=>nil, 60=>:enemy}, 60, "X:H", true], [{50=>nil, 58=>nil}, 58, "X:H", false], [{50=>nil, 60=>nil}, 60, "X:H", false]], 42=>[[{33=>nil, 23=>:enemy}, 23, "X:H", true], [{33=>nil, 25=>:enemy}, 25, "X:H", true], [{33=>nil, 23=>nil}, 23, "X:H", false], [{33=>nil, 25=>nil}, 25, "X:H", false], [{41=>nil, 31=>:enemy}, 31, "X:H", true], [{41=>nil, 49=>:enemy}, 49, "X:H", true], [{41=>nil, 31=>nil}, 31, "X:H", false], [{41=>nil, 49=>nil}, 49, "X:H", false], [{43=>nil, 35=>:enemy}, 35, "X:H", true], [{43=>nil, 53=>:enemy}, 53, "X:H", true], [{43=>nil, 35=>nil}, 35, "X:H", false], [{43=>nil, 53=>nil}, 53, "X:H", false], [{51=>nil, 59=>:enemy}, 59, "X:H", true], [{51=>nil, 61=>:enemy}, 61, "X:H", true], [{51=>nil, 59=>nil}, 59, "X:H", false], [{51=>nil, 61=>nil}, 61, "X:H", false]], 43=>[[{34=>nil, 24=>:enemy}, 24, "X:H", true], [{34=>nil, 26=>:enemy}, 26, "X:H", true], [{34=>nil, 24=>nil}, 24, "X:H", false], [{34=>nil, 26=>nil}, 26, "X:H", false], [{42=>nil, 32=>:enemy}, 32, "X:H", true], [{42=>nil, 50=>:enemy}, 50, "X:H", true], [{42=>nil, 32=>nil}, 32, "X:H", false], [{42=>nil, 50=>nil}, 50, "X:H", false], [{52=>nil, 60=>:enemy}, 60, "X:H", true], [{52=>nil, 62=>:enemy}, 62, "X:H", true], [{52=>nil, 60=>nil}, 60, "X:H", false], [{52=>nil, 62=>nil}, 62, "X:H", false]], 44=>[[{35=>nil, 25=>:enemy}, 25, "X:H", true], [{35=>nil, 25=>nil}, 25, "X:H", false], [{43=>nil, 33=>:enemy}, 33, "X:H", true], [{43=>nil, 51=>:enemy}, 51, "X:H", true], [{43=>nil, 33=>nil}, 33, "X:H", false], [{43=>nil, 51=>nil}, 51, "X:H", false], [{53=>nil, 61=>:enemy}, 61, "X:H", true], [{53=>nil, 61=>nil}, 61, "X:H", false]], 45=>[[{36=>nil, 28=>:enemy}, 28, "X:H", true], [{36=>nil, 28=>nil}, 28, "X:H", false], [{46=>nil, 38=>:enemy}, 38, "X:H", true], [{46=>nil, 56=>:enemy}, 56, "X:H", true], [{46=>nil, 38=>nil}, 38, "X:H", false], [{46=>nil, 56=>nil}, 56, "X:H", false], [{54=>nil, 64=>:enemy}, 64, "X:H", true], [{54=>nil, 64=>nil}, 64, "X:H", false]], 46=>[[{37=>nil, 27=>:enemy}, 27, "X:H", true], [{37=>nil, 29=>:enemy}, 29, "X:H", true], [{37=>nil, 27=>nil}, 27, "X:H", false], [{37=>nil, 29=>nil}, 29, "X:H", false], [{47=>nil, 39=>:enemy}, 39, "X:H", true], [{47=>nil, 57=>:enemy}, 57, "X:H", true], [{47=>nil, 39=>nil}, 39, "X:H", false], [{47=>nil, 57=>nil}, 57, "X:H", false], [{55=>nil, 63=>:enemy}, 63, "X:H", true], [{55=>nil, 65=>:enemy}, 65, "X:H", true], [{55=>nil, 63=>nil}, 63, "X:H", false], [{55=>nil, 65=>nil}, 65, "X:H", false]], 47=>[[{38=>nil, 28=>:enemy}, 28, "X:H", true], [{38=>nil, 30=>:enemy}, 30, "X:H", true], [{38=>nil, 28=>nil}, 28, "X:H", false], [{38=>nil, 30=>nil}, 30, "X:H", false], [{46=>nil, 36=>:enemy}, 36, "X:H", true], [{46=>nil, 54=>:enemy}, 54, "X:H", true], [{46=>nil, 36=>nil}, 36, "X:H", false], [{46=>nil, 54=>nil}, 54, "X:H", false], [{48=>nil, 40=>:enemy}, 40, "X:H", true], [{48=>nil, 58=>:enemy}, 58, "X:H", true], [{48=>nil, 40=>nil}, 40, "X:H", false], [{48=>nil, 58=>nil}, 58, "X:H", false], [{56=>nil, 64=>:enemy}, 64, "X:H", true], [{56=>nil, 66=>:enemy}, 66, "X:H", true], [{56=>nil, 64=>nil}, 64, "X:H", false], [{56=>nil, 66=>nil}, 66, "X:H", false]], 48=>[[{39=>nil, 29=>:enemy}, 29, "X:H", true], [{39=>nil, 31=>:enemy}, 31, "X:H", true], [{39=>nil, 29=>nil}, 29, "X:H", false], [{39=>nil, 31=>nil}, 31, "X:H", false], [{47=>nil, 37=>:enemy}, 37, "X:H", true], [{47=>nil, 55=>:enemy}, 55, "X:H", true], [{47=>nil, 37=>nil}, 37, "X:H", false], [{47=>nil, 55=>nil}, 55, "X:H", false], [{49=>nil, 41=>:enemy}, 41, "X:H", true], [{49=>nil, 59=>:enemy}, 59, "X:H", true], [{49=>nil, 41=>nil}, 41, "X:H", false], [{49=>nil, 59=>nil}, 59, "X:H", false], [{57=>nil, 65=>:enemy}, 65, "X:H", true], [{57=>nil, 67=>:enemy}, 67, "X:H", true], [{57=>nil, 65=>nil}, 65, "X:H", false], [{57=>nil, 67=>nil}, 67, "X:H", false]], 49=>[[{40=>nil, 30=>:enemy}, 30, "X:H", true], [{40=>nil, 32=>:enemy}, 32, "X:H", true], [{40=>nil, 30=>nil}, 30, "X:H", false], [{40=>nil, 32=>nil}, 32, "X:H", false], [{48=>nil, 38=>:enemy}, 38, "X:H", true], [{48=>nil, 56=>:enemy}, 56, "X:H", true], [{48=>nil, 38=>nil}, 38, "X:H", false], [{48=>nil, 56=>nil}, 56, "X:H", false], [{50=>nil, 42=>:enemy}, 42, "X:H", true], [{50=>nil, 60=>:enemy}, 60, "X:H", true], [{50=>nil, 42=>nil}, 42, "X:H", false], [{50=>nil, 60=>nil}, 60, "X:H", false], [{58=>nil, 66=>:enemy}, 66, "X:H", true], [{58=>nil, 68=>:enemy}, 68, "X:H", true], [{58=>nil, 66=>nil}, 66, "X:H", false], [{58=>nil, 68=>nil}, 68, "X:H", false]], 50=>[[{41=>nil, 31=>:enemy}, 31, "X:H", true], [{41=>nil, 33=>:enemy}, 33, "X:H", true], [{41=>nil, 31=>nil}, 31, "X:H", false], [{41=>nil, 33=>nil}, 33, "X:H", false], [{49=>nil, 39=>:enemy}, 39, "X:H", true], [{49=>nil, 57=>:enemy}, 57, "X:H", true], [{49=>nil, 39=>nil}, 39, "X:H", false], [{49=>nil, 57=>nil}, 57, "X:H", false], [{51=>nil, 43=>:enemy}, 43, "X:H", true], [{51=>nil, 61=>:enemy}, 61, "X:H", true], [{51=>nil, 43=>nil}, 43, "X:H", false], [{51=>nil, 61=>nil}, 61, "X:H", false], [{59=>nil, 67=>:enemy}, 67, "X:H", true], [{59=>nil, 69=>:enemy}, 69, "X:H", true], [{59=>nil, 67=>nil}, 67, "X:H", false], [{59=>nil, 69=>nil}, 69, "X:H", false]], 51=>[[{42=>nil, 32=>:enemy}, 32, "X:H", true], [{42=>nil, 34=>:enemy}, 34, "X:H", true], [{42=>nil, 32=>nil}, 32, "X:H", false], [{42=>nil, 34=>nil}, 34, "X:H", false], [{50=>nil, 40=>:enemy}, 40, "X:H", true], [{50=>nil, 58=>:enemy}, 58, "X:H", true], [{50=>nil, 40=>nil}, 40, "X:H", false], [{50=>nil, 58=>nil}, 58, "X:H", false], [{52=>nil, 44=>:enemy}, 44, "X:H", true], [{52=>nil, 62=>:enemy}, 62, "X:H", true], [{52=>nil, 44=>nil}, 44, "X:H", false], [{52=>nil, 62=>nil}, 62, "X:H", false], [{60=>nil, 68=>:enemy}, 68, "X:H", true], [{60=>nil, 70=>:enemy}, 70, "X:H", true], [{60=>nil, 68=>nil}, 68, "X:H", false], [{60=>nil, 70=>nil}, 70, "X:H", false]], 52=>[[{43=>nil, 33=>:enemy}, 33, "X:H", true], [{43=>nil, 35=>:enemy}, 35, "X:H", true], [{43=>nil, 33=>nil}, 33, "X:H", false], [{43=>nil, 35=>nil}, 35, "X:H", false], [{51=>nil, 41=>:enemy}, 41, "X:H", true], [{51=>nil, 59=>:enemy}, 59, "X:H", true], [{51=>nil, 41=>nil}, 41, "X:H", false], [{51=>nil, 59=>nil}, 59, "X:H", false], [{61=>nil, 69=>:enemy}, 69, "X:H", true], [{61=>nil, 71=>:enemy}, 71, "X:H", true], [{61=>nil, 69=>nil}, 69, "X:H", false], [{61=>nil, 71=>nil}, 71, "X:H", false]], 53=>[[{44=>nil, 34=>:enemy}, 34, "X:H", true], [{44=>nil, 34=>nil}, 34, "X:H", false], [{52=>nil, 42=>:enemy}, 42, "X:H", true], [{52=>nil, 60=>:enemy}, 60, "X:H", true], [{52=>nil, 42=>nil}, 42, "X:H", false], [{52=>nil, 60=>nil}, 60, "X:H", false], [{62=>nil, 70=>:enemy}, 70, "X:H", true], [{62=>nil, 70=>nil}, 70, "X:H", false]], 54=>[[{45=>nil, 37=>:enemy}, 37, "X:H", true], [{45=>nil, 37=>nil}, 37, "X:H", false], [{55=>nil, 47=>:enemy}, 47, "X:H", true], [{55=>nil, 65=>:enemy}, 65, "X:H", true], [{55=>nil, 47=>nil}, 47, "X:H", false], [{55=>nil, 65=>nil}, 65, "X:H", false], [{63=>nil, 73=>:enemy}, 73, "X:H", true], [{63=>nil, 73=>nil}, 73, "X:H", false]], 55=>[[{46=>nil, 36=>:enemy}, 36, "X:H", true], [{46=>nil, 38=>:enemy}, 38, "X:H", true], [{46=>nil, 36=>nil}, 36, "X:H", false], [{46=>nil, 38=>nil}, 38, "X:H", false], [{56=>nil, 48=>:enemy}, 48, "X:H", true], [{56=>nil, 66=>:enemy}, 66, "X:H", true], [{56=>nil, 48=>nil}, 48, "X:H", false], [{56=>nil, 66=>nil}, 66, "X:H", false], [{64=>nil, 72=>:enemy}, 72, "X:H", true], [{64=>nil, 74=>:enemy}, 74, "X:H", true], [{64=>nil, 72=>nil}, 72, "X:H", false], [{64=>nil, 74=>nil}, 74, "X:H", false]], 56=>[[{47=>nil, 37=>:enemy}, 37, "X:H", true], [{47=>nil, 39=>:enemy}, 39, "X:H", true], [{47=>nil, 37=>nil}, 37, "X:H", false], [{47=>nil, 39=>nil}, 39, "X:H", false], [{55=>nil, 45=>:enemy}, 45, "X:H", true], [{55=>nil, 63=>:enemy}, 63, "X:H", true], [{55=>nil, 45=>nil}, 45, "X:H", false], [{55=>nil, 63=>nil}, 63, "X:H", false], [{57=>nil, 49=>:enemy}, 49, "X:H", true], [{57=>nil, 67=>:enemy}, 67, "X:H", true], [{57=>nil, 49=>nil}, 49, "X:H", false], [{57=>nil, 67=>nil}, 67, "X:H", false], [{65=>nil, 73=>:enemy}, 73, "X:H", true], [{65=>nil, 75=>:enemy}, 75, "X:H", true], [{65=>nil, 73=>nil}, 73, "X:H", false], [{65=>nil, 75=>nil}, 75, "X:H", false]], 57=>[[{48=>nil, 38=>:enemy}, 38, "X:H", true], [{48=>nil, 40=>:enemy}, 40, "X:H", true], [{48=>nil, 38=>nil}, 38, "X:H", false], [{48=>nil, 40=>nil}, 40, "X:H", false], [{56=>nil, 46=>:enemy}, 46, "X:H", true], [{56=>nil, 64=>:enemy}, 64, "X:H", true], [{56=>nil, 46=>nil}, 46, "X:H", false], [{56=>nil, 64=>nil}, 64, "X:H", false], [{58=>nil, 50=>:enemy}, 50, "X:H", true], [{58=>nil, 68=>:enemy}, 68, "X:H", true], [{58=>nil, 50=>nil}, 50, "X:H", false], [{58=>nil, 68=>nil}, 68, "X:H", false], [{66=>nil, 74=>:enemy}, 74, "X:H", true], [{66=>nil, 76=>:enemy}, 76, "X:H", true], [{66=>nil, 74=>nil}, 74, "X:H", false], [{66=>nil, 76=>nil}, 76, "X:H", false]], 58=>[[{49=>nil, 39=>:enemy}, 39, "X:H", true], [{49=>nil, 41=>:enemy}, 41, "X:H", true], [{49=>nil, 39=>nil}, 39, "X:H", false], [{49=>nil, 41=>nil}, 41, "X:H", false], [{57=>nil, 47=>:enemy}, 47, "X:H", true], [{57=>nil, 65=>:enemy}, 65, "X:H", true], [{57=>nil, 47=>nil}, 47, "X:H", false], [{57=>nil, 65=>nil}, 65, "X:H", false], [{59=>nil, 51=>:enemy}, 51, "X:H", true], [{59=>nil, 69=>:enemy}, 69, "X:H", true], [{59=>nil, 51=>nil}, 51, "X:H", false], [{59=>nil, 69=>nil}, 69, "X:H", false], [{67=>nil, 75=>:enemy}, 75, "X:H", true], [{67=>nil, 77=>:enemy}, 77, "X:H", true], [{67=>nil, 75=>nil}, 75, "X:H", false], [{67=>nil, 77=>nil}, 77, "X:H", false]], 59=>[[{50=>nil, 40=>:enemy}, 40, "X:H", true], [{50=>nil, 42=>:enemy}, 42, "X:H", true], [{50=>nil, 40=>nil}, 40, "X:H", false], [{50=>nil, 42=>nil}, 42, "X:H", false], [{58=>nil, 48=>:enemy}, 48, "X:H", true], [{58=>nil, 66=>:enemy}, 66, "X:H", true], [{58=>nil, 48=>nil}, 48, "X:H", false], [{58=>nil, 66=>nil}, 66, "X:H", false], [{60=>nil, 52=>:enemy}, 52, "X:H", true], [{60=>nil, 70=>:enemy}, 70, "X:H", true], [{60=>nil, 52=>nil}, 52, "X:H", false], [{60=>nil, 70=>nil}, 70, "X:H", false], [{68=>nil, 76=>:enemy}, 76, "X:H", true], [{68=>nil, 78=>:enemy}, 78, "X:H", true], [{68=>nil, 76=>nil}, 76, "X:H", false], [{68=>nil, 78=>nil}, 78, "X:H", false]], 60=>[[{51=>nil, 41=>:enemy}, 41, "X:H", true], [{51=>nil, 43=>:enemy}, 43, "X:H", true], [{51=>nil, 41=>nil}, 41, "X:H", false], [{51=>nil, 43=>nil}, 43, "X:H", false], [{59=>nil, 49=>:enemy}, 49, "X:H", true], [{59=>nil, 67=>:enemy}, 67, "X:H", true], [{59=>nil, 49=>nil}, 49, "X:H", false], [{59=>nil, 67=>nil}, 67, "X:H", false], [{61=>nil, 53=>:enemy}, 53, "X:H", true], [{61=>nil, 71=>:enemy}, 71, "X:H", true], [{61=>nil, 53=>nil}, 53, "X:H", false], [{61=>nil, 71=>nil}, 71, "X:H", false], [{69=>nil, 77=>:enemy}, 77, "X:H", true], [{69=>nil, 79=>:enemy}, 79, "X:H", true], [{69=>nil, 77=>nil}, 77, "X:H", false], [{69=>nil, 79=>nil}, 79, "X:H", false]], 61=>[[{52=>nil, 42=>:enemy}, 42, "X:H", true], [{52=>nil, 44=>:enemy}, 44, "X:H", true], [{52=>nil, 42=>nil}, 42, "X:H", false], [{52=>nil, 44=>nil}, 44, "X:H", false], [{60=>nil, 50=>:enemy}, 50, "X:H", true], [{60=>nil, 68=>:enemy}, 68, "X:H", true], [{60=>nil, 50=>nil}, 50, "X:H", false], [{60=>nil, 68=>nil}, 68, "X:H", false], [{70=>nil, 78=>:enemy}, 78, "X:H", true], [{70=>nil, 80=>:enemy}, 80, "X:H", true], [{70=>nil, 78=>nil}, 78, "X:H", false], [{70=>nil, 80=>nil}, 80, "X:H", false]], 62=>[[{53=>nil, 43=>:enemy}, 43, "X:H", true], [{53=>nil, 43=>nil}, 43, "X:H", false], [{61=>nil, 51=>:enemy}, 51, "X:H", true], [{61=>nil, 69=>:enemy}, 69, "X:H", true], [{61=>nil, 51=>nil}, 51, "X:H", false], [{61=>nil, 69=>nil}, 69, "X:H", false], [{71=>nil, 79=>:enemy}, 79, "X:H", true], [{71=>nil, 79=>nil}, 79, "X:H", false]], 63=>[[{54=>nil, 46=>:enemy}, 46, "X:H", true], [{54=>nil, 46=>nil}, 46, "X:H", false], [{64=>nil, 56=>:enemy}, 56, "X:H", true], [{64=>nil, 74=>:enemy}, 74, "X:H", true], [{64=>nil, 56=>nil}, 56, "X:H", false], [{64=>nil, 74=>nil}, 74, "X:H", false]], 64=>[[{55=>nil, 45=>:enemy}, 45, "X:H", true], [{55=>nil, 47=>:enemy}, 47, "X:H", true], [{55=>nil, 45=>nil}, 45, "X:H", false], [{55=>nil, 47=>nil}, 47, "X:H", false], [{65=>nil, 57=>:enemy}, 57, "X:H", true], [{65=>nil, 75=>:enemy}, 75, "X:H", true], [{65=>nil, 57=>nil}, 57, "X:H", false], [{65=>nil, 75=>nil}, 75, "X:H", false]], 65=>[[{56=>nil, 46=>:enemy}, 46, "X:H", true], [{56=>nil, 48=>:enemy}, 48, "X:H", true], [{56=>nil, 46=>nil}, 46, "X:H", false], [{56=>nil, 48=>nil}, 48, "X:H", false], [{64=>nil, 54=>:enemy}, 54, "X:H", true], [{64=>nil, 72=>:enemy}, 72, "X:H", true], [{64=>nil, 54=>nil}, 54, "X:H", false], [{64=>nil, 72=>nil}, 72, "X:H", false], [{66=>nil, 58=>:enemy}, 58, "X:H", true], [{66=>nil, 76=>:enemy}, 76, "X:H", true], [{66=>nil, 58=>nil}, 58, "X:H", false], [{66=>nil, 76=>nil}, 76, "X:H", false]], 66=>[[{57=>nil, 47=>:enemy}, 47, "X:H", true], [{57=>nil, 49=>:enemy}, 49, "X:H", true], [{57=>nil, 47=>nil}, 47, "X:H", false], [{57=>nil, 49=>nil}, 49, "X:H", false], [{65=>nil, 55=>:enemy}, 55, "X:H", true], [{65=>nil, 73=>:enemy}, 73, "X:H", true], [{65=>nil, 55=>nil}, 55, "X:H", false], [{65=>nil, 73=>nil}, 73, "X:H", false], [{67=>nil, 59=>:enemy}, 59, "X:H", true], [{67=>nil, 77=>:enemy}, 77, "X:H", true], [{67=>nil, 59=>nil}, 59, "X:H", false], [{67=>nil, 77=>nil}, 77, "X:H", false]], 67=>[[{58=>nil, 48=>:enemy}, 48, "X:H", true], [{58=>nil, 50=>:enemy}, 50, "X:H", true], [{58=>nil, 48=>nil}, 48, "X:H", false], [{58=>nil, 50=>nil}, 50, "X:H", false], [{66=>nil, 56=>:enemy}, 56, "X:H", true], [{66=>nil, 74=>:enemy}, 74, "X:H", true], [{66=>nil, 56=>nil}, 56, "X:H", false], [{66=>nil, 74=>nil}, 74, "X:H", false], [{68=>nil, 60=>:enemy}, 60, "X:H", true], [{68=>nil, 78=>:enemy}, 78, "X:H", true], [{68=>nil, 60=>nil}, 60, "X:H", false], [{68=>nil, 78=>nil}, 78, "X:H", false]], 68=>[[{59=>nil, 49=>:enemy}, 49, "X:H", true], [{59=>nil, 51=>:enemy}, 51, "X:H", true], [{59=>nil, 49=>nil}, 49, "X:H", false], [{59=>nil, 51=>nil}, 51, "X:H", false], [{67=>nil, 57=>:enemy}, 57, "X:H", true], [{67=>nil, 75=>:enemy}, 75, "X:H", true], [{67=>nil, 57=>nil}, 57, "X:H", false], [{67=>nil, 75=>nil}, 75, "X:H", false], [{69=>nil, 61=>:enemy}, 61, "X:H", true], [{69=>nil, 79=>:enemy}, 79, "X:H", true], [{69=>nil, 61=>nil}, 61, "X:H", false], [{69=>nil, 79=>nil}, 79, "X:H", false]], 69=>[[{60=>nil, 50=>:enemy}, 50, "X:H", true], [{60=>nil, 52=>:enemy}, 52, "X:H", true], [{60=>nil, 50=>nil}, 50, "X:H", false], [{60=>nil, 52=>nil}, 52, "X:H", false], [{68=>nil, 58=>:enemy}, 58, "X:H", true], [{68=>nil, 76=>:enemy}, 76, "X:H", true], [{68=>nil, 58=>nil}, 58, "X:H", false], [{68=>nil, 76=>nil}, 76, "X:H", false], [{70=>nil, 62=>:enemy}, 62, "X:H", true], [{70=>nil, 80=>:enemy}, 80, "X:H", true], [{70=>nil, 62=>nil}, 62, "X:H", false], [{70=>nil, 80=>nil}, 80, "X:H", false]], 70=>[[{61=>nil, 51=>:enemy}, 51, "X:H", true], [{61=>nil, 53=>:enemy}, 53, "X:H", true], [{61=>nil, 51=>nil}, 51, "X:H", false], [{61=>nil, 53=>nil}, 53, "X:H", false], [{69=>nil, 59=>:enemy}, 59, "X:H", true], [{69=>nil, 77=>:enemy}, 77, "X:H", true], [{69=>nil, 59=>nil}, 59, "X:H", false], [{69=>nil, 77=>nil}, 77, "X:H", false]], 71=>[[{62=>nil, 52=>:enemy}, 52, "X:H", true], [{62=>nil, 52=>nil}, 52, "X:H", false], [{70=>nil, 60=>:enemy}, 60, "X:H", true], [{70=>nil, 78=>:enemy}, 78, "X:H", true], [{70=>nil, 60=>nil}, 60, "X:H", false], [{70=>nil, 78=>nil}, 78, "X:H", false]], 72=>[[{63=>nil, 55=>:enemy}, 55, "X:H", true], [{63=>nil, 55=>nil}, 55, "X:H", false], [{73=>nil, 65=>:enemy}, 65, "X:H", true], [{73=>nil, 65=>nil}, 65, "X:H", false]], 73=>[[{64=>nil, 54=>:enemy}, 54, "X:H", true], [{64=>nil, 56=>:enemy}, 56, "X:H", true], [{64=>nil, 54=>nil}, 54, "X:H", false], [{64=>nil, 56=>nil}, 56, "X:H", false], [{74=>nil, 66=>:enemy}, 66, "X:H", true], [{74=>nil, 66=>nil}, 66, "X:H", false]], 74=>[[{65=>nil, 55=>:enemy}, 55, "X:H", true], [{65=>nil, 57=>:enemy}, 57, "X:H", true], [{65=>nil, 55=>nil}, 55, "X:H", false], [{65=>nil, 57=>nil}, 57, "X:H", false], [{73=>nil, 63=>:enemy}, 63, "X:H", true], [{73=>nil, 63=>nil}, 63, "X:H", false], [{75=>nil, 67=>:enemy}, 67, "X:H", true], [{75=>nil, 67=>nil}, 67, "X:H", false]], 75=>[[{66=>nil, 56=>:enemy}, 56, "X:H", true], [{66=>nil, 58=>:enemy}, 58, "X:H", true], [{66=>nil, 56=>nil}, 56, "X:H", false], [{66=>nil, 58=>nil}, 58, "X:H", false], [{74=>nil, 64=>:enemy}, 64, "X:H", true], [{74=>nil, 64=>nil}, 64, "X:H", false], [{76=>nil, 68=>:enemy}, 68, "X:H", true], [{76=>nil, 68=>nil}, 68, "X:H", false]], 76=>[[{67=>nil, 57=>:enemy}, 57, "X:H", true], [{67=>nil, 59=>:enemy}, 59, "X:H", true], [{67=>nil, 57=>nil}, 57, "X:H", false], [{67=>nil, 59=>nil}, 59, "X:H", false], [{75=>nil, 65=>:enemy}, 65, "X:H", true], [{75=>nil, 65=>nil}, 65, "X:H", false], [{77=>nil, 69=>:enemy}, 69, "X:H", true], [{77=>nil, 69=>nil}, 69, "X:H", false]], 77=>[[{68=>nil, 58=>:enemy}, 58, "X:H", true], [{68=>nil, 60=>:enemy}, 60, "X:H", true], [{68=>nil, 58=>nil}, 58, "X:H", false], [{68=>nil, 60=>nil}, 60, "X:H", false], [{76=>nil, 66=>:enemy}, 66, "X:H", true], [{76=>nil, 66=>nil}, 66, "X:H", false], [{78=>nil, 70=>:enemy}, 70, "X:H", true], [{78=>nil, 70=>nil}, 70, "X:H", false]], 78=>[[{69=>nil, 59=>:enemy}, 59, "X:H", true], [{69=>nil, 61=>:enemy}, 61, "X:H", true], [{69=>nil, 59=>nil}, 59, "X:H", false], [{69=>nil, 61=>nil}, 61, "X:H", false], [{77=>nil, 67=>:enemy}, 67, "X:H", true], [{77=>nil, 67=>nil}, 67, "X:H", false], [{79=>nil, 71=>:enemy}, 71, "X:H", true], [{79=>nil, 71=>nil}, 71, "X:H", false]], 79=>[[{70=>nil, 60=>:enemy}, 60, "X:H", true], [{70=>nil, 62=>:enemy}, 62, "X:H", true], [{70=>nil, 60=>nil}, 60, "X:H", false], [{70=>nil, 62=>nil}, 62, "X:H", false], [{78=>nil, 68=>:enemy}, 68, "X:H", true], [{78=>nil, 68=>nil}, 68, "X:H", false]], 80=>[[{71=>nil, 61=>:enemy}, 61, "X:H", true], [{71=>nil, 61=>nil}, 61, "X:H", false], [{79=>nil, 69=>:enemy}, 69, "X:H", true], [{79=>nil, 69=>nil}, 69, "X:H", false]], nil=>[[{0=>nil}, 0, "X:H", false], [{1=>nil}, 1, "X:H", false], [{2=>nil}, 2, "X:H", false], [{3=>nil}, 3, "X:H", false], [{4=>nil}, 4, "X:H", false], [{5=>nil}, 5, "X:H", false], [{6=>nil}, 6, "X:H", false], [{7=>nil}, 7, "X:H", false], [{8=>nil}, 8, "X:H", false], [{9=>nil}, 9, "X:H", false], [{10=>nil}, 10, "X:H", false], [{11=>nil}, 11, "X:H", false], [{12=>nil}, 12, "X:H", false], [{13=>nil}, 13, "X:H", false], [{14=>nil}, 14, "X:H", false], [{15=>nil}, 15, "X:H", false], [{16=>nil}, 16, "X:H", false], [{17=>nil}, 17, "X:H", false], [{18=>nil}, 18, "X:H", false], [{19=>nil}, 19, "X:H", false], [{20=>nil}, 20, "X:H", false], [{21=>nil}, 21, "X:H", false], [{22=>nil}, 22, "X:H", false], [{23=>nil}, 23, "X:H", false], [{24=>nil}, 24, "X:H", false], [{25=>nil}, 25, "X:H", false], [{26=>nil}, 26, "X:H", false], [{27=>nil}, 27, "X:H", false], [{28=>nil}, 28, "X:H", false], [{29=>nil}, 29, "X:H", false], [{30=>nil}, 30, "X:H", false], [{31=>nil}, 31, "X:H", false], [{32=>nil}, 32, "X:H", false], [{33=>nil}, 33, "X:H", false], [{34=>nil}, 34, "X:H", false], [{35=>nil}, 35, "X:H", false], [{36=>nil}, 36, "X:H", false], [{37=>nil}, 37, "X:H", false], [{38=>nil}, 38, "X:H", false], [{39=>nil}, 39, "X:H", false], [{40=>nil}, 40, "X:H", false], [{41=>nil}, 41, "X:H", false], [{42=>nil}, 42, "X:H", false], [{43=>nil}, 43, "X:H", false], [{44=>nil}, 44, "X:H", false], [{45=>nil}, 45, "X:H", false], [{46=>nil}, 46, "X:H", false], [{47=>nil}, 47, "X:H", false], [{48=>nil}, 48, "X:H", false], [{49=>nil}, 49, "X:H", false], [{50=>nil}, 50, "X:H", false], [{51=>nil}, 51, "X:H", false], [{52=>nil}, 52, "X:H", false], [{53=>nil}, 53, "X:H", false], [{54=>nil}, 54, "X:H", false], [{55=>nil}, 55, "X:H", false], [{56=>nil}, 56, "X:H", false], [{57=>nil}, 57, "X:H", false], [{58=>nil}, 58, "X:H", false], [{59=>nil}, 59, "X:H", false], [{60=>nil}, 60, "X:H", false], [{61=>nil}, 61, "X:H", false], [{62=>nil}, 62, "X:H", false], [{63=>nil}, 63, "X:H", false], [{64=>nil}, 64, "X:H", false], [{65=>nil}, 65, "X:H", false], [{66=>nil}, 66, "X:H", false], [{67=>nil}, 67, "X:H", false], [{68=>nil}, 68, "X:H", false], [{69=>nil}, 69, "X:H", false], [{70=>nil}, 70, "X:H", false], [{71=>nil}, 71, "X:H", false], [{72=>nil}, 72, "X:H", false], [{73=>nil}, 73, "X:H", false], [{74=>nil}, 74, "X:H", false], [{75=>nil}, 75, "X:H", false], [{76=>nil}, 76, "X:H", false], [{77=>nil}, 77, "X:H", false], [{78=>nil}, 78, "X:H", false], [{79=>nil}, 79, "X:H", false], [{80=>nil}, 80, "X:H", false]]}, "X:R"=>{0=>[[{1=>:enemy}, 1, "X:R", true], [{9=>:enemy}, 9, "X:R", true], [{1=>nil}, 1, "X:R", false], [{1=>nil, 2=>:enemy}, 2, "X:R", true], [{1=>nil, 2=>nil}, 2, "X:R", false], [{1=>nil, 2=>nil, 3=>:enemy}, 3, "X:R", true], [{1=>nil, 2=>nil, 3=>nil}, 3, "X:R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, 4, "X:R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil}, 4, "X:R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "X:R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "X:R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "X:R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "X:R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "X:R", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:R", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:R", false], [{9=>nil}, 9, "X:R", false], [{9=>nil, 18=>:enemy}, 18, "X:R", true], [{9=>nil, 18=>nil}, 18, "X:R", false], [{9=>nil, 18=>nil, 27=>:enemy}, 27, "X:R", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "X:R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, 36, "X:R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "X:R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "X:R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "X:R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "X:R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "X:R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "X:R", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:R", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:R", false]], 1=>[[{0=>:enemy}, 0, "X:R", true], [{2=>:enemy}, 2, "X:R", true], [{10=>:enemy}, 10, "X:R", true], [{0=>nil}, 0, "X:R", false], [{2=>nil}, 2, "X:R", false], [{2=>nil, 3=>:enemy}, 3, "X:R", true], [{2=>nil, 3=>nil}, 3, "X:R", false], [{2=>nil, 3=>nil, 4=>:enemy}, 4, "X:R", true], [{2=>nil, 3=>nil, 4=>nil}, 4, "X:R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "X:R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "X:R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "X:R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "X:R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "X:R", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:R", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:R", false], [{10=>nil}, 10, "X:R", false], [{10=>nil, 19=>:enemy}, 19, "X:R", true], [{10=>nil, 19=>nil}, 19, "X:R", false], [{10=>nil, 19=>nil, 28=>:enemy}, 28, "X:R", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "X:R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, 37, "X:R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "X:R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "X:R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "X:R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "X:R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "X:R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "X:R", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:R", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:R", false]], 2=>[[{1=>:enemy}, 1, "X:R", true], [{3=>:enemy}, 3, "X:R", true], [{11=>:enemy}, 11, "X:R", true], [{1=>nil}, 1, "X:R", false], [{1=>nil, 0=>:enemy}, 0, "X:R", true], [{1=>nil, 0=>nil}, 0, "X:R", false], [{3=>nil}, 3, "X:R", false], [{3=>nil, 4=>:enemy}, 4, "X:R", true], [{3=>nil, 4=>nil}, 4, "X:R", false], [{3=>nil, 4=>nil, 5=>:enemy}, 5, "X:R", true], [{3=>nil, 4=>nil, 5=>nil}, 5, "X:R", false], [{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "X:R", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "X:R", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:R", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "X:R", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:R", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:R", false], [{11=>nil}, 11, "X:R", false], [{11=>nil, 20=>:enemy}, 20, "X:R", true], [{11=>nil, 20=>nil}, 20, "X:R", false], [{11=>nil, 20=>nil, 29=>:enemy}, 29, "X:R", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "X:R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, 38, "X:R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "X:R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "X:R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "X:R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "X:R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "X:R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "X:R", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:R", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:R", false]], 3=>[[{2=>:enemy}, 2, "X:R", true], [{4=>:enemy}, 4, "X:R", true], [{12=>:enemy}, 12, "X:R", true], [{2=>nil}, 2, "X:R", false], [{2=>nil, 1=>:enemy}, 1, "X:R", true], [{2=>nil, 1=>nil}, 1, "X:R", false], [{2=>nil, 1=>nil, 0=>:enemy}, 0, "X:R", true], [{2=>nil, 1=>nil, 0=>nil}, 0, "X:R", false], [{4=>nil}, 4, "X:R", false], [{4=>nil, 5=>:enemy}, 5, "X:R", true], [{4=>nil, 5=>nil}, 5, "X:R", false], [{4=>nil, 5=>nil, 6=>:enemy}, 6, "X:R", true], [{4=>nil, 5=>nil, 6=>nil}, 6, "X:R", false], [{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "X:R", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "X:R", false], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:R", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:R", false], [{12=>nil}, 12, "X:R", false], [{12=>nil, 21=>:enemy}, 21, "X:R", true], [{12=>nil, 21=>nil}, 21, "X:R", false], [{12=>nil, 21=>nil, 30=>:enemy}, 30, "X:R", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "X:R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, 39, "X:R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "X:R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "X:R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "X:R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "X:R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "X:R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "X:R", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:R", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:R", false]], 4=>[[{3=>:enemy}, 3, "X:R", true], [{5=>:enemy}, 5, "X:R", true], [{13=>:enemy}, 13, "X:R", true], [{3=>nil}, 3, "X:R", false], [{3=>nil, 2=>:enemy}, 2, "X:R", true], [{3=>nil, 2=>nil}, 2, "X:R", false], [{3=>nil, 2=>nil, 1=>:enemy}, 1, "X:R", true], [{3=>nil, 2=>nil, 1=>nil}, 1, "X:R", false], [{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:R", true], [{3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:R", false], [{5=>nil}, 5, "X:R", false], [{5=>nil, 6=>:enemy}, 6, "X:R", true], [{5=>nil, 6=>nil}, 6, "X:R", false], [{5=>nil, 6=>nil, 7=>:enemy}, 7, "X:R", true], [{5=>nil, 6=>nil, 7=>nil}, 7, "X:R", false], [{5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "X:R", true], [{5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "X:R", false], [{13=>nil}, 13, "X:R", false], [{13=>nil, 22=>:enemy}, 22, "X:R", true], [{13=>nil, 22=>nil}, 22, "X:R", false], [{13=>nil, 22=>nil, 31=>:enemy}, 31, "X:R", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "X:R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:enemy}, 40, "X:R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "X:R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "X:R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "X:R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "X:R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "X:R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "X:R", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:R", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:R", false]], 5=>[[{4=>:enemy}, 4, "X:R", true], [{6=>:enemy}, 6, "X:R", true], [{14=>:enemy}, 14, "X:R", true], [{4=>nil}, 4, "X:R", false], [{4=>nil, 3=>:enemy}, 3, "X:R", true], [{4=>nil, 3=>nil}, 3, "X:R", false], [{4=>nil, 3=>nil, 2=>:enemy}, 2, "X:R", true], [{4=>nil, 3=>nil, 2=>nil}, 2, "X:R", false], [{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:R", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "X:R", false], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:R", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:R", false], [{6=>nil}, 6, "X:R", false], [{6=>nil, 7=>:enemy}, 7, "X:R", true], [{6=>nil, 7=>nil}, 7, "X:R", false], [{6=>nil, 7=>nil, 8=>:enemy}, 8, "X:R", true], [{6=>nil, 7=>nil, 8=>nil}, 8, "X:R", false], [{14=>nil}, 14, "X:R", false], [{14=>nil, 23=>:enemy}, 23, "X:R", true], [{14=>nil, 23=>nil}, 23, "X:R", false], [{14=>nil, 23=>nil, 32=>:enemy}, 32, "X:R", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "X:R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:enemy}, 41, "X:R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "X:R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "X:R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "X:R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "X:R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "X:R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "X:R", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:R", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:R", false]], 6=>[[{5=>:enemy}, 5, "X:R", true], [{7=>:enemy}, 7, "X:R", true], [{15=>:enemy}, 15, "X:R", true], [{5=>nil}, 5, "X:R", false], [{5=>nil, 4=>:enemy}, 4, "X:R", true], [{5=>nil, 4=>nil}, 4, "X:R", false], [{5=>nil, 4=>nil, 3=>:enemy}, 3, "X:R", true], [{5=>nil, 4=>nil, 3=>nil}, 3, "X:R", false], [{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "X:R", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "X:R", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:R", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "X:R", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:R", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:R", false], [{7=>nil}, 7, "X:R", false], [{7=>nil, 8=>:enemy}, 8, "X:R", true], [{7=>nil, 8=>nil}, 8, "X:R", false], [{15=>nil}, 15, "X:R", false], [{15=>nil, 24=>:enemy}, 24, "X:R", true], [{15=>nil, 24=>nil}, 24, "X:R", false], [{15=>nil, 24=>nil, 33=>:enemy}, 33, "X:R", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "X:R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:enemy}, 42, "X:R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "X:R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "X:R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "X:R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "X:R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "X:R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "X:R", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:R", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:R", false]], 7=>[[{6=>:enemy}, 6, "X:R", true], [{8=>:enemy}, 8, "X:R", true], [{16=>:enemy}, 16, "X:R", true], [{6=>nil}, 6, "X:R", false], [{6=>nil, 5=>:enemy}, 5, "X:R", true], [{6=>nil, 5=>nil}, 5, "X:R", false], [{6=>nil, 5=>nil, 4=>:enemy}, 4, "X:R", true], [{6=>nil, 5=>nil, 4=>nil}, 4, "X:R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "X:R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "X:R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "X:R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "X:R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "X:R", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:R", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:R", false], [{8=>nil}, 8, "X:R", false], [{16=>nil}, 16, "X:R", false], [{16=>nil, 25=>:enemy}, 25, "X:R", true], [{16=>nil, 25=>nil}, 25, "X:R", false], [{16=>nil, 25=>nil, 34=>:enemy}, 34, "X:R", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "X:R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:enemy}, 43, "X:R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "X:R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "X:R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "X:R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "X:R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "X:R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "X:R", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:R", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:R", false]], 8=>[[{7=>:enemy}, 7, "X:R", true], [{17=>:enemy}, 17, "X:R", true], [{7=>nil}, 7, "X:R", false], [{7=>nil, 6=>:enemy}, 6, "X:R", true], [{7=>nil, 6=>nil}, 6, "X:R", false], [{7=>nil, 6=>nil, 5=>:enemy}, 5, "X:R", true], [{7=>nil, 6=>nil, 5=>nil}, 5, "X:R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>:enemy}, 4, "X:R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil}, 4, "X:R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "X:R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "X:R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "X:R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "X:R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "X:R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "X:R", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "X:R", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "X:R", false], [{17=>nil}, 17, "X:R", false], [{17=>nil, 26=>:enemy}, 26, "X:R", true], [{17=>nil, 26=>nil}, 26, "X:R", false], [{17=>nil, 26=>nil, 35=>:enemy}, 35, "X:R", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "X:R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, 44, "X:R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "X:R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "X:R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "X:R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "X:R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "X:R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "X:R", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:R", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:R", false]], 9=>[[{0=>:enemy}, 0, "X:R", true], [{10=>:enemy}, 10, "X:R", true], [{18=>:enemy}, 18, "X:R", true], [{0=>nil}, 0, "X:R", false], [{10=>nil}, 10, "X:R", false], [{10=>nil, 11=>:enemy}, 11, "X:R", true], [{10=>nil, 11=>nil}, 11, "X:R", false], [{10=>nil, 11=>nil, 12=>:enemy}, 12, "X:R", true], [{10=>nil, 11=>nil, 12=>nil}, 12, "X:R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, 13, "X:R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil}, 13, "X:R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "X:R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "X:R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "X:R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "X:R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "X:R", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:R", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:R", false], [{18=>nil}, 18, "X:R", false], [{18=>nil, 27=>:enemy}, 27, "X:R", true], [{18=>nil, 27=>nil}, 27, "X:R", false], [{18=>nil, 27=>nil, 36=>:enemy}, 36, "X:R", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "X:R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "X:R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "X:R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "X:R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "X:R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "X:R", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:R", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:R", false]], 10=>[[{1=>:enemy}, 1, "X:R", true], [{9=>:enemy}, 9, "X:R", true], [{11=>:enemy}, 11, "X:R", true], [{19=>:enemy}, 19, "X:R", true], [{1=>nil}, 1, "X:R", false], [{9=>nil}, 9, "X:R", false], [{11=>nil}, 11, "X:R", false], [{11=>nil, 12=>:enemy}, 12, "X:R", true], [{11=>nil, 12=>nil}, 12, "X:R", false], [{11=>nil, 12=>nil, 13=>:enemy}, 13, "X:R", true], [{11=>nil, 12=>nil, 13=>nil}, 13, "X:R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "X:R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "X:R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "X:R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "X:R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "X:R", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:R", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:R", false], [{19=>nil}, 19, "X:R", false], [{19=>nil, 28=>:enemy}, 28, "X:R", true], [{19=>nil, 28=>nil}, 28, "X:R", false], [{19=>nil, 28=>nil, 37=>:enemy}, 37, "X:R", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "X:R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "X:R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "X:R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "X:R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "X:R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "X:R", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:R", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:R", false]], 11=>[[{2=>:enemy}, 2, "X:R", true], [{10=>:enemy}, 10, "X:R", true], [{12=>:enemy}, 12, "X:R", true], [{20=>:enemy}, 20, "X:R", true], [{2=>nil}, 2, "X:R", false], [{10=>nil}, 10, "X:R", false], [{10=>nil, 9=>:enemy}, 9, "X:R", true], [{10=>nil, 9=>nil}, 9, "X:R", false], [{12=>nil}, 12, "X:R", false], [{12=>nil, 13=>:enemy}, 13, "X:R", true], [{12=>nil, 13=>nil}, 13, "X:R", false], [{12=>nil, 13=>nil, 14=>:enemy}, 14, "X:R", true], [{12=>nil, 13=>nil, 14=>nil}, 14, "X:R", false], [{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "X:R", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "X:R", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:R", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "X:R", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:R", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:R", false], [{20=>nil}, 20, "X:R", false], [{20=>nil, 29=>:enemy}, 29, "X:R", true], [{20=>nil, 29=>nil}, 29, "X:R", false], [{20=>nil, 29=>nil, 38=>:enemy}, 38, "X:R", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "X:R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "X:R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "X:R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "X:R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "X:R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "X:R", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:R", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:R", false]], 12=>[[{3=>:enemy}, 3, "X:R", true], [{11=>:enemy}, 11, "X:R", true], [{13=>:enemy}, 13, "X:R", true], [{21=>:enemy}, 21, "X:R", true], [{3=>nil}, 3, "X:R", false], [{11=>nil}, 11, "X:R", false], [{11=>nil, 10=>:enemy}, 10, "X:R", true], [{11=>nil, 10=>nil}, 10, "X:R", false], [{11=>nil, 10=>nil, 9=>:enemy}, 9, "X:R", true], [{11=>nil, 10=>nil, 9=>nil}, 9, "X:R", false], [{13=>nil}, 13, "X:R", false], [{13=>nil, 14=>:enemy}, 14, "X:R", true], [{13=>nil, 14=>nil}, 14, "X:R", false], [{13=>nil, 14=>nil, 15=>:enemy}, 15, "X:R", true], [{13=>nil, 14=>nil, 15=>nil}, 15, "X:R", false], [{13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "X:R", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "X:R", false], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:R", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:R", false], [{21=>nil}, 21, "X:R", false], [{21=>nil, 30=>:enemy}, 30, "X:R", true], [{21=>nil, 30=>nil}, 30, "X:R", false], [{21=>nil, 30=>nil, 39=>:enemy}, 39, "X:R", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "X:R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "X:R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "X:R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "X:R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "X:R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "X:R", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:R", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:R", false]], 13=>[[{4=>:enemy}, 4, "X:R", true], [{12=>:enemy}, 12, "X:R", true], [{14=>:enemy}, 14, "X:R", true], [{22=>:enemy}, 22, "X:R", true], [{4=>nil}, 4, "X:R", false], [{12=>nil}, 12, "X:R", false], [{12=>nil, 11=>:enemy}, 11, "X:R", true], [{12=>nil, 11=>nil}, 11, "X:R", false], [{12=>nil, 11=>nil, 10=>:enemy}, 10, "X:R", true], [{12=>nil, 11=>nil, 10=>nil}, 10, "X:R", false], [{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:R", true], [{12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:R", false], [{14=>nil}, 14, "X:R", false], [{14=>nil, 15=>:enemy}, 15, "X:R", true], [{14=>nil, 15=>nil}, 15, "X:R", false], [{14=>nil, 15=>nil, 16=>:enemy}, 16, "X:R", true], [{14=>nil, 15=>nil, 16=>nil}, 16, "X:R", false], [{14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "X:R", true], [{14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "X:R", false], [{22=>nil}, 22, "X:R", false], [{22=>nil, 31=>:enemy}, 31, "X:R", true], [{22=>nil, 31=>nil}, 31, "X:R", false], [{22=>nil, 31=>nil, 40=>:enemy}, 40, "X:R", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "X:R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "X:R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "X:R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "X:R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "X:R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "X:R", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:R", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:R", false]], 14=>[[{5=>:enemy}, 5, "X:R", true], [{13=>:enemy}, 13, "X:R", true], [{15=>:enemy}, 15, "X:R", true], [{23=>:enemy}, 23, "X:R", true], [{5=>nil}, 5, "X:R", false], [{13=>nil}, 13, "X:R", false], [{13=>nil, 12=>:enemy}, 12, "X:R", true], [{13=>nil, 12=>nil}, 12, "X:R", false], [{13=>nil, 12=>nil, 11=>:enemy}, 11, "X:R", true], [{13=>nil, 12=>nil, 11=>nil}, 11, "X:R", false], [{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:R", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "X:R", false], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:R", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:R", false], [{15=>nil}, 15, "X:R", false], [{15=>nil, 16=>:enemy}, 16, "X:R", true], [{15=>nil, 16=>nil}, 16, "X:R", false], [{15=>nil, 16=>nil, 17=>:enemy}, 17, "X:R", true], [{15=>nil, 16=>nil, 17=>nil}, 17, "X:R", false], [{23=>nil}, 23, "X:R", false], [{23=>nil, 32=>:enemy}, 32, "X:R", true], [{23=>nil, 32=>nil}, 32, "X:R", false], [{23=>nil, 32=>nil, 41=>:enemy}, 41, "X:R", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "X:R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "X:R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "X:R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "X:R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "X:R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "X:R", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:R", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:R", false]], 15=>[[{6=>:enemy}, 6, "X:R", true], [{14=>:enemy}, 14, "X:R", true], [{16=>:enemy}, 16, "X:R", true], [{24=>:enemy}, 24, "X:R", true], [{6=>nil}, 6, "X:R", false], [{14=>nil}, 14, "X:R", false], [{14=>nil, 13=>:enemy}, 13, "X:R", true], [{14=>nil, 13=>nil}, 13, "X:R", false], [{14=>nil, 13=>nil, 12=>:enemy}, 12, "X:R", true], [{14=>nil, 13=>nil, 12=>nil}, 12, "X:R", false], [{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "X:R", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "X:R", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:R", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "X:R", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:R", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:R", false], [{16=>nil}, 16, "X:R", false], [{16=>nil, 17=>:enemy}, 17, "X:R", true], [{16=>nil, 17=>nil}, 17, "X:R", false], [{24=>nil}, 24, "X:R", false], [{24=>nil, 33=>:enemy}, 33, "X:R", true], [{24=>nil, 33=>nil}, 33, "X:R", false], [{24=>nil, 33=>nil, 42=>:enemy}, 42, "X:R", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "X:R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "X:R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "X:R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "X:R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "X:R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "X:R", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:R", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:R", false]], 16=>[[{7=>:enemy}, 7, "X:R", true], [{15=>:enemy}, 15, "X:R", true], [{17=>:enemy}, 17, "X:R", true], [{25=>:enemy}, 25, "X:R", true], [{7=>nil}, 7, "X:R", false], [{15=>nil}, 15, "X:R", false], [{15=>nil, 14=>:enemy}, 14, "X:R", true], [{15=>nil, 14=>nil}, 14, "X:R", false], [{15=>nil, 14=>nil, 13=>:enemy}, 13, "X:R", true], [{15=>nil, 14=>nil, 13=>nil}, 13, "X:R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "X:R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "X:R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "X:R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "X:R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "X:R", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:R", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:R", false], [{17=>nil}, 17, "X:R", false], [{25=>nil}, 25, "X:R", false], [{25=>nil, 34=>:enemy}, 34, "X:R", true], [{25=>nil, 34=>nil}, 34, "X:R", false], [{25=>nil, 34=>nil, 43=>:enemy}, 43, "X:R", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "X:R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "X:R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "X:R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "X:R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "X:R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "X:R", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:R", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:R", false]], 17=>[[{8=>:enemy}, 8, "X:R", true], [{16=>:enemy}, 16, "X:R", true], [{26=>:enemy}, 26, "X:R", true], [{8=>nil}, 8, "X:R", false], [{16=>nil}, 16, "X:R", false], [{16=>nil, 15=>:enemy}, 15, "X:R", true], [{16=>nil, 15=>nil}, 15, "X:R", false], [{16=>nil, 15=>nil, 14=>:enemy}, 14, "X:R", true], [{16=>nil, 15=>nil, 14=>nil}, 14, "X:R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>:enemy}, 13, "X:R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil}, 13, "X:R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "X:R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "X:R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "X:R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "X:R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "X:R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "X:R", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "X:R", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "X:R", false], [{26=>nil}, 26, "X:R", false], [{26=>nil, 35=>:enemy}, 35, "X:R", true], [{26=>nil, 35=>nil}, 35, "X:R", false], [{26=>nil, 35=>nil, 44=>:enemy}, 44, "X:R", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "X:R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "X:R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "X:R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "X:R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "X:R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "X:R", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:R", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:R", false]], 18=>[[{9=>:enemy}, 9, "X:R", true], [{19=>:enemy}, 19, "X:R", true], [{27=>:enemy}, 27, "X:R", true], [{9=>nil}, 9, "X:R", false], [{9=>nil, 0=>:enemy}, 0, "X:R", true], [{9=>nil, 0=>nil}, 0, "X:R", false], [{19=>nil}, 19, "X:R", false], [{19=>nil, 20=>:enemy}, 20, "X:R", true], [{19=>nil, 20=>nil}, 20, "X:R", false], [{19=>nil, 20=>nil, 21=>:enemy}, 21, "X:R", true], [{19=>nil, 20=>nil, 21=>nil}, 21, "X:R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, 22, "X:R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil}, 22, "X:R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "X:R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "X:R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "X:R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "X:R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "X:R", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:R", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:R", false], [{27=>nil}, 27, "X:R", false], [{27=>nil, 36=>:enemy}, 36, "X:R", true], [{27=>nil, 36=>nil}, 36, "X:R", false], [{27=>nil, 36=>nil, 45=>:enemy}, 45, "X:R", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "X:R", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "X:R", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "X:R", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:R", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "X:R", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:R", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:R", false]], 19=>[[{10=>:enemy}, 10, "X:R", true], [{18=>:enemy}, 18, "X:R", true], [{20=>:enemy}, 20, "X:R", true], [{28=>:enemy}, 28, "X:R", true], [{10=>nil}, 10, "X:R", false], [{10=>nil, 1=>:enemy}, 1, "X:R", true], [{10=>nil, 1=>nil}, 1, "X:R", false], [{18=>nil}, 18, "X:R", false], [{20=>nil}, 20, "X:R", false], [{20=>nil, 21=>:enemy}, 21, "X:R", true], [{20=>nil, 21=>nil}, 21, "X:R", false], [{20=>nil, 21=>nil, 22=>:enemy}, 22, "X:R", true], [{20=>nil, 21=>nil, 22=>nil}, 22, "X:R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "X:R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "X:R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "X:R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "X:R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "X:R", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:R", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:R", false], [{28=>nil}, 28, "X:R", false], [{28=>nil, 37=>:enemy}, 37, "X:R", true], [{28=>nil, 37=>nil}, 37, "X:R", false], [{28=>nil, 37=>nil, 46=>:enemy}, 46, "X:R", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "X:R", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "X:R", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "X:R", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:R", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "X:R", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:R", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:R", false]], 20=>[[{11=>:enemy}, 11, "X:R", true], [{19=>:enemy}, 19, "X:R", true], [{21=>:enemy}, 21, "X:R", true], [{29=>:enemy}, 29, "X:R", true], [{11=>nil}, 11, "X:R", false], [{11=>nil, 2=>:enemy}, 2, "X:R", true], [{11=>nil, 2=>nil}, 2, "X:R", false], [{19=>nil}, 19, "X:R", false], [{19=>nil, 18=>:enemy}, 18, "X:R", true], [{19=>nil, 18=>nil}, 18, "X:R", false], [{21=>nil}, 21, "X:R", false], [{21=>nil, 22=>:enemy}, 22, "X:R", true], [{21=>nil, 22=>nil}, 22, "X:R", false], [{21=>nil, 22=>nil, 23=>:enemy}, 23, "X:R", true], [{21=>nil, 22=>nil, 23=>nil}, 23, "X:R", false], [{21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "X:R", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "X:R", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:R", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "X:R", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:R", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:R", false], [{29=>nil}, 29, "X:R", false], [{29=>nil, 38=>:enemy}, 38, "X:R", true], [{29=>nil, 38=>nil}, 38, "X:R", false], [{29=>nil, 38=>nil, 47=>:enemy}, 47, "X:R", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "X:R", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "X:R", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "X:R", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:R", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "X:R", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:R", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:R", false]], 21=>[[{12=>:enemy}, 12, "X:R", true], [{20=>:enemy}, 20, "X:R", true], [{22=>:enemy}, 22, "X:R", true], [{30=>:enemy}, 30, "X:R", true], [{12=>nil}, 12, "X:R", false], [{12=>nil, 3=>:enemy}, 3, "X:R", true], [{12=>nil, 3=>nil}, 3, "X:R", false], [{20=>nil}, 20, "X:R", false], [{20=>nil, 19=>:enemy}, 19, "X:R", true], [{20=>nil, 19=>nil}, 19, "X:R", false], [{20=>nil, 19=>nil, 18=>:enemy}, 18, "X:R", true], [{20=>nil, 19=>nil, 18=>nil}, 18, "X:R", false], [{22=>nil}, 22, "X:R", false], [{22=>nil, 23=>:enemy}, 23, "X:R", true], [{22=>nil, 23=>nil}, 23, "X:R", false], [{22=>nil, 23=>nil, 24=>:enemy}, 24, "X:R", true], [{22=>nil, 23=>nil, 24=>nil}, 24, "X:R", false], [{22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "X:R", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "X:R", false], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:R", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:R", false], [{30=>nil}, 30, "X:R", false], [{30=>nil, 39=>:enemy}, 39, "X:R", true], [{30=>nil, 39=>nil}, 39, "X:R", false], [{30=>nil, 39=>nil, 48=>:enemy}, 48, "X:R", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "X:R", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "X:R", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "X:R", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:R", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "X:R", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:R", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:R", false]], 22=>[[{13=>:enemy}, 13, "X:R", true], [{21=>:enemy}, 21, "X:R", true], [{23=>:enemy}, 23, "X:R", true], [{31=>:enemy}, 31, "X:R", true], [{13=>nil}, 13, "X:R", false], [{13=>nil, 4=>:enemy}, 4, "X:R", true], [{13=>nil, 4=>nil}, 4, "X:R", false], [{21=>nil}, 21, "X:R", false], [{21=>nil, 20=>:enemy}, 20, "X:R", true], [{21=>nil, 20=>nil}, 20, "X:R", false], [{21=>nil, 20=>nil, 19=>:enemy}, 19, "X:R", true], [{21=>nil, 20=>nil, 19=>nil}, 19, "X:R", false], [{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:R", true], [{21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:R", false], [{23=>nil}, 23, "X:R", false], [{23=>nil, 24=>:enemy}, 24, "X:R", true], [{23=>nil, 24=>nil}, 24, "X:R", false], [{23=>nil, 24=>nil, 25=>:enemy}, 25, "X:R", true], [{23=>nil, 24=>nil, 25=>nil}, 25, "X:R", false], [{23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "X:R", true], [{23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "X:R", false], [{31=>nil}, 31, "X:R", false], [{31=>nil, 40=>:enemy}, 40, "X:R", true], [{31=>nil, 40=>nil}, 40, "X:R", false], [{31=>nil, 40=>nil, 49=>:enemy}, 49, "X:R", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "X:R", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "X:R", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "X:R", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:R", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "X:R", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:R", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:R", false]], 23=>[[{14=>:enemy}, 14, "X:R", true], [{22=>:enemy}, 22, "X:R", true], [{24=>:enemy}, 24, "X:R", true], [{32=>:enemy}, 32, "X:R", true], [{14=>nil}, 14, "X:R", false], [{14=>nil, 5=>:enemy}, 5, "X:R", true], [{14=>nil, 5=>nil}, 5, "X:R", false], [{22=>nil}, 22, "X:R", false], [{22=>nil, 21=>:enemy}, 21, "X:R", true], [{22=>nil, 21=>nil}, 21, "X:R", false], [{22=>nil, 21=>nil, 20=>:enemy}, 20, "X:R", true], [{22=>nil, 21=>nil, 20=>nil}, 20, "X:R", false], [{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:R", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "X:R", false], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:R", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:R", false], [{24=>nil}, 24, "X:R", false], [{24=>nil, 25=>:enemy}, 25, "X:R", true], [{24=>nil, 25=>nil}, 25, "X:R", false], [{24=>nil, 25=>nil, 26=>:enemy}, 26, "X:R", true], [{24=>nil, 25=>nil, 26=>nil}, 26, "X:R", false], [{32=>nil}, 32, "X:R", false], [{32=>nil, 41=>:enemy}, 41, "X:R", true], [{32=>nil, 41=>nil}, 41, "X:R", false], [{32=>nil, 41=>nil, 50=>:enemy}, 50, "X:R", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "X:R", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "X:R", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "X:R", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:R", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "X:R", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:R", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:R", false]], 24=>[[{15=>:enemy}, 15, "X:R", true], [{23=>:enemy}, 23, "X:R", true], [{25=>:enemy}, 25, "X:R", true], [{33=>:enemy}, 33, "X:R", true], [{15=>nil}, 15, "X:R", false], [{15=>nil, 6=>:enemy}, 6, "X:R", true], [{15=>nil, 6=>nil}, 6, "X:R", false], [{23=>nil}, 23, "X:R", false], [{23=>nil, 22=>:enemy}, 22, "X:R", true], [{23=>nil, 22=>nil}, 22, "X:R", false], [{23=>nil, 22=>nil, 21=>:enemy}, 21, "X:R", true], [{23=>nil, 22=>nil, 21=>nil}, 21, "X:R", false], [{23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "X:R", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "X:R", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:R", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "X:R", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:R", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:R", false], [{25=>nil}, 25, "X:R", false], [{25=>nil, 26=>:enemy}, 26, "X:R", true], [{25=>nil, 26=>nil}, 26, "X:R", false], [{33=>nil}, 33, "X:R", false], [{33=>nil, 42=>:enemy}, 42, "X:R", true], [{33=>nil, 42=>nil}, 42, "X:R", false], [{33=>nil, 42=>nil, 51=>:enemy}, 51, "X:R", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "X:R", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "X:R", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "X:R", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:R", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "X:R", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:R", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:R", false]], 25=>[[{16=>:enemy}, 16, "X:R", true], [{24=>:enemy}, 24, "X:R", true], [{26=>:enemy}, 26, "X:R", true], [{34=>:enemy}, 34, "X:R", true], [{16=>nil}, 16, "X:R", false], [{16=>nil, 7=>:enemy}, 7, "X:R", true], [{16=>nil, 7=>nil}, 7, "X:R", false], [{24=>nil}, 24, "X:R", false], [{24=>nil, 23=>:enemy}, 23, "X:R", true], [{24=>nil, 23=>nil}, 23, "X:R", false], [{24=>nil, 23=>nil, 22=>:enemy}, 22, "X:R", true], [{24=>nil, 23=>nil, 22=>nil}, 22, "X:R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "X:R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "X:R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "X:R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "X:R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "X:R", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:R", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:R", false], [{26=>nil}, 26, "X:R", false], [{34=>nil}, 34, "X:R", false], [{34=>nil, 43=>:enemy}, 43, "X:R", true], [{34=>nil, 43=>nil}, 43, "X:R", false], [{34=>nil, 43=>nil, 52=>:enemy}, 52, "X:R", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "X:R", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "X:R", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "X:R", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:R", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "X:R", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:R", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:R", false]], 26=>[[{17=>:enemy}, 17, "X:R", true], [{25=>:enemy}, 25, "X:R", true], [{35=>:enemy}, 35, "X:R", true], [{17=>nil}, 17, "X:R", false], [{17=>nil, 8=>:enemy}, 8, "X:R", true], [{17=>nil, 8=>nil}, 8, "X:R", false], [{25=>nil}, 25, "X:R", false], [{25=>nil, 24=>:enemy}, 24, "X:R", true], [{25=>nil, 24=>nil}, 24, "X:R", false], [{25=>nil, 24=>nil, 23=>:enemy}, 23, "X:R", true], [{25=>nil, 24=>nil, 23=>nil}, 23, "X:R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>:enemy}, 22, "X:R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil}, 22, "X:R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "X:R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "X:R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "X:R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "X:R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "X:R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "X:R", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "X:R", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "X:R", false], [{35=>nil}, 35, "X:R", false], [{35=>nil, 44=>:enemy}, 44, "X:R", true], [{35=>nil, 44=>nil}, 44, "X:R", false], [{35=>nil, 44=>nil, 53=>:enemy}, 53, "X:R", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "X:R", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "X:R", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "X:R", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:R", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "X:R", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:R", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:R", false]], 27=>[[{18=>:enemy}, 18, "X:R", true], [{28=>:enemy}, 28, "X:R", true], [{36=>:enemy}, 36, "X:R", true], [{18=>nil}, 18, "X:R", false], [{18=>nil, 9=>:enemy}, 9, "X:R", true], [{18=>nil, 9=>nil}, 9, "X:R", false], [{18=>nil, 9=>nil, 0=>:enemy}, 0, "X:R", true], [{18=>nil, 9=>nil, 0=>nil}, 0, "X:R", false], [{28=>nil}, 28, "X:R", false], [{28=>nil, 29=>:enemy}, 29, "X:R", true], [{28=>nil, 29=>nil}, 29, "X:R", false], [{28=>nil, 29=>nil, 30=>:enemy}, 30, "X:R", true], [{28=>nil, 29=>nil, 30=>nil}, 30, "X:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, 31, "X:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil}, 31, "X:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "X:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "X:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "X:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "X:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "X:R", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:R", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:R", false], [{36=>nil}, 36, "X:R", false], [{36=>nil, 45=>:enemy}, 45, "X:R", true], [{36=>nil, 45=>nil}, 45, "X:R", false], [{36=>nil, 45=>nil, 54=>:enemy}, 54, "X:R", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "X:R", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "X:R", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "X:R", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:R", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:R", false]], 28=>[[{19=>:enemy}, 19, "X:R", true], [{27=>:enemy}, 27, "X:R", true], [{29=>:enemy}, 29, "X:R", true], [{37=>:enemy}, 37, "X:R", true], [{19=>nil}, 19, "X:R", false], [{19=>nil, 10=>:enemy}, 10, "X:R", true], [{19=>nil, 10=>nil}, 10, "X:R", false], [{19=>nil, 10=>nil, 1=>:enemy}, 1, "X:R", true], [{19=>nil, 10=>nil, 1=>nil}, 1, "X:R", false], [{27=>nil}, 27, "X:R", false], [{29=>nil}, 29, "X:R", false], [{29=>nil, 30=>:enemy}, 30, "X:R", true], [{29=>nil, 30=>nil}, 30, "X:R", false], [{29=>nil, 30=>nil, 31=>:enemy}, 31, "X:R", true], [{29=>nil, 30=>nil, 31=>nil}, 31, "X:R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "X:R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "X:R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "X:R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "X:R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "X:R", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:R", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:R", false], [{37=>nil}, 37, "X:R", false], [{37=>nil, 46=>:enemy}, 46, "X:R", true], [{37=>nil, 46=>nil}, 46, "X:R", false], [{37=>nil, 46=>nil, 55=>:enemy}, 55, "X:R", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "X:R", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "X:R", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "X:R", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:R", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:R", false]], 29=>[[{20=>:enemy}, 20, "X:R", true], [{28=>:enemy}, 28, "X:R", true], [{30=>:enemy}, 30, "X:R", true], [{38=>:enemy}, 38, "X:R", true], [{20=>nil}, 20, "X:R", false], [{20=>nil, 11=>:enemy}, 11, "X:R", true], [{20=>nil, 11=>nil}, 11, "X:R", false], [{20=>nil, 11=>nil, 2=>:enemy}, 2, "X:R", true], [{20=>nil, 11=>nil, 2=>nil}, 2, "X:R", false], [{28=>nil}, 28, "X:R", false], [{28=>nil, 27=>:enemy}, 27, "X:R", true], [{28=>nil, 27=>nil}, 27, "X:R", false], [{30=>nil}, 30, "X:R", false], [{30=>nil, 31=>:enemy}, 31, "X:R", true], [{30=>nil, 31=>nil}, 31, "X:R", false], [{30=>nil, 31=>nil, 32=>:enemy}, 32, "X:R", true], [{30=>nil, 31=>nil, 32=>nil}, 32, "X:R", false], [{30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "X:R", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "X:R", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:R", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "X:R", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:R", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:R", false], [{38=>nil}, 38, "X:R", false], [{38=>nil, 47=>:enemy}, 47, "X:R", true], [{38=>nil, 47=>nil}, 47, "X:R", false], [{38=>nil, 47=>nil, 56=>:enemy}, 56, "X:R", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "X:R", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "X:R", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "X:R", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:R", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:R", false]], 30=>[[{21=>:enemy}, 21, "X:R", true], [{29=>:enemy}, 29, "X:R", true], [{31=>:enemy}, 31, "X:R", true], [{39=>:enemy}, 39, "X:R", true], [{21=>nil}, 21, "X:R", false], [{21=>nil, 12=>:enemy}, 12, "X:R", true], [{21=>nil, 12=>nil}, 12, "X:R", false], [{21=>nil, 12=>nil, 3=>:enemy}, 3, "X:R", true], [{21=>nil, 12=>nil, 3=>nil}, 3, "X:R", false], [{29=>nil}, 29, "X:R", false], [{29=>nil, 28=>:enemy}, 28, "X:R", true], [{29=>nil, 28=>nil}, 28, "X:R", false], [{29=>nil, 28=>nil, 27=>:enemy}, 27, "X:R", true], [{29=>nil, 28=>nil, 27=>nil}, 27, "X:R", false], [{31=>nil}, 31, "X:R", false], [{31=>nil, 32=>:enemy}, 32, "X:R", true], [{31=>nil, 32=>nil}, 32, "X:R", false], [{31=>nil, 32=>nil, 33=>:enemy}, 33, "X:R", true], [{31=>nil, 32=>nil, 33=>nil}, 33, "X:R", false], [{31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "X:R", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "X:R", false], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:R", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:R", false], [{39=>nil}, 39, "X:R", false], [{39=>nil, 48=>:enemy}, 48, "X:R", true], [{39=>nil, 48=>nil}, 48, "X:R", false], [{39=>nil, 48=>nil, 57=>:enemy}, 57, "X:R", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "X:R", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "X:R", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "X:R", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:R", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:R", false]], 31=>[[{22=>:enemy}, 22, "X:R", true], [{30=>:enemy}, 30, "X:R", true], [{32=>:enemy}, 32, "X:R", true], [{40=>:enemy}, 40, "X:R", true], [{22=>nil}, 22, "X:R", false], [{22=>nil, 13=>:enemy}, 13, "X:R", true], [{22=>nil, 13=>nil}, 13, "X:R", false], [{22=>nil, 13=>nil, 4=>:enemy}, 4, "X:R", true], [{22=>nil, 13=>nil, 4=>nil}, 4, "X:R", false], [{30=>nil}, 30, "X:R", false], [{30=>nil, 29=>:enemy}, 29, "X:R", true], [{30=>nil, 29=>nil}, 29, "X:R", false], [{30=>nil, 29=>nil, 28=>:enemy}, 28, "X:R", true], [{30=>nil, 29=>nil, 28=>nil}, 28, "X:R", false], [{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:R", true], [{30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:R", false], [{32=>nil}, 32, "X:R", false], [{32=>nil, 33=>:enemy}, 33, "X:R", true], [{32=>nil, 33=>nil}, 33, "X:R", false], [{32=>nil, 33=>nil, 34=>:enemy}, 34, "X:R", true], [{32=>nil, 33=>nil, 34=>nil}, 34, "X:R", false], [{32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "X:R", true], [{32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "X:R", false], [{40=>nil}, 40, "X:R", false], [{40=>nil, 49=>:enemy}, 49, "X:R", true], [{40=>nil, 49=>nil}, 49, "X:R", false], [{40=>nil, 49=>nil, 58=>:enemy}, 58, "X:R", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "X:R", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "X:R", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "X:R", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:R", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:R", false]], 32=>[[{23=>:enemy}, 23, "X:R", true], [{31=>:enemy}, 31, "X:R", true], [{33=>:enemy}, 33, "X:R", true], [{41=>:enemy}, 41, "X:R", true], [{23=>nil}, 23, "X:R", false], [{23=>nil, 14=>:enemy}, 14, "X:R", true], [{23=>nil, 14=>nil}, 14, "X:R", false], [{23=>nil, 14=>nil, 5=>:enemy}, 5, "X:R", true], [{23=>nil, 14=>nil, 5=>nil}, 5, "X:R", false], [{31=>nil}, 31, "X:R", false], [{31=>nil, 30=>:enemy}, 30, "X:R", true], [{31=>nil, 30=>nil}, 30, "X:R", false], [{31=>nil, 30=>nil, 29=>:enemy}, 29, "X:R", true], [{31=>nil, 30=>nil, 29=>nil}, 29, "X:R", false], [{31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:R", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "X:R", false], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:R", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:R", false], [{33=>nil}, 33, "X:R", false], [{33=>nil, 34=>:enemy}, 34, "X:R", true], [{33=>nil, 34=>nil}, 34, "X:R", false], [{33=>nil, 34=>nil, 35=>:enemy}, 35, "X:R", true], [{33=>nil, 34=>nil, 35=>nil}, 35, "X:R", false], [{41=>nil}, 41, "X:R", false], [{41=>nil, 50=>:enemy}, 50, "X:R", true], [{41=>nil, 50=>nil}, 50, "X:R", false], [{41=>nil, 50=>nil, 59=>:enemy}, 59, "X:R", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "X:R", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "X:R", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "X:R", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:R", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:R", false]], 33=>[[{24=>:enemy}, 24, "X:R", true], [{32=>:enemy}, 32, "X:R", true], [{34=>:enemy}, 34, "X:R", true], [{42=>:enemy}, 42, "X:R", true], [{24=>nil}, 24, "X:R", false], [{24=>nil, 15=>:enemy}, 15, "X:R", true], [{24=>nil, 15=>nil}, 15, "X:R", false], [{24=>nil, 15=>nil, 6=>:enemy}, 6, "X:R", true], [{24=>nil, 15=>nil, 6=>nil}, 6, "X:R", false], [{32=>nil}, 32, "X:R", false], [{32=>nil, 31=>:enemy}, 31, "X:R", true], [{32=>nil, 31=>nil}, 31, "X:R", false], [{32=>nil, 31=>nil, 30=>:enemy}, 30, "X:R", true], [{32=>nil, 31=>nil, 30=>nil}, 30, "X:R", false], [{32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "X:R", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "X:R", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:R", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "X:R", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:R", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:R", false], [{34=>nil}, 34, "X:R", false], [{34=>nil, 35=>:enemy}, 35, "X:R", true], [{34=>nil, 35=>nil}, 35, "X:R", false], [{42=>nil}, 42, "X:R", false], [{42=>nil, 51=>:enemy}, 51, "X:R", true], [{42=>nil, 51=>nil}, 51, "X:R", false], [{42=>nil, 51=>nil, 60=>:enemy}, 60, "X:R", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "X:R", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "X:R", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "X:R", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:R", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:R", false]], 34=>[[{25=>:enemy}, 25, "X:R", true], [{33=>:enemy}, 33, "X:R", true], [{35=>:enemy}, 35, "X:R", true], [{43=>:enemy}, 43, "X:R", true], [{25=>nil}, 25, "X:R", false], [{25=>nil, 16=>:enemy}, 16, "X:R", true], [{25=>nil, 16=>nil}, 16, "X:R", false], [{25=>nil, 16=>nil, 7=>:enemy}, 7, "X:R", true], [{25=>nil, 16=>nil, 7=>nil}, 7, "X:R", false], [{33=>nil}, 33, "X:R", false], [{33=>nil, 32=>:enemy}, 32, "X:R", true], [{33=>nil, 32=>nil}, 32, "X:R", false], [{33=>nil, 32=>nil, 31=>:enemy}, 31, "X:R", true], [{33=>nil, 32=>nil, 31=>nil}, 31, "X:R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "X:R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "X:R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "X:R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "X:R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "X:R", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:R", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:R", false], [{35=>nil}, 35, "X:R", false], [{43=>nil}, 43, "X:R", false], [{43=>nil, 52=>:enemy}, 52, "X:R", true], [{43=>nil, 52=>nil}, 52, "X:R", false], [{43=>nil, 52=>nil, 61=>:enemy}, 61, "X:R", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "X:R", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "X:R", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "X:R", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:R", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:R", false]], 35=>[[{26=>:enemy}, 26, "X:R", true], [{34=>:enemy}, 34, "X:R", true], [{44=>:enemy}, 44, "X:R", true], [{26=>nil}, 26, "X:R", false], [{26=>nil, 17=>:enemy}, 17, "X:R", true], [{26=>nil, 17=>nil}, 17, "X:R", false], [{26=>nil, 17=>nil, 8=>:enemy}, 8, "X:R", true], [{26=>nil, 17=>nil, 8=>nil}, 8, "X:R", false], [{34=>nil}, 34, "X:R", false], [{34=>nil, 33=>:enemy}, 33, "X:R", true], [{34=>nil, 33=>nil}, 33, "X:R", false], [{34=>nil, 33=>nil, 32=>:enemy}, 32, "X:R", true], [{34=>nil, 33=>nil, 32=>nil}, 32, "X:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>:enemy}, 31, "X:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil}, 31, "X:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "X:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "X:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "X:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "X:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "X:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "X:R", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "X:R", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "X:R", false], [{44=>nil}, 44, "X:R", false], [{44=>nil, 53=>:enemy}, 53, "X:R", true], [{44=>nil, 53=>nil}, 53, "X:R", false], [{44=>nil, 53=>nil, 62=>:enemy}, 62, "X:R", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "X:R", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "X:R", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "X:R", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:R", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:R", false]], 36=>[[{27=>:enemy}, 27, "X:R", true], [{37=>:enemy}, 37, "X:R", true], [{45=>:enemy}, 45, "X:R", true], [{27=>nil}, 27, "X:R", false], [{27=>nil, 18=>:enemy}, 18, "X:R", true], [{27=>nil, 18=>nil}, 18, "X:R", false], [{27=>nil, 18=>nil, 9=>:enemy}, 9, "X:R", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "X:R", false], [{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:R", true], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:R", false], [{37=>nil}, 37, "X:R", false], [{37=>nil, 38=>:enemy}, 38, "X:R", true], [{37=>nil, 38=>nil}, 38, "X:R", false], [{37=>nil, 38=>nil, 39=>:enemy}, 39, "X:R", true], [{37=>nil, 38=>nil, 39=>nil}, 39, "X:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>:enemy}, 40, "X:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil}, 40, "X:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "X:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "X:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "X:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "X:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "X:R", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:R", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:R", false], [{45=>nil}, 45, "X:R", false], [{45=>nil, 54=>:enemy}, 54, "X:R", true], [{45=>nil, 54=>nil}, 54, "X:R", false], [{45=>nil, 54=>nil, 63=>:enemy}, 63, "X:R", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "X:R", false], [{45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "X:R", true], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "X:R", false]], 37=>[[{28=>:enemy}, 28, "X:R", true], [{36=>:enemy}, 36, "X:R", true], [{38=>:enemy}, 38, "X:R", true], [{46=>:enemy}, 46, "X:R", true], [{28=>nil}, 28, "X:R", false], [{28=>nil, 19=>:enemy}, 19, "X:R", true], [{28=>nil, 19=>nil}, 19, "X:R", false], [{28=>nil, 19=>nil, 10=>:enemy}, 10, "X:R", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "X:R", false], [{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:R", true], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:R", false], [{36=>nil}, 36, "X:R", false], [{38=>nil}, 38, "X:R", false], [{38=>nil, 39=>:enemy}, 39, "X:R", true], [{38=>nil, 39=>nil}, 39, "X:R", false], [{38=>nil, 39=>nil, 40=>:enemy}, 40, "X:R", true], [{38=>nil, 39=>nil, 40=>nil}, 40, "X:R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "X:R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "X:R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "X:R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "X:R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "X:R", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:R", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:R", false], [{46=>nil}, 46, "X:R", false], [{46=>nil, 55=>:enemy}, 55, "X:R", true], [{46=>nil, 55=>nil}, 55, "X:R", false], [{46=>nil, 55=>nil, 64=>:enemy}, 64, "X:R", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "X:R", false], [{46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "X:R", true], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "X:R", false]], 38=>[[{29=>:enemy}, 29, "X:R", true], [{37=>:enemy}, 37, "X:R", true], [{39=>:enemy}, 39, "X:R", true], [{47=>:enemy}, 47, "X:R", true], [{29=>nil}, 29, "X:R", false], [{29=>nil, 20=>:enemy}, 20, "X:R", true], [{29=>nil, 20=>nil}, 20, "X:R", false], [{29=>nil, 20=>nil, 11=>:enemy}, 11, "X:R", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "X:R", false], [{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:R", true], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:R", false], [{37=>nil}, 37, "X:R", false], [{37=>nil, 36=>:enemy}, 36, "X:R", true], [{37=>nil, 36=>nil}, 36, "X:R", false], [{39=>nil}, 39, "X:R", false], [{39=>nil, 40=>:enemy}, 40, "X:R", true], [{39=>nil, 40=>nil}, 40, "X:R", false], [{39=>nil, 40=>nil, 41=>:enemy}, 41, "X:R", true], [{39=>nil, 40=>nil, 41=>nil}, 41, "X:R", false], [{39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "X:R", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "X:R", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:R", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "X:R", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:R", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:R", false], [{47=>nil}, 47, "X:R", false], [{47=>nil, 56=>:enemy}, 56, "X:R", true], [{47=>nil, 56=>nil}, 56, "X:R", false], [{47=>nil, 56=>nil, 65=>:enemy}, 65, "X:R", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "X:R", false], [{47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "X:R", true], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "X:R", false]], 39=>[[{30=>:enemy}, 30, "X:R", true], [{38=>:enemy}, 38, "X:R", true], [{40=>:enemy}, 40, "X:R", true], [{48=>:enemy}, 48, "X:R", true], [{30=>nil}, 30, "X:R", false], [{30=>nil, 21=>:enemy}, 21, "X:R", true], [{30=>nil, 21=>nil}, 21, "X:R", false], [{30=>nil, 21=>nil, 12=>:enemy}, 12, "X:R", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "X:R", false], [{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:R", true], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:R", false], [{38=>nil}, 38, "X:R", false], [{38=>nil, 37=>:enemy}, 37, "X:R", true], [{38=>nil, 37=>nil}, 37, "X:R", false], [{38=>nil, 37=>nil, 36=>:enemy}, 36, "X:R", true], [{38=>nil, 37=>nil, 36=>nil}, 36, "X:R", false], [{40=>nil}, 40, "X:R", false], [{40=>nil, 41=>:enemy}, 41, "X:R", true], [{40=>nil, 41=>nil}, 41, "X:R", false], [{40=>nil, 41=>nil, 42=>:enemy}, 42, "X:R", true], [{40=>nil, 41=>nil, 42=>nil}, 42, "X:R", false], [{40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "X:R", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "X:R", false], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:R", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:R", false], [{48=>nil}, 48, "X:R", false], [{48=>nil, 57=>:enemy}, 57, "X:R", true], [{48=>nil, 57=>nil}, 57, "X:R", false], [{48=>nil, 57=>nil, 66=>:enemy}, 66, "X:R", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "X:R", false], [{48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "X:R", true], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "X:R", false]], 40=>[[{31=>:enemy}, 31, "X:R", true], [{39=>:enemy}, 39, "X:R", true], [{41=>:enemy}, 41, "X:R", true], [{49=>:enemy}, 49, "X:R", true], [{31=>nil}, 31, "X:R", false], [{31=>nil, 22=>:enemy}, 22, "X:R", true], [{31=>nil, 22=>nil}, 22, "X:R", false], [{31=>nil, 22=>nil, 13=>:enemy}, 13, "X:R", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "X:R", false], [{31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:R", true], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:R", false], [{39=>nil}, 39, "X:R", false], [{39=>nil, 38=>:enemy}, 38, "X:R", true], [{39=>nil, 38=>nil}, 38, "X:R", false], [{39=>nil, 38=>nil, 37=>:enemy}, 37, "X:R", true], [{39=>nil, 38=>nil, 37=>nil}, 37, "X:R", false], [{39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:R", true], [{39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:R", false], [{41=>nil}, 41, "X:R", false], [{41=>nil, 42=>:enemy}, 42, "X:R", true], [{41=>nil, 42=>nil}, 42, "X:R", false], [{41=>nil, 42=>nil, 43=>:enemy}, 43, "X:R", true], [{41=>nil, 42=>nil, 43=>nil}, 43, "X:R", false], [{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "X:R", true], [{41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "X:R", false], [{49=>nil}, 49, "X:R", false], [{49=>nil, 58=>:enemy}, 58, "X:R", true], [{49=>nil, 58=>nil}, 58, "X:R", false], [{49=>nil, 58=>nil, 67=>:enemy}, 67, "X:R", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "X:R", false], [{49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "X:R", true], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "X:R", false]], 41=>[[{32=>:enemy}, 32, "X:R", true], [{40=>:enemy}, 40, "X:R", true], [{42=>:enemy}, 42, "X:R", true], [{50=>:enemy}, 50, "X:R", true], [{32=>nil}, 32, "X:R", false], [{32=>nil, 23=>:enemy}, 23, "X:R", true], [{32=>nil, 23=>nil}, 23, "X:R", false], [{32=>nil, 23=>nil, 14=>:enemy}, 14, "X:R", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "X:R", false], [{32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:R", true], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:R", false], [{40=>nil}, 40, "X:R", false], [{40=>nil, 39=>:enemy}, 39, "X:R", true], [{40=>nil, 39=>nil}, 39, "X:R", false], [{40=>nil, 39=>nil, 38=>:enemy}, 38, "X:R", true], [{40=>nil, 39=>nil, 38=>nil}, 38, "X:R", false], [{40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:R", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "X:R", false], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:R", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:R", false], [{42=>nil}, 42, "X:R", false], [{42=>nil, 43=>:enemy}, 43, "X:R", true], [{42=>nil, 43=>nil}, 43, "X:R", false], [{42=>nil, 43=>nil, 44=>:enemy}, 44, "X:R", true], [{42=>nil, 43=>nil, 44=>nil}, 44, "X:R", false], [{50=>nil}, 50, "X:R", false], [{50=>nil, 59=>:enemy}, 59, "X:R", true], [{50=>nil, 59=>nil}, 59, "X:R", false], [{50=>nil, 59=>nil, 68=>:enemy}, 68, "X:R", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "X:R", false], [{50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "X:R", true], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "X:R", false]], 42=>[[{33=>:enemy}, 33, "X:R", true], [{41=>:enemy}, 41, "X:R", true], [{43=>:enemy}, 43, "X:R", true], [{51=>:enemy}, 51, "X:R", true], [{33=>nil}, 33, "X:R", false], [{33=>nil, 24=>:enemy}, 24, "X:R", true], [{33=>nil, 24=>nil}, 24, "X:R", false], [{33=>nil, 24=>nil, 15=>:enemy}, 15, "X:R", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "X:R", false], [{33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:R", true], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:R", false], [{41=>nil}, 41, "X:R", false], [{41=>nil, 40=>:enemy}, 40, "X:R", true], [{41=>nil, 40=>nil}, 40, "X:R", false], [{41=>nil, 40=>nil, 39=>:enemy}, 39, "X:R", true], [{41=>nil, 40=>nil, 39=>nil}, 39, "X:R", false], [{41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "X:R", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "X:R", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:R", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "X:R", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:R", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:R", false], [{43=>nil}, 43, "X:R", false], [{43=>nil, 44=>:enemy}, 44, "X:R", true], [{43=>nil, 44=>nil}, 44, "X:R", false], [{51=>nil}, 51, "X:R", false], [{51=>nil, 60=>:enemy}, 60, "X:R", true], [{51=>nil, 60=>nil}, 60, "X:R", false], [{51=>nil, 60=>nil, 69=>:enemy}, 69, "X:R", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "X:R", false], [{51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "X:R", true], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "X:R", false]], 43=>[[{34=>:enemy}, 34, "X:R", true], [{42=>:enemy}, 42, "X:R", true], [{44=>:enemy}, 44, "X:R", true], [{52=>:enemy}, 52, "X:R", true], [{34=>nil}, 34, "X:R", false], [{34=>nil, 25=>:enemy}, 25, "X:R", true], [{34=>nil, 25=>nil}, 25, "X:R", false], [{34=>nil, 25=>nil, 16=>:enemy}, 16, "X:R", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "X:R", false], [{34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:R", true], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:R", false], [{42=>nil}, 42, "X:R", false], [{42=>nil, 41=>:enemy}, 41, "X:R", true], [{42=>nil, 41=>nil}, 41, "X:R", false], [{42=>nil, 41=>nil, 40=>:enemy}, 40, "X:R", true], [{42=>nil, 41=>nil, 40=>nil}, 40, "X:R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "X:R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "X:R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "X:R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "X:R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "X:R", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:R", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:R", false], [{44=>nil}, 44, "X:R", false], [{52=>nil}, 52, "X:R", false], [{52=>nil, 61=>:enemy}, 61, "X:R", true], [{52=>nil, 61=>nil}, 61, "X:R", false], [{52=>nil, 61=>nil, 70=>:enemy}, 70, "X:R", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "X:R", false], [{52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "X:R", true], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "X:R", false]], 44=>[[{35=>:enemy}, 35, "X:R", true], [{43=>:enemy}, 43, "X:R", true], [{53=>:enemy}, 53, "X:R", true], [{35=>nil}, 35, "X:R", false], [{35=>nil, 26=>:enemy}, 26, "X:R", true], [{35=>nil, 26=>nil}, 26, "X:R", false], [{35=>nil, 26=>nil, 17=>:enemy}, 17, "X:R", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "X:R", false], [{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:R", true], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:R", false], [{43=>nil}, 43, "X:R", false], [{43=>nil, 42=>:enemy}, 42, "X:R", true], [{43=>nil, 42=>nil}, 42, "X:R", false], [{43=>nil, 42=>nil, 41=>:enemy}, 41, "X:R", true], [{43=>nil, 42=>nil, 41=>nil}, 41, "X:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, 40, "X:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil}, 40, "X:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "X:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "X:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "X:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "X:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "X:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "X:R", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "X:R", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "X:R", false], [{53=>nil}, 53, "X:R", false], [{53=>nil, 62=>:enemy}, 62, "X:R", true], [{53=>nil, 62=>nil}, 62, "X:R", false], [{53=>nil, 62=>nil, 71=>:enemy}, 71, "X:R", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "X:R", false], [{53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "X:R", true], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "X:R", false]], 45=>[[{36=>:enemy}, 36, "X:R", true], [{46=>:enemy}, 46, "X:R", true], [{54=>:enemy}, 54, "X:R", true], [{36=>nil}, 36, "X:R", false], [{36=>nil, 27=>:enemy}, 27, "X:R", true], [{36=>nil, 27=>nil}, 27, "X:R", false], [{36=>nil, 27=>nil, 18=>:enemy}, 18, "X:R", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "X:R", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:R", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "X:R", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:R", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:R", false], [{46=>nil}, 46, "X:R", false], [{46=>nil, 47=>:enemy}, 47, "X:R", true], [{46=>nil, 47=>nil}, 47, "X:R", false], [{46=>nil, 47=>nil, 48=>:enemy}, 48, "X:R", true], [{46=>nil, 47=>nil, 48=>nil}, 48, "X:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>:enemy}, 49, "X:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil}, 49, "X:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "X:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "X:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "X:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "X:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "X:R", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:R", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:R", false], [{54=>nil}, 54, "X:R", false], [{54=>nil, 63=>:enemy}, 63, "X:R", true], [{54=>nil, 63=>nil}, 63, "X:R", false], [{54=>nil, 63=>nil, 72=>:enemy}, 72, "X:R", true], [{54=>nil, 63=>nil, 72=>nil}, 72, "X:R", false]], 46=>[[{37=>:enemy}, 37, "X:R", true], [{45=>:enemy}, 45, "X:R", true], [{47=>:enemy}, 47, "X:R", true], [{55=>:enemy}, 55, "X:R", true], [{37=>nil}, 37, "X:R", false], [{37=>nil, 28=>:enemy}, 28, "X:R", true], [{37=>nil, 28=>nil}, 28, "X:R", false], [{37=>nil, 28=>nil, 19=>:enemy}, 19, "X:R", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "X:R", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:R", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "X:R", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:R", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:R", false], [{45=>nil}, 45, "X:R", false], [{47=>nil}, 47, "X:R", false], [{47=>nil, 48=>:enemy}, 48, "X:R", true], [{47=>nil, 48=>nil}, 48, "X:R", false], [{47=>nil, 48=>nil, 49=>:enemy}, 49, "X:R", true], [{47=>nil, 48=>nil, 49=>nil}, 49, "X:R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "X:R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "X:R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "X:R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "X:R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "X:R", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:R", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:R", false], [{55=>nil}, 55, "X:R", false], [{55=>nil, 64=>:enemy}, 64, "X:R", true], [{55=>nil, 64=>nil}, 64, "X:R", false], [{55=>nil, 64=>nil, 73=>:enemy}, 73, "X:R", true], [{55=>nil, 64=>nil, 73=>nil}, 73, "X:R", false]], 47=>[[{38=>:enemy}, 38, "X:R", true], [{46=>:enemy}, 46, "X:R", true], [{48=>:enemy}, 48, "X:R", true], [{56=>:enemy}, 56, "X:R", true], [{38=>nil}, 38, "X:R", false], [{38=>nil, 29=>:enemy}, 29, "X:R", true], [{38=>nil, 29=>nil}, 29, "X:R", false], [{38=>nil, 29=>nil, 20=>:enemy}, 20, "X:R", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "X:R", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:R", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "X:R", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:R", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:R", false], [{46=>nil}, 46, "X:R", false], [{46=>nil, 45=>:enemy}, 45, "X:R", true], [{46=>nil, 45=>nil}, 45, "X:R", false], [{48=>nil}, 48, "X:R", false], [{48=>nil, 49=>:enemy}, 49, "X:R", true], [{48=>nil, 49=>nil}, 49, "X:R", false], [{48=>nil, 49=>nil, 50=>:enemy}, 50, "X:R", true], [{48=>nil, 49=>nil, 50=>nil}, 50, "X:R", false], [{48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "X:R", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "X:R", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:R", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "X:R", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:R", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:R", false], [{56=>nil}, 56, "X:R", false], [{56=>nil, 65=>:enemy}, 65, "X:R", true], [{56=>nil, 65=>nil}, 65, "X:R", false], [{56=>nil, 65=>nil, 74=>:enemy}, 74, "X:R", true], [{56=>nil, 65=>nil, 74=>nil}, 74, "X:R", false]], 48=>[[{39=>:enemy}, 39, "X:R", true], [{47=>:enemy}, 47, "X:R", true], [{49=>:enemy}, 49, "X:R", true], [{57=>:enemy}, 57, "X:R", true], [{39=>nil}, 39, "X:R", false], [{39=>nil, 30=>:enemy}, 30, "X:R", true], [{39=>nil, 30=>nil}, 30, "X:R", false], [{39=>nil, 30=>nil, 21=>:enemy}, 21, "X:R", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "X:R", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:R", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "X:R", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:R", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:R", false], [{47=>nil}, 47, "X:R", false], [{47=>nil, 46=>:enemy}, 46, "X:R", true], [{47=>nil, 46=>nil}, 46, "X:R", false], [{47=>nil, 46=>nil, 45=>:enemy}, 45, "X:R", true], [{47=>nil, 46=>nil, 45=>nil}, 45, "X:R", false], [{49=>nil}, 49, "X:R", false], [{49=>nil, 50=>:enemy}, 50, "X:R", true], [{49=>nil, 50=>nil}, 50, "X:R", false], [{49=>nil, 50=>nil, 51=>:enemy}, 51, "X:R", true], [{49=>nil, 50=>nil, 51=>nil}, 51, "X:R", false], [{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "X:R", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "X:R", false], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:R", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:R", false], [{57=>nil}, 57, "X:R", false], [{57=>nil, 66=>:enemy}, 66, "X:R", true], [{57=>nil, 66=>nil}, 66, "X:R", false], [{57=>nil, 66=>nil, 75=>:enemy}, 75, "X:R", true], [{57=>nil, 66=>nil, 75=>nil}, 75, "X:R", false]], 49=>[[{40=>:enemy}, 40, "X:R", true], [{48=>:enemy}, 48, "X:R", true], [{50=>:enemy}, 50, "X:R", true], [{58=>:enemy}, 58, "X:R", true], [{40=>nil}, 40, "X:R", false], [{40=>nil, 31=>:enemy}, 31, "X:R", true], [{40=>nil, 31=>nil}, 31, "X:R", false], [{40=>nil, 31=>nil, 22=>:enemy}, 22, "X:R", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "X:R", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:R", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "X:R", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:R", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:R", false], [{48=>nil}, 48, "X:R", false], [{48=>nil, 47=>:enemy}, 47, "X:R", true], [{48=>nil, 47=>nil}, 47, "X:R", false], [{48=>nil, 47=>nil, 46=>:enemy}, 46, "X:R", true], [{48=>nil, 47=>nil, 46=>nil}, 46, "X:R", false], [{48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:R", true], [{48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:R", false], [{50=>nil}, 50, "X:R", false], [{50=>nil, 51=>:enemy}, 51, "X:R", true], [{50=>nil, 51=>nil}, 51, "X:R", false], [{50=>nil, 51=>nil, 52=>:enemy}, 52, "X:R", true], [{50=>nil, 51=>nil, 52=>nil}, 52, "X:R", false], [{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "X:R", true], [{50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "X:R", false], [{58=>nil}, 58, "X:R", false], [{58=>nil, 67=>:enemy}, 67, "X:R", true], [{58=>nil, 67=>nil}, 67, "X:R", false], [{58=>nil, 67=>nil, 76=>:enemy}, 76, "X:R", true], [{58=>nil, 67=>nil, 76=>nil}, 76, "X:R", false]], 50=>[[{41=>:enemy}, 41, "X:R", true], [{49=>:enemy}, 49, "X:R", true], [{51=>:enemy}, 51, "X:R", true], [{59=>:enemy}, 59, "X:R", true], [{41=>nil}, 41, "X:R", false], [{41=>nil, 32=>:enemy}, 32, "X:R", true], [{41=>nil, 32=>nil}, 32, "X:R", false], [{41=>nil, 32=>nil, 23=>:enemy}, 23, "X:R", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "X:R", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:R", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "X:R", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:R", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:R", false], [{49=>nil}, 49, "X:R", false], [{49=>nil, 48=>:enemy}, 48, "X:R", true], [{49=>nil, 48=>nil}, 48, "X:R", false], [{49=>nil, 48=>nil, 47=>:enemy}, 47, "X:R", true], [{49=>nil, 48=>nil, 47=>nil}, 47, "X:R", false], [{49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:R", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "X:R", false], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:R", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:R", false], [{51=>nil}, 51, "X:R", false], [{51=>nil, 52=>:enemy}, 52, "X:R", true], [{51=>nil, 52=>nil}, 52, "X:R", false], [{51=>nil, 52=>nil, 53=>:enemy}, 53, "X:R", true], [{51=>nil, 52=>nil, 53=>nil}, 53, "X:R", false], [{59=>nil}, 59, "X:R", false], [{59=>nil, 68=>:enemy}, 68, "X:R", true], [{59=>nil, 68=>nil}, 68, "X:R", false], [{59=>nil, 68=>nil, 77=>:enemy}, 77, "X:R", true], [{59=>nil, 68=>nil, 77=>nil}, 77, "X:R", false]], 51=>[[{42=>:enemy}, 42, "X:R", true], [{50=>:enemy}, 50, "X:R", true], [{52=>:enemy}, 52, "X:R", true], [{60=>:enemy}, 60, "X:R", true], [{42=>nil}, 42, "X:R", false], [{42=>nil, 33=>:enemy}, 33, "X:R", true], [{42=>nil, 33=>nil}, 33, "X:R", false], [{42=>nil, 33=>nil, 24=>:enemy}, 24, "X:R", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "X:R", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:R", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "X:R", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:R", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:R", false], [{50=>nil}, 50, "X:R", false], [{50=>nil, 49=>:enemy}, 49, "X:R", true], [{50=>nil, 49=>nil}, 49, "X:R", false], [{50=>nil, 49=>nil, 48=>:enemy}, 48, "X:R", true], [{50=>nil, 49=>nil, 48=>nil}, 48, "X:R", false], [{50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "X:R", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "X:R", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:R", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "X:R", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:R", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:R", false], [{52=>nil}, 52, "X:R", false], [{52=>nil, 53=>:enemy}, 53, "X:R", true], [{52=>nil, 53=>nil}, 53, "X:R", false], [{60=>nil}, 60, "X:R", false], [{60=>nil, 69=>:enemy}, 69, "X:R", true], [{60=>nil, 69=>nil}, 69, "X:R", false], [{60=>nil, 69=>nil, 78=>:enemy}, 78, "X:R", true], [{60=>nil, 69=>nil, 78=>nil}, 78, "X:R", false]], 52=>[[{43=>:enemy}, 43, "X:R", true], [{51=>:enemy}, 51, "X:R", true], [{53=>:enemy}, 53, "X:R", true], [{61=>:enemy}, 61, "X:R", true], [{43=>nil}, 43, "X:R", false], [{43=>nil, 34=>:enemy}, 34, "X:R", true], [{43=>nil, 34=>nil}, 34, "X:R", false], [{43=>nil, 34=>nil, 25=>:enemy}, 25, "X:R", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "X:R", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:R", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "X:R", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:R", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:R", false], [{51=>nil}, 51, "X:R", false], [{51=>nil, 50=>:enemy}, 50, "X:R", true], [{51=>nil, 50=>nil}, 50, "X:R", false], [{51=>nil, 50=>nil, 49=>:enemy}, 49, "X:R", true], [{51=>nil, 50=>nil, 49=>nil}, 49, "X:R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "X:R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "X:R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "X:R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "X:R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "X:R", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:R", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:R", false], [{53=>nil}, 53, "X:R", false], [{61=>nil}, 61, "X:R", false], [{61=>nil, 70=>:enemy}, 70, "X:R", true], [{61=>nil, 70=>nil}, 70, "X:R", false], [{61=>nil, 70=>nil, 79=>:enemy}, 79, "X:R", true], [{61=>nil, 70=>nil, 79=>nil}, 79, "X:R", false]], 53=>[[{44=>:enemy}, 44, "X:R", true], [{52=>:enemy}, 52, "X:R", true], [{62=>:enemy}, 62, "X:R", true], [{44=>nil}, 44, "X:R", false], [{44=>nil, 35=>:enemy}, 35, "X:R", true], [{44=>nil, 35=>nil}, 35, "X:R", false], [{44=>nil, 35=>nil, 26=>:enemy}, 26, "X:R", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "X:R", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:R", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "X:R", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:R", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:R", false], [{52=>nil}, 52, "X:R", false], [{52=>nil, 51=>:enemy}, 51, "X:R", true], [{52=>nil, 51=>nil}, 51, "X:R", false], [{52=>nil, 51=>nil, 50=>:enemy}, 50, "X:R", true], [{52=>nil, 51=>nil, 50=>nil}, 50, "X:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, 49, "X:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil}, 49, "X:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "X:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "X:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "X:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "X:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "X:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "X:R", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "X:R", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "X:R", false], [{62=>nil}, 62, "X:R", false], [{62=>nil, 71=>:enemy}, 71, "X:R", true], [{62=>nil, 71=>nil}, 71, "X:R", false], [{62=>nil, 71=>nil, 80=>:enemy}, 80, "X:R", true], [{62=>nil, 71=>nil, 80=>nil}, 80, "X:R", false]], 54=>[[{45=>:enemy}, 45, "X:R", true], [{55=>:enemy}, 55, "X:R", true], [{63=>:enemy}, 63, "X:R", true], [{45=>nil}, 45, "X:R", false], [{45=>nil, 36=>:enemy}, 36, "X:R", true], [{45=>nil, 36=>nil}, 36, "X:R", false], [{45=>nil, 36=>nil, 27=>:enemy}, 27, "X:R", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "X:R", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "X:R", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "X:R", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:R", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "X:R", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:R", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:R", false], [{55=>nil}, 55, "X:R", false], [{55=>nil, 56=>:enemy}, 56, "X:R", true], [{55=>nil, 56=>nil}, 56, "X:R", false], [{55=>nil, 56=>nil, 57=>:enemy}, 57, "X:R", true], [{55=>nil, 56=>nil, 57=>nil}, 57, "X:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>:enemy}, 58, "X:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil}, 58, "X:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "X:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "X:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "X:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "X:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "X:R", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:R", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:R", false], [{63=>nil}, 63, "X:R", false], [{63=>nil, 72=>:enemy}, 72, "X:R", true], [{63=>nil, 72=>nil}, 72, "X:R", false]], 55=>[[{46=>:enemy}, 46, "X:R", true], [{54=>:enemy}, 54, "X:R", true], [{56=>:enemy}, 56, "X:R", true], [{64=>:enemy}, 64, "X:R", true], [{46=>nil}, 46, "X:R", false], [{46=>nil, 37=>:enemy}, 37, "X:R", true], [{46=>nil, 37=>nil}, 37, "X:R", false], [{46=>nil, 37=>nil, 28=>:enemy}, 28, "X:R", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "X:R", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "X:R", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "X:R", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:R", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "X:R", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:R", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:R", false], [{54=>nil}, 54, "X:R", false], [{56=>nil}, 56, "X:R", false], [{56=>nil, 57=>:enemy}, 57, "X:R", true], [{56=>nil, 57=>nil}, 57, "X:R", false], [{56=>nil, 57=>nil, 58=>:enemy}, 58, "X:R", true], [{56=>nil, 57=>nil, 58=>nil}, 58, "X:R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "X:R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "X:R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "X:R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "X:R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "X:R", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:R", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:R", false], [{64=>nil}, 64, "X:R", false], [{64=>nil, 73=>:enemy}, 73, "X:R", true], [{64=>nil, 73=>nil}, 73, "X:R", false]], 56=>[[{47=>:enemy}, 47, "X:R", true], [{55=>:enemy}, 55, "X:R", true], [{57=>:enemy}, 57, "X:R", true], [{65=>:enemy}, 65, "X:R", true], [{47=>nil}, 47, "X:R", false], [{47=>nil, 38=>:enemy}, 38, "X:R", true], [{47=>nil, 38=>nil}, 38, "X:R", false], [{47=>nil, 38=>nil, 29=>:enemy}, 29, "X:R", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "X:R", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "X:R", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "X:R", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:R", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "X:R", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:R", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:R", false], [{55=>nil}, 55, "X:R", false], [{55=>nil, 54=>:enemy}, 54, "X:R", true], [{55=>nil, 54=>nil}, 54, "X:R", false], [{57=>nil}, 57, "X:R", false], [{57=>nil, 58=>:enemy}, 58, "X:R", true], [{57=>nil, 58=>nil}, 58, "X:R", false], [{57=>nil, 58=>nil, 59=>:enemy}, 59, "X:R", true], [{57=>nil, 58=>nil, 59=>nil}, 59, "X:R", false], [{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "X:R", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "X:R", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:R", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "X:R", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:R", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:R", false], [{65=>nil}, 65, "X:R", false], [{65=>nil, 74=>:enemy}, 74, "X:R", true], [{65=>nil, 74=>nil}, 74, "X:R", false]], 57=>[[{48=>:enemy}, 48, "X:R", true], [{56=>:enemy}, 56, "X:R", true], [{58=>:enemy}, 58, "X:R", true], [{66=>:enemy}, 66, "X:R", true], [{48=>nil}, 48, "X:R", false], [{48=>nil, 39=>:enemy}, 39, "X:R", true], [{48=>nil, 39=>nil}, 39, "X:R", false], [{48=>nil, 39=>nil, 30=>:enemy}, 30, "X:R", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "X:R", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "X:R", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "X:R", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:R", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "X:R", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:R", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:R", false], [{56=>nil}, 56, "X:R", false], [{56=>nil, 55=>:enemy}, 55, "X:R", true], [{56=>nil, 55=>nil}, 55, "X:R", false], [{56=>nil, 55=>nil, 54=>:enemy}, 54, "X:R", true], [{56=>nil, 55=>nil, 54=>nil}, 54, "X:R", false], [{58=>nil}, 58, "X:R", false], [{58=>nil, 59=>:enemy}, 59, "X:R", true], [{58=>nil, 59=>nil}, 59, "X:R", false], [{58=>nil, 59=>nil, 60=>:enemy}, 60, "X:R", true], [{58=>nil, 59=>nil, 60=>nil}, 60, "X:R", false], [{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "X:R", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "X:R", false], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:R", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:R", false], [{66=>nil}, 66, "X:R", false], [{66=>nil, 75=>:enemy}, 75, "X:R", true], [{66=>nil, 75=>nil}, 75, "X:R", false]], 58=>[[{49=>:enemy}, 49, "X:R", true], [{57=>:enemy}, 57, "X:R", true], [{59=>:enemy}, 59, "X:R", true], [{67=>:enemy}, 67, "X:R", true], [{49=>nil}, 49, "X:R", false], [{49=>nil, 40=>:enemy}, 40, "X:R", true], [{49=>nil, 40=>nil}, 40, "X:R", false], [{49=>nil, 40=>nil, 31=>:enemy}, 31, "X:R", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "X:R", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "X:R", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "X:R", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:R", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "X:R", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:R", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:R", false], [{57=>nil}, 57, "X:R", false], [{57=>nil, 56=>:enemy}, 56, "X:R", true], [{57=>nil, 56=>nil}, 56, "X:R", false], [{57=>nil, 56=>nil, 55=>:enemy}, 55, "X:R", true], [{57=>nil, 56=>nil, 55=>nil}, 55, "X:R", false], [{57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:R", true], [{57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:R", false], [{59=>nil}, 59, "X:R", false], [{59=>nil, 60=>:enemy}, 60, "X:R", true], [{59=>nil, 60=>nil}, 60, "X:R", false], [{59=>nil, 60=>nil, 61=>:enemy}, 61, "X:R", true], [{59=>nil, 60=>nil, 61=>nil}, 61, "X:R", false], [{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "X:R", true], [{59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "X:R", false], [{67=>nil}, 67, "X:R", false], [{67=>nil, 76=>:enemy}, 76, "X:R", true], [{67=>nil, 76=>nil}, 76, "X:R", false]], 59=>[[{50=>:enemy}, 50, "X:R", true], [{58=>:enemy}, 58, "X:R", true], [{60=>:enemy}, 60, "X:R", true], [{68=>:enemy}, 68, "X:R", true], [{50=>nil}, 50, "X:R", false], [{50=>nil, 41=>:enemy}, 41, "X:R", true], [{50=>nil, 41=>nil}, 41, "X:R", false], [{50=>nil, 41=>nil, 32=>:enemy}, 32, "X:R", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "X:R", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "X:R", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "X:R", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:R", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "X:R", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:R", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:R", false], [{58=>nil}, 58, "X:R", false], [{58=>nil, 57=>:enemy}, 57, "X:R", true], [{58=>nil, 57=>nil}, 57, "X:R", false], [{58=>nil, 57=>nil, 56=>:enemy}, 56, "X:R", true], [{58=>nil, 57=>nil, 56=>nil}, 56, "X:R", false], [{58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:R", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "X:R", false], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:R", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:R", false], [{60=>nil}, 60, "X:R", false], [{60=>nil, 61=>:enemy}, 61, "X:R", true], [{60=>nil, 61=>nil}, 61, "X:R", false], [{60=>nil, 61=>nil, 62=>:enemy}, 62, "X:R", true], [{60=>nil, 61=>nil, 62=>nil}, 62, "X:R", false], [{68=>nil}, 68, "X:R", false], [{68=>nil, 77=>:enemy}, 77, "X:R", true], [{68=>nil, 77=>nil}, 77, "X:R", false]], 60=>[[{51=>:enemy}, 51, "X:R", true], [{59=>:enemy}, 59, "X:R", true], [{61=>:enemy}, 61, "X:R", true], [{69=>:enemy}, 69, "X:R", true], [{51=>nil}, 51, "X:R", false], [{51=>nil, 42=>:enemy}, 42, "X:R", true], [{51=>nil, 42=>nil}, 42, "X:R", false], [{51=>nil, 42=>nil, 33=>:enemy}, 33, "X:R", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "X:R", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "X:R", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "X:R", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:R", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "X:R", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:R", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:R", false], [{59=>nil}, 59, "X:R", false], [{59=>nil, 58=>:enemy}, 58, "X:R", true], [{59=>nil, 58=>nil}, 58, "X:R", false], [{59=>nil, 58=>nil, 57=>:enemy}, 57, "X:R", true], [{59=>nil, 58=>nil, 57=>nil}, 57, "X:R", false], [{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "X:R", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "X:R", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:R", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "X:R", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:R", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:R", false], [{61=>nil}, 61, "X:R", false], [{61=>nil, 62=>:enemy}, 62, "X:R", true], [{61=>nil, 62=>nil}, 62, "X:R", false], [{69=>nil}, 69, "X:R", false], [{69=>nil, 78=>:enemy}, 78, "X:R", true], [{69=>nil, 78=>nil}, 78, "X:R", false]], 61=>[[{52=>:enemy}, 52, "X:R", true], [{60=>:enemy}, 60, "X:R", true], [{62=>:enemy}, 62, "X:R", true], [{70=>:enemy}, 70, "X:R", true], [{52=>nil}, 52, "X:R", false], [{52=>nil, 43=>:enemy}, 43, "X:R", true], [{52=>nil, 43=>nil}, 43, "X:R", false], [{52=>nil, 43=>nil, 34=>:enemy}, 34, "X:R", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "X:R", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "X:R", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "X:R", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:R", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "X:R", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:R", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:R", false], [{60=>nil}, 60, "X:R", false], [{60=>nil, 59=>:enemy}, 59, "X:R", true], [{60=>nil, 59=>nil}, 59, "X:R", false], [{60=>nil, 59=>nil, 58=>:enemy}, 58, "X:R", true], [{60=>nil, 59=>nil, 58=>nil}, 58, "X:R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "X:R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "X:R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "X:R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "X:R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "X:R", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:R", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:R", false], [{62=>nil}, 62, "X:R", false], [{70=>nil}, 70, "X:R", false], [{70=>nil, 79=>:enemy}, 79, "X:R", true], [{70=>nil, 79=>nil}, 79, "X:R", false]], 62=>[[{53=>:enemy}, 53, "X:R", true], [{61=>:enemy}, 61, "X:R", true], [{71=>:enemy}, 71, "X:R", true], [{53=>nil}, 53, "X:R", false], [{53=>nil, 44=>:enemy}, 44, "X:R", true], [{53=>nil, 44=>nil}, 44, "X:R", false], [{53=>nil, 44=>nil, 35=>:enemy}, 35, "X:R", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "X:R", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "X:R", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "X:R", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:R", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "X:R", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:R", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:R", false], [{61=>nil}, 61, "X:R", false], [{61=>nil, 60=>:enemy}, 60, "X:R", true], [{61=>nil, 60=>nil}, 60, "X:R", false], [{61=>nil, 60=>nil, 59=>:enemy}, 59, "X:R", true], [{61=>nil, 60=>nil, 59=>nil}, 59, "X:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, 58, "X:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil}, 58, "X:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "X:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "X:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "X:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "X:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "X:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "X:R", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "X:R", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "X:R", false], [{71=>nil}, 71, "X:R", false], [{71=>nil, 80=>:enemy}, 80, "X:R", true], [{71=>nil, 80=>nil}, 80, "X:R", false]], 63=>[[{54=>:enemy}, 54, "X:R", true], [{64=>:enemy}, 64, "X:R", true], [{72=>:enemy}, 72, "X:R", true], [{54=>nil}, 54, "X:R", false], [{54=>nil, 45=>:enemy}, 45, "X:R", true], [{54=>nil, 45=>nil}, 45, "X:R", false], [{54=>nil, 45=>nil, 36=>:enemy}, 36, "X:R", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "X:R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "X:R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "X:R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "X:R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "X:R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "X:R", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:R", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:R", false], [{64=>nil}, 64, "X:R", false], [{64=>nil, 65=>:enemy}, 65, "X:R", true], [{64=>nil, 65=>nil}, 65, "X:R", false], [{64=>nil, 65=>nil, 66=>:enemy}, 66, "X:R", true], [{64=>nil, 65=>nil, 66=>nil}, 66, "X:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>:enemy}, 67, "X:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil}, 67, "X:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "X:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "X:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "X:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "X:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "X:R", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:R", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:R", false], [{72=>nil}, 72, "X:R", false]], 64=>[[{55=>:enemy}, 55, "X:R", true], [{63=>:enemy}, 63, "X:R", true], [{65=>:enemy}, 65, "X:R", true], [{73=>:enemy}, 73, "X:R", true], [{55=>nil}, 55, "X:R", false], [{55=>nil, 46=>:enemy}, 46, "X:R", true], [{55=>nil, 46=>nil}, 46, "X:R", false], [{55=>nil, 46=>nil, 37=>:enemy}, 37, "X:R", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "X:R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "X:R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "X:R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "X:R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "X:R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "X:R", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:R", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:R", false], [{63=>nil}, 63, "X:R", false], [{65=>nil}, 65, "X:R", false], [{65=>nil, 66=>:enemy}, 66, "X:R", true], [{65=>nil, 66=>nil}, 66, "X:R", false], [{65=>nil, 66=>nil, 67=>:enemy}, 67, "X:R", true], [{65=>nil, 66=>nil, 67=>nil}, 67, "X:R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "X:R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "X:R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "X:R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "X:R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "X:R", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:R", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:R", false], [{73=>nil}, 73, "X:R", false]], 65=>[[{56=>:enemy}, 56, "X:R", true], [{64=>:enemy}, 64, "X:R", true], [{66=>:enemy}, 66, "X:R", true], [{74=>:enemy}, 74, "X:R", true], [{56=>nil}, 56, "X:R", false], [{56=>nil, 47=>:enemy}, 47, "X:R", true], [{56=>nil, 47=>nil}, 47, "X:R", false], [{56=>nil, 47=>nil, 38=>:enemy}, 38, "X:R", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "X:R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "X:R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "X:R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "X:R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "X:R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "X:R", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:R", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:R", false], [{64=>nil}, 64, "X:R", false], [{64=>nil, 63=>:enemy}, 63, "X:R", true], [{64=>nil, 63=>nil}, 63, "X:R", false], [{66=>nil}, 66, "X:R", false], [{66=>nil, 67=>:enemy}, 67, "X:R", true], [{66=>nil, 67=>nil}, 67, "X:R", false], [{66=>nil, 67=>nil, 68=>:enemy}, 68, "X:R", true], [{66=>nil, 67=>nil, 68=>nil}, 68, "X:R", false], [{66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "X:R", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "X:R", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:R", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "X:R", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:R", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:R", false], [{74=>nil}, 74, "X:R", false]], 66=>[[{57=>:enemy}, 57, "X:R", true], [{65=>:enemy}, 65, "X:R", true], [{67=>:enemy}, 67, "X:R", true], [{75=>:enemy}, 75, "X:R", true], [{57=>nil}, 57, "X:R", false], [{57=>nil, 48=>:enemy}, 48, "X:R", true], [{57=>nil, 48=>nil}, 48, "X:R", false], [{57=>nil, 48=>nil, 39=>:enemy}, 39, "X:R", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "X:R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "X:R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "X:R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "X:R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "X:R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "X:R", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:R", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:R", false], [{65=>nil}, 65, "X:R", false], [{65=>nil, 64=>:enemy}, 64, "X:R", true], [{65=>nil, 64=>nil}, 64, "X:R", false], [{65=>nil, 64=>nil, 63=>:enemy}, 63, "X:R", true], [{65=>nil, 64=>nil, 63=>nil}, 63, "X:R", false], [{67=>nil}, 67, "X:R", false], [{67=>nil, 68=>:enemy}, 68, "X:R", true], [{67=>nil, 68=>nil}, 68, "X:R", false], [{67=>nil, 68=>nil, 69=>:enemy}, 69, "X:R", true], [{67=>nil, 68=>nil, 69=>nil}, 69, "X:R", false], [{67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "X:R", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "X:R", false], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:R", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:R", false], [{75=>nil}, 75, "X:R", false]], 67=>[[{58=>:enemy}, 58, "X:R", true], [{66=>:enemy}, 66, "X:R", true], [{68=>:enemy}, 68, "X:R", true], [{76=>:enemy}, 76, "X:R", true], [{58=>nil}, 58, "X:R", false], [{58=>nil, 49=>:enemy}, 49, "X:R", true], [{58=>nil, 49=>nil}, 49, "X:R", false], [{58=>nil, 49=>nil, 40=>:enemy}, 40, "X:R", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "X:R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "X:R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "X:R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "X:R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "X:R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "X:R", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:R", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:R", false], [{66=>nil}, 66, "X:R", false], [{66=>nil, 65=>:enemy}, 65, "X:R", true], [{66=>nil, 65=>nil}, 65, "X:R", false], [{66=>nil, 65=>nil, 64=>:enemy}, 64, "X:R", true], [{66=>nil, 65=>nil, 64=>nil}, 64, "X:R", false], [{66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:R", true], [{66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:R", false], [{68=>nil}, 68, "X:R", false], [{68=>nil, 69=>:enemy}, 69, "X:R", true], [{68=>nil, 69=>nil}, 69, "X:R", false], [{68=>nil, 69=>nil, 70=>:enemy}, 70, "X:R", true], [{68=>nil, 69=>nil, 70=>nil}, 70, "X:R", false], [{68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "X:R", true], [{68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "X:R", false], [{76=>nil}, 76, "X:R", false]], 68=>[[{59=>:enemy}, 59, "X:R", true], [{67=>:enemy}, 67, "X:R", true], [{69=>:enemy}, 69, "X:R", true], [{77=>:enemy}, 77, "X:R", true], [{59=>nil}, 59, "X:R", false], [{59=>nil, 50=>:enemy}, 50, "X:R", true], [{59=>nil, 50=>nil}, 50, "X:R", false], [{59=>nil, 50=>nil, 41=>:enemy}, 41, "X:R", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "X:R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "X:R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "X:R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "X:R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "X:R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "X:R", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:R", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:R", false], [{67=>nil}, 67, "X:R", false], [{67=>nil, 66=>:enemy}, 66, "X:R", true], [{67=>nil, 66=>nil}, 66, "X:R", false], [{67=>nil, 66=>nil, 65=>:enemy}, 65, "X:R", true], [{67=>nil, 66=>nil, 65=>nil}, 65, "X:R", false], [{67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:R", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "X:R", false], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:R", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:R", false], [{69=>nil}, 69, "X:R", false], [{69=>nil, 70=>:enemy}, 70, "X:R", true], [{69=>nil, 70=>nil}, 70, "X:R", false], [{69=>nil, 70=>nil, 71=>:enemy}, 71, "X:R", true], [{69=>nil, 70=>nil, 71=>nil}, 71, "X:R", false], [{77=>nil}, 77, "X:R", false]], 69=>[[{60=>:enemy}, 60, "X:R", true], [{68=>:enemy}, 68, "X:R", true], [{70=>:enemy}, 70, "X:R", true], [{78=>:enemy}, 78, "X:R", true], [{60=>nil}, 60, "X:R", false], [{60=>nil, 51=>:enemy}, 51, "X:R", true], [{60=>nil, 51=>nil}, 51, "X:R", false], [{60=>nil, 51=>nil, 42=>:enemy}, 42, "X:R", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "X:R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "X:R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "X:R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "X:R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "X:R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "X:R", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:R", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:R", false], [{68=>nil}, 68, "X:R", false], [{68=>nil, 67=>:enemy}, 67, "X:R", true], [{68=>nil, 67=>nil}, 67, "X:R", false], [{68=>nil, 67=>nil, 66=>:enemy}, 66, "X:R", true], [{68=>nil, 67=>nil, 66=>nil}, 66, "X:R", false], [{68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "X:R", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "X:R", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:R", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "X:R", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:R", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:R", false], [{70=>nil}, 70, "X:R", false], [{70=>nil, 71=>:enemy}, 71, "X:R", true], [{70=>nil, 71=>nil}, 71, "X:R", false], [{78=>nil}, 78, "X:R", false]], 70=>[[{61=>:enemy}, 61, "X:R", true], [{69=>:enemy}, 69, "X:R", true], [{71=>:enemy}, 71, "X:R", true], [{79=>:enemy}, 79, "X:R", true], [{61=>nil}, 61, "X:R", false], [{61=>nil, 52=>:enemy}, 52, "X:R", true], [{61=>nil, 52=>nil}, 52, "X:R", false], [{61=>nil, 52=>nil, 43=>:enemy}, 43, "X:R", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "X:R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "X:R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "X:R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "X:R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "X:R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "X:R", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:R", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:R", false], [{69=>nil}, 69, "X:R", false], [{69=>nil, 68=>:enemy}, 68, "X:R", true], [{69=>nil, 68=>nil}, 68, "X:R", false], [{69=>nil, 68=>nil, 67=>:enemy}, 67, "X:R", true], [{69=>nil, 68=>nil, 67=>nil}, 67, "X:R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "X:R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "X:R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "X:R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "X:R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "X:R", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:R", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:R", false], [{71=>nil}, 71, "X:R", false], [{79=>nil}, 79, "X:R", false]], 71=>[[{62=>:enemy}, 62, "X:R", true], [{70=>:enemy}, 70, "X:R", true], [{80=>:enemy}, 80, "X:R", true], [{62=>nil}, 62, "X:R", false], [{62=>nil, 53=>:enemy}, 53, "X:R", true], [{62=>nil, 53=>nil}, 53, "X:R", false], [{62=>nil, 53=>nil, 44=>:enemy}, 44, "X:R", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "X:R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "X:R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "X:R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "X:R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "X:R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "X:R", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:R", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:R", false], [{70=>nil}, 70, "X:R", false], [{70=>nil, 69=>:enemy}, 69, "X:R", true], [{70=>nil, 69=>nil}, 69, "X:R", false], [{70=>nil, 69=>nil, 68=>:enemy}, 68, "X:R", true], [{70=>nil, 69=>nil, 68=>nil}, 68, "X:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>:enemy}, 67, "X:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil}, 67, "X:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "X:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "X:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "X:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "X:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "X:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "X:R", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "X:R", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "X:R", false], [{80=>nil}, 80, "X:R", false]], 72=>[[{63=>:enemy}, 63, "X:R", true], [{73=>:enemy}, 73, "X:R", true], [{63=>nil}, 63, "X:R", false], [{63=>nil, 54=>:enemy}, 54, "X:R", true], [{63=>nil, 54=>nil}, 54, "X:R", false], [{63=>nil, 54=>nil, 45=>:enemy}, 45, "X:R", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "X:R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:enemy}, 36, "X:R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "X:R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "X:R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "X:R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "X:R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "X:R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "X:R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "X:R", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "X:R", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "X:R", false], [{73=>nil}, 73, "X:R", false], [{73=>nil, 74=>:enemy}, 74, "X:R", true], [{73=>nil, 74=>nil}, 74, "X:R", false], [{73=>nil, 74=>nil, 75=>:enemy}, 75, "X:R", true], [{73=>nil, 74=>nil, 75=>nil}, 75, "X:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>:enemy}, 76, "X:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil}, 76, "X:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "X:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "X:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "X:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "X:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "X:R", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:R", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:R", false]], 73=>[[{64=>:enemy}, 64, "X:R", true], [{72=>:enemy}, 72, "X:R", true], [{74=>:enemy}, 74, "X:R", true], [{64=>nil}, 64, "X:R", false], [{64=>nil, 55=>:enemy}, 55, "X:R", true], [{64=>nil, 55=>nil}, 55, "X:R", false], [{64=>nil, 55=>nil, 46=>:enemy}, 46, "X:R", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "X:R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:enemy}, 37, "X:R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "X:R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "X:R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "X:R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "X:R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "X:R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "X:R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "X:R", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "X:R", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "X:R", false], [{72=>nil}, 72, "X:R", false], [{74=>nil}, 74, "X:R", false], [{74=>nil, 75=>:enemy}, 75, "X:R", true], [{74=>nil, 75=>nil}, 75, "X:R", false], [{74=>nil, 75=>nil, 76=>:enemy}, 76, "X:R", true], [{74=>nil, 75=>nil, 76=>nil}, 76, "X:R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "X:R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "X:R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "X:R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "X:R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "X:R", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:R", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:R", false]], 74=>[[{65=>:enemy}, 65, "X:R", true], [{73=>:enemy}, 73, "X:R", true], [{75=>:enemy}, 75, "X:R", true], [{65=>nil}, 65, "X:R", false], [{65=>nil, 56=>:enemy}, 56, "X:R", true], [{65=>nil, 56=>nil}, 56, "X:R", false], [{65=>nil, 56=>nil, 47=>:enemy}, 47, "X:R", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "X:R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:enemy}, 38, "X:R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "X:R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "X:R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "X:R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "X:R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "X:R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "X:R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "X:R", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "X:R", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "X:R", false], [{73=>nil}, 73, "X:R", false], [{73=>nil, 72=>:enemy}, 72, "X:R", true], [{73=>nil, 72=>nil}, 72, "X:R", false], [{75=>nil}, 75, "X:R", false], [{75=>nil, 76=>:enemy}, 76, "X:R", true], [{75=>nil, 76=>nil}, 76, "X:R", false], [{75=>nil, 76=>nil, 77=>:enemy}, 77, "X:R", true], [{75=>nil, 76=>nil, 77=>nil}, 77, "X:R", false], [{75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "X:R", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "X:R", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:R", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "X:R", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:R", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:R", false]], 75=>[[{66=>:enemy}, 66, "X:R", true], [{74=>:enemy}, 74, "X:R", true], [{76=>:enemy}, 76, "X:R", true], [{66=>nil}, 66, "X:R", false], [{66=>nil, 57=>:enemy}, 57, "X:R", true], [{66=>nil, 57=>nil}, 57, "X:R", false], [{66=>nil, 57=>nil, 48=>:enemy}, 48, "X:R", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "X:R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:enemy}, 39, "X:R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "X:R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "X:R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "X:R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "X:R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "X:R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "X:R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "X:R", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "X:R", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "X:R", false], [{74=>nil}, 74, "X:R", false], [{74=>nil, 73=>:enemy}, 73, "X:R", true], [{74=>nil, 73=>nil}, 73, "X:R", false], [{74=>nil, 73=>nil, 72=>:enemy}, 72, "X:R", true], [{74=>nil, 73=>nil, 72=>nil}, 72, "X:R", false], [{76=>nil}, 76, "X:R", false], [{76=>nil, 77=>:enemy}, 77, "X:R", true], [{76=>nil, 77=>nil}, 77, "X:R", false], [{76=>nil, 77=>nil, 78=>:enemy}, 78, "X:R", true], [{76=>nil, 77=>nil, 78=>nil}, 78, "X:R", false], [{76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "X:R", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "X:R", false], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:R", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:R", false]], 76=>[[{67=>:enemy}, 67, "X:R", true], [{75=>:enemy}, 75, "X:R", true], [{77=>:enemy}, 77, "X:R", true], [{67=>nil}, 67, "X:R", false], [{67=>nil, 58=>:enemy}, 58, "X:R", true], [{67=>nil, 58=>nil}, 58, "X:R", false], [{67=>nil, 58=>nil, 49=>:enemy}, 49, "X:R", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "X:R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:enemy}, 40, "X:R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "X:R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "X:R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "X:R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "X:R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "X:R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "X:R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "X:R", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "X:R", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "X:R", false], [{75=>nil}, 75, "X:R", false], [{75=>nil, 74=>:enemy}, 74, "X:R", true], [{75=>nil, 74=>nil}, 74, "X:R", false], [{75=>nil, 74=>nil, 73=>:enemy}, 73, "X:R", true], [{75=>nil, 74=>nil, 73=>nil}, 73, "X:R", false], [{75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:R", true], [{75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:R", false], [{77=>nil}, 77, "X:R", false], [{77=>nil, 78=>:enemy}, 78, "X:R", true], [{77=>nil, 78=>nil}, 78, "X:R", false], [{77=>nil, 78=>nil, 79=>:enemy}, 79, "X:R", true], [{77=>nil, 78=>nil, 79=>nil}, 79, "X:R", false], [{77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "X:R", true], [{77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "X:R", false]], 77=>[[{68=>:enemy}, 68, "X:R", true], [{76=>:enemy}, 76, "X:R", true], [{78=>:enemy}, 78, "X:R", true], [{68=>nil}, 68, "X:R", false], [{68=>nil, 59=>:enemy}, 59, "X:R", true], [{68=>nil, 59=>nil}, 59, "X:R", false], [{68=>nil, 59=>nil, 50=>:enemy}, 50, "X:R", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "X:R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:enemy}, 41, "X:R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "X:R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "X:R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "X:R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "X:R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "X:R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "X:R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "X:R", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "X:R", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "X:R", false], [{76=>nil}, 76, "X:R", false], [{76=>nil, 75=>:enemy}, 75, "X:R", true], [{76=>nil, 75=>nil}, 75, "X:R", false], [{76=>nil, 75=>nil, 74=>:enemy}, 74, "X:R", true], [{76=>nil, 75=>nil, 74=>nil}, 74, "X:R", false], [{76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:R", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "X:R", false], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:R", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:R", false], [{78=>nil}, 78, "X:R", false], [{78=>nil, 79=>:enemy}, 79, "X:R", true], [{78=>nil, 79=>nil}, 79, "X:R", false], [{78=>nil, 79=>nil, 80=>:enemy}, 80, "X:R", true], [{78=>nil, 79=>nil, 80=>nil}, 80, "X:R", false]], 78=>[[{69=>:enemy}, 69, "X:R", true], [{77=>:enemy}, 77, "X:R", true], [{79=>:enemy}, 79, "X:R", true], [{69=>nil}, 69, "X:R", false], [{69=>nil, 60=>:enemy}, 60, "X:R", true], [{69=>nil, 60=>nil}, 60, "X:R", false], [{69=>nil, 60=>nil, 51=>:enemy}, 51, "X:R", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "X:R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:enemy}, 42, "X:R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "X:R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "X:R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "X:R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "X:R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "X:R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "X:R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "X:R", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "X:R", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "X:R", false], [{77=>nil}, 77, "X:R", false], [{77=>nil, 76=>:enemy}, 76, "X:R", true], [{77=>nil, 76=>nil}, 76, "X:R", false], [{77=>nil, 76=>nil, 75=>:enemy}, 75, "X:R", true], [{77=>nil, 76=>nil, 75=>nil}, 75, "X:R", false], [{77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "X:R", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "X:R", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:R", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "X:R", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:R", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:R", false], [{79=>nil}, 79, "X:R", false], [{79=>nil, 80=>:enemy}, 80, "X:R", true], [{79=>nil, 80=>nil}, 80, "X:R", false]], 79=>[[{70=>:enemy}, 70, "X:R", true], [{78=>:enemy}, 78, "X:R", true], [{80=>:enemy}, 80, "X:R", true], [{70=>nil}, 70, "X:R", false], [{70=>nil, 61=>:enemy}, 61, "X:R", true], [{70=>nil, 61=>nil}, 61, "X:R", false], [{70=>nil, 61=>nil, 52=>:enemy}, 52, "X:R", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "X:R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:enemy}, 43, "X:R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "X:R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "X:R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "X:R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "X:R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "X:R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "X:R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "X:R", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "X:R", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "X:R", false], [{78=>nil}, 78, "X:R", false], [{78=>nil, 77=>:enemy}, 77, "X:R", true], [{78=>nil, 77=>nil}, 77, "X:R", false], [{78=>nil, 77=>nil, 76=>:enemy}, 76, "X:R", true], [{78=>nil, 77=>nil, 76=>nil}, 76, "X:R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "X:R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "X:R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "X:R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "X:R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "X:R", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:R", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:R", false], [{80=>nil}, 80, "X:R", false]], 80=>[[{71=>:enemy}, 71, "X:R", true], [{79=>:enemy}, 79, "X:R", true], [{71=>nil}, 71, "X:R", false], [{71=>nil, 62=>:enemy}, 62, "X:R", true], [{71=>nil, 62=>nil}, 62, "X:R", false], [{71=>nil, 62=>nil, 53=>:enemy}, 53, "X:R", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "X:R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:enemy}, 44, "X:R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "X:R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "X:R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "X:R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "X:R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "X:R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "X:R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "X:R", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "X:R", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "X:R", false], [{79=>nil}, 79, "X:R", false], [{79=>nil, 78=>:enemy}, 78, "X:R", true], [{79=>nil, 78=>nil}, 78, "X:R", false], [{79=>nil, 78=>nil, 77=>:enemy}, 77, "X:R", true], [{79=>nil, 78=>nil, 77=>nil}, 77, "X:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>:enemy}, 76, "X:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil}, 76, "X:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "X:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "X:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "X:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "X:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "X:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "X:R", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "X:R", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "X:R", false]], nil=>[[{0=>nil}, 0, "X:R", false], [{1=>nil}, 1, "X:R", false], [{2=>nil}, 2, "X:R", false], [{3=>nil}, 3, "X:R", false], [{4=>nil}, 4, "X:R", false], [{5=>nil}, 5, "X:R", false], [{6=>nil}, 6, "X:R", false], [{7=>nil}, 7, "X:R", false], [{8=>nil}, 8, "X:R", false], [{9=>nil}, 9, "X:R", false], [{10=>nil}, 10, "X:R", false], [{11=>nil}, 11, "X:R", false], [{12=>nil}, 12, "X:R", false], [{13=>nil}, 13, "X:R", false], [{14=>nil}, 14, "X:R", false], [{15=>nil}, 15, "X:R", false], [{16=>nil}, 16, "X:R", false], [{17=>nil}, 17, "X:R", false], [{18=>nil}, 18, "X:R", false], [{19=>nil}, 19, "X:R", false], [{20=>nil}, 20, "X:R", false], [{21=>nil}, 21, "X:R", false], [{22=>nil}, 22, "X:R", false], [{23=>nil}, 23, "X:R", false], [{24=>nil}, 24, "X:R", false], [{25=>nil}, 25, "X:R", false], [{26=>nil}, 26, "X:R", false], [{27=>nil}, 27, "X:R", false], [{28=>nil}, 28, "X:R", false], [{29=>nil}, 29, "X:R", false], [{30=>nil}, 30, "X:R", false], [{31=>nil}, 31, "X:R", false], [{32=>nil}, 32, "X:R", false], [{33=>nil}, 33, "X:R", false], [{34=>nil}, 34, "X:R", false], [{35=>nil}, 35, "X:R", false], [{36=>nil}, 36, "X:R", false], [{37=>nil}, 37, "X:R", false], [{38=>nil}, 38, "X:R", false], [{39=>nil}, 39, "X:R", false], [{40=>nil}, 40, "X:R", false], [{41=>nil}, 41, "X:R", false], [{42=>nil}, 42, "X:R", false], [{43=>nil}, 43, "X:R", false], [{44=>nil}, 44, "X:R", false], [{45=>nil}, 45, "X:R", false], [{46=>nil}, 46, "X:R", false], [{47=>nil}, 47, "X:R", false], [{48=>nil}, 48, "X:R", false], [{49=>nil}, 49, "X:R", false], [{50=>nil}, 50, "X:R", false], [{51=>nil}, 51, "X:R", false], [{52=>nil}, 52, "X:R", false], [{53=>nil}, 53, "X:R", false], [{54=>nil}, 54, "X:R", false], [{55=>nil}, 55, "X:R", false], [{56=>nil}, 56, "X:R", false], [{57=>nil}, 57, "X:R", false], [{58=>nil}, 58, "X:R", false], [{59=>nil}, 59, "X:R", false], [{60=>nil}, 60, "X:R", false], [{61=>nil}, 61, "X:R", false], [{62=>nil}, 62, "X:R", false], [{63=>nil}, 63, "X:R", false], [{64=>nil}, 64, "X:R", false], [{65=>nil}, 65, "X:R", false], [{66=>nil}, 66, "X:R", false], [{67=>nil}, 67, "X:R", false], [{68=>nil}, 68, "X:R", false], [{69=>nil}, 69, "X:R", false], [{70=>nil}, 70, "X:R", false], [{71=>nil}, 71, "X:R", false], [{72=>nil}, 72, "X:R", false], [{73=>nil}, 73, "X:R", false], [{74=>nil}, 74, "X:R", false], [{75=>nil}, 75, "X:R", false], [{76=>nil}, 76, "X:R", false], [{77=>nil}, 77, "X:R", false], [{78=>nil}, 78, "X:R", false], [{79=>nil}, 79, "X:R", false], [{80=>nil}, 80, "X:R", false]]}, "X:S"=>{0=>[[{1=>:enemy}, 1, "X:S", true], [{1=>nil}, 1, "X:S", false]], 1=>[[{0=>:enemy}, 0, "X:S", true], [{2=>:enemy}, 2, "X:S", true], [{0=>nil}, 0, "X:S", false], [{2=>nil}, 2, "X:S", false]], 2=>[[{1=>:enemy}, 1, "X:S", true], [{3=>:enemy}, 3, "X:S", true], [{1=>nil}, 1, "X:S", false], [{3=>nil}, 3, "X:S", false]], 3=>[[{2=>:enemy}, 2, "X:S", true], [{4=>:enemy}, 4, "X:S", true], [{2=>nil}, 2, "X:S", false], [{4=>nil}, 4, "X:S", false]], 4=>[[{3=>:enemy}, 3, "X:S", true], [{5=>:enemy}, 5, "X:S", true], [{3=>nil}, 3, "X:S", false], [{5=>nil}, 5, "X:S", false]], 5=>[[{4=>:enemy}, 4, "X:S", true], [{6=>:enemy}, 6, "X:S", true], [{4=>nil}, 4, "X:S", false], [{6=>nil}, 6, "X:S", false]], 6=>[[{5=>:enemy}, 5, "X:S", true], [{7=>:enemy}, 7, "X:S", true], [{5=>nil}, 5, "X:S", false], [{7=>nil}, 7, "X:S", false]], 7=>[[{6=>:enemy}, 6, "X:S", true], [{8=>:enemy}, 8, "X:S", true], [{6=>nil}, 6, "X:S", false], [{8=>nil}, 8, "X:S", false]], 8=>[[{7=>:enemy}, 7, "X:S", true], [{7=>nil}, 7, "X:S", false]], 9=>[[{0=>:enemy}, 0, "X:S", true], [{10=>:enemy}, 10, "X:S", true], [{0=>nil}, 0, "X:S", false], [{10=>nil}, 10, "X:S", false]], 10=>[[{1=>:enemy}, 1, "X:S", true], [{9=>:enemy}, 9, "X:S", true], [{11=>:enemy}, 11, "X:S", true], [{1=>nil}, 1, "X:S", false], [{9=>nil}, 9, "X:S", false], [{11=>nil}, 11, "X:S", false]], 11=>[[{2=>:enemy}, 2, "X:S", true], [{10=>:enemy}, 10, "X:S", true], [{12=>:enemy}, 12, "X:S", true], [{2=>nil}, 2, "X:S", false], [{10=>nil}, 10, "X:S", false], [{12=>nil}, 12, "X:S", false]], 12=>[[{3=>:enemy}, 3, "X:S", true], [{11=>:enemy}, 11, "X:S", true], [{13=>:enemy}, 13, "X:S", true], [{3=>nil}, 3, "X:S", false], [{11=>nil}, 11, "X:S", false], [{13=>nil}, 13, "X:S", false]], 13=>[[{4=>:enemy}, 4, "X:S", true], [{12=>:enemy}, 12, "X:S", true], [{14=>:enemy}, 14, "X:S", true], [{4=>nil}, 4, "X:S", false], [{12=>nil}, 12, "X:S", false], [{14=>nil}, 14, "X:S", false]], 14=>[[{5=>:enemy}, 5, "X:S", true], [{13=>:enemy}, 13, "X:S", true], [{15=>:enemy}, 15, "X:S", true], [{5=>nil}, 5, "X:S", false], [{13=>nil}, 13, "X:S", false], [{15=>nil}, 15, "X:S", false]], 15=>[[{6=>:enemy}, 6, "X:S", true], [{14=>:enemy}, 14, "X:S", true], [{16=>:enemy}, 16, "X:S", true], [{6=>nil}, 6, "X:S", false], [{14=>nil}, 14, "X:S", false], [{16=>nil}, 16, "X:S", false]], 16=>[[{7=>:enemy}, 7, "X:S", true], [{15=>:enemy}, 15, "X:S", true], [{17=>:enemy}, 17, "X:S", true], [{7=>nil}, 7, "X:S", false], [{15=>nil}, 15, "X:S", false], [{17=>nil}, 17, "X:S", false]], 17=>[[{8=>:enemy}, 8, "X:S", true], [{16=>:enemy}, 16, "X:S", true], [{8=>nil}, 8, "X:S", false], [{16=>nil}, 16, "X:S", false]], 18=>[[{9=>:enemy}, 9, "X:S", true], [{19=>:enemy}, 19, "X:S", true], [{9=>nil}, 9, "X:S", false], [{19=>nil}, 19, "X:S", false]], 19=>[[{10=>:enemy}, 10, "X:S", true], [{18=>:enemy}, 18, "X:S", true], [{20=>:enemy}, 20, "X:S", true], [{10=>nil}, 10, "X:S", false], [{18=>nil}, 18, "X:S", false], [{20=>nil}, 20, "X:S", false]], 20=>[[{11=>:enemy}, 11, "X:S", true], [{19=>:enemy}, 19, "X:S", true], [{21=>:enemy}, 21, "X:S", true], [{11=>nil}, 11, "X:S", false], [{19=>nil}, 19, "X:S", false], [{21=>nil}, 21, "X:S", false]], 21=>[[{12=>:enemy}, 12, "X:S", true], [{20=>:enemy}, 20, "X:S", true], [{22=>:enemy}, 22, "X:S", true], [{12=>nil}, 12, "X:S", false], [{20=>nil}, 20, "X:S", false], [{22=>nil}, 22, "X:S", false]], 22=>[[{13=>:enemy}, 13, "X:S", true], [{21=>:enemy}, 21, "X:S", true], [{23=>:enemy}, 23, "X:S", true], [{13=>nil}, 13, "X:S", false], [{21=>nil}, 21, "X:S", false], [{23=>nil}, 23, "X:S", false]], 23=>[[{14=>:enemy}, 14, "X:S", true], [{22=>:enemy}, 22, "X:S", true], [{24=>:enemy}, 24, "X:S", true], [{14=>nil}, 14, "X:S", false], [{22=>nil}, 22, "X:S", false], [{24=>nil}, 24, "X:S", false]], 24=>[[{15=>:enemy}, 15, "X:S", true], [{23=>:enemy}, 23, "X:S", true], [{25=>:enemy}, 25, "X:S", true], [{15=>nil}, 15, "X:S", false], [{23=>nil}, 23, "X:S", false], [{25=>nil}, 25, "X:S", false]], 25=>[[{16=>:enemy}, 16, "X:S", true], [{24=>:enemy}, 24, "X:S", true], [{26=>:enemy}, 26, "X:S", true], [{16=>nil}, 16, "X:S", false], [{24=>nil}, 24, "X:S", false], [{26=>nil}, 26, "X:S", false]], 26=>[[{17=>:enemy}, 17, "X:S", true], [{25=>:enemy}, 25, "X:S", true], [{17=>nil}, 17, "X:S", false], [{25=>nil}, 25, "X:S", false]], 27=>[[{18=>:enemy}, 18, "X:S", true], [{28=>:enemy}, 28, "X:S", true], [{18=>nil}, 18, "X:S", false], [{28=>nil}, 28, "X:S", false]], 28=>[[{19=>:enemy}, 19, "X:S", true], [{27=>:enemy}, 27, "X:S", true], [{29=>:enemy}, 29, "X:S", true], [{19=>nil}, 19, "X:S", false], [{27=>nil}, 27, "X:S", false], [{29=>nil}, 29, "X:S", false]], 29=>[[{20=>:enemy}, 20, "X:S", true], [{28=>:enemy}, 28, "X:S", true], [{30=>:enemy}, 30, "X:S", true], [{20=>nil}, 20, "X:S", false], [{28=>nil}, 28, "X:S", false], [{30=>nil}, 30, "X:S", false]], 30=>[[{21=>:enemy}, 21, "X:S", true], [{29=>:enemy}, 29, "X:S", true], [{31=>:enemy}, 31, "X:S", true], [{21=>nil}, 21, "X:S", false], [{29=>nil}, 29, "X:S", false], [{31=>nil}, 31, "X:S", false]], 31=>[[{22=>:enemy}, 22, "X:S", true], [{30=>:enemy}, 30, "X:S", true], [{32=>:enemy}, 32, "X:S", true], [{22=>nil}, 22, "X:S", false], [{30=>nil}, 30, "X:S", false], [{32=>nil}, 32, "X:S", false]], 32=>[[{23=>:enemy}, 23, "X:S", true], [{31=>:enemy}, 31, "X:S", true], [{33=>:enemy}, 33, "X:S", true], [{23=>nil}, 23, "X:S", false], [{31=>nil}, 31, "X:S", false], [{33=>nil}, 33, "X:S", false]], 33=>[[{24=>:enemy}, 24, "X:S", true], [{32=>:enemy}, 32, "X:S", true], [{34=>:enemy}, 34, "X:S", true], [{24=>nil}, 24, "X:S", false], [{32=>nil}, 32, "X:S", false], [{34=>nil}, 34, "X:S", false]], 34=>[[{25=>:enemy}, 25, "X:S", true], [{33=>:enemy}, 33, "X:S", true], [{35=>:enemy}, 35, "X:S", true], [{25=>nil}, 25, "X:S", false], [{33=>nil}, 33, "X:S", false], [{35=>nil}, 35, "X:S", false]], 35=>[[{26=>:enemy}, 26, "X:S", true], [{34=>:enemy}, 34, "X:S", true], [{26=>nil}, 26, "X:S", false], [{34=>nil}, 34, "X:S", false]], 36=>[[{27=>:enemy}, 27, "X:S", true], [{37=>:enemy}, 37, "X:S", true], [{27=>nil}, 27, "X:S", false], [{37=>nil}, 37, "X:S", false]], 37=>[[{28=>:enemy}, 28, "X:S", true], [{36=>:enemy}, 36, "X:S", true], [{38=>:enemy}, 38, "X:S", true], [{28=>nil}, 28, "X:S", false], [{36=>nil}, 36, "X:S", false], [{38=>nil}, 38, "X:S", false]], 38=>[[{29=>:enemy}, 29, "X:S", true], [{37=>:enemy}, 37, "X:S", true], [{39=>:enemy}, 39, "X:S", true], [{29=>nil}, 29, "X:S", false], [{37=>nil}, 37, "X:S", false], [{39=>nil}, 39, "X:S", false]], 39=>[[{30=>:enemy}, 30, "X:S", true], [{38=>:enemy}, 38, "X:S", true], [{40=>:enemy}, 40, "X:S", true], [{30=>nil}, 30, "X:S", false], [{38=>nil}, 38, "X:S", false], [{40=>nil}, 40, "X:S", false]], 40=>[[{31=>:enemy}, 31, "X:S", true], [{39=>:enemy}, 39, "X:S", true], [{41=>:enemy}, 41, "X:S", true], [{31=>nil}, 31, "X:S", false], [{39=>nil}, 39, "X:S", false], [{41=>nil}, 41, "X:S", false]], 41=>[[{32=>:enemy}, 32, "X:S", true], [{40=>:enemy}, 40, "X:S", true], [{42=>:enemy}, 42, "X:S", true], [{32=>nil}, 32, "X:S", false], [{40=>nil}, 40, "X:S", false], [{42=>nil}, 42, "X:S", false]], 42=>[[{33=>:enemy}, 33, "X:S", true], [{41=>:enemy}, 41, "X:S", true], [{43=>:enemy}, 43, "X:S", true], [{33=>nil}, 33, "X:S", false], [{41=>nil}, 41, "X:S", false], [{43=>nil}, 43, "X:S", false]], 43=>[[{34=>:enemy}, 34, "X:S", true], [{42=>:enemy}, 42, "X:S", true], [{44=>:enemy}, 44, "X:S", true], [{34=>nil}, 34, "X:S", false], [{42=>nil}, 42, "X:S", false], [{44=>nil}, 44, "X:S", false]], 44=>[[{35=>:enemy}, 35, "X:S", true], [{43=>:enemy}, 43, "X:S", true], [{35=>nil}, 35, "X:S", false], [{43=>nil}, 43, "X:S", false]], 45=>[[{36=>:enemy}, 36, "X:S", true], [{46=>:enemy}, 46, "X:S", true], [{36=>nil}, 36, "X:S", false], [{46=>nil}, 46, "X:S", false]], 46=>[[{37=>:enemy}, 37, "X:S", true], [{45=>:enemy}, 45, "X:S", true], [{47=>:enemy}, 47, "X:S", true], [{37=>nil}, 37, "X:S", false], [{45=>nil}, 45, "X:S", false], [{47=>nil}, 47, "X:S", false]], 47=>[[{38=>:enemy}, 38, "X:S", true], [{46=>:enemy}, 46, "X:S", true], [{48=>:enemy}, 48, "X:S", true], [{38=>nil}, 38, "X:S", false], [{46=>nil}, 46, "X:S", false], [{48=>nil}, 48, "X:S", false]], 48=>[[{39=>:enemy}, 39, "X:S", true], [{47=>:enemy}, 47, "X:S", true], [{49=>:enemy}, 49, "X:S", true], [{39=>nil}, 39, "X:S", false], [{47=>nil}, 47, "X:S", false], [{49=>nil}, 49, "X:S", false]], 49=>[[{40=>:enemy}, 40, "X:S", true], [{48=>:enemy}, 48, "X:S", true], [{50=>:enemy}, 50, "X:S", true], [{40=>nil}, 40, "X:S", false], [{48=>nil}, 48, "X:S", false], [{50=>nil}, 50, "X:S", false]], 50=>[[{41=>:enemy}, 41, "X:S", true], [{49=>:enemy}, 49, "X:S", true], [{51=>:enemy}, 51, "X:S", true], [{41=>nil}, 41, "X:S", false], [{49=>nil}, 49, "X:S", false], [{51=>nil}, 51, "X:S", false]], 51=>[[{42=>:enemy}, 42, "X:S", true], [{50=>:enemy}, 50, "X:S", true], [{52=>:enemy}, 52, "X:S", true], [{42=>nil}, 42, "X:S", false], [{50=>nil}, 50, "X:S", false], [{52=>nil}, 52, "X:S", false]], 52=>[[{43=>:enemy}, 43, "X:S", true], [{51=>:enemy}, 51, "X:S", true], [{53=>:enemy}, 53, "X:S", true], [{43=>nil}, 43, "X:S", false], [{51=>nil}, 51, "X:S", false], [{53=>nil}, 53, "X:S", false]], 53=>[[{44=>:enemy}, 44, "X:S", true], [{52=>:enemy}, 52, "X:S", true], [{44=>nil}, 44, "X:S", false], [{52=>nil}, 52, "X:S", false]], 54=>[[{45=>:enemy}, 45, "X:S", true], [{55=>:enemy}, 55, "X:S", true], [{45=>nil}, 45, "X:S", false], [{55=>nil}, 55, "X:S", false]], 55=>[[{46=>:enemy}, 46, "X:S", true], [{54=>:enemy}, 54, "X:S", true], [{56=>:enemy}, 56, "X:S", true], [{46=>nil}, 46, "X:S", false], [{54=>nil}, 54, "X:S", false], [{56=>nil}, 56, "X:S", false]], 56=>[[{47=>:enemy}, 47, "X:S", true], [{55=>:enemy}, 55, "X:S", true], [{57=>:enemy}, 57, "X:S", true], [{47=>nil}, 47, "X:S", false], [{55=>nil}, 55, "X:S", false], [{57=>nil}, 57, "X:S", false]], 57=>[[{48=>:enemy}, 48, "X:S", true], [{56=>:enemy}, 56, "X:S", true], [{58=>:enemy}, 58, "X:S", true], [{48=>nil}, 48, "X:S", false], [{56=>nil}, 56, "X:S", false], [{58=>nil}, 58, "X:S", false]], 58=>[[{49=>:enemy}, 49, "X:S", true], [{57=>:enemy}, 57, "X:S", true], [{59=>:enemy}, 59, "X:S", true], [{49=>nil}, 49, "X:S", false], [{57=>nil}, 57, "X:S", false], [{59=>nil}, 59, "X:S", false]], 59=>[[{50=>:enemy}, 50, "X:S", true], [{58=>:enemy}, 58, "X:S", true], [{60=>:enemy}, 60, "X:S", true], [{50=>nil}, 50, "X:S", false], [{58=>nil}, 58, "X:S", false], [{60=>nil}, 60, "X:S", false]], 60=>[[{51=>:enemy}, 51, "X:S", true], [{59=>:enemy}, 59, "X:S", true], [{61=>:enemy}, 61, "X:S", true], [{51=>nil}, 51, "X:S", false], [{59=>nil}, 59, "X:S", false], [{61=>nil}, 61, "X:S", false]], 61=>[[{52=>:enemy}, 52, "X:S", true], [{60=>:enemy}, 60, "X:S", true], [{62=>:enemy}, 62, "X:S", true], [{52=>nil}, 52, "X:S", false], [{60=>nil}, 60, "X:S", false], [{62=>nil}, 62, "X:S", false]], 62=>[[{53=>:enemy}, 53, "X:S", true], [{61=>:enemy}, 61, "X:S", true], [{53=>nil}, 53, "X:S", false], [{61=>nil}, 61, "X:S", false]], 63=>[[{54=>:enemy}, 54, "X:S", true], [{64=>:enemy}, 64, "X:S", true], [{54=>nil}, 54, "X:S", false], [{64=>nil}, 64, "X:S", false]], 64=>[[{55=>:enemy}, 55, "X:S", true], [{63=>:enemy}, 63, "X:S", true], [{65=>:enemy}, 65, "X:S", true], [{55=>nil}, 55, "X:S", false], [{63=>nil}, 63, "X:S", false], [{65=>nil}, 65, "X:S", false]], 65=>[[{56=>:enemy}, 56, "X:S", true], [{64=>:enemy}, 64, "X:S", true], [{66=>:enemy}, 66, "X:S", true], [{56=>nil}, 56, "X:S", false], [{64=>nil}, 64, "X:S", false], [{66=>nil}, 66, "X:S", false]], 66=>[[{57=>:enemy}, 57, "X:S", true], [{65=>:enemy}, 65, "X:S", true], [{67=>:enemy}, 67, "X:S", true], [{57=>nil}, 57, "X:S", false], [{65=>nil}, 65, "X:S", false], [{67=>nil}, 67, "X:S", false]], 67=>[[{58=>:enemy}, 58, "X:S", true], [{66=>:enemy}, 66, "X:S", true], [{68=>:enemy}, 68, "X:S", true], [{58=>nil}, 58, "X:S", false], [{66=>nil}, 66, "X:S", false], [{68=>nil}, 68, "X:S", false]], 68=>[[{59=>:enemy}, 59, "X:S", true], [{67=>:enemy}, 67, "X:S", true], [{69=>:enemy}, 69, "X:S", true], [{59=>nil}, 59, "X:S", false], [{67=>nil}, 67, "X:S", false], [{69=>nil}, 69, "X:S", false]], 69=>[[{60=>:enemy}, 60, "X:S", true], [{68=>:enemy}, 68, "X:S", true], [{70=>:enemy}, 70, "X:S", true], [{60=>nil}, 60, "X:S", false], [{68=>nil}, 68, "X:S", false], [{70=>nil}, 70, "X:S", false]], 70=>[[{61=>:enemy}, 61, "X:S", true], [{69=>:enemy}, 69, "X:S", true], [{71=>:enemy}, 71, "X:S", true], [{61=>nil}, 61, "X:S", false], [{69=>nil}, 69, "X:S", false], [{71=>nil}, 71, "X:S", false]], 71=>[[{62=>:enemy}, 62, "X:S", true], [{70=>:enemy}, 70, "X:S", true], [{62=>nil}, 62, "X:S", false], [{70=>nil}, 70, "X:S", false]], 72=>[[{63=>:enemy}, 63, "X:S", true], [{73=>:enemy}, 73, "X:S", true], [{63=>nil}, 63, "X:S", false], [{73=>nil}, 73, "X:S", false]], 73=>[[{64=>:enemy}, 64, "X:S", true], [{72=>:enemy}, 72, "X:S", true], [{74=>:enemy}, 74, "X:S", true], [{64=>nil}, 64, "X:S", false], [{72=>nil}, 72, "X:S", false], [{74=>nil}, 74, "X:S", false]], 74=>[[{65=>:enemy}, 65, "X:S", true], [{73=>:enemy}, 73, "X:S", true], [{75=>:enemy}, 75, "X:S", true], [{65=>nil}, 65, "X:S", false], [{73=>nil}, 73, "X:S", false], [{75=>nil}, 75, "X:S", false]], 75=>[[{66=>:enemy}, 66, "X:S", true], [{74=>:enemy}, 74, "X:S", true], [{76=>:enemy}, 76, "X:S", true], [{66=>nil}, 66, "X:S", false], [{74=>nil}, 74, "X:S", false], [{76=>nil}, 76, "X:S", false]], 76=>[[{67=>:enemy}, 67, "X:S", true], [{75=>:enemy}, 75, "X:S", true], [{77=>:enemy}, 77, "X:S", true], [{67=>nil}, 67, "X:S", false], [{75=>nil}, 75, "X:S", false], [{77=>nil}, 77, "X:S", false]], 77=>[[{68=>:enemy}, 68, "X:S", true], [{76=>:enemy}, 76, "X:S", true], [{78=>:enemy}, 78, "X:S", true], [{68=>nil}, 68, "X:S", false], [{76=>nil}, 76, "X:S", false], [{78=>nil}, 78, "X:S", false]], 78=>[[{69=>:enemy}, 69, "X:S", true], [{77=>:enemy}, 77, "X:S", true], [{79=>:enemy}, 79, "X:S", true], [{69=>nil}, 69, "X:S", false], [{77=>nil}, 77, "X:S", false], [{79=>nil}, 79, "X:S", false]], 79=>[[{70=>:enemy}, 70, "X:S", true], [{78=>:enemy}, 78, "X:S", true], [{80=>:enemy}, 80, "X:S", true], [{70=>nil}, 70, "X:S", false], [{78=>nil}, 78, "X:S", false], [{80=>nil}, 80, "X:S", false]], 80=>[[{71=>:enemy}, 71, "X:S", true], [{79=>:enemy}, 79, "X:S", true], [{71=>nil}, 71, "X:S", false], [{79=>nil}, 79, "X:S", false]], nil=>[[{0=>nil}, 0, "X:S", false], [{1=>nil}, 1, "X:S", false], [{2=>nil}, 2, "X:S", false], [{3=>nil}, 3, "X:S", false], [{4=>nil}, 4, "X:S", false], [{5=>nil}, 5, "X:S", false], [{6=>nil}, 6, "X:S", false], [{7=>nil}, 7, "X:S", false], [{8=>nil}, 8, "X:S", false], [{9=>nil}, 9, "X:S", false], [{10=>nil}, 10, "X:S", false], [{11=>nil}, 11, "X:S", false], [{12=>nil}, 12, "X:S", false], [{13=>nil}, 13, "X:S", false], [{14=>nil}, 14, "X:S", false], [{15=>nil}, 15, "X:S", false], [{16=>nil}, 16, "X:S", false], [{17=>nil}, 17, "X:S", false], [{18=>nil}, 18, "X:S", false], [{19=>nil}, 19, "X:S", false], [{20=>nil}, 20, "X:S", false], [{21=>nil}, 21, "X:S", false], [{22=>nil}, 22, "X:S", false], [{23=>nil}, 23, "X:S", false], [{24=>nil}, 24, "X:S", false], [{25=>nil}, 25, "X:S", false], [{26=>nil}, 26, "X:S", false], [{27=>nil}, 27, "X:S", false], [{28=>nil}, 28, "X:S", false], [{29=>nil}, 29, "X:S", false], [{30=>nil}, 30, "X:S", false], [{31=>nil}, 31, "X:S", false], [{32=>nil}, 32, "X:S", false], [{33=>nil}, 33, "X:S", false], [{34=>nil}, 34, "X:S", false], [{35=>nil}, 35, "X:S", false], [{36=>nil}, 36, "X:S", false], [{37=>nil}, 37, "X:S", false], [{38=>nil}, 38, "X:S", false], [{39=>nil}, 39, "X:S", false], [{40=>nil}, 40, "X:S", false], [{41=>nil}, 41, "X:S", false], [{42=>nil}, 42, "X:S", false], [{43=>nil}, 43, "X:S", false], [{44=>nil}, 44, "X:S", false], [{45=>nil}, 45, "X:S", false], [{46=>nil}, 46, "X:S", false], [{47=>nil}, 47, "X:S", false], [{48=>nil}, 48, "X:S", false], [{49=>nil}, 49, "X:S", false], [{50=>nil}, 50, "X:S", false], [{51=>nil}, 51, "X:S", false], [{52=>nil}, 52, "X:S", false], [{53=>nil}, 53, "X:S", false], [{54=>nil}, 54, "X:S", false], [{55=>nil}, 55, "X:S", false], [{56=>nil}, 56, "X:S", false], [{57=>nil}, 57, "X:S", false], [{58=>nil}, 58, "X:S", false], [{59=>nil}, 59, "X:S", false], [{60=>nil}, 60, "X:S", false], [{61=>nil}, 61, "X:S", false], [{62=>nil}, 62, "X:S", false], [{63=>nil}, 63, "X:S", false], [{64=>nil}, 64, "X:S", false], [{65=>nil}, 65, "X:S", false], [{66=>nil}, 66, "X:S", false], [{67=>nil}, 67, "X:S", false], [{68=>nil}, 68, "X:S", false], [{69=>nil}, 69, "X:S", false], [{70=>nil}, 70, "X:S", false], [{71=>nil}, 71, "X:S", false], [{72=>nil}, 72, "X:S", false], [{73=>nil}, 73, "X:S", false], [{74=>nil}, 74, "X:S", false], [{75=>nil}, 75, "X:S", false], [{76=>nil}, 76, "X:S", false], [{77=>nil}, 77, "X:S", false], [{78=>nil}, 78, "X:S", false], [{79=>nil}, 79, "X:S", false], [{80=>nil}, 80, "X:S", false]]}, "x:-g"=>{0=>[[{1=>:enemy}, 1, "x:-g", true], [{9=>:enemy}, 9, "x:-g", true], [{1=>nil}, 1, "x:-g", false], [{9=>nil}, 9, "x:-g", false]], 1=>[[{0=>:enemy}, 0, "x:-g", true], [{2=>:enemy}, 2, "x:-g", true], [{10=>:enemy}, 10, "x:-g", true], [{0=>nil}, 0, "x:-g", false], [{2=>nil}, 2, "x:-g", false], [{10=>nil}, 10, "x:-g", false]], 2=>[[{1=>:enemy}, 1, "x:-g", true], [{3=>:enemy}, 3, "x:-g", true], [{11=>:enemy}, 11, "x:-g", true], [{1=>nil}, 1, "x:-g", false], [{3=>nil}, 3, "x:-g", false], [{11=>nil}, 11, "x:-g", false]], 3=>[[{2=>:enemy}, 2, "x:-g", true], [{4=>:enemy}, 4, "x:-g", true], [{12=>:enemy}, 12, "x:-g", true], [{2=>nil}, 2, "x:-g", false], [{4=>nil}, 4, "x:-g", false], [{12=>nil}, 12, "x:-g", false]], 4=>[[{3=>:enemy}, 3, "x:-g", true], [{5=>:enemy}, 5, "x:-g", true], [{13=>:enemy}, 13, "x:-g", true], [{3=>nil}, 3, "x:-g", false], [{5=>nil}, 5, "x:-g", false], [{13=>nil}, 13, "x:-g", false]], 5=>[[{4=>:enemy}, 4, "x:-g", true], [{6=>:enemy}, 6, "x:-g", true], [{14=>:enemy}, 14, "x:-g", true], [{4=>nil}, 4, "x:-g", false], [{6=>nil}, 6, "x:-g", false], [{14=>nil}, 14, "x:-g", false]], 6=>[[{5=>:enemy}, 5, "x:-g", true], [{7=>:enemy}, 7, "x:-g", true], [{15=>:enemy}, 15, "x:-g", true], [{5=>nil}, 5, "x:-g", false], [{7=>nil}, 7, "x:-g", false], [{15=>nil}, 15, "x:-g", false]], 7=>[[{6=>:enemy}, 6, "x:-g", true], [{8=>:enemy}, 8, "x:-g", true], [{16=>:enemy}, 16, "x:-g", true], [{6=>nil}, 6, "x:-g", false], [{8=>nil}, 8, "x:-g", false], [{16=>nil}, 16, "x:-g", false]], 8=>[[{7=>:enemy}, 7, "x:-g", true], [{17=>:enemy}, 17, "x:-g", true], [{7=>nil}, 7, "x:-g", false], [{17=>nil}, 17, "x:-g", false]], 9=>[[{0=>:enemy}, 0, "x:-g", true], [{10=>:enemy}, 10, "x:-g", true], [{18=>:enemy}, 18, "x:-g", true], [{0=>nil}, 0, "x:-g", false], [{10=>nil}, 10, "x:-g", false], [{18=>nil}, 18, "x:-g", false]], 10=>[[{1=>:enemy}, 1, "x:-g", true], [{9=>:enemy}, 9, "x:-g", true], [{11=>:enemy}, 11, "x:-g", true], [{19=>:enemy}, 19, "x:-g", true], [{1=>nil}, 1, "x:-g", false], [{9=>nil}, 9, "x:-g", false], [{11=>nil}, 11, "x:-g", false], [{19=>nil}, 19, "x:-g", false]], 11=>[[{2=>:enemy}, 2, "x:-g", true], [{10=>:enemy}, 10, "x:-g", true], [{12=>:enemy}, 12, "x:-g", true], [{20=>:enemy}, 20, "x:-g", true], [{2=>nil}, 2, "x:-g", false], [{10=>nil}, 10, "x:-g", false], [{12=>nil}, 12, "x:-g", false], [{20=>nil}, 20, "x:-g", false]], 12=>[[{3=>:enemy}, 3, "x:-g", true], [{11=>:enemy}, 11, "x:-g", true], [{13=>:enemy}, 13, "x:-g", true], [{21=>:enemy}, 21, "x:-g", true], [{3=>nil}, 3, "x:-g", false], [{11=>nil}, 11, "x:-g", false], [{13=>nil}, 13, "x:-g", false], [{21=>nil}, 21, "x:-g", false]], 13=>[[{4=>:enemy}, 4, "x:-g", true], [{12=>:enemy}, 12, "x:-g", true], [{14=>:enemy}, 14, "x:-g", true], [{22=>:enemy}, 22, "x:-g", true], [{4=>nil}, 4, "x:-g", false], [{12=>nil}, 12, "x:-g", false], [{14=>nil}, 14, "x:-g", false], [{22=>nil}, 22, "x:-g", false]], 14=>[[{5=>:enemy}, 5, "x:-g", true], [{13=>:enemy}, 13, "x:-g", true], [{15=>:enemy}, 15, "x:-g", true], [{23=>:enemy}, 23, "x:-g", true], [{5=>nil}, 5, "x:-g", false], [{13=>nil}, 13, "x:-g", false], [{15=>nil}, 15, "x:-g", false], [{23=>nil}, 23, "x:-g", false]], 15=>[[{6=>:enemy}, 6, "x:-g", true], [{14=>:enemy}, 14, "x:-g", true], [{16=>:enemy}, 16, "x:-g", true], [{24=>:enemy}, 24, "x:-g", true], [{6=>nil}, 6, "x:-g", false], [{14=>nil}, 14, "x:-g", false], [{16=>nil}, 16, "x:-g", false], [{24=>nil}, 24, "x:-g", false]], 16=>[[{7=>:enemy}, 7, "x:-g", true], [{15=>:enemy}, 15, "x:-g", true], [{17=>:enemy}, 17, "x:-g", true], [{25=>:enemy}, 25, "x:-g", true], [{7=>nil}, 7, "x:-g", false], [{15=>nil}, 15, "x:-g", false], [{17=>nil}, 17, "x:-g", false], [{25=>nil}, 25, "x:-g", false]], 17=>[[{8=>:enemy}, 8, "x:-g", true], [{16=>:enemy}, 16, "x:-g", true], [{26=>:enemy}, 26, "x:-g", true], [{8=>nil}, 8, "x:-g", false], [{16=>nil}, 16, "x:-g", false], [{26=>nil}, 26, "x:-g", false]], 18=>[[{9=>:enemy}, 9, "x:-g", true], [{19=>:enemy}, 19, "x:-g", true], [{27=>:enemy}, 27, "x:-g", true], [{9=>nil}, 9, "x:-g", false], [{19=>nil}, 19, "x:-g", false], [{27=>nil}, 27, "x:-g", false]], 19=>[[{10=>:enemy}, 10, "x:-g", true], [{18=>:enemy}, 18, "x:-g", true], [{20=>:enemy}, 20, "x:-g", true], [{28=>:enemy}, 28, "x:-g", true], [{10=>nil}, 10, "x:-g", false], [{18=>nil}, 18, "x:-g", false], [{20=>nil}, 20, "x:-g", false], [{28=>nil}, 28, "x:-g", false]], 20=>[[{11=>:enemy}, 11, "x:-g", true], [{19=>:enemy}, 19, "x:-g", true], [{21=>:enemy}, 21, "x:-g", true], [{29=>:enemy}, 29, "x:-g", true], [{11=>nil}, 11, "x:-g", false], [{19=>nil}, 19, "x:-g", false], [{21=>nil}, 21, "x:-g", false], [{29=>nil}, 29, "x:-g", false]], 21=>[[{12=>:enemy}, 12, "x:-g", true], [{20=>:enemy}, 20, "x:-g", true], [{22=>:enemy}, 22, "x:-g", true], [{30=>:enemy}, 30, "x:-g", true], [{12=>nil}, 12, "x:-g", false], [{20=>nil}, 20, "x:-g", false], [{22=>nil}, 22, "x:-g", false], [{30=>nil}, 30, "x:-g", false]], 22=>[[{13=>:enemy}, 13, "x:-g", true], [{21=>:enemy}, 21, "x:-g", true], [{23=>:enemy}, 23, "x:-g", true], [{31=>:enemy}, 31, "x:-g", true], [{13=>nil}, 13, "x:-g", false], [{21=>nil}, 21, "x:-g", false], [{23=>nil}, 23, "x:-g", false], [{31=>nil}, 31, "x:-g", false]], 23=>[[{14=>:enemy}, 14, "x:-g", true], [{22=>:enemy}, 22, "x:-g", true], [{24=>:enemy}, 24, "x:-g", true], [{32=>:enemy}, 32, "x:-g", true], [{14=>nil}, 14, "x:-g", false], [{22=>nil}, 22, "x:-g", false], [{24=>nil}, 24, "x:-g", false], [{32=>nil}, 32, "x:-g", false]], 24=>[[{15=>:enemy}, 15, "x:-g", true], [{23=>:enemy}, 23, "x:-g", true], [{25=>:enemy}, 25, "x:-g", true], [{33=>:enemy}, 33, "x:-g", true], [{15=>nil}, 15, "x:-g", false], [{23=>nil}, 23, "x:-g", false], [{25=>nil}, 25, "x:-g", false], [{33=>nil}, 33, "x:-g", false]], 25=>[[{16=>:enemy}, 16, "x:-g", true], [{24=>:enemy}, 24, "x:-g", true], [{26=>:enemy}, 26, "x:-g", true], [{34=>:enemy}, 34, "x:-g", true], [{16=>nil}, 16, "x:-g", false], [{24=>nil}, 24, "x:-g", false], [{26=>nil}, 26, "x:-g", false], [{34=>nil}, 34, "x:-g", false]], 26=>[[{17=>:enemy}, 17, "x:-g", true], [{25=>:enemy}, 25, "x:-g", true], [{35=>:enemy}, 35, "x:-g", true], [{17=>nil}, 17, "x:-g", false], [{25=>nil}, 25, "x:-g", false], [{35=>nil}, 35, "x:-g", false]], 27=>[[{18=>:enemy}, 18, "x:-g", true], [{28=>:enemy}, 28, "x:-g", true], [{36=>:enemy}, 36, "x:-g", true], [{18=>nil}, 18, "x:-g", false], [{28=>nil}, 28, "x:-g", false], [{36=>nil}, 36, "x:-g", false]], 28=>[[{19=>:enemy}, 19, "x:-g", true], [{27=>:enemy}, 27, "x:-g", true], [{29=>:enemy}, 29, "x:-g", true], [{37=>:enemy}, 37, "x:-g", true], [{19=>nil}, 19, "x:-g", false], [{27=>nil}, 27, "x:-g", false], [{29=>nil}, 29, "x:-g", false], [{37=>nil}, 37, "x:-g", false]], 29=>[[{20=>:enemy}, 20, "x:-g", true], [{28=>:enemy}, 28, "x:-g", true], [{30=>:enemy}, 30, "x:-g", true], [{38=>:enemy}, 38, "x:-g", true], [{20=>nil}, 20, "x:-g", false], [{28=>nil}, 28, "x:-g", false], [{30=>nil}, 30, "x:-g", false], [{38=>nil}, 38, "x:-g", false]], 30=>[[{21=>:enemy}, 21, "x:-g", true], [{29=>:enemy}, 29, "x:-g", true], [{31=>:enemy}, 31, "x:-g", true], [{39=>:enemy}, 39, "x:-g", true], [{21=>nil}, 21, "x:-g", false], [{29=>nil}, 29, "x:-g", false], [{31=>nil}, 31, "x:-g", false], [{39=>nil}, 39, "x:-g", false]], 31=>[[{22=>:enemy}, 22, "x:-g", true], [{30=>:enemy}, 30, "x:-g", true], [{32=>:enemy}, 32, "x:-g", true], [{40=>:enemy}, 40, "x:-g", true], [{22=>nil}, 22, "x:-g", false], [{30=>nil}, 30, "x:-g", false], [{32=>nil}, 32, "x:-g", false], [{40=>nil}, 40, "x:-g", false]], 32=>[[{23=>:enemy}, 23, "x:-g", true], [{31=>:enemy}, 31, "x:-g", true], [{33=>:enemy}, 33, "x:-g", true], [{41=>:enemy}, 41, "x:-g", true], [{23=>nil}, 23, "x:-g", false], [{31=>nil}, 31, "x:-g", false], [{33=>nil}, 33, "x:-g", false], [{41=>nil}, 41, "x:-g", false]], 33=>[[{24=>:enemy}, 24, "x:-g", true], [{32=>:enemy}, 32, "x:-g", true], [{34=>:enemy}, 34, "x:-g", true], [{42=>:enemy}, 42, "x:-g", true], [{24=>nil}, 24, "x:-g", false], [{32=>nil}, 32, "x:-g", false], [{34=>nil}, 34, "x:-g", false], [{42=>nil}, 42, "x:-g", false]], 34=>[[{25=>:enemy}, 25, "x:-g", true], [{33=>:enemy}, 33, "x:-g", true], [{35=>:enemy}, 35, "x:-g", true], [{43=>:enemy}, 43, "x:-g", true], [{25=>nil}, 25, "x:-g", false], [{33=>nil}, 33, "x:-g", false], [{35=>nil}, 35, "x:-g", false], [{43=>nil}, 43, "x:-g", false]], 35=>[[{26=>:enemy}, 26, "x:-g", true], [{34=>:enemy}, 34, "x:-g", true], [{44=>:enemy}, 44, "x:-g", true], [{26=>nil}, 26, "x:-g", false], [{34=>nil}, 34, "x:-g", false], [{44=>nil}, 44, "x:-g", false]], 36=>[[{27=>:enemy}, 27, "x:-g", true], [{37=>:enemy}, 37, "x:-g", true], [{45=>:enemy}, 45, "x:-g", true], [{27=>nil}, 27, "x:-g", false], [{37=>nil}, 37, "x:-g", false], [{45=>nil}, 45, "x:-g", false]], 37=>[[{28=>:enemy}, 28, "x:-g", true], [{36=>:enemy}, 36, "x:-g", true], [{38=>:enemy}, 38, "x:-g", true], [{46=>:enemy}, 46, "x:-g", true], [{28=>nil}, 28, "x:-g", false], [{36=>nil}, 36, "x:-g", false], [{38=>nil}, 38, "x:-g", false], [{46=>nil}, 46, "x:-g", false]], 38=>[[{29=>:enemy}, 29, "x:-g", true], [{37=>:enemy}, 37, "x:-g", true], [{39=>:enemy}, 39, "x:-g", true], [{47=>:enemy}, 47, "x:-g", true], [{29=>nil}, 29, "x:-g", false], [{37=>nil}, 37, "x:-g", false], [{39=>nil}, 39, "x:-g", false], [{47=>nil}, 47, "x:-g", false]], 39=>[[{30=>:enemy}, 30, "x:-g", true], [{38=>:enemy}, 38, "x:-g", true], [{40=>:enemy}, 40, "x:-g", true], [{48=>:enemy}, 48, "x:-g", true], [{30=>nil}, 30, "x:-g", false], [{38=>nil}, 38, "x:-g", false], [{40=>nil}, 40, "x:-g", false], [{48=>nil}, 48, "x:-g", false]], 40=>[[{31=>:enemy}, 31, "x:-g", true], [{39=>:enemy}, 39, "x:-g", true], [{41=>:enemy}, 41, "x:-g", true], [{49=>:enemy}, 49, "x:-g", true], [{31=>nil}, 31, "x:-g", false], [{39=>nil}, 39, "x:-g", false], [{41=>nil}, 41, "x:-g", false], [{49=>nil}, 49, "x:-g", false]], 41=>[[{32=>:enemy}, 32, "x:-g", true], [{40=>:enemy}, 40, "x:-g", true], [{42=>:enemy}, 42, "x:-g", true], [{50=>:enemy}, 50, "x:-g", true], [{32=>nil}, 32, "x:-g", false], [{40=>nil}, 40, "x:-g", false], [{42=>nil}, 42, "x:-g", false], [{50=>nil}, 50, "x:-g", false]], 42=>[[{33=>:enemy}, 33, "x:-g", true], [{41=>:enemy}, 41, "x:-g", true], [{43=>:enemy}, 43, "x:-g", true], [{51=>:enemy}, 51, "x:-g", true], [{33=>nil}, 33, "x:-g", false], [{41=>nil}, 41, "x:-g", false], [{43=>nil}, 43, "x:-g", false], [{51=>nil}, 51, "x:-g", false]], 43=>[[{34=>:enemy}, 34, "x:-g", true], [{42=>:enemy}, 42, "x:-g", true], [{44=>:enemy}, 44, "x:-g", true], [{52=>:enemy}, 52, "x:-g", true], [{34=>nil}, 34, "x:-g", false], [{42=>nil}, 42, "x:-g", false], [{44=>nil}, 44, "x:-g", false], [{52=>nil}, 52, "x:-g", false]], 44=>[[{35=>:enemy}, 35, "x:-g", true], [{43=>:enemy}, 43, "x:-g", true], [{53=>:enemy}, 53, "x:-g", true], [{35=>nil}, 35, "x:-g", false], [{43=>nil}, 43, "x:-g", false], [{53=>nil}, 53, "x:-g", false]], 45=>[[{36=>:enemy}, 36, "x:-g", true], [{46=>:enemy}, 46, "x:-g", true], [{54=>:enemy}, 54, "x:-g", true], [{36=>nil}, 36, "x:-g", false], [{46=>nil}, 46, "x:-g", false], [{54=>nil}, 54, "x:-g", false]], 46=>[[{37=>:enemy}, 37, "x:-g", true], [{45=>:enemy}, 45, "x:-g", true], [{47=>:enemy}, 47, "x:-g", true], [{55=>:enemy}, 55, "x:-g", true], [{37=>nil}, 37, "x:-g", false], [{45=>nil}, 45, "x:-g", false], [{47=>nil}, 47, "x:-g", false], [{55=>nil}, 55, "x:-g", false]], 47=>[[{38=>:enemy}, 38, "x:-g", true], [{46=>:enemy}, 46, "x:-g", true], [{48=>:enemy}, 48, "x:-g", true], [{56=>:enemy}, 56, "x:-g", true], [{38=>nil}, 38, "x:-g", false], [{46=>nil}, 46, "x:-g", false], [{48=>nil}, 48, "x:-g", false], [{56=>nil}, 56, "x:-g", false]], 48=>[[{39=>:enemy}, 39, "x:-g", true], [{47=>:enemy}, 47, "x:-g", true], [{49=>:enemy}, 49, "x:-g", true], [{57=>:enemy}, 57, "x:-g", true], [{39=>nil}, 39, "x:-g", false], [{47=>nil}, 47, "x:-g", false], [{49=>nil}, 49, "x:-g", false], [{57=>nil}, 57, "x:-g", false]], 49=>[[{40=>:enemy}, 40, "x:-g", true], [{48=>:enemy}, 48, "x:-g", true], [{50=>:enemy}, 50, "x:-g", true], [{58=>:enemy}, 58, "x:-g", true], [{40=>nil}, 40, "x:-g", false], [{48=>nil}, 48, "x:-g", false], [{50=>nil}, 50, "x:-g", false], [{58=>nil}, 58, "x:-g", false]], 50=>[[{41=>:enemy}, 41, "x:-g", true], [{49=>:enemy}, 49, "x:-g", true], [{51=>:enemy}, 51, "x:-g", true], [{59=>:enemy}, 59, "x:-g", true], [{41=>nil}, 41, "x:-g", false], [{49=>nil}, 49, "x:-g", false], [{51=>nil}, 51, "x:-g", false], [{59=>nil}, 59, "x:-g", false]], 51=>[[{42=>:enemy}, 42, "x:-g", true], [{50=>:enemy}, 50, "x:-g", true], [{52=>:enemy}, 52, "x:-g", true], [{60=>:enemy}, 60, "x:-g", true], [{42=>nil}, 42, "x:-g", false], [{50=>nil}, 50, "x:-g", false], [{52=>nil}, 52, "x:-g", false], [{60=>nil}, 60, "x:-g", false]], 52=>[[{43=>:enemy}, 43, "x:-g", true], [{51=>:enemy}, 51, "x:-g", true], [{53=>:enemy}, 53, "x:-g", true], [{61=>:enemy}, 61, "x:-g", true], [{43=>nil}, 43, "x:-g", false], [{51=>nil}, 51, "x:-g", false], [{53=>nil}, 53, "x:-g", false], [{61=>nil}, 61, "x:-g", false]], 53=>[[{44=>:enemy}, 44, "x:-g", true], [{52=>:enemy}, 52, "x:-g", true], [{62=>:enemy}, 62, "x:-g", true], [{44=>nil}, 44, "x:-g", false], [{52=>nil}, 52, "x:-g", false], [{62=>nil}, 62, "x:-g", false]], 54=>[[{45=>:enemy}, 45, "x:-g", true], [{55=>:enemy}, 55, "x:-g", true], [{63=>:enemy}, 63, "x:-g", true], [{45=>nil}, 45, "x:-g", false], [{55=>nil}, 55, "x:-g", false], [{63=>nil}, 63, "x:-g", false]], 55=>[[{46=>:enemy}, 46, "x:-g", true], [{54=>:enemy}, 54, "x:-g", true], [{56=>:enemy}, 56, "x:-g", true], [{64=>:enemy}, 64, "x:-g", true], [{46=>nil}, 46, "x:-g", false], [{54=>nil}, 54, "x:-g", false], [{56=>nil}, 56, "x:-g", false], [{64=>nil}, 64, "x:-g", false]], 56=>[[{47=>:enemy}, 47, "x:-g", true], [{55=>:enemy}, 55, "x:-g", true], [{57=>:enemy}, 57, "x:-g", true], [{65=>:enemy}, 65, "x:-g", true], [{47=>nil}, 47, "x:-g", false], [{55=>nil}, 55, "x:-g", false], [{57=>nil}, 57, "x:-g", false], [{65=>nil}, 65, "x:-g", false]], 57=>[[{48=>:enemy}, 48, "x:-g", true], [{56=>:enemy}, 56, "x:-g", true], [{58=>:enemy}, 58, "x:-g", true], [{66=>:enemy}, 66, "x:-g", true], [{48=>nil}, 48, "x:-g", false], [{56=>nil}, 56, "x:-g", false], [{58=>nil}, 58, "x:-g", false], [{66=>nil}, 66, "x:-g", false]], 58=>[[{49=>:enemy}, 49, "x:-g", true], [{57=>:enemy}, 57, "x:-g", true], [{59=>:enemy}, 59, "x:-g", true], [{67=>:enemy}, 67, "x:-g", true], [{49=>nil}, 49, "x:-g", false], [{57=>nil}, 57, "x:-g", false], [{59=>nil}, 59, "x:-g", false], [{67=>nil}, 67, "x:-g", false]], 59=>[[{50=>:enemy}, 50, "x:-g", true], [{58=>:enemy}, 58, "x:-g", true], [{60=>:enemy}, 60, "x:-g", true], [{68=>:enemy}, 68, "x:-g", true], [{50=>nil}, 50, "x:-g", false], [{58=>nil}, 58, "x:-g", false], [{60=>nil}, 60, "x:-g", false], [{68=>nil}, 68, "x:-g", false]], 60=>[[{51=>:enemy}, 51, "x:-g", true], [{59=>:enemy}, 59, "x:-g", true], [{61=>:enemy}, 61, "x:-g", true], [{69=>:enemy}, 69, "x:-g", true], [{51=>nil}, 51, "x:-g", false], [{59=>nil}, 59, "x:-g", false], [{61=>nil}, 61, "x:-g", false], [{69=>nil}, 69, "x:-g", false]], 61=>[[{52=>:enemy}, 52, "x:-g", true], [{60=>:enemy}, 60, "x:-g", true], [{62=>:enemy}, 62, "x:-g", true], [{70=>:enemy}, 70, "x:-g", true], [{52=>nil}, 52, "x:-g", false], [{60=>nil}, 60, "x:-g", false], [{62=>nil}, 62, "x:-g", false], [{70=>nil}, 70, "x:-g", false]], 62=>[[{53=>:enemy}, 53, "x:-g", true], [{61=>:enemy}, 61, "x:-g", true], [{71=>:enemy}, 71, "x:-g", true], [{53=>nil}, 53, "x:-g", false], [{61=>nil}, 61, "x:-g", false], [{71=>nil}, 71, "x:-g", false]], 63=>[[{54=>:enemy}, 54, "x:-g", true], [{64=>:enemy}, 64, "x:-g", true], [{72=>:enemy}, 72, "x:-g", true], [{54=>nil}, 54, "x:-g", false], [{64=>nil}, 64, "x:-g", false], [{72=>nil}, 72, "x:-g", false]], 64=>[[{55=>:enemy}, 55, "x:-g", true], [{63=>:enemy}, 63, "x:-g", true], [{65=>:enemy}, 65, "x:-g", true], [{73=>:enemy}, 73, "x:-g", true], [{55=>nil}, 55, "x:-g", false], [{63=>nil}, 63, "x:-g", false], [{65=>nil}, 65, "x:-g", false], [{73=>nil}, 73, "x:-g", false]], 65=>[[{56=>:enemy}, 56, "x:-g", true], [{64=>:enemy}, 64, "x:-g", true], [{66=>:enemy}, 66, "x:-g", true], [{74=>:enemy}, 74, "x:-g", true], [{56=>nil}, 56, "x:-g", false], [{64=>nil}, 64, "x:-g", false], [{66=>nil}, 66, "x:-g", false], [{74=>nil}, 74, "x:-g", false]], 66=>[[{57=>:enemy}, 57, "x:-g", true], [{65=>:enemy}, 65, "x:-g", true], [{67=>:enemy}, 67, "x:-g", true], [{75=>:enemy}, 75, "x:-g", true], [{57=>nil}, 57, "x:-g", false], [{65=>nil}, 65, "x:-g", false], [{67=>nil}, 67, "x:-g", false], [{75=>nil}, 75, "x:-g", false]], 67=>[[{58=>:enemy}, 58, "x:-g", true], [{66=>:enemy}, 66, "x:-g", true], [{68=>:enemy}, 68, "x:-g", true], [{76=>:enemy}, 76, "x:-g", true], [{58=>nil}, 58, "x:-g", false], [{66=>nil}, 66, "x:-g", false], [{68=>nil}, 68, "x:-g", false], [{76=>nil}, 76, "x:-g", false]], 68=>[[{59=>:enemy}, 59, "x:-g", true], [{67=>:enemy}, 67, "x:-g", true], [{69=>:enemy}, 69, "x:-g", true], [{77=>:enemy}, 77, "x:-g", true], [{59=>nil}, 59, "x:-g", false], [{67=>nil}, 67, "x:-g", false], [{69=>nil}, 69, "x:-g", false], [{77=>nil}, 77, "x:-g", false]], 69=>[[{60=>:enemy}, 60, "x:-g", true], [{68=>:enemy}, 68, "x:-g", true], [{70=>:enemy}, 70, "x:-g", true], [{78=>:enemy}, 78, "x:-g", true], [{60=>nil}, 60, "x:-g", false], [{68=>nil}, 68, "x:-g", false], [{70=>nil}, 70, "x:-g", false], [{78=>nil}, 78, "x:-g", false]], 70=>[[{61=>:enemy}, 61, "x:-g", true], [{69=>:enemy}, 69, "x:-g", true], [{71=>:enemy}, 71, "x:-g", true], [{79=>:enemy}, 79, "x:-g", true], [{61=>nil}, 61, "x:-g", false], [{69=>nil}, 69, "x:-g", false], [{71=>nil}, 71, "x:-g", false], [{79=>nil}, 79, "x:-g", false]], 71=>[[{62=>:enemy}, 62, "x:-g", true], [{70=>:enemy}, 70, "x:-g", true], [{80=>:enemy}, 80, "x:-g", true], [{62=>nil}, 62, "x:-g", false], [{70=>nil}, 70, "x:-g", false], [{80=>nil}, 80, "x:-g", false]], 72=>[[{63=>:enemy}, 63, "x:-g", true], [{73=>:enemy}, 73, "x:-g", true], [{63=>nil}, 63, "x:-g", false], [{73=>nil}, 73, "x:-g", false]], 73=>[[{64=>:enemy}, 64, "x:-g", true], [{72=>:enemy}, 72, "x:-g", true], [{74=>:enemy}, 74, "x:-g", true], [{64=>nil}, 64, "x:-g", false], [{72=>nil}, 72, "x:-g", false], [{74=>nil}, 74, "x:-g", false]], 74=>[[{65=>:enemy}, 65, "x:-g", true], [{73=>:enemy}, 73, "x:-g", true], [{75=>:enemy}, 75, "x:-g", true], [{65=>nil}, 65, "x:-g", false], [{73=>nil}, 73, "x:-g", false], [{75=>nil}, 75, "x:-g", false]], 75=>[[{66=>:enemy}, 66, "x:-g", true], [{74=>:enemy}, 74, "x:-g", true], [{76=>:enemy}, 76, "x:-g", true], [{66=>nil}, 66, "x:-g", false], [{74=>nil}, 74, "x:-g", false], [{76=>nil}, 76, "x:-g", false]], 76=>[[{67=>:enemy}, 67, "x:-g", true], [{75=>:enemy}, 75, "x:-g", true], [{77=>:enemy}, 77, "x:-g", true], [{67=>nil}, 67, "x:-g", false], [{75=>nil}, 75, "x:-g", false], [{77=>nil}, 77, "x:-g", false]], 77=>[[{68=>:enemy}, 68, "x:-g", true], [{76=>:enemy}, 76, "x:-g", true], [{78=>:enemy}, 78, "x:-g", true], [{68=>nil}, 68, "x:-g", false], [{76=>nil}, 76, "x:-g", false], [{78=>nil}, 78, "x:-g", false]], 78=>[[{69=>:enemy}, 69, "x:-g", true], [{77=>:enemy}, 77, "x:-g", true], [{79=>:enemy}, 79, "x:-g", true], [{69=>nil}, 69, "x:-g", false], [{77=>nil}, 77, "x:-g", false], [{79=>nil}, 79, "x:-g", false]], 79=>[[{70=>:enemy}, 70, "x:-g", true], [{78=>:enemy}, 78, "x:-g", true], [{80=>:enemy}, 80, "x:-g", true], [{70=>nil}, 70, "x:-g", false], [{78=>nil}, 78, "x:-g", false], [{80=>nil}, 80, "x:-g", false]], 80=>[[{71=>:enemy}, 71, "x:-g", true], [{79=>:enemy}, 79, "x:-g", true], [{71=>nil}, 71, "x:-g", false], [{79=>nil}, 79, "x:-g", false]], nil=>[[{0=>nil}, 0, "x:-g", false], [{1=>nil}, 1, "x:-g", false], [{2=>nil}, 2, "x:-g", false], [{3=>nil}, 3, "x:-g", false], [{4=>nil}, 4, "x:-g", false], [{5=>nil}, 5, "x:-g", false], [{6=>nil}, 6, "x:-g", false], [{7=>nil}, 7, "x:-g", false], [{8=>nil}, 8, "x:-g", false], [{9=>nil}, 9, "x:-g", false], [{10=>nil}, 10, "x:-g", false], [{11=>nil}, 11, "x:-g", false], [{12=>nil}, 12, "x:-g", false], [{13=>nil}, 13, "x:-g", false], [{14=>nil}, 14, "x:-g", false], [{15=>nil}, 15, "x:-g", false], [{16=>nil}, 16, "x:-g", false], [{17=>nil}, 17, "x:-g", false], [{18=>nil}, 18, "x:-g", false], [{19=>nil}, 19, "x:-g", false], [{20=>nil}, 20, "x:-g", false], [{21=>nil}, 21, "x:-g", false], [{22=>nil}, 22, "x:-g", false], [{23=>nil}, 23, "x:-g", false], [{24=>nil}, 24, "x:-g", false], [{25=>nil}, 25, "x:-g", false], [{26=>nil}, 26, "x:-g", false], [{27=>nil}, 27, "x:-g", false], [{28=>nil}, 28, "x:-g", false], [{29=>nil}, 29, "x:-g", false], [{30=>nil}, 30, "x:-g", false], [{31=>nil}, 31, "x:-g", false], [{32=>nil}, 32, "x:-g", false], [{33=>nil}, 33, "x:-g", false], [{34=>nil}, 34, "x:-g", false], [{35=>nil}, 35, "x:-g", false], [{36=>nil}, 36, "x:-g", false], [{37=>nil}, 37, "x:-g", false], [{38=>nil}, 38, "x:-g", false], [{39=>nil}, 39, "x:-g", false], [{40=>nil}, 40, "x:-g", false], [{41=>nil}, 41, "x:-g", false], [{42=>nil}, 42, "x:-g", false], [{43=>nil}, 43, "x:-g", false], [{44=>nil}, 44, "x:-g", false], [{45=>nil}, 45, "x:-g", false], [{46=>nil}, 46, "x:-g", false], [{47=>nil}, 47, "x:-g", false], [{48=>nil}, 48, "x:-g", false], [{49=>nil}, 49, "x:-g", false], [{50=>nil}, 50, "x:-g", false], [{51=>nil}, 51, "x:-g", false], [{52=>nil}, 52, "x:-g", false], [{53=>nil}, 53, "x:-g", false], [{54=>nil}, 54, "x:-g", false], [{55=>nil}, 55, "x:-g", false], [{56=>nil}, 56, "x:-g", false], [{57=>nil}, 57, "x:-g", false], [{58=>nil}, 58, "x:-g", false], [{59=>nil}, 59, "x:-g", false], [{60=>nil}, 60, "x:-g", false], [{61=>nil}, 61, "x:-g", false], [{62=>nil}, 62, "x:-g", false], [{63=>nil}, 63, "x:-g", false], [{64=>nil}, 64, "x:-g", false], [{65=>nil}, 65, "x:-g", false], [{66=>nil}, 66, "x:-g", false], [{67=>nil}, 67, "x:-g", false], [{68=>nil}, 68, "x:-g", false], [{69=>nil}, 69, "x:-g", false], [{70=>nil}, 70, "x:-g", false], [{71=>nil}, 71, "x:-g", false], [{72=>nil}, 72, "x:-g", false], [{73=>nil}, 73, "x:-g", false], [{74=>nil}, 74, "x:-g", false], [{75=>nil}, 75, "x:-g", false], [{76=>nil}, 76, "x:-g", false], [{77=>nil}, 77, "x:-g", false], [{78=>nil}, 78, "x:-g", false], [{79=>nil}, 79, "x:-g", false], [{80=>nil}, 80, "x:-g", false]]}, "x:a"=>{0=>[[{10=>:enemy}, 10, "x:a", true], [{10=>nil}, 10, "x:a", false]], 1=>[[{9=>:enemy}, 9, "x:a", true], [{11=>:enemy}, 11, "x:a", true], [{9=>nil}, 9, "x:a", false], [{11=>nil}, 11, "x:a", false]], 2=>[[{10=>:enemy}, 10, "x:a", true], [{12=>:enemy}, 12, "x:a", true], [{10=>nil}, 10, "x:a", false], [{12=>nil}, 12, "x:a", false]], 3=>[[{11=>:enemy}, 11, "x:a", true], [{13=>:enemy}, 13, "x:a", true], [{11=>nil}, 11, "x:a", false], [{13=>nil}, 13, "x:a", false]], 4=>[[{12=>:enemy}, 12, "x:a", true], [{14=>:enemy}, 14, "x:a", true], [{12=>nil}, 12, "x:a", false], [{14=>nil}, 14, "x:a", false]], 5=>[[{13=>:enemy}, 13, "x:a", true], [{15=>:enemy}, 15, "x:a", true], [{13=>nil}, 13, "x:a", false], [{15=>nil}, 15, "x:a", false]], 6=>[[{14=>:enemy}, 14, "x:a", true], [{16=>:enemy}, 16, "x:a", true], [{14=>nil}, 14, "x:a", false], [{16=>nil}, 16, "x:a", false]], 7=>[[{15=>:enemy}, 15, "x:a", true], [{17=>:enemy}, 17, "x:a", true], [{15=>nil}, 15, "x:a", false], [{17=>nil}, 17, "x:a", false]], 8=>[[{16=>:enemy}, 16, "x:a", true], [{16=>nil}, 16, "x:a", false]], 9=>[[{1=>:enemy}, 1, "x:a", true], [{19=>:enemy}, 19, "x:a", true], [{1=>nil}, 1, "x:a", false], [{19=>nil}, 19, "x:a", false]], 10=>[[{0=>:enemy}, 0, "x:a", true], [{2=>:enemy}, 2, "x:a", true], [{18=>:enemy}, 18, "x:a", true], [{20=>:enemy}, 20, "x:a", true], [{0=>nil}, 0, "x:a", false], [{2=>nil}, 2, "x:a", false], [{18=>nil}, 18, "x:a", false], [{20=>nil}, 20, "x:a", false]], 11=>[[{1=>:enemy}, 1, "x:a", true], [{3=>:enemy}, 3, "x:a", true], [{19=>:enemy}, 19, "x:a", true], [{21=>:enemy}, 21, "x:a", true], [{1=>nil}, 1, "x:a", false], [{3=>nil}, 3, "x:a", false], [{19=>nil}, 19, "x:a", false], [{21=>nil}, 21, "x:a", false]], 12=>[[{2=>:enemy}, 2, "x:a", true], [{4=>:enemy}, 4, "x:a", true], [{20=>:enemy}, 20, "x:a", true], [{22=>:enemy}, 22, "x:a", true], [{2=>nil}, 2, "x:a", false], [{4=>nil}, 4, "x:a", false], [{20=>nil}, 20, "x:a", false], [{22=>nil}, 22, "x:a", false]], 13=>[[{3=>:enemy}, 3, "x:a", true], [{5=>:enemy}, 5, "x:a", true], [{21=>:enemy}, 21, "x:a", true], [{23=>:enemy}, 23, "x:a", true], [{3=>nil}, 3, "x:a", false], [{5=>nil}, 5, "x:a", false], [{21=>nil}, 21, "x:a", false], [{23=>nil}, 23, "x:a", false]], 14=>[[{4=>:enemy}, 4, "x:a", true], [{6=>:enemy}, 6, "x:a", true], [{22=>:enemy}, 22, "x:a", true], [{24=>:enemy}, 24, "x:a", true], [{4=>nil}, 4, "x:a", false], [{6=>nil}, 6, "x:a", false], [{22=>nil}, 22, "x:a", false], [{24=>nil}, 24, "x:a", false]], 15=>[[{5=>:enemy}, 5, "x:a", true], [{7=>:enemy}, 7, "x:a", true], [{23=>:enemy}, 23, "x:a", true], [{25=>:enemy}, 25, "x:a", true], [{5=>nil}, 5, "x:a", false], [{7=>nil}, 7, "x:a", false], [{23=>nil}, 23, "x:a", false], [{25=>nil}, 25, "x:a", false]], 16=>[[{6=>:enemy}, 6, "x:a", true], [{8=>:enemy}, 8, "x:a", true], [{24=>:enemy}, 24, "x:a", true], [{26=>:enemy}, 26, "x:a", true], [{6=>nil}, 6, "x:a", false], [{8=>nil}, 8, "x:a", false], [{24=>nil}, 24, "x:a", false], [{26=>nil}, 26, "x:a", false]], 17=>[[{7=>:enemy}, 7, "x:a", true], [{25=>:enemy}, 25, "x:a", true], [{7=>nil}, 7, "x:a", false], [{25=>nil}, 25, "x:a", false]], 18=>[[{10=>:enemy}, 10, "x:a", true], [{28=>:enemy}, 28, "x:a", true], [{10=>nil}, 10, "x:a", false], [{28=>nil}, 28, "x:a", false]], 19=>[[{9=>:enemy}, 9, "x:a", true], [{11=>:enemy}, 11, "x:a", true], [{27=>:enemy}, 27, "x:a", true], [{29=>:enemy}, 29, "x:a", true], [{9=>nil}, 9, "x:a", false], [{11=>nil}, 11, "x:a", false], [{27=>nil}, 27, "x:a", false], [{29=>nil}, 29, "x:a", false]], 20=>[[{10=>:enemy}, 10, "x:a", true], [{12=>:enemy}, 12, "x:a", true], [{28=>:enemy}, 28, "x:a", true], [{30=>:enemy}, 30, "x:a", true], [{10=>nil}, 10, "x:a", false], [{12=>nil}, 12, "x:a", false], [{28=>nil}, 28, "x:a", false], [{30=>nil}, 30, "x:a", false]], 21=>[[{11=>:enemy}, 11, "x:a", true], [{13=>:enemy}, 13, "x:a", true], [{29=>:enemy}, 29, "x:a", true], [{31=>:enemy}, 31, "x:a", true], [{11=>nil}, 11, "x:a", false], [{13=>nil}, 13, "x:a", false], [{29=>nil}, 29, "x:a", false], [{31=>nil}, 31, "x:a", false]], 22=>[[{12=>:enemy}, 12, "x:a", true], [{14=>:enemy}, 14, "x:a", true], [{30=>:enemy}, 30, "x:a", true], [{32=>:enemy}, 32, "x:a", true], [{12=>nil}, 12, "x:a", false], [{14=>nil}, 14, "x:a", false], [{30=>nil}, 30, "x:a", false], [{32=>nil}, 32, "x:a", false]], 23=>[[{13=>:enemy}, 13, "x:a", true], [{15=>:enemy}, 15, "x:a", true], [{31=>:enemy}, 31, "x:a", true], [{33=>:enemy}, 33, "x:a", true], [{13=>nil}, 13, "x:a", false], [{15=>nil}, 15, "x:a", false], [{31=>nil}, 31, "x:a", false], [{33=>nil}, 33, "x:a", false]], 24=>[[{14=>:enemy}, 14, "x:a", true], [{16=>:enemy}, 16, "x:a", true], [{32=>:enemy}, 32, "x:a", true], [{34=>:enemy}, 34, "x:a", true], [{14=>nil}, 14, "x:a", false], [{16=>nil}, 16, "x:a", false], [{32=>nil}, 32, "x:a", false], [{34=>nil}, 34, "x:a", false]], 25=>[[{15=>:enemy}, 15, "x:a", true], [{17=>:enemy}, 17, "x:a", true], [{33=>:enemy}, 33, "x:a", true], [{35=>:enemy}, 35, "x:a", true], [{15=>nil}, 15, "x:a", false], [{17=>nil}, 17, "x:a", false], [{33=>nil}, 33, "x:a", false], [{35=>nil}, 35, "x:a", false]], 26=>[[{16=>:enemy}, 16, "x:a", true], [{34=>:enemy}, 34, "x:a", true], [{16=>nil}, 16, "x:a", false], [{34=>nil}, 34, "x:a", false]], 27=>[[{19=>:enemy}, 19, "x:a", true], [{37=>:enemy}, 37, "x:a", true], [{19=>nil}, 19, "x:a", false], [{37=>nil}, 37, "x:a", false]], 28=>[[{18=>:enemy}, 18, "x:a", true], [{20=>:enemy}, 20, "x:a", true], [{36=>:enemy}, 36, "x:a", true], [{38=>:enemy}, 38, "x:a", true], [{18=>nil}, 18, "x:a", false], [{20=>nil}, 20, "x:a", false], [{36=>nil}, 36, "x:a", false], [{38=>nil}, 38, "x:a", false]], 29=>[[{19=>:enemy}, 19, "x:a", true], [{21=>:enemy}, 21, "x:a", true], [{37=>:enemy}, 37, "x:a", true], [{39=>:enemy}, 39, "x:a", true], [{19=>nil}, 19, "x:a", false], [{21=>nil}, 21, "x:a", false], [{37=>nil}, 37, "x:a", false], [{39=>nil}, 39, "x:a", false]], 30=>[[{20=>:enemy}, 20, "x:a", true], [{22=>:enemy}, 22, "x:a", true], [{38=>:enemy}, 38, "x:a", true], [{40=>:enemy}, 40, "x:a", true], [{20=>nil}, 20, "x:a", false], [{22=>nil}, 22, "x:a", false], [{38=>nil}, 38, "x:a", false], [{40=>nil}, 40, "x:a", false]], 31=>[[{21=>:enemy}, 21, "x:a", true], [{23=>:enemy}, 23, "x:a", true], [{39=>:enemy}, 39, "x:a", true], [{41=>:enemy}, 41, "x:a", true], [{21=>nil}, 21, "x:a", false], [{23=>nil}, 23, "x:a", false], [{39=>nil}, 39, "x:a", false], [{41=>nil}, 41, "x:a", false]], 32=>[[{22=>:enemy}, 22, "x:a", true], [{24=>:enemy}, 24, "x:a", true], [{40=>:enemy}, 40, "x:a", true], [{42=>:enemy}, 42, "x:a", true], [{22=>nil}, 22, "x:a", false], [{24=>nil}, 24, "x:a", false], [{40=>nil}, 40, "x:a", false], [{42=>nil}, 42, "x:a", false]], 33=>[[{23=>:enemy}, 23, "x:a", true], [{25=>:enemy}, 25, "x:a", true], [{41=>:enemy}, 41, "x:a", true], [{43=>:enemy}, 43, "x:a", true], [{23=>nil}, 23, "x:a", false], [{25=>nil}, 25, "x:a", false], [{41=>nil}, 41, "x:a", false], [{43=>nil}, 43, "x:a", false]], 34=>[[{24=>:enemy}, 24, "x:a", true], [{26=>:enemy}, 26, "x:a", true], [{42=>:enemy}, 42, "x:a", true], [{44=>:enemy}, 44, "x:a", true], [{24=>nil}, 24, "x:a", false], [{26=>nil}, 26, "x:a", false], [{42=>nil}, 42, "x:a", false], [{44=>nil}, 44, "x:a", false]], 35=>[[{25=>:enemy}, 25, "x:a", true], [{43=>:enemy}, 43, "x:a", true], [{25=>nil}, 25, "x:a", false], [{43=>nil}, 43, "x:a", false]], 36=>[[{28=>:enemy}, 28, "x:a", true], [{46=>:enemy}, 46, "x:a", true], [{28=>nil}, 28, "x:a", false], [{46=>nil}, 46, "x:a", false]], 37=>[[{27=>:enemy}, 27, "x:a", true], [{29=>:enemy}, 29, "x:a", true], [{45=>:enemy}, 45, "x:a", true], [{47=>:enemy}, 47, "x:a", true], [{27=>nil}, 27, "x:a", false], [{29=>nil}, 29, "x:a", false], [{45=>nil}, 45, "x:a", false], [{47=>nil}, 47, "x:a", false]], 38=>[[{28=>:enemy}, 28, "x:a", true], [{30=>:enemy}, 30, "x:a", true], [{46=>:enemy}, 46, "x:a", true], [{48=>:enemy}, 48, "x:a", true], [{28=>nil}, 28, "x:a", false], [{30=>nil}, 30, "x:a", false], [{46=>nil}, 46, "x:a", false], [{48=>nil}, 48, "x:a", false]], 39=>[[{29=>:enemy}, 29, "x:a", true], [{31=>:enemy}, 31, "x:a", true], [{47=>:enemy}, 47, "x:a", true], [{49=>:enemy}, 49, "x:a", true], [{29=>nil}, 29, "x:a", false], [{31=>nil}, 31, "x:a", false], [{47=>nil}, 47, "x:a", false], [{49=>nil}, 49, "x:a", false]], 40=>[[{30=>:enemy}, 30, "x:a", true], [{32=>:enemy}, 32, "x:a", true], [{48=>:enemy}, 48, "x:a", true], [{50=>:enemy}, 50, "x:a", true], [{30=>nil}, 30, "x:a", false], [{32=>nil}, 32, "x:a", false], [{48=>nil}, 48, "x:a", false], [{50=>nil}, 50, "x:a", false]], 41=>[[{31=>:enemy}, 31, "x:a", true], [{33=>:enemy}, 33, "x:a", true], [{49=>:enemy}, 49, "x:a", true], [{51=>:enemy}, 51, "x:a", true], [{31=>nil}, 31, "x:a", false], [{33=>nil}, 33, "x:a", false], [{49=>nil}, 49, "x:a", false], [{51=>nil}, 51, "x:a", false]], 42=>[[{32=>:enemy}, 32, "x:a", true], [{34=>:enemy}, 34, "x:a", true], [{50=>:enemy}, 50, "x:a", true], [{52=>:enemy}, 52, "x:a", true], [{32=>nil}, 32, "x:a", false], [{34=>nil}, 34, "x:a", false], [{50=>nil}, 50, "x:a", false], [{52=>nil}, 52, "x:a", false]], 43=>[[{33=>:enemy}, 33, "x:a", true], [{35=>:enemy}, 35, "x:a", true], [{51=>:enemy}, 51, "x:a", true], [{53=>:enemy}, 53, "x:a", true], [{33=>nil}, 33, "x:a", false], [{35=>nil}, 35, "x:a", false], [{51=>nil}, 51, "x:a", false], [{53=>nil}, 53, "x:a", false]], 44=>[[{34=>:enemy}, 34, "x:a", true], [{52=>:enemy}, 52, "x:a", true], [{34=>nil}, 34, "x:a", false], [{52=>nil}, 52, "x:a", false]], 45=>[[{37=>:enemy}, 37, "x:a", true], [{55=>:enemy}, 55, "x:a", true], [{37=>nil}, 37, "x:a", false], [{55=>nil}, 55, "x:a", false]], 46=>[[{36=>:enemy}, 36, "x:a", true], [{38=>:enemy}, 38, "x:a", true], [{54=>:enemy}, 54, "x:a", true], [{56=>:enemy}, 56, "x:a", true], [{36=>nil}, 36, "x:a", false], [{38=>nil}, 38, "x:a", false], [{54=>nil}, 54, "x:a", false], [{56=>nil}, 56, "x:a", false]], 47=>[[{37=>:enemy}, 37, "x:a", true], [{39=>:enemy}, 39, "x:a", true], [{55=>:enemy}, 55, "x:a", true], [{57=>:enemy}, 57, "x:a", true], [{37=>nil}, 37, "x:a", false], [{39=>nil}, 39, "x:a", false], [{55=>nil}, 55, "x:a", false], [{57=>nil}, 57, "x:a", false]], 48=>[[{38=>:enemy}, 38, "x:a", true], [{40=>:enemy}, 40, "x:a", true], [{56=>:enemy}, 56, "x:a", true], [{58=>:enemy}, 58, "x:a", true], [{38=>nil}, 38, "x:a", false], [{40=>nil}, 40, "x:a", false], [{56=>nil}, 56, "x:a", false], [{58=>nil}, 58, "x:a", false]], 49=>[[{39=>:enemy}, 39, "x:a", true], [{41=>:enemy}, 41, "x:a", true], [{57=>:enemy}, 57, "x:a", true], [{59=>:enemy}, 59, "x:a", true], [{39=>nil}, 39, "x:a", false], [{41=>nil}, 41, "x:a", false], [{57=>nil}, 57, "x:a", false], [{59=>nil}, 59, "x:a", false]], 50=>[[{40=>:enemy}, 40, "x:a", true], [{42=>:enemy}, 42, "x:a", true], [{58=>:enemy}, 58, "x:a", true], [{60=>:enemy}, 60, "x:a", true], [{40=>nil}, 40, "x:a", false], [{42=>nil}, 42, "x:a", false], [{58=>nil}, 58, "x:a", false], [{60=>nil}, 60, "x:a", false]], 51=>[[{41=>:enemy}, 41, "x:a", true], [{43=>:enemy}, 43, "x:a", true], [{59=>:enemy}, 59, "x:a", true], [{61=>:enemy}, 61, "x:a", true], [{41=>nil}, 41, "x:a", false], [{43=>nil}, 43, "x:a", false], [{59=>nil}, 59, "x:a", false], [{61=>nil}, 61, "x:a", false]], 52=>[[{42=>:enemy}, 42, "x:a", true], [{44=>:enemy}, 44, "x:a", true], [{60=>:enemy}, 60, "x:a", true], [{62=>:enemy}, 62, "x:a", true], [{42=>nil}, 42, "x:a", false], [{44=>nil}, 44, "x:a", false], [{60=>nil}, 60, "x:a", false], [{62=>nil}, 62, "x:a", false]], 53=>[[{43=>:enemy}, 43, "x:a", true], [{61=>:enemy}, 61, "x:a", true], [{43=>nil}, 43, "x:a", false], [{61=>nil}, 61, "x:a", false]], 54=>[[{46=>:enemy}, 46, "x:a", true], [{64=>:enemy}, 64, "x:a", true], [{46=>nil}, 46, "x:a", false], [{64=>nil}, 64, "x:a", false]], 55=>[[{45=>:enemy}, 45, "x:a", true], [{47=>:enemy}, 47, "x:a", true], [{63=>:enemy}, 63, "x:a", true], [{65=>:enemy}, 65, "x:a", true], [{45=>nil}, 45, "x:a", false], [{47=>nil}, 47, "x:a", false], [{63=>nil}, 63, "x:a", false], [{65=>nil}, 65, "x:a", false]], 56=>[[{46=>:enemy}, 46, "x:a", true], [{48=>:enemy}, 48, "x:a", true], [{64=>:enemy}, 64, "x:a", true], [{66=>:enemy}, 66, "x:a", true], [{46=>nil}, 46, "x:a", false], [{48=>nil}, 48, "x:a", false], [{64=>nil}, 64, "x:a", false], [{66=>nil}, 66, "x:a", false]], 57=>[[{47=>:enemy}, 47, "x:a", true], [{49=>:enemy}, 49, "x:a", true], [{65=>:enemy}, 65, "x:a", true], [{67=>:enemy}, 67, "x:a", true], [{47=>nil}, 47, "x:a", false], [{49=>nil}, 49, "x:a", false], [{65=>nil}, 65, "x:a", false], [{67=>nil}, 67, "x:a", false]], 58=>[[{48=>:enemy}, 48, "x:a", true], [{50=>:enemy}, 50, "x:a", true], [{66=>:enemy}, 66, "x:a", true], [{68=>:enemy}, 68, "x:a", true], [{48=>nil}, 48, "x:a", false], [{50=>nil}, 50, "x:a", false], [{66=>nil}, 66, "x:a", false], [{68=>nil}, 68, "x:a", false]], 59=>[[{49=>:enemy}, 49, "x:a", true], [{51=>:enemy}, 51, "x:a", true], [{67=>:enemy}, 67, "x:a", true], [{69=>:enemy}, 69, "x:a", true], [{49=>nil}, 49, "x:a", false], [{51=>nil}, 51, "x:a", false], [{67=>nil}, 67, "x:a", false], [{69=>nil}, 69, "x:a", false]], 60=>[[{50=>:enemy}, 50, "x:a", true], [{52=>:enemy}, 52, "x:a", true], [{68=>:enemy}, 68, "x:a", true], [{70=>:enemy}, 70, "x:a", true], [{50=>nil}, 50, "x:a", false], [{52=>nil}, 52, "x:a", false], [{68=>nil}, 68, "x:a", false], [{70=>nil}, 70, "x:a", false]], 61=>[[{51=>:enemy}, 51, "x:a", true], [{53=>:enemy}, 53, "x:a", true], [{69=>:enemy}, 69, "x:a", true], [{71=>:enemy}, 71, "x:a", true], [{51=>nil}, 51, "x:a", false], [{53=>nil}, 53, "x:a", false], [{69=>nil}, 69, "x:a", false], [{71=>nil}, 71, "x:a", false]], 62=>[[{52=>:enemy}, 52, "x:a", true], [{70=>:enemy}, 70, "x:a", true], [{52=>nil}, 52, "x:a", false], [{70=>nil}, 70, "x:a", false]], 63=>[[{55=>:enemy}, 55, "x:a", true], [{73=>:enemy}, 73, "x:a", true], [{55=>nil}, 55, "x:a", false], [{73=>nil}, 73, "x:a", false]], 64=>[[{54=>:enemy}, 54, "x:a", true], [{56=>:enemy}, 56, "x:a", true], [{72=>:enemy}, 72, "x:a", true], [{74=>:enemy}, 74, "x:a", true], [{54=>nil}, 54, "x:a", false], [{56=>nil}, 56, "x:a", false], [{72=>nil}, 72, "x:a", false], [{74=>nil}, 74, "x:a", false]], 65=>[[{55=>:enemy}, 55, "x:a", true], [{57=>:enemy}, 57, "x:a", true], [{73=>:enemy}, 73, "x:a", true], [{75=>:enemy}, 75, "x:a", true], [{55=>nil}, 55, "x:a", false], [{57=>nil}, 57, "x:a", false], [{73=>nil}, 73, "x:a", false], [{75=>nil}, 75, "x:a", false]], 66=>[[{56=>:enemy}, 56, "x:a", true], [{58=>:enemy}, 58, "x:a", true], [{74=>:enemy}, 74, "x:a", true], [{76=>:enemy}, 76, "x:a", true], [{56=>nil}, 56, "x:a", false], [{58=>nil}, 58, "x:a", false], [{74=>nil}, 74, "x:a", false], [{76=>nil}, 76, "x:a", false]], 67=>[[{57=>:enemy}, 57, "x:a", true], [{59=>:enemy}, 59, "x:a", true], [{75=>:enemy}, 75, "x:a", true], [{77=>:enemy}, 77, "x:a", true], [{57=>nil}, 57, "x:a", false], [{59=>nil}, 59, "x:a", false], [{75=>nil}, 75, "x:a", false], [{77=>nil}, 77, "x:a", false]], 68=>[[{58=>:enemy}, 58, "x:a", true], [{60=>:enemy}, 60, "x:a", true], [{76=>:enemy}, 76, "x:a", true], [{78=>:enemy}, 78, "x:a", true], [{58=>nil}, 58, "x:a", false], [{60=>nil}, 60, "x:a", false], [{76=>nil}, 76, "x:a", false], [{78=>nil}, 78, "x:a", false]], 69=>[[{59=>:enemy}, 59, "x:a", true], [{61=>:enemy}, 61, "x:a", true], [{77=>:enemy}, 77, "x:a", true], [{79=>:enemy}, 79, "x:a", true], [{59=>nil}, 59, "x:a", false], [{61=>nil}, 61, "x:a", false], [{77=>nil}, 77, "x:a", false], [{79=>nil}, 79, "x:a", false]], 70=>[[{60=>:enemy}, 60, "x:a", true], [{62=>:enemy}, 62, "x:a", true], [{78=>:enemy}, 78, "x:a", true], [{80=>:enemy}, 80, "x:a", true], [{60=>nil}, 60, "x:a", false], [{62=>nil}, 62, "x:a", false], [{78=>nil}, 78, "x:a", false], [{80=>nil}, 80, "x:a", false]], 71=>[[{61=>:enemy}, 61, "x:a", true], [{79=>:enemy}, 79, "x:a", true], [{61=>nil}, 61, "x:a", false], [{79=>nil}, 79, "x:a", false]], 72=>[[{64=>:enemy}, 64, "x:a", true], [{64=>nil}, 64, "x:a", false]], 73=>[[{63=>:enemy}, 63, "x:a", true], [{65=>:enemy}, 65, "x:a", true], [{63=>nil}, 63, "x:a", false], [{65=>nil}, 65, "x:a", false]], 74=>[[{64=>:enemy}, 64, "x:a", true], [{66=>:enemy}, 66, "x:a", true], [{64=>nil}, 64, "x:a", false], [{66=>nil}, 66, "x:a", false]], 75=>[[{65=>:enemy}, 65, "x:a", true], [{67=>:enemy}, 67, "x:a", true], [{65=>nil}, 65, "x:a", false], [{67=>nil}, 67, "x:a", false]], 76=>[[{66=>:enemy}, 66, "x:a", true], [{68=>:enemy}, 68, "x:a", true], [{66=>nil}, 66, "x:a", false], [{68=>nil}, 68, "x:a", false]], 77=>[[{67=>:enemy}, 67, "x:a", true], [{69=>:enemy}, 69, "x:a", true], [{67=>nil}, 67, "x:a", false], [{69=>nil}, 69, "x:a", false]], 78=>[[{68=>:enemy}, 68, "x:a", true], [{70=>:enemy}, 70, "x:a", true], [{68=>nil}, 68, "x:a", false], [{70=>nil}, 70, "x:a", false]], 79=>[[{69=>:enemy}, 69, "x:a", true], [{71=>:enemy}, 71, "x:a", true], [{69=>nil}, 69, "x:a", false], [{71=>nil}, 71, "x:a", false]], 80=>[[{70=>:enemy}, 70, "x:a", true], [{70=>nil}, 70, "x:a", false]], nil=>[[{0=>nil}, 0, "x:a", false], [{1=>nil}, 1, "x:a", false], [{2=>nil}, 2, "x:a", false], [{3=>nil}, 3, "x:a", false], [{4=>nil}, 4, "x:a", false], [{5=>nil}, 5, "x:a", false], [{6=>nil}, 6, "x:a", false], [{7=>nil}, 7, "x:a", false], [{8=>nil}, 8, "x:a", false], [{9=>nil}, 9, "x:a", false], [{10=>nil}, 10, "x:a", false], [{11=>nil}, 11, "x:a", false], [{12=>nil}, 12, "x:a", false], [{13=>nil}, 13, "x:a", false], [{14=>nil}, 14, "x:a", false], [{15=>nil}, 15, "x:a", false], [{16=>nil}, 16, "x:a", false], [{17=>nil}, 17, "x:a", false], [{18=>nil}, 18, "x:a", false], [{19=>nil}, 19, "x:a", false], [{20=>nil}, 20, "x:a", false], [{21=>nil}, 21, "x:a", false], [{22=>nil}, 22, "x:a", false], [{23=>nil}, 23, "x:a", false], [{24=>nil}, 24, "x:a", false], [{25=>nil}, 25, "x:a", false], [{26=>nil}, 26, "x:a", false], [{27=>nil}, 27, "x:a", false], [{28=>nil}, 28, "x:a", false], [{29=>nil}, 29, "x:a", false], [{30=>nil}, 30, "x:a", false], [{31=>nil}, 31, "x:a", false], [{32=>nil}, 32, "x:a", false], [{33=>nil}, 33, "x:a", false], [{34=>nil}, 34, "x:a", false], [{35=>nil}, 35, "x:a", false], [{36=>nil}, 36, "x:a", false], [{37=>nil}, 37, "x:a", false], [{38=>nil}, 38, "x:a", false], [{39=>nil}, 39, "x:a", false], [{40=>nil}, 40, "x:a", false], [{41=>nil}, 41, "x:a", false], [{42=>nil}, 42, "x:a", false], [{43=>nil}, 43, "x:a", false], [{44=>nil}, 44, "x:a", false], [{45=>nil}, 45, "x:a", false], [{46=>nil}, 46, "x:a", false], [{47=>nil}, 47, "x:a", false], [{48=>nil}, 48, "x:a", false], [{49=>nil}, 49, "x:a", false], [{50=>nil}, 50, "x:a", false], [{51=>nil}, 51, "x:a", false], [{52=>nil}, 52, "x:a", false], [{53=>nil}, 53, "x:a", false], [{54=>nil}, 54, "x:a", false], [{55=>nil}, 55, "x:a", false], [{56=>nil}, 56, "x:a", false], [{57=>nil}, 57, "x:a", false], [{58=>nil}, 58, "x:a", false], [{59=>nil}, 59, "x:a", false], [{60=>nil}, 60, "x:a", false], [{61=>nil}, 61, "x:a", false], [{62=>nil}, 62, "x:a", false], [{63=>nil}, 63, "x:a", false], [{64=>nil}, 64, "x:a", false], [{65=>nil}, 65, "x:a", false], [{66=>nil}, 66, "x:a", false], [{67=>nil}, 67, "x:a", false], [{68=>nil}, 68, "x:a", false], [{69=>nil}, 69, "x:a", false], [{70=>nil}, 70, "x:a", false], [{71=>nil}, 71, "x:a", false], [{72=>nil}, 72, "x:a", false], [{73=>nil}, 73, "x:a", false], [{74=>nil}, 74, "x:a", false], [{75=>nil}, 75, "x:a", false], [{76=>nil}, 76, "x:a", false], [{77=>nil}, 77, "x:a", false], [{78=>nil}, 78, "x:a", false], [{79=>nil}, 79, "x:a", false], [{80=>nil}, 80, "x:a", false]]}, "x:c"=>{0=>[[{1=>:occupied, 2=>nil, 3=>:enemy}, 3, "x:c", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>:enemy}, 4, "x:c", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "x:c", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{1=>:occupied, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{1=>:occupied, 2=>:enemy}, 2, "x:c", true], [{9=>:occupied, 18=>nil, 27=>:enemy}, 27, "x:c", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>:enemy}, 36, "x:c", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "x:c", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{9=>:occupied, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{9=>:occupied, 18=>:enemy}, 18, "x:c", true], [{1=>nil}, 1, "x:c", false], [{1=>nil, 2=>:occupied, 3=>nil, 4=>:enemy}, 4, "x:c", true], [{1=>nil, 2=>:occupied, 3=>nil, 4=>nil, 5=>:enemy}, 5, "x:c", true], [{1=>nil, 2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{1=>nil, 2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{1=>nil, 2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{1=>nil, 2=>:occupied, 3=>:enemy}, 3, "x:c", true], [{1=>nil, 2=>nil}, 2, "x:c", false], [{1=>nil, 2=>nil, 3=>:occupied, 4=>nil, 5=>:enemy}, 5, "x:c", true], [{1=>nil, 2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{1=>nil, 2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{1=>nil, 2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{1=>nil, 2=>nil, 3=>:occupied, 4=>:enemy}, 4, "x:c", true], [{1=>nil, 2=>nil, 3=>nil}, 3, "x:c", false], [{1=>nil, 2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>:occupied, 5=>:enemy}, 5, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil}, 4, "x:c", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>:enemy}, 6, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "x:c", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>:enemy}, 7, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "x:c", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "x:c", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "x:c", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:c", false], [{9=>nil}, 9, "x:c", false], [{9=>nil, 18=>:occupied, 27=>nil, 36=>:enemy}, 36, "x:c", true], [{9=>nil, 18=>:occupied, 27=>nil, 36=>nil, 45=>:enemy}, 45, "x:c", true], [{9=>nil, 18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{9=>nil, 18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{9=>nil, 18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{9=>nil, 18=>:occupied, 27=>:enemy}, 27, "x:c", true], [{9=>nil, 18=>nil}, 18, "x:c", false], [{9=>nil, 18=>nil, 27=>:occupied, 36=>nil, 45=>:enemy}, 45, "x:c", true], [{9=>nil, 18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{9=>nil, 18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{9=>nil, 18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{9=>nil, 18=>nil, 27=>:occupied, 36=>:enemy}, 36, "x:c", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "x:c", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>:occupied, 45=>:enemy}, 45, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "x:c", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>:enemy}, 54, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "x:c", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>:enemy}, 63, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "x:c", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "x:c", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "x:c", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:c", false]], 1=>[[{2=>:occupied, 3=>nil, 4=>:enemy}, 4, "x:c", true], [{2=>:occupied, 3=>nil, 4=>nil, 5=>:enemy}, 5, "x:c", true], [{2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{2=>:occupied, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{2=>:occupied, 3=>:enemy}, 3, "x:c", true], [{10=>:occupied, 19=>nil, 28=>:enemy}, 28, "x:c", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>:enemy}, 37, "x:c", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "x:c", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{10=>:occupied, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{10=>:occupied, 19=>:enemy}, 19, "x:c", true], [{0=>nil}, 0, "x:c", false], [{2=>nil}, 2, "x:c", false], [{2=>nil, 3=>:occupied, 4=>nil, 5=>:enemy}, 5, "x:c", true], [{2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{2=>nil, 3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{2=>nil, 3=>:occupied, 4=>:enemy}, 4, "x:c", true], [{2=>nil, 3=>nil}, 3, "x:c", false], [{2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{2=>nil, 3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{2=>nil, 3=>nil, 4=>:occupied, 5=>:enemy}, 5, "x:c", true], [{2=>nil, 3=>nil, 4=>nil}, 4, "x:c", false], [{2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{2=>nil, 3=>nil, 4=>nil, 5=>:occupied, 6=>:enemy}, 6, "x:c", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "x:c", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>:enemy}, 7, "x:c", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "x:c", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "x:c", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "x:c", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:c", false], [{10=>nil}, 10, "x:c", false], [{10=>nil, 19=>:occupied, 28=>nil, 37=>:enemy}, 37, "x:c", true], [{10=>nil, 19=>:occupied, 28=>nil, 37=>nil, 46=>:enemy}, 46, "x:c", true], [{10=>nil, 19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{10=>nil, 19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{10=>nil, 19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{10=>nil, 19=>:occupied, 28=>:enemy}, 28, "x:c", true], [{10=>nil, 19=>nil}, 19, "x:c", false], [{10=>nil, 19=>nil, 28=>:occupied, 37=>nil, 46=>:enemy}, 46, "x:c", true], [{10=>nil, 19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{10=>nil, 19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{10=>nil, 19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{10=>nil, 19=>nil, 28=>:occupied, 37=>:enemy}, 37, "x:c", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "x:c", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>:occupied, 46=>:enemy}, 46, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "x:c", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>:enemy}, 55, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "x:c", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>:enemy}, 64, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "x:c", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "x:c", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "x:c", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:c", false]], 2=>[[{1=>:occupied, 0=>:enemy}, 0, "x:c", true], [{3=>:occupied, 4=>nil, 5=>:enemy}, 5, "x:c", true], [{3=>:occupied, 4=>nil, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{3=>:occupied, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{3=>:occupied, 4=>:enemy}, 4, "x:c", true], [{11=>:occupied, 20=>nil, 29=>:enemy}, 29, "x:c", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>:enemy}, 38, "x:c", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "x:c", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{11=>:occupied, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{11=>:occupied, 20=>:enemy}, 20, "x:c", true], [{1=>nil}, 1, "x:c", false], [{1=>nil, 0=>nil}, 0, "x:c", false], [{3=>nil}, 3, "x:c", false], [{3=>nil, 4=>:occupied, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{3=>nil, 4=>:occupied, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{3=>nil, 4=>:occupied, 5=>:enemy}, 5, "x:c", true], [{3=>nil, 4=>nil}, 4, "x:c", false], [{3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{3=>nil, 4=>nil, 5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{3=>nil, 4=>nil, 5=>:occupied, 6=>:enemy}, 6, "x:c", true], [{3=>nil, 4=>nil, 5=>nil}, 5, "x:c", false], [{3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{3=>nil, 4=>nil, 5=>nil, 6=>:occupied, 7=>:enemy}, 7, "x:c", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "x:c", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "x:c", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "x:c", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:c", false], [{11=>nil}, 11, "x:c", false], [{11=>nil, 20=>:occupied, 29=>nil, 38=>:enemy}, 38, "x:c", true], [{11=>nil, 20=>:occupied, 29=>nil, 38=>nil, 47=>:enemy}, 47, "x:c", true], [{11=>nil, 20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{11=>nil, 20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{11=>nil, 20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{11=>nil, 20=>:occupied, 29=>:enemy}, 29, "x:c", true], [{11=>nil, 20=>nil}, 20, "x:c", false], [{11=>nil, 20=>nil, 29=>:occupied, 38=>nil, 47=>:enemy}, 47, "x:c", true], [{11=>nil, 20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{11=>nil, 20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{11=>nil, 20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{11=>nil, 20=>nil, 29=>:occupied, 38=>:enemy}, 38, "x:c", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "x:c", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>:occupied, 47=>:enemy}, 47, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "x:c", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>:enemy}, 56, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "x:c", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>:enemy}, 65, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "x:c", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "x:c", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "x:c", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:c", false]], 3=>[[{2=>:occupied, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{2=>:occupied, 1=>:enemy}, 1, "x:c", true], [{4=>:occupied, 5=>nil, 6=>:enemy}, 6, "x:c", true], [{4=>:occupied, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{4=>:occupied, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{4=>:occupied, 5=>:enemy}, 5, "x:c", true], [{12=>:occupied, 21=>nil, 30=>:enemy}, 30, "x:c", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>:enemy}, 39, "x:c", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "x:c", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{12=>:occupied, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{12=>:occupied, 21=>:enemy}, 21, "x:c", true], [{2=>nil}, 2, "x:c", false], [{2=>nil, 1=>:occupied, 0=>:enemy}, 0, "x:c", true], [{2=>nil, 1=>nil}, 1, "x:c", false], [{2=>nil, 1=>nil, 0=>nil}, 0, "x:c", false], [{4=>nil}, 4, "x:c", false], [{4=>nil, 5=>:occupied, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{4=>nil, 5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{4=>nil, 5=>:occupied, 6=>:enemy}, 6, "x:c", true], [{4=>nil, 5=>nil}, 5, "x:c", false], [{4=>nil, 5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{4=>nil, 5=>nil, 6=>:occupied, 7=>:enemy}, 7, "x:c", true], [{4=>nil, 5=>nil, 6=>nil}, 6, "x:c", false], [{4=>nil, 5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "x:c", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "x:c", false], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:c", false], [{12=>nil}, 12, "x:c", false], [{12=>nil, 21=>:occupied, 30=>nil, 39=>:enemy}, 39, "x:c", true], [{12=>nil, 21=>:occupied, 30=>nil, 39=>nil, 48=>:enemy}, 48, "x:c", true], [{12=>nil, 21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{12=>nil, 21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{12=>nil, 21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{12=>nil, 21=>:occupied, 30=>:enemy}, 30, "x:c", true], [{12=>nil, 21=>nil}, 21, "x:c", false], [{12=>nil, 21=>nil, 30=>:occupied, 39=>nil, 48=>:enemy}, 48, "x:c", true], [{12=>nil, 21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{12=>nil, 21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{12=>nil, 21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{12=>nil, 21=>nil, 30=>:occupied, 39=>:enemy}, 39, "x:c", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "x:c", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>:occupied, 48=>:enemy}, 48, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "x:c", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>:enemy}, 57, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "x:c", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>:enemy}, 66, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "x:c", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "x:c", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "x:c", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:c", false]], 4=>[[{3=>:occupied, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{3=>:occupied, 2=>:enemy}, 2, "x:c", true], [{5=>:occupied, 6=>nil, 7=>:enemy}, 7, "x:c", true], [{5=>:occupied, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{5=>:occupied, 6=>:enemy}, 6, "x:c", true], [{13=>:occupied, 22=>nil, 31=>:enemy}, 31, "x:c", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>:enemy}, 40, "x:c", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "x:c", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{13=>:occupied, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{13=>:occupied, 22=>:enemy}, 22, "x:c", true], [{3=>nil}, 3, "x:c", false], [{3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{3=>nil, 2=>:occupied, 1=>:enemy}, 1, "x:c", true], [{3=>nil, 2=>nil}, 2, "x:c", false], [{3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "x:c", true], [{3=>nil, 2=>nil, 1=>nil}, 1, "x:c", false], [{3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:c", false], [{5=>nil}, 5, "x:c", false], [{5=>nil, 6=>:occupied, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{5=>nil, 6=>:occupied, 7=>:enemy}, 7, "x:c", true], [{5=>nil, 6=>nil}, 6, "x:c", false], [{5=>nil, 6=>nil, 7=>:occupied, 8=>:enemy}, 8, "x:c", true], [{5=>nil, 6=>nil, 7=>nil}, 7, "x:c", false], [{5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:c", false], [{13=>nil}, 13, "x:c", false], [{13=>nil, 22=>:occupied, 31=>nil, 40=>:enemy}, 40, "x:c", true], [{13=>nil, 22=>:occupied, 31=>nil, 40=>nil, 49=>:enemy}, 49, "x:c", true], [{13=>nil, 22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{13=>nil, 22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{13=>nil, 22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{13=>nil, 22=>:occupied, 31=>:enemy}, 31, "x:c", true], [{13=>nil, 22=>nil}, 22, "x:c", false], [{13=>nil, 22=>nil, 31=>:occupied, 40=>nil, 49=>:enemy}, 49, "x:c", true], [{13=>nil, 22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{13=>nil, 22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{13=>nil, 22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{13=>nil, 22=>nil, 31=>:occupied, 40=>:enemy}, 40, "x:c", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "x:c", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>:occupied, 49=>:enemy}, 49, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "x:c", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>:enemy}, 58, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "x:c", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>:enemy}, 67, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "x:c", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "x:c", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "x:c", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:c", false]], 5=>[[{4=>:occupied, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{4=>:occupied, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{4=>:occupied, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{4=>:occupied, 3=>:enemy}, 3, "x:c", true], [{6=>:occupied, 7=>nil, 8=>:enemy}, 8, "x:c", true], [{6=>:occupied, 7=>:enemy}, 7, "x:c", true], [{14=>:occupied, 23=>nil, 32=>:enemy}, 32, "x:c", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>:enemy}, 41, "x:c", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "x:c", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{14=>:occupied, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{14=>:occupied, 23=>:enemy}, 23, "x:c", true], [{4=>nil}, 4, "x:c", false], [{4=>nil, 3=>:occupied, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{4=>nil, 3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{4=>nil, 3=>:occupied, 2=>:enemy}, 2, "x:c", true], [{4=>nil, 3=>nil}, 3, "x:c", false], [{4=>nil, 3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{4=>nil, 3=>nil, 2=>:occupied, 1=>:enemy}, 1, "x:c", true], [{4=>nil, 3=>nil, 2=>nil}, 2, "x:c", false], [{4=>nil, 3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "x:c", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "x:c", false], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:c", false], [{6=>nil}, 6, "x:c", false], [{6=>nil, 7=>:occupied, 8=>:enemy}, 8, "x:c", true], [{6=>nil, 7=>nil}, 7, "x:c", false], [{6=>nil, 7=>nil, 8=>nil}, 8, "x:c", false], [{14=>nil}, 14, "x:c", false], [{14=>nil, 23=>:occupied, 32=>nil, 41=>:enemy}, 41, "x:c", true], [{14=>nil, 23=>:occupied, 32=>nil, 41=>nil, 50=>:enemy}, 50, "x:c", true], [{14=>nil, 23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{14=>nil, 23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{14=>nil, 23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{14=>nil, 23=>:occupied, 32=>:enemy}, 32, "x:c", true], [{14=>nil, 23=>nil}, 23, "x:c", false], [{14=>nil, 23=>nil, 32=>:occupied, 41=>nil, 50=>:enemy}, 50, "x:c", true], [{14=>nil, 23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{14=>nil, 23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{14=>nil, 23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{14=>nil, 23=>nil, 32=>:occupied, 41=>:enemy}, 41, "x:c", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "x:c", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>:occupied, 50=>:enemy}, 50, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "x:c", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>:enemy}, 59, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "x:c", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>:enemy}, 68, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "x:c", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "x:c", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "x:c", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:c", false]], 6=>[[{5=>:occupied, 4=>nil, 3=>:enemy}, 3, "x:c", true], [{5=>:occupied, 4=>nil, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{5=>:occupied, 4=>:enemy}, 4, "x:c", true], [{7=>:occupied, 8=>:enemy}, 8, "x:c", true], [{15=>:occupied, 24=>nil, 33=>:enemy}, 33, "x:c", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>:enemy}, 42, "x:c", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "x:c", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{15=>:occupied, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{15=>:occupied, 24=>:enemy}, 24, "x:c", true], [{5=>nil}, 5, "x:c", false], [{5=>nil, 4=>:occupied, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{5=>nil, 4=>:occupied, 3=>:enemy}, 3, "x:c", true], [{5=>nil, 4=>nil}, 4, "x:c", false], [{5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{5=>nil, 4=>nil, 3=>:occupied, 2=>:enemy}, 2, "x:c", true], [{5=>nil, 4=>nil, 3=>nil}, 3, "x:c", false], [{5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>:enemy}, 1, "x:c", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "x:c", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "x:c", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "x:c", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:c", false], [{7=>nil}, 7, "x:c", false], [{7=>nil, 8=>nil}, 8, "x:c", false], [{15=>nil}, 15, "x:c", false], [{15=>nil, 24=>:occupied, 33=>nil, 42=>:enemy}, 42, "x:c", true], [{15=>nil, 24=>:occupied, 33=>nil, 42=>nil, 51=>:enemy}, 51, "x:c", true], [{15=>nil, 24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{15=>nil, 24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{15=>nil, 24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{15=>nil, 24=>:occupied, 33=>:enemy}, 33, "x:c", true], [{15=>nil, 24=>nil}, 24, "x:c", false], [{15=>nil, 24=>nil, 33=>:occupied, 42=>nil, 51=>:enemy}, 51, "x:c", true], [{15=>nil, 24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{15=>nil, 24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{15=>nil, 24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{15=>nil, 24=>nil, 33=>:occupied, 42=>:enemy}, 42, "x:c", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "x:c", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>:occupied, 51=>:enemy}, 51, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "x:c", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>:enemy}, 60, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "x:c", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>:enemy}, 69, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "x:c", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "x:c", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "x:c", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:c", false]], 7=>[[{6=>:occupied, 5=>nil, 4=>:enemy}, 4, "x:c", true], [{6=>:occupied, 5=>nil, 4=>nil, 3=>:enemy}, 3, "x:c", true], [{6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{6=>:occupied, 5=>:enemy}, 5, "x:c", true], [{16=>:occupied, 25=>nil, 34=>:enemy}, 34, "x:c", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>:enemy}, 43, "x:c", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "x:c", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{16=>:occupied, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{16=>:occupied, 25=>:enemy}, 25, "x:c", true], [{6=>nil}, 6, "x:c", false], [{6=>nil, 5=>:occupied, 4=>nil, 3=>:enemy}, 3, "x:c", true], [{6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{6=>nil, 5=>:occupied, 4=>:enemy}, 4, "x:c", true], [{6=>nil, 5=>nil}, 5, "x:c", false], [{6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{6=>nil, 5=>nil, 4=>:occupied, 3=>:enemy}, 3, "x:c", true], [{6=>nil, 5=>nil, 4=>nil}, 4, "x:c", false], [{6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>:enemy}, 2, "x:c", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "x:c", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>:enemy}, 1, "x:c", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "x:c", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "x:c", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "x:c", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:c", false], [{8=>nil}, 8, "x:c", false], [{16=>nil}, 16, "x:c", false], [{16=>nil, 25=>:occupied, 34=>nil, 43=>:enemy}, 43, "x:c", true], [{16=>nil, 25=>:occupied, 34=>nil, 43=>nil, 52=>:enemy}, 52, "x:c", true], [{16=>nil, 25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{16=>nil, 25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{16=>nil, 25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{16=>nil, 25=>:occupied, 34=>:enemy}, 34, "x:c", true], [{16=>nil, 25=>nil}, 25, "x:c", false], [{16=>nil, 25=>nil, 34=>:occupied, 43=>nil, 52=>:enemy}, 52, "x:c", true], [{16=>nil, 25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{16=>nil, 25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{16=>nil, 25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{16=>nil, 25=>nil, 34=>:occupied, 43=>:enemy}, 43, "x:c", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "x:c", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>:occupied, 52=>:enemy}, 52, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "x:c", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>:enemy}, 61, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "x:c", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>:enemy}, 70, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "x:c", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "x:c", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "x:c", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:c", false]], 8=>[[{7=>:occupied, 6=>nil, 5=>:enemy}, 5, "x:c", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>:enemy}, 4, "x:c", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "x:c", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{7=>:occupied, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{7=>:occupied, 6=>:enemy}, 6, "x:c", true], [{17=>:occupied, 26=>nil, 35=>:enemy}, 35, "x:c", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>:enemy}, 44, "x:c", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "x:c", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{17=>:occupied, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{17=>:occupied, 26=>:enemy}, 26, "x:c", true], [{7=>nil}, 7, "x:c", false], [{7=>nil, 6=>:occupied, 5=>nil, 4=>:enemy}, 4, "x:c", true], [{7=>nil, 6=>:occupied, 5=>nil, 4=>nil, 3=>:enemy}, 3, "x:c", true], [{7=>nil, 6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{7=>nil, 6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{7=>nil, 6=>:occupied, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{7=>nil, 6=>:occupied, 5=>:enemy}, 5, "x:c", true], [{7=>nil, 6=>nil}, 6, "x:c", false], [{7=>nil, 6=>nil, 5=>:occupied, 4=>nil, 3=>:enemy}, 3, "x:c", true], [{7=>nil, 6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{7=>nil, 6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{7=>nil, 6=>nil, 5=>:occupied, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{7=>nil, 6=>nil, 5=>:occupied, 4=>:enemy}, 4, "x:c", true], [{7=>nil, 6=>nil, 5=>nil}, 5, "x:c", false], [{7=>nil, 6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>:enemy}, 2, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>:occupied, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>:occupied, 3=>:enemy}, 3, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil}, 4, "x:c", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>:enemy}, 1, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:occupied, 2=>:enemy}, 2, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "x:c", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>nil, 0=>:enemy}, 0, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:occupied, 1=>:enemy}, 1, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "x:c", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:occupied, 0=>:enemy}, 0, "x:c", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "x:c", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:c", false], [{17=>nil}, 17, "x:c", false], [{17=>nil, 26=>:occupied, 35=>nil, 44=>:enemy}, 44, "x:c", true], [{17=>nil, 26=>:occupied, 35=>nil, 44=>nil, 53=>:enemy}, 53, "x:c", true], [{17=>nil, 26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{17=>nil, 26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{17=>nil, 26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{17=>nil, 26=>:occupied, 35=>:enemy}, 35, "x:c", true], [{17=>nil, 26=>nil}, 26, "x:c", false], [{17=>nil, 26=>nil, 35=>:occupied, 44=>nil, 53=>:enemy}, 53, "x:c", true], [{17=>nil, 26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{17=>nil, 26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{17=>nil, 26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{17=>nil, 26=>nil, 35=>:occupied, 44=>:enemy}, 44, "x:c", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "x:c", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>:occupied, 53=>:enemy}, 53, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "x:c", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>:enemy}, 62, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "x:c", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>:enemy}, 71, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "x:c", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "x:c", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "x:c", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:c", false]], 9=>[[{10=>:occupied, 11=>nil, 12=>:enemy}, 12, "x:c", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>:enemy}, 13, "x:c", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "x:c", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{10=>:occupied, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{10=>:occupied, 11=>:enemy}, 11, "x:c", true], [{18=>:occupied, 27=>nil, 36=>:enemy}, 36, "x:c", true], [{18=>:occupied, 27=>nil, 36=>nil, 45=>:enemy}, 45, "x:c", true], [{18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{18=>:occupied, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{18=>:occupied, 27=>:enemy}, 27, "x:c", true], [{0=>nil}, 0, "x:c", false], [{10=>nil}, 10, "x:c", false], [{10=>nil, 11=>:occupied, 12=>nil, 13=>:enemy}, 13, "x:c", true], [{10=>nil, 11=>:occupied, 12=>nil, 13=>nil, 14=>:enemy}, 14, "x:c", true], [{10=>nil, 11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{10=>nil, 11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{10=>nil, 11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{10=>nil, 11=>:occupied, 12=>:enemy}, 12, "x:c", true], [{10=>nil, 11=>nil}, 11, "x:c", false], [{10=>nil, 11=>nil, 12=>:occupied, 13=>nil, 14=>:enemy}, 14, "x:c", true], [{10=>nil, 11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{10=>nil, 11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{10=>nil, 11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{10=>nil, 11=>nil, 12=>:occupied, 13=>:enemy}, 13, "x:c", true], [{10=>nil, 11=>nil, 12=>nil}, 12, "x:c", false], [{10=>nil, 11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>:occupied, 14=>:enemy}, 14, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil}, 13, "x:c", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>:enemy}, 15, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "x:c", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>:enemy}, 16, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "x:c", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "x:c", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "x:c", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:c", false], [{18=>nil}, 18, "x:c", false], [{18=>nil, 27=>:occupied, 36=>nil, 45=>:enemy}, 45, "x:c", true], [{18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{18=>nil, 27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{18=>nil, 27=>:occupied, 36=>:enemy}, 36, "x:c", true], [{18=>nil, 27=>nil}, 27, "x:c", false], [{18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{18=>nil, 27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{18=>nil, 27=>nil, 36=>:occupied, 45=>:enemy}, 45, "x:c", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "x:c", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{18=>nil, 27=>nil, 36=>nil, 45=>:occupied, 54=>:enemy}, 54, "x:c", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "x:c", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>:enemy}, 63, "x:c", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "x:c", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "x:c", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "x:c", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:c", false]], 10=>[[{11=>:occupied, 12=>nil, 13=>:enemy}, 13, "x:c", true], [{11=>:occupied, 12=>nil, 13=>nil, 14=>:enemy}, 14, "x:c", true], [{11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{11=>:occupied, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{11=>:occupied, 12=>:enemy}, 12, "x:c", true], [{19=>:occupied, 28=>nil, 37=>:enemy}, 37, "x:c", true], [{19=>:occupied, 28=>nil, 37=>nil, 46=>:enemy}, 46, "x:c", true], [{19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{19=>:occupied, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{19=>:occupied, 28=>:enemy}, 28, "x:c", true], [{1=>nil}, 1, "x:c", false], [{9=>nil}, 9, "x:c", false], [{11=>nil}, 11, "x:c", false], [{11=>nil, 12=>:occupied, 13=>nil, 14=>:enemy}, 14, "x:c", true], [{11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{11=>nil, 12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{11=>nil, 12=>:occupied, 13=>:enemy}, 13, "x:c", true], [{11=>nil, 12=>nil}, 12, "x:c", false], [{11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{11=>nil, 12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{11=>nil, 12=>nil, 13=>:occupied, 14=>:enemy}, 14, "x:c", true], [{11=>nil, 12=>nil, 13=>nil}, 13, "x:c", false], [{11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{11=>nil, 12=>nil, 13=>nil, 14=>:occupied, 15=>:enemy}, 15, "x:c", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "x:c", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>:enemy}, 16, "x:c", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "x:c", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "x:c", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "x:c", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:c", false], [{19=>nil}, 19, "x:c", false], [{19=>nil, 28=>:occupied, 37=>nil, 46=>:enemy}, 46, "x:c", true], [{19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{19=>nil, 28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{19=>nil, 28=>:occupied, 37=>:enemy}, 37, "x:c", true], [{19=>nil, 28=>nil}, 28, "x:c", false], [{19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{19=>nil, 28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{19=>nil, 28=>nil, 37=>:occupied, 46=>:enemy}, 46, "x:c", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "x:c", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{19=>nil, 28=>nil, 37=>nil, 46=>:occupied, 55=>:enemy}, 55, "x:c", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "x:c", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>:enemy}, 64, "x:c", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "x:c", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "x:c", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "x:c", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:c", false]], 11=>[[{10=>:occupied, 9=>:enemy}, 9, "x:c", true], [{12=>:occupied, 13=>nil, 14=>:enemy}, 14, "x:c", true], [{12=>:occupied, 13=>nil, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{12=>:occupied, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{12=>:occupied, 13=>:enemy}, 13, "x:c", true], [{20=>:occupied, 29=>nil, 38=>:enemy}, 38, "x:c", true], [{20=>:occupied, 29=>nil, 38=>nil, 47=>:enemy}, 47, "x:c", true], [{20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{20=>:occupied, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{20=>:occupied, 29=>:enemy}, 29, "x:c", true], [{2=>nil}, 2, "x:c", false], [{10=>nil}, 10, "x:c", false], [{10=>nil, 9=>nil}, 9, "x:c", false], [{12=>nil}, 12, "x:c", false], [{12=>nil, 13=>:occupied, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{12=>nil, 13=>:occupied, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{12=>nil, 13=>:occupied, 14=>:enemy}, 14, "x:c", true], [{12=>nil, 13=>nil}, 13, "x:c", false], [{12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{12=>nil, 13=>nil, 14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{12=>nil, 13=>nil, 14=>:occupied, 15=>:enemy}, 15, "x:c", true], [{12=>nil, 13=>nil, 14=>nil}, 14, "x:c", false], [{12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{12=>nil, 13=>nil, 14=>nil, 15=>:occupied, 16=>:enemy}, 16, "x:c", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "x:c", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "x:c", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "x:c", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:c", false], [{20=>nil}, 20, "x:c", false], [{20=>nil, 29=>:occupied, 38=>nil, 47=>:enemy}, 47, "x:c", true], [{20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{20=>nil, 29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{20=>nil, 29=>:occupied, 38=>:enemy}, 38, "x:c", true], [{20=>nil, 29=>nil}, 29, "x:c", false], [{20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{20=>nil, 29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{20=>nil, 29=>nil, 38=>:occupied, 47=>:enemy}, 47, "x:c", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "x:c", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{20=>nil, 29=>nil, 38=>nil, 47=>:occupied, 56=>:enemy}, 56, "x:c", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "x:c", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>:enemy}, 65, "x:c", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "x:c", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "x:c", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "x:c", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:c", false]], 12=>[[{11=>:occupied, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{11=>:occupied, 10=>:enemy}, 10, "x:c", true], [{13=>:occupied, 14=>nil, 15=>:enemy}, 15, "x:c", true], [{13=>:occupied, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{13=>:occupied, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{13=>:occupied, 14=>:enemy}, 14, "x:c", true], [{21=>:occupied, 30=>nil, 39=>:enemy}, 39, "x:c", true], [{21=>:occupied, 30=>nil, 39=>nil, 48=>:enemy}, 48, "x:c", true], [{21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{21=>:occupied, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{21=>:occupied, 30=>:enemy}, 30, "x:c", true], [{3=>nil}, 3, "x:c", false], [{11=>nil}, 11, "x:c", false], [{11=>nil, 10=>:occupied, 9=>:enemy}, 9, "x:c", true], [{11=>nil, 10=>nil}, 10, "x:c", false], [{11=>nil, 10=>nil, 9=>nil}, 9, "x:c", false], [{13=>nil}, 13, "x:c", false], [{13=>nil, 14=>:occupied, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{13=>nil, 14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{13=>nil, 14=>:occupied, 15=>:enemy}, 15, "x:c", true], [{13=>nil, 14=>nil}, 14, "x:c", false], [{13=>nil, 14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{13=>nil, 14=>nil, 15=>:occupied, 16=>:enemy}, 16, "x:c", true], [{13=>nil, 14=>nil, 15=>nil}, 15, "x:c", false], [{13=>nil, 14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "x:c", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "x:c", false], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:c", false], [{21=>nil}, 21, "x:c", false], [{21=>nil, 30=>:occupied, 39=>nil, 48=>:enemy}, 48, "x:c", true], [{21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{21=>nil, 30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{21=>nil, 30=>:occupied, 39=>:enemy}, 39, "x:c", true], [{21=>nil, 30=>nil}, 30, "x:c", false], [{21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{21=>nil, 30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{21=>nil, 30=>nil, 39=>:occupied, 48=>:enemy}, 48, "x:c", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "x:c", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{21=>nil, 30=>nil, 39=>nil, 48=>:occupied, 57=>:enemy}, 57, "x:c", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "x:c", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>:enemy}, 66, "x:c", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "x:c", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "x:c", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "x:c", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:c", false]], 13=>[[{12=>:occupied, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{12=>:occupied, 11=>:enemy}, 11, "x:c", true], [{14=>:occupied, 15=>nil, 16=>:enemy}, 16, "x:c", true], [{14=>:occupied, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{14=>:occupied, 15=>:enemy}, 15, "x:c", true], [{22=>:occupied, 31=>nil, 40=>:enemy}, 40, "x:c", true], [{22=>:occupied, 31=>nil, 40=>nil, 49=>:enemy}, 49, "x:c", true], [{22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{22=>:occupied, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{22=>:occupied, 31=>:enemy}, 31, "x:c", true], [{4=>nil}, 4, "x:c", false], [{12=>nil}, 12, "x:c", false], [{12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{12=>nil, 11=>:occupied, 10=>:enemy}, 10, "x:c", true], [{12=>nil, 11=>nil}, 11, "x:c", false], [{12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "x:c", true], [{12=>nil, 11=>nil, 10=>nil}, 10, "x:c", false], [{12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:c", false], [{14=>nil}, 14, "x:c", false], [{14=>nil, 15=>:occupied, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{14=>nil, 15=>:occupied, 16=>:enemy}, 16, "x:c", true], [{14=>nil, 15=>nil}, 15, "x:c", false], [{14=>nil, 15=>nil, 16=>:occupied, 17=>:enemy}, 17, "x:c", true], [{14=>nil, 15=>nil, 16=>nil}, 16, "x:c", false], [{14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:c", false], [{22=>nil}, 22, "x:c", false], [{22=>nil, 31=>:occupied, 40=>nil, 49=>:enemy}, 49, "x:c", true], [{22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{22=>nil, 31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{22=>nil, 31=>:occupied, 40=>:enemy}, 40, "x:c", true], [{22=>nil, 31=>nil}, 31, "x:c", false], [{22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{22=>nil, 31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{22=>nil, 31=>nil, 40=>:occupied, 49=>:enemy}, 49, "x:c", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "x:c", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{22=>nil, 31=>nil, 40=>nil, 49=>:occupied, 58=>:enemy}, 58, "x:c", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "x:c", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>:enemy}, 67, "x:c", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "x:c", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "x:c", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "x:c", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:c", false]], 14=>[[{13=>:occupied, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{13=>:occupied, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{13=>:occupied, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{13=>:occupied, 12=>:enemy}, 12, "x:c", true], [{15=>:occupied, 16=>nil, 17=>:enemy}, 17, "x:c", true], [{15=>:occupied, 16=>:enemy}, 16, "x:c", true], [{23=>:occupied, 32=>nil, 41=>:enemy}, 41, "x:c", true], [{23=>:occupied, 32=>nil, 41=>nil, 50=>:enemy}, 50, "x:c", true], [{23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{23=>:occupied, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{23=>:occupied, 32=>:enemy}, 32, "x:c", true], [{5=>nil}, 5, "x:c", false], [{13=>nil}, 13, "x:c", false], [{13=>nil, 12=>:occupied, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{13=>nil, 12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{13=>nil, 12=>:occupied, 11=>:enemy}, 11, "x:c", true], [{13=>nil, 12=>nil}, 12, "x:c", false], [{13=>nil, 12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{13=>nil, 12=>nil, 11=>:occupied, 10=>:enemy}, 10, "x:c", true], [{13=>nil, 12=>nil, 11=>nil}, 11, "x:c", false], [{13=>nil, 12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "x:c", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "x:c", false], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:c", false], [{15=>nil}, 15, "x:c", false], [{15=>nil, 16=>:occupied, 17=>:enemy}, 17, "x:c", true], [{15=>nil, 16=>nil}, 16, "x:c", false], [{15=>nil, 16=>nil, 17=>nil}, 17, "x:c", false], [{23=>nil}, 23, "x:c", false], [{23=>nil, 32=>:occupied, 41=>nil, 50=>:enemy}, 50, "x:c", true], [{23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{23=>nil, 32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{23=>nil, 32=>:occupied, 41=>:enemy}, 41, "x:c", true], [{23=>nil, 32=>nil}, 32, "x:c", false], [{23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{23=>nil, 32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{23=>nil, 32=>nil, 41=>:occupied, 50=>:enemy}, 50, "x:c", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "x:c", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{23=>nil, 32=>nil, 41=>nil, 50=>:occupied, 59=>:enemy}, 59, "x:c", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "x:c", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>:enemy}, 68, "x:c", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "x:c", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "x:c", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "x:c", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:c", false]], 15=>[[{14=>:occupied, 13=>nil, 12=>:enemy}, 12, "x:c", true], [{14=>:occupied, 13=>nil, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{14=>:occupied, 13=>:enemy}, 13, "x:c", true], [{16=>:occupied, 17=>:enemy}, 17, "x:c", true], [{24=>:occupied, 33=>nil, 42=>:enemy}, 42, "x:c", true], [{24=>:occupied, 33=>nil, 42=>nil, 51=>:enemy}, 51, "x:c", true], [{24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{24=>:occupied, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{24=>:occupied, 33=>:enemy}, 33, "x:c", true], [{6=>nil}, 6, "x:c", false], [{14=>nil}, 14, "x:c", false], [{14=>nil, 13=>:occupied, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{14=>nil, 13=>:occupied, 12=>:enemy}, 12, "x:c", true], [{14=>nil, 13=>nil}, 13, "x:c", false], [{14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{14=>nil, 13=>nil, 12=>:occupied, 11=>:enemy}, 11, "x:c", true], [{14=>nil, 13=>nil, 12=>nil}, 12, "x:c", false], [{14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>:enemy}, 10, "x:c", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "x:c", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "x:c", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "x:c", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:c", false], [{16=>nil}, 16, "x:c", false], [{16=>nil, 17=>nil}, 17, "x:c", false], [{24=>nil}, 24, "x:c", false], [{24=>nil, 33=>:occupied, 42=>nil, 51=>:enemy}, 51, "x:c", true], [{24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{24=>nil, 33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{24=>nil, 33=>:occupied, 42=>:enemy}, 42, "x:c", true], [{24=>nil, 33=>nil}, 33, "x:c", false], [{24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{24=>nil, 33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{24=>nil, 33=>nil, 42=>:occupied, 51=>:enemy}, 51, "x:c", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "x:c", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{24=>nil, 33=>nil, 42=>nil, 51=>:occupied, 60=>:enemy}, 60, "x:c", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "x:c", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>:enemy}, 69, "x:c", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "x:c", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "x:c", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "x:c", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:c", false]], 16=>[[{15=>:occupied, 14=>nil, 13=>:enemy}, 13, "x:c", true], [{15=>:occupied, 14=>nil, 13=>nil, 12=>:enemy}, 12, "x:c", true], [{15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{15=>:occupied, 14=>:enemy}, 14, "x:c", true], [{25=>:occupied, 34=>nil, 43=>:enemy}, 43, "x:c", true], [{25=>:occupied, 34=>nil, 43=>nil, 52=>:enemy}, 52, "x:c", true], [{25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{25=>:occupied, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{25=>:occupied, 34=>:enemy}, 34, "x:c", true], [{7=>nil}, 7, "x:c", false], [{15=>nil}, 15, "x:c", false], [{15=>nil, 14=>:occupied, 13=>nil, 12=>:enemy}, 12, "x:c", true], [{15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{15=>nil, 14=>:occupied, 13=>:enemy}, 13, "x:c", true], [{15=>nil, 14=>nil}, 14, "x:c", false], [{15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{15=>nil, 14=>nil, 13=>:occupied, 12=>:enemy}, 12, "x:c", true], [{15=>nil, 14=>nil, 13=>nil}, 13, "x:c", false], [{15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>:enemy}, 11, "x:c", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "x:c", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>:enemy}, 10, "x:c", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "x:c", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "x:c", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "x:c", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:c", false], [{17=>nil}, 17, "x:c", false], [{25=>nil}, 25, "x:c", false], [{25=>nil, 34=>:occupied, 43=>nil, 52=>:enemy}, 52, "x:c", true], [{25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{25=>nil, 34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{25=>nil, 34=>:occupied, 43=>:enemy}, 43, "x:c", true], [{25=>nil, 34=>nil}, 34, "x:c", false], [{25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{25=>nil, 34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{25=>nil, 34=>nil, 43=>:occupied, 52=>:enemy}, 52, "x:c", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "x:c", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{25=>nil, 34=>nil, 43=>nil, 52=>:occupied, 61=>:enemy}, 61, "x:c", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "x:c", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>:enemy}, 70, "x:c", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "x:c", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "x:c", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "x:c", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:c", false]], 17=>[[{16=>:occupied, 15=>nil, 14=>:enemy}, 14, "x:c", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>:enemy}, 13, "x:c", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "x:c", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{16=>:occupied, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{16=>:occupied, 15=>:enemy}, 15, "x:c", true], [{26=>:occupied, 35=>nil, 44=>:enemy}, 44, "x:c", true], [{26=>:occupied, 35=>nil, 44=>nil, 53=>:enemy}, 53, "x:c", true], [{26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{26=>:occupied, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{26=>:occupied, 35=>:enemy}, 35, "x:c", true], [{8=>nil}, 8, "x:c", false], [{16=>nil}, 16, "x:c", false], [{16=>nil, 15=>:occupied, 14=>nil, 13=>:enemy}, 13, "x:c", true], [{16=>nil, 15=>:occupied, 14=>nil, 13=>nil, 12=>:enemy}, 12, "x:c", true], [{16=>nil, 15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{16=>nil, 15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{16=>nil, 15=>:occupied, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{16=>nil, 15=>:occupied, 14=>:enemy}, 14, "x:c", true], [{16=>nil, 15=>nil}, 15, "x:c", false], [{16=>nil, 15=>nil, 14=>:occupied, 13=>nil, 12=>:enemy}, 12, "x:c", true], [{16=>nil, 15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{16=>nil, 15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{16=>nil, 15=>nil, 14=>:occupied, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{16=>nil, 15=>nil, 14=>:occupied, 13=>:enemy}, 13, "x:c", true], [{16=>nil, 15=>nil, 14=>nil}, 14, "x:c", false], [{16=>nil, 15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>:enemy}, 11, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>:occupied, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>:occupied, 12=>:enemy}, 12, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil}, 13, "x:c", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>:enemy}, 10, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:occupied, 11=>:enemy}, 11, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "x:c", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>nil, 9=>:enemy}, 9, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:occupied, 10=>:enemy}, 10, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "x:c", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:occupied, 9=>:enemy}, 9, "x:c", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "x:c", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:c", false], [{26=>nil}, 26, "x:c", false], [{26=>nil, 35=>:occupied, 44=>nil, 53=>:enemy}, 53, "x:c", true], [{26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{26=>nil, 35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{26=>nil, 35=>:occupied, 44=>:enemy}, 44, "x:c", true], [{26=>nil, 35=>nil}, 35, "x:c", false], [{26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{26=>nil, 35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{26=>nil, 35=>nil, 44=>:occupied, 53=>:enemy}, 53, "x:c", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "x:c", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{26=>nil, 35=>nil, 44=>nil, 53=>:occupied, 62=>:enemy}, 62, "x:c", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "x:c", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>:enemy}, 71, "x:c", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "x:c", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "x:c", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "x:c", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:c", false]], 18=>[[{9=>:occupied, 0=>:enemy}, 0, "x:c", true], [{19=>:occupied, 20=>nil, 21=>:enemy}, 21, "x:c", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>:enemy}, 22, "x:c", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "x:c", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{19=>:occupied, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{19=>:occupied, 20=>:enemy}, 20, "x:c", true], [{27=>:occupied, 36=>nil, 45=>:enemy}, 45, "x:c", true], [{27=>:occupied, 36=>nil, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{27=>:occupied, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{27=>:occupied, 36=>:enemy}, 36, "x:c", true], [{9=>nil}, 9, "x:c", false], [{9=>nil, 0=>nil}, 0, "x:c", false], [{19=>nil}, 19, "x:c", false], [{19=>nil, 20=>:occupied, 21=>nil, 22=>:enemy}, 22, "x:c", true], [{19=>nil, 20=>:occupied, 21=>nil, 22=>nil, 23=>:enemy}, 23, "x:c", true], [{19=>nil, 20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{19=>nil, 20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{19=>nil, 20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{19=>nil, 20=>:occupied, 21=>:enemy}, 21, "x:c", true], [{19=>nil, 20=>nil}, 20, "x:c", false], [{19=>nil, 20=>nil, 21=>:occupied, 22=>nil, 23=>:enemy}, 23, "x:c", true], [{19=>nil, 20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{19=>nil, 20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{19=>nil, 20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{19=>nil, 20=>nil, 21=>:occupied, 22=>:enemy}, 22, "x:c", true], [{19=>nil, 20=>nil, 21=>nil}, 21, "x:c", false], [{19=>nil, 20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>:occupied, 23=>:enemy}, 23, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil}, 22, "x:c", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>:enemy}, 24, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "x:c", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>:enemy}, 25, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "x:c", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "x:c", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "x:c", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:c", false], [{27=>nil}, 27, "x:c", false], [{27=>nil, 36=>:occupied, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{27=>nil, 36=>:occupied, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{27=>nil, 36=>:occupied, 45=>:enemy}, 45, "x:c", true], [{27=>nil, 36=>nil}, 36, "x:c", false], [{27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{27=>nil, 36=>nil, 45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{27=>nil, 36=>nil, 45=>:occupied, 54=>:enemy}, 54, "x:c", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "x:c", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{27=>nil, 36=>nil, 45=>nil, 54=>:occupied, 63=>:enemy}, 63, "x:c", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "x:c", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "x:c", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "x:c", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:c", false]], 19=>[[{10=>:occupied, 1=>:enemy}, 1, "x:c", true], [{20=>:occupied, 21=>nil, 22=>:enemy}, 22, "x:c", true], [{20=>:occupied, 21=>nil, 22=>nil, 23=>:enemy}, 23, "x:c", true], [{20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{20=>:occupied, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{20=>:occupied, 21=>:enemy}, 21, "x:c", true], [{28=>:occupied, 37=>nil, 46=>:enemy}, 46, "x:c", true], [{28=>:occupied, 37=>nil, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{28=>:occupied, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{28=>:occupied, 37=>:enemy}, 37, "x:c", true], [{10=>nil}, 10, "x:c", false], [{10=>nil, 1=>nil}, 1, "x:c", false], [{18=>nil}, 18, "x:c", false], [{20=>nil}, 20, "x:c", false], [{20=>nil, 21=>:occupied, 22=>nil, 23=>:enemy}, 23, "x:c", true], [{20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{20=>nil, 21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{20=>nil, 21=>:occupied, 22=>:enemy}, 22, "x:c", true], [{20=>nil, 21=>nil}, 21, "x:c", false], [{20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{20=>nil, 21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{20=>nil, 21=>nil, 22=>:occupied, 23=>:enemy}, 23, "x:c", true], [{20=>nil, 21=>nil, 22=>nil}, 22, "x:c", false], [{20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{20=>nil, 21=>nil, 22=>nil, 23=>:occupied, 24=>:enemy}, 24, "x:c", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "x:c", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>:enemy}, 25, "x:c", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "x:c", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "x:c", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "x:c", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:c", false], [{28=>nil}, 28, "x:c", false], [{28=>nil, 37=>:occupied, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{28=>nil, 37=>:occupied, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{28=>nil, 37=>:occupied, 46=>:enemy}, 46, "x:c", true], [{28=>nil, 37=>nil}, 37, "x:c", false], [{28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{28=>nil, 37=>nil, 46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{28=>nil, 37=>nil, 46=>:occupied, 55=>:enemy}, 55, "x:c", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "x:c", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{28=>nil, 37=>nil, 46=>nil, 55=>:occupied, 64=>:enemy}, 64, "x:c", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "x:c", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "x:c", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "x:c", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:c", false]], 20=>[[{11=>:occupied, 2=>:enemy}, 2, "x:c", true], [{19=>:occupied, 18=>:enemy}, 18, "x:c", true], [{21=>:occupied, 22=>nil, 23=>:enemy}, 23, "x:c", true], [{21=>:occupied, 22=>nil, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{21=>:occupied, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{21=>:occupied, 22=>:enemy}, 22, "x:c", true], [{29=>:occupied, 38=>nil, 47=>:enemy}, 47, "x:c", true], [{29=>:occupied, 38=>nil, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{29=>:occupied, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{29=>:occupied, 38=>:enemy}, 38, "x:c", true], [{11=>nil}, 11, "x:c", false], [{11=>nil, 2=>nil}, 2, "x:c", false], [{19=>nil}, 19, "x:c", false], [{19=>nil, 18=>nil}, 18, "x:c", false], [{21=>nil}, 21, "x:c", false], [{21=>nil, 22=>:occupied, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{21=>nil, 22=>:occupied, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{21=>nil, 22=>:occupied, 23=>:enemy}, 23, "x:c", true], [{21=>nil, 22=>nil}, 22, "x:c", false], [{21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{21=>nil, 22=>nil, 23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{21=>nil, 22=>nil, 23=>:occupied, 24=>:enemy}, 24, "x:c", true], [{21=>nil, 22=>nil, 23=>nil}, 23, "x:c", false], [{21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{21=>nil, 22=>nil, 23=>nil, 24=>:occupied, 25=>:enemy}, 25, "x:c", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "x:c", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "x:c", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "x:c", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:c", false], [{29=>nil}, 29, "x:c", false], [{29=>nil, 38=>:occupied, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{29=>nil, 38=>:occupied, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{29=>nil, 38=>:occupied, 47=>:enemy}, 47, "x:c", true], [{29=>nil, 38=>nil}, 38, "x:c", false], [{29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{29=>nil, 38=>nil, 47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{29=>nil, 38=>nil, 47=>:occupied, 56=>:enemy}, 56, "x:c", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "x:c", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{29=>nil, 38=>nil, 47=>nil, 56=>:occupied, 65=>:enemy}, 65, "x:c", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "x:c", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "x:c", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "x:c", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:c", false]], 21=>[[{12=>:occupied, 3=>:enemy}, 3, "x:c", true], [{20=>:occupied, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{20=>:occupied, 19=>:enemy}, 19, "x:c", true], [{22=>:occupied, 23=>nil, 24=>:enemy}, 24, "x:c", true], [{22=>:occupied, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{22=>:occupied, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{22=>:occupied, 23=>:enemy}, 23, "x:c", true], [{30=>:occupied, 39=>nil, 48=>:enemy}, 48, "x:c", true], [{30=>:occupied, 39=>nil, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{30=>:occupied, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{30=>:occupied, 39=>:enemy}, 39, "x:c", true], [{12=>nil}, 12, "x:c", false], [{12=>nil, 3=>nil}, 3, "x:c", false], [{20=>nil}, 20, "x:c", false], [{20=>nil, 19=>:occupied, 18=>:enemy}, 18, "x:c", true], [{20=>nil, 19=>nil}, 19, "x:c", false], [{20=>nil, 19=>nil, 18=>nil}, 18, "x:c", false], [{22=>nil}, 22, "x:c", false], [{22=>nil, 23=>:occupied, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{22=>nil, 23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{22=>nil, 23=>:occupied, 24=>:enemy}, 24, "x:c", true], [{22=>nil, 23=>nil}, 23, "x:c", false], [{22=>nil, 23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{22=>nil, 23=>nil, 24=>:occupied, 25=>:enemy}, 25, "x:c", true], [{22=>nil, 23=>nil, 24=>nil}, 24, "x:c", false], [{22=>nil, 23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "x:c", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "x:c", false], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:c", false], [{30=>nil}, 30, "x:c", false], [{30=>nil, 39=>:occupied, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{30=>nil, 39=>:occupied, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{30=>nil, 39=>:occupied, 48=>:enemy}, 48, "x:c", true], [{30=>nil, 39=>nil}, 39, "x:c", false], [{30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{30=>nil, 39=>nil, 48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{30=>nil, 39=>nil, 48=>:occupied, 57=>:enemy}, 57, "x:c", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "x:c", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{30=>nil, 39=>nil, 48=>nil, 57=>:occupied, 66=>:enemy}, 66, "x:c", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "x:c", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "x:c", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "x:c", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:c", false]], 22=>[[{13=>:occupied, 4=>:enemy}, 4, "x:c", true], [{21=>:occupied, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{21=>:occupied, 20=>:enemy}, 20, "x:c", true], [{23=>:occupied, 24=>nil, 25=>:enemy}, 25, "x:c", true], [{23=>:occupied, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{23=>:occupied, 24=>:enemy}, 24, "x:c", true], [{31=>:occupied, 40=>nil, 49=>:enemy}, 49, "x:c", true], [{31=>:occupied, 40=>nil, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{31=>:occupied, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{31=>:occupied, 40=>:enemy}, 40, "x:c", true], [{13=>nil}, 13, "x:c", false], [{13=>nil, 4=>nil}, 4, "x:c", false], [{21=>nil}, 21, "x:c", false], [{21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{21=>nil, 20=>:occupied, 19=>:enemy}, 19, "x:c", true], [{21=>nil, 20=>nil}, 20, "x:c", false], [{21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "x:c", true], [{21=>nil, 20=>nil, 19=>nil}, 19, "x:c", false], [{21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:c", false], [{23=>nil}, 23, "x:c", false], [{23=>nil, 24=>:occupied, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{23=>nil, 24=>:occupied, 25=>:enemy}, 25, "x:c", true], [{23=>nil, 24=>nil}, 24, "x:c", false], [{23=>nil, 24=>nil, 25=>:occupied, 26=>:enemy}, 26, "x:c", true], [{23=>nil, 24=>nil, 25=>nil}, 25, "x:c", false], [{23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:c", false], [{31=>nil}, 31, "x:c", false], [{31=>nil, 40=>:occupied, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{31=>nil, 40=>:occupied, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{31=>nil, 40=>:occupied, 49=>:enemy}, 49, "x:c", true], [{31=>nil, 40=>nil}, 40, "x:c", false], [{31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{31=>nil, 40=>nil, 49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{31=>nil, 40=>nil, 49=>:occupied, 58=>:enemy}, 58, "x:c", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "x:c", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{31=>nil, 40=>nil, 49=>nil, 58=>:occupied, 67=>:enemy}, 67, "x:c", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "x:c", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "x:c", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "x:c", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:c", false]], 23=>[[{14=>:occupied, 5=>:enemy}, 5, "x:c", true], [{22=>:occupied, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{22=>:occupied, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{22=>:occupied, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{22=>:occupied, 21=>:enemy}, 21, "x:c", true], [{24=>:occupied, 25=>nil, 26=>:enemy}, 26, "x:c", true], [{24=>:occupied, 25=>:enemy}, 25, "x:c", true], [{32=>:occupied, 41=>nil, 50=>:enemy}, 50, "x:c", true], [{32=>:occupied, 41=>nil, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{32=>:occupied, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{32=>:occupied, 41=>:enemy}, 41, "x:c", true], [{14=>nil}, 14, "x:c", false], [{14=>nil, 5=>nil}, 5, "x:c", false], [{22=>nil}, 22, "x:c", false], [{22=>nil, 21=>:occupied, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{22=>nil, 21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{22=>nil, 21=>:occupied, 20=>:enemy}, 20, "x:c", true], [{22=>nil, 21=>nil}, 21, "x:c", false], [{22=>nil, 21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{22=>nil, 21=>nil, 20=>:occupied, 19=>:enemy}, 19, "x:c", true], [{22=>nil, 21=>nil, 20=>nil}, 20, "x:c", false], [{22=>nil, 21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "x:c", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "x:c", false], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:c", false], [{24=>nil}, 24, "x:c", false], [{24=>nil, 25=>:occupied, 26=>:enemy}, 26, "x:c", true], [{24=>nil, 25=>nil}, 25, "x:c", false], [{24=>nil, 25=>nil, 26=>nil}, 26, "x:c", false], [{32=>nil}, 32, "x:c", false], [{32=>nil, 41=>:occupied, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{32=>nil, 41=>:occupied, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{32=>nil, 41=>:occupied, 50=>:enemy}, 50, "x:c", true], [{32=>nil, 41=>nil}, 41, "x:c", false], [{32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{32=>nil, 41=>nil, 50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{32=>nil, 41=>nil, 50=>:occupied, 59=>:enemy}, 59, "x:c", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "x:c", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{32=>nil, 41=>nil, 50=>nil, 59=>:occupied, 68=>:enemy}, 68, "x:c", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "x:c", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "x:c", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "x:c", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:c", false]], 24=>[[{15=>:occupied, 6=>:enemy}, 6, "x:c", true], [{23=>:occupied, 22=>nil, 21=>:enemy}, 21, "x:c", true], [{23=>:occupied, 22=>nil, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{23=>:occupied, 22=>:enemy}, 22, "x:c", true], [{25=>:occupied, 26=>:enemy}, 26, "x:c", true], [{33=>:occupied, 42=>nil, 51=>:enemy}, 51, "x:c", true], [{33=>:occupied, 42=>nil, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{33=>:occupied, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{33=>:occupied, 42=>:enemy}, 42, "x:c", true], [{15=>nil}, 15, "x:c", false], [{15=>nil, 6=>nil}, 6, "x:c", false], [{23=>nil}, 23, "x:c", false], [{23=>nil, 22=>:occupied, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{23=>nil, 22=>:occupied, 21=>:enemy}, 21, "x:c", true], [{23=>nil, 22=>nil}, 22, "x:c", false], [{23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{23=>nil, 22=>nil, 21=>:occupied, 20=>:enemy}, 20, "x:c", true], [{23=>nil, 22=>nil, 21=>nil}, 21, "x:c", false], [{23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>:enemy}, 19, "x:c", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "x:c", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "x:c", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "x:c", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:c", false], [{25=>nil}, 25, "x:c", false], [{25=>nil, 26=>nil}, 26, "x:c", false], [{33=>nil}, 33, "x:c", false], [{33=>nil, 42=>:occupied, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{33=>nil, 42=>:occupied, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{33=>nil, 42=>:occupied, 51=>:enemy}, 51, "x:c", true], [{33=>nil, 42=>nil}, 42, "x:c", false], [{33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{33=>nil, 42=>nil, 51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{33=>nil, 42=>nil, 51=>:occupied, 60=>:enemy}, 60, "x:c", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "x:c", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{33=>nil, 42=>nil, 51=>nil, 60=>:occupied, 69=>:enemy}, 69, "x:c", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "x:c", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "x:c", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "x:c", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:c", false]], 25=>[[{16=>:occupied, 7=>:enemy}, 7, "x:c", true], [{24=>:occupied, 23=>nil, 22=>:enemy}, 22, "x:c", true], [{24=>:occupied, 23=>nil, 22=>nil, 21=>:enemy}, 21, "x:c", true], [{24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{24=>:occupied, 23=>:enemy}, 23, "x:c", true], [{34=>:occupied, 43=>nil, 52=>:enemy}, 52, "x:c", true], [{34=>:occupied, 43=>nil, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{34=>:occupied, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{34=>:occupied, 43=>:enemy}, 43, "x:c", true], [{16=>nil}, 16, "x:c", false], [{16=>nil, 7=>nil}, 7, "x:c", false], [{24=>nil}, 24, "x:c", false], [{24=>nil, 23=>:occupied, 22=>nil, 21=>:enemy}, 21, "x:c", true], [{24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{24=>nil, 23=>:occupied, 22=>:enemy}, 22, "x:c", true], [{24=>nil, 23=>nil}, 23, "x:c", false], [{24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{24=>nil, 23=>nil, 22=>:occupied, 21=>:enemy}, 21, "x:c", true], [{24=>nil, 23=>nil, 22=>nil}, 22, "x:c", false], [{24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>:enemy}, 20, "x:c", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "x:c", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>:enemy}, 19, "x:c", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "x:c", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "x:c", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "x:c", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:c", false], [{26=>nil}, 26, "x:c", false], [{34=>nil}, 34, "x:c", false], [{34=>nil, 43=>:occupied, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{34=>nil, 43=>:occupied, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{34=>nil, 43=>:occupied, 52=>:enemy}, 52, "x:c", true], [{34=>nil, 43=>nil}, 43, "x:c", false], [{34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{34=>nil, 43=>nil, 52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{34=>nil, 43=>nil, 52=>:occupied, 61=>:enemy}, 61, "x:c", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "x:c", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{34=>nil, 43=>nil, 52=>nil, 61=>:occupied, 70=>:enemy}, 70, "x:c", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "x:c", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "x:c", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "x:c", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:c", false]], 26=>[[{17=>:occupied, 8=>:enemy}, 8, "x:c", true], [{25=>:occupied, 24=>nil, 23=>:enemy}, 23, "x:c", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>:enemy}, 22, "x:c", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "x:c", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{25=>:occupied, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{25=>:occupied, 24=>:enemy}, 24, "x:c", true], [{35=>:occupied, 44=>nil, 53=>:enemy}, 53, "x:c", true], [{35=>:occupied, 44=>nil, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{35=>:occupied, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{35=>:occupied, 44=>:enemy}, 44, "x:c", true], [{17=>nil}, 17, "x:c", false], [{17=>nil, 8=>nil}, 8, "x:c", false], [{25=>nil}, 25, "x:c", false], [{25=>nil, 24=>:occupied, 23=>nil, 22=>:enemy}, 22, "x:c", true], [{25=>nil, 24=>:occupied, 23=>nil, 22=>nil, 21=>:enemy}, 21, "x:c", true], [{25=>nil, 24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{25=>nil, 24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{25=>nil, 24=>:occupied, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{25=>nil, 24=>:occupied, 23=>:enemy}, 23, "x:c", true], [{25=>nil, 24=>nil}, 24, "x:c", false], [{25=>nil, 24=>nil, 23=>:occupied, 22=>nil, 21=>:enemy}, 21, "x:c", true], [{25=>nil, 24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{25=>nil, 24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{25=>nil, 24=>nil, 23=>:occupied, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{25=>nil, 24=>nil, 23=>:occupied, 22=>:enemy}, 22, "x:c", true], [{25=>nil, 24=>nil, 23=>nil}, 23, "x:c", false], [{25=>nil, 24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>:enemy}, 20, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>:occupied, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>:occupied, 21=>:enemy}, 21, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil}, 22, "x:c", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>:enemy}, 19, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:occupied, 20=>:enemy}, 20, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "x:c", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>nil, 18=>:enemy}, 18, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:occupied, 19=>:enemy}, 19, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "x:c", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:occupied, 18=>:enemy}, 18, "x:c", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "x:c", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:c", false], [{35=>nil}, 35, "x:c", false], [{35=>nil, 44=>:occupied, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{35=>nil, 44=>:occupied, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{35=>nil, 44=>:occupied, 53=>:enemy}, 53, "x:c", true], [{35=>nil, 44=>nil}, 44, "x:c", false], [{35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{35=>nil, 44=>nil, 53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{35=>nil, 44=>nil, 53=>:occupied, 62=>:enemy}, 62, "x:c", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "x:c", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{35=>nil, 44=>nil, 53=>nil, 62=>:occupied, 71=>:enemy}, 71, "x:c", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "x:c", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "x:c", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "x:c", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:c", false]], 27=>[[{18=>:occupied, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{18=>:occupied, 9=>:enemy}, 9, "x:c", true], [{28=>:occupied, 29=>nil, 30=>:enemy}, 30, "x:c", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>:enemy}, 31, "x:c", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "x:c", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{28=>:occupied, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{28=>:occupied, 29=>:enemy}, 29, "x:c", true], [{36=>:occupied, 45=>nil, 54=>:enemy}, 54, "x:c", true], [{36=>:occupied, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{36=>:occupied, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{36=>:occupied, 45=>:enemy}, 45, "x:c", true], [{18=>nil}, 18, "x:c", false], [{18=>nil, 9=>:occupied, 0=>:enemy}, 0, "x:c", true], [{18=>nil, 9=>nil}, 9, "x:c", false], [{18=>nil, 9=>nil, 0=>nil}, 0, "x:c", false], [{28=>nil}, 28, "x:c", false], [{28=>nil, 29=>:occupied, 30=>nil, 31=>:enemy}, 31, "x:c", true], [{28=>nil, 29=>:occupied, 30=>nil, 31=>nil, 32=>:enemy}, 32, "x:c", true], [{28=>nil, 29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{28=>nil, 29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{28=>nil, 29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{28=>nil, 29=>:occupied, 30=>:enemy}, 30, "x:c", true], [{28=>nil, 29=>nil}, 29, "x:c", false], [{28=>nil, 29=>nil, 30=>:occupied, 31=>nil, 32=>:enemy}, 32, "x:c", true], [{28=>nil, 29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{28=>nil, 29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{28=>nil, 29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{28=>nil, 29=>nil, 30=>:occupied, 31=>:enemy}, 31, "x:c", true], [{28=>nil, 29=>nil, 30=>nil}, 30, "x:c", false], [{28=>nil, 29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>:occupied, 32=>:enemy}, 32, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil}, 31, "x:c", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>:enemy}, 33, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "x:c", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>:enemy}, 34, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "x:c", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "x:c", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "x:c", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:c", false], [{36=>nil}, 36, "x:c", false], [{36=>nil, 45=>:occupied, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{36=>nil, 45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{36=>nil, 45=>:occupied, 54=>:enemy}, 54, "x:c", true], [{36=>nil, 45=>nil}, 45, "x:c", false], [{36=>nil, 45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{36=>nil, 45=>nil, 54=>:occupied, 63=>:enemy}, 63, "x:c", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "x:c", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "x:c", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "x:c", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:c", false]], 28=>[[{19=>:occupied, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{19=>:occupied, 10=>:enemy}, 10, "x:c", true], [{29=>:occupied, 30=>nil, 31=>:enemy}, 31, "x:c", true], [{29=>:occupied, 30=>nil, 31=>nil, 32=>:enemy}, 32, "x:c", true], [{29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{29=>:occupied, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{29=>:occupied, 30=>:enemy}, 30, "x:c", true], [{37=>:occupied, 46=>nil, 55=>:enemy}, 55, "x:c", true], [{37=>:occupied, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{37=>:occupied, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{37=>:occupied, 46=>:enemy}, 46, "x:c", true], [{19=>nil}, 19, "x:c", false], [{19=>nil, 10=>:occupied, 1=>:enemy}, 1, "x:c", true], [{19=>nil, 10=>nil}, 10, "x:c", false], [{19=>nil, 10=>nil, 1=>nil}, 1, "x:c", false], [{27=>nil}, 27, "x:c", false], [{29=>nil}, 29, "x:c", false], [{29=>nil, 30=>:occupied, 31=>nil, 32=>:enemy}, 32, "x:c", true], [{29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{29=>nil, 30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{29=>nil, 30=>:occupied, 31=>:enemy}, 31, "x:c", true], [{29=>nil, 30=>nil}, 30, "x:c", false], [{29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{29=>nil, 30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{29=>nil, 30=>nil, 31=>:occupied, 32=>:enemy}, 32, "x:c", true], [{29=>nil, 30=>nil, 31=>nil}, 31, "x:c", false], [{29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{29=>nil, 30=>nil, 31=>nil, 32=>:occupied, 33=>:enemy}, 33, "x:c", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "x:c", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>:enemy}, 34, "x:c", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "x:c", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "x:c", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "x:c", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:c", false], [{37=>nil}, 37, "x:c", false], [{37=>nil, 46=>:occupied, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{37=>nil, 46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{37=>nil, 46=>:occupied, 55=>:enemy}, 55, "x:c", true], [{37=>nil, 46=>nil}, 46, "x:c", false], [{37=>nil, 46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{37=>nil, 46=>nil, 55=>:occupied, 64=>:enemy}, 64, "x:c", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "x:c", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "x:c", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "x:c", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:c", false]], 29=>[[{20=>:occupied, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{20=>:occupied, 11=>:enemy}, 11, "x:c", true], [{28=>:occupied, 27=>:enemy}, 27, "x:c", true], [{30=>:occupied, 31=>nil, 32=>:enemy}, 32, "x:c", true], [{30=>:occupied, 31=>nil, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{30=>:occupied, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{30=>:occupied, 31=>:enemy}, 31, "x:c", true], [{38=>:occupied, 47=>nil, 56=>:enemy}, 56, "x:c", true], [{38=>:occupied, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{38=>:occupied, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{38=>:occupied, 47=>:enemy}, 47, "x:c", true], [{20=>nil}, 20, "x:c", false], [{20=>nil, 11=>:occupied, 2=>:enemy}, 2, "x:c", true], [{20=>nil, 11=>nil}, 11, "x:c", false], [{20=>nil, 11=>nil, 2=>nil}, 2, "x:c", false], [{28=>nil}, 28, "x:c", false], [{28=>nil, 27=>nil}, 27, "x:c", false], [{30=>nil}, 30, "x:c", false], [{30=>nil, 31=>:occupied, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{30=>nil, 31=>:occupied, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{30=>nil, 31=>:occupied, 32=>:enemy}, 32, "x:c", true], [{30=>nil, 31=>nil}, 31, "x:c", false], [{30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{30=>nil, 31=>nil, 32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{30=>nil, 31=>nil, 32=>:occupied, 33=>:enemy}, 33, "x:c", true], [{30=>nil, 31=>nil, 32=>nil}, 32, "x:c", false], [{30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{30=>nil, 31=>nil, 32=>nil, 33=>:occupied, 34=>:enemy}, 34, "x:c", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "x:c", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "x:c", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "x:c", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:c", false], [{38=>nil}, 38, "x:c", false], [{38=>nil, 47=>:occupied, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{38=>nil, 47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{38=>nil, 47=>:occupied, 56=>:enemy}, 56, "x:c", true], [{38=>nil, 47=>nil}, 47, "x:c", false], [{38=>nil, 47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{38=>nil, 47=>nil, 56=>:occupied, 65=>:enemy}, 65, "x:c", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "x:c", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "x:c", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "x:c", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:c", false]], 30=>[[{21=>:occupied, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{21=>:occupied, 12=>:enemy}, 12, "x:c", true], [{29=>:occupied, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{29=>:occupied, 28=>:enemy}, 28, "x:c", true], [{31=>:occupied, 32=>nil, 33=>:enemy}, 33, "x:c", true], [{31=>:occupied, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{31=>:occupied, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{31=>:occupied, 32=>:enemy}, 32, "x:c", true], [{39=>:occupied, 48=>nil, 57=>:enemy}, 57, "x:c", true], [{39=>:occupied, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{39=>:occupied, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{39=>:occupied, 48=>:enemy}, 48, "x:c", true], [{21=>nil}, 21, "x:c", false], [{21=>nil, 12=>:occupied, 3=>:enemy}, 3, "x:c", true], [{21=>nil, 12=>nil}, 12, "x:c", false], [{21=>nil, 12=>nil, 3=>nil}, 3, "x:c", false], [{29=>nil}, 29, "x:c", false], [{29=>nil, 28=>:occupied, 27=>:enemy}, 27, "x:c", true], [{29=>nil, 28=>nil}, 28, "x:c", false], [{29=>nil, 28=>nil, 27=>nil}, 27, "x:c", false], [{31=>nil}, 31, "x:c", false], [{31=>nil, 32=>:occupied, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{31=>nil, 32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{31=>nil, 32=>:occupied, 33=>:enemy}, 33, "x:c", true], [{31=>nil, 32=>nil}, 32, "x:c", false], [{31=>nil, 32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{31=>nil, 32=>nil, 33=>:occupied, 34=>:enemy}, 34, "x:c", true], [{31=>nil, 32=>nil, 33=>nil}, 33, "x:c", false], [{31=>nil, 32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "x:c", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "x:c", false], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:c", false], [{39=>nil}, 39, "x:c", false], [{39=>nil, 48=>:occupied, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{39=>nil, 48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{39=>nil, 48=>:occupied, 57=>:enemy}, 57, "x:c", true], [{39=>nil, 48=>nil}, 48, "x:c", false], [{39=>nil, 48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{39=>nil, 48=>nil, 57=>:occupied, 66=>:enemy}, 66, "x:c", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "x:c", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "x:c", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "x:c", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:c", false]], 31=>[[{22=>:occupied, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{22=>:occupied, 13=>:enemy}, 13, "x:c", true], [{30=>:occupied, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{30=>:occupied, 29=>:enemy}, 29, "x:c", true], [{32=>:occupied, 33=>nil, 34=>:enemy}, 34, "x:c", true], [{32=>:occupied, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{32=>:occupied, 33=>:enemy}, 33, "x:c", true], [{40=>:occupied, 49=>nil, 58=>:enemy}, 58, "x:c", true], [{40=>:occupied, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{40=>:occupied, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{40=>:occupied, 49=>:enemy}, 49, "x:c", true], [{22=>nil}, 22, "x:c", false], [{22=>nil, 13=>:occupied, 4=>:enemy}, 4, "x:c", true], [{22=>nil, 13=>nil}, 13, "x:c", false], [{22=>nil, 13=>nil, 4=>nil}, 4, "x:c", false], [{30=>nil}, 30, "x:c", false], [{30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{30=>nil, 29=>:occupied, 28=>:enemy}, 28, "x:c", true], [{30=>nil, 29=>nil}, 29, "x:c", false], [{30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "x:c", true], [{30=>nil, 29=>nil, 28=>nil}, 28, "x:c", false], [{30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:c", false], [{32=>nil}, 32, "x:c", false], [{32=>nil, 33=>:occupied, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{32=>nil, 33=>:occupied, 34=>:enemy}, 34, "x:c", true], [{32=>nil, 33=>nil}, 33, "x:c", false], [{32=>nil, 33=>nil, 34=>:occupied, 35=>:enemy}, 35, "x:c", true], [{32=>nil, 33=>nil, 34=>nil}, 34, "x:c", false], [{32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:c", false], [{40=>nil}, 40, "x:c", false], [{40=>nil, 49=>:occupied, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{40=>nil, 49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{40=>nil, 49=>:occupied, 58=>:enemy}, 58, "x:c", true], [{40=>nil, 49=>nil}, 49, "x:c", false], [{40=>nil, 49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{40=>nil, 49=>nil, 58=>:occupied, 67=>:enemy}, 67, "x:c", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "x:c", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "x:c", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "x:c", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:c", false]], 32=>[[{23=>:occupied, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{23=>:occupied, 14=>:enemy}, 14, "x:c", true], [{31=>:occupied, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{31=>:occupied, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{31=>:occupied, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{31=>:occupied, 30=>:enemy}, 30, "x:c", true], [{33=>:occupied, 34=>nil, 35=>:enemy}, 35, "x:c", true], [{33=>:occupied, 34=>:enemy}, 34, "x:c", true], [{41=>:occupied, 50=>nil, 59=>:enemy}, 59, "x:c", true], [{41=>:occupied, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{41=>:occupied, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{41=>:occupied, 50=>:enemy}, 50, "x:c", true], [{23=>nil}, 23, "x:c", false], [{23=>nil, 14=>:occupied, 5=>:enemy}, 5, "x:c", true], [{23=>nil, 14=>nil}, 14, "x:c", false], [{23=>nil, 14=>nil, 5=>nil}, 5, "x:c", false], [{31=>nil}, 31, "x:c", false], [{31=>nil, 30=>:occupied, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{31=>nil, 30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{31=>nil, 30=>:occupied, 29=>:enemy}, 29, "x:c", true], [{31=>nil, 30=>nil}, 30, "x:c", false], [{31=>nil, 30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{31=>nil, 30=>nil, 29=>:occupied, 28=>:enemy}, 28, "x:c", true], [{31=>nil, 30=>nil, 29=>nil}, 29, "x:c", false], [{31=>nil, 30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "x:c", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "x:c", false], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:c", false], [{33=>nil}, 33, "x:c", false], [{33=>nil, 34=>:occupied, 35=>:enemy}, 35, "x:c", true], [{33=>nil, 34=>nil}, 34, "x:c", false], [{33=>nil, 34=>nil, 35=>nil}, 35, "x:c", false], [{41=>nil}, 41, "x:c", false], [{41=>nil, 50=>:occupied, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{41=>nil, 50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{41=>nil, 50=>:occupied, 59=>:enemy}, 59, "x:c", true], [{41=>nil, 50=>nil}, 50, "x:c", false], [{41=>nil, 50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{41=>nil, 50=>nil, 59=>:occupied, 68=>:enemy}, 68, "x:c", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "x:c", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "x:c", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "x:c", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:c", false]], 33=>[[{24=>:occupied, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{24=>:occupied, 15=>:enemy}, 15, "x:c", true], [{32=>:occupied, 31=>nil, 30=>:enemy}, 30, "x:c", true], [{32=>:occupied, 31=>nil, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{32=>:occupied, 31=>:enemy}, 31, "x:c", true], [{34=>:occupied, 35=>:enemy}, 35, "x:c", true], [{42=>:occupied, 51=>nil, 60=>:enemy}, 60, "x:c", true], [{42=>:occupied, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{42=>:occupied, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{42=>:occupied, 51=>:enemy}, 51, "x:c", true], [{24=>nil}, 24, "x:c", false], [{24=>nil, 15=>:occupied, 6=>:enemy}, 6, "x:c", true], [{24=>nil, 15=>nil}, 15, "x:c", false], [{24=>nil, 15=>nil, 6=>nil}, 6, "x:c", false], [{32=>nil}, 32, "x:c", false], [{32=>nil, 31=>:occupied, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{32=>nil, 31=>:occupied, 30=>:enemy}, 30, "x:c", true], [{32=>nil, 31=>nil}, 31, "x:c", false], [{32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{32=>nil, 31=>nil, 30=>:occupied, 29=>:enemy}, 29, "x:c", true], [{32=>nil, 31=>nil, 30=>nil}, 30, "x:c", false], [{32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>:enemy}, 28, "x:c", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "x:c", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "x:c", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "x:c", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:c", false], [{34=>nil}, 34, "x:c", false], [{34=>nil, 35=>nil}, 35, "x:c", false], [{42=>nil}, 42, "x:c", false], [{42=>nil, 51=>:occupied, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{42=>nil, 51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{42=>nil, 51=>:occupied, 60=>:enemy}, 60, "x:c", true], [{42=>nil, 51=>nil}, 51, "x:c", false], [{42=>nil, 51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{42=>nil, 51=>nil, 60=>:occupied, 69=>:enemy}, 69, "x:c", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "x:c", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "x:c", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "x:c", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:c", false]], 34=>[[{25=>:occupied, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{25=>:occupied, 16=>:enemy}, 16, "x:c", true], [{33=>:occupied, 32=>nil, 31=>:enemy}, 31, "x:c", true], [{33=>:occupied, 32=>nil, 31=>nil, 30=>:enemy}, 30, "x:c", true], [{33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{33=>:occupied, 32=>:enemy}, 32, "x:c", true], [{43=>:occupied, 52=>nil, 61=>:enemy}, 61, "x:c", true], [{43=>:occupied, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{43=>:occupied, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{43=>:occupied, 52=>:enemy}, 52, "x:c", true], [{25=>nil}, 25, "x:c", false], [{25=>nil, 16=>:occupied, 7=>:enemy}, 7, "x:c", true], [{25=>nil, 16=>nil}, 16, "x:c", false], [{25=>nil, 16=>nil, 7=>nil}, 7, "x:c", false], [{33=>nil}, 33, "x:c", false], [{33=>nil, 32=>:occupied, 31=>nil, 30=>:enemy}, 30, "x:c", true], [{33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{33=>nil, 32=>:occupied, 31=>:enemy}, 31, "x:c", true], [{33=>nil, 32=>nil}, 32, "x:c", false], [{33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{33=>nil, 32=>nil, 31=>:occupied, 30=>:enemy}, 30, "x:c", true], [{33=>nil, 32=>nil, 31=>nil}, 31, "x:c", false], [{33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>:enemy}, 29, "x:c", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "x:c", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>:enemy}, 28, "x:c", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "x:c", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "x:c", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "x:c", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:c", false], [{35=>nil}, 35, "x:c", false], [{43=>nil}, 43, "x:c", false], [{43=>nil, 52=>:occupied, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{43=>nil, 52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{43=>nil, 52=>:occupied, 61=>:enemy}, 61, "x:c", true], [{43=>nil, 52=>nil}, 52, "x:c", false], [{43=>nil, 52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{43=>nil, 52=>nil, 61=>:occupied, 70=>:enemy}, 70, "x:c", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "x:c", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "x:c", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "x:c", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:c", false]], 35=>[[{26=>:occupied, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{26=>:occupied, 17=>:enemy}, 17, "x:c", true], [{34=>:occupied, 33=>nil, 32=>:enemy}, 32, "x:c", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>:enemy}, 31, "x:c", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "x:c", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{34=>:occupied, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{34=>:occupied, 33=>:enemy}, 33, "x:c", true], [{44=>:occupied, 53=>nil, 62=>:enemy}, 62, "x:c", true], [{44=>:occupied, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{44=>:occupied, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{44=>:occupied, 53=>:enemy}, 53, "x:c", true], [{26=>nil}, 26, "x:c", false], [{26=>nil, 17=>:occupied, 8=>:enemy}, 8, "x:c", true], [{26=>nil, 17=>nil}, 17, "x:c", false], [{26=>nil, 17=>nil, 8=>nil}, 8, "x:c", false], [{34=>nil}, 34, "x:c", false], [{34=>nil, 33=>:occupied, 32=>nil, 31=>:enemy}, 31, "x:c", true], [{34=>nil, 33=>:occupied, 32=>nil, 31=>nil, 30=>:enemy}, 30, "x:c", true], [{34=>nil, 33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{34=>nil, 33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{34=>nil, 33=>:occupied, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{34=>nil, 33=>:occupied, 32=>:enemy}, 32, "x:c", true], [{34=>nil, 33=>nil}, 33, "x:c", false], [{34=>nil, 33=>nil, 32=>:occupied, 31=>nil, 30=>:enemy}, 30, "x:c", true], [{34=>nil, 33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{34=>nil, 33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{34=>nil, 33=>nil, 32=>:occupied, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{34=>nil, 33=>nil, 32=>:occupied, 31=>:enemy}, 31, "x:c", true], [{34=>nil, 33=>nil, 32=>nil}, 32, "x:c", false], [{34=>nil, 33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>:enemy}, 29, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>:occupied, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>:occupied, 30=>:enemy}, 30, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil}, 31, "x:c", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>:enemy}, 28, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:occupied, 29=>:enemy}, 29, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "x:c", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>nil, 27=>:enemy}, 27, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:occupied, 28=>:enemy}, 28, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "x:c", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:occupied, 27=>:enemy}, 27, "x:c", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "x:c", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:c", false], [{44=>nil}, 44, "x:c", false], [{44=>nil, 53=>:occupied, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{44=>nil, 53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{44=>nil, 53=>:occupied, 62=>:enemy}, 62, "x:c", true], [{44=>nil, 53=>nil}, 53, "x:c", false], [{44=>nil, 53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{44=>nil, 53=>nil, 62=>:occupied, 71=>:enemy}, 71, "x:c", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "x:c", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "x:c", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "x:c", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:c", false]], 36=>[[{27=>:occupied, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{27=>:occupied, 18=>:enemy}, 18, "x:c", true], [{37=>:occupied, 38=>nil, 39=>:enemy}, 39, "x:c", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>:enemy}, 40, "x:c", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "x:c", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{37=>:occupied, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{37=>:occupied, 38=>:enemy}, 38, "x:c", true], [{45=>:occupied, 54=>nil, 63=>:enemy}, 63, "x:c", true], [{45=>:occupied, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{45=>:occupied, 54=>:enemy}, 54, "x:c", true], [{27=>nil}, 27, "x:c", false], [{27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{27=>nil, 18=>:occupied, 9=>:enemy}, 9, "x:c", true], [{27=>nil, 18=>nil}, 18, "x:c", false], [{27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "x:c", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "x:c", false], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:c", false], [{37=>nil}, 37, "x:c", false], [{37=>nil, 38=>:occupied, 39=>nil, 40=>:enemy}, 40, "x:c", true], [{37=>nil, 38=>:occupied, 39=>nil, 40=>nil, 41=>:enemy}, 41, "x:c", true], [{37=>nil, 38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{37=>nil, 38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{37=>nil, 38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{37=>nil, 38=>:occupied, 39=>:enemy}, 39, "x:c", true], [{37=>nil, 38=>nil}, 38, "x:c", false], [{37=>nil, 38=>nil, 39=>:occupied, 40=>nil, 41=>:enemy}, 41, "x:c", true], [{37=>nil, 38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{37=>nil, 38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{37=>nil, 38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{37=>nil, 38=>nil, 39=>:occupied, 40=>:enemy}, 40, "x:c", true], [{37=>nil, 38=>nil, 39=>nil}, 39, "x:c", false], [{37=>nil, 38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>:occupied, 41=>:enemy}, 41, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil}, 40, "x:c", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>:enemy}, 42, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "x:c", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>:enemy}, 43, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "x:c", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "x:c", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "x:c", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:c", false], [{45=>nil}, 45, "x:c", false], [{45=>nil, 54=>:occupied, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{45=>nil, 54=>:occupied, 63=>:enemy}, 63, "x:c", true], [{45=>nil, 54=>nil}, 54, "x:c", false], [{45=>nil, 54=>nil, 63=>:occupied, 72=>:enemy}, 72, "x:c", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "x:c", false], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:c", false]], 37=>[[{28=>:occupied, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{28=>:occupied, 19=>:enemy}, 19, "x:c", true], [{38=>:occupied, 39=>nil, 40=>:enemy}, 40, "x:c", true], [{38=>:occupied, 39=>nil, 40=>nil, 41=>:enemy}, 41, "x:c", true], [{38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{38=>:occupied, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{38=>:occupied, 39=>:enemy}, 39, "x:c", true], [{46=>:occupied, 55=>nil, 64=>:enemy}, 64, "x:c", true], [{46=>:occupied, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{46=>:occupied, 55=>:enemy}, 55, "x:c", true], [{28=>nil}, 28, "x:c", false], [{28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{28=>nil, 19=>:occupied, 10=>:enemy}, 10, "x:c", true], [{28=>nil, 19=>nil}, 19, "x:c", false], [{28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "x:c", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "x:c", false], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:c", false], [{36=>nil}, 36, "x:c", false], [{38=>nil}, 38, "x:c", false], [{38=>nil, 39=>:occupied, 40=>nil, 41=>:enemy}, 41, "x:c", true], [{38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{38=>nil, 39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{38=>nil, 39=>:occupied, 40=>:enemy}, 40, "x:c", true], [{38=>nil, 39=>nil}, 39, "x:c", false], [{38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{38=>nil, 39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{38=>nil, 39=>nil, 40=>:occupied, 41=>:enemy}, 41, "x:c", true], [{38=>nil, 39=>nil, 40=>nil}, 40, "x:c", false], [{38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{38=>nil, 39=>nil, 40=>nil, 41=>:occupied, 42=>:enemy}, 42, "x:c", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "x:c", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>:enemy}, 43, "x:c", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "x:c", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "x:c", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "x:c", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:c", false], [{46=>nil}, 46, "x:c", false], [{46=>nil, 55=>:occupied, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{46=>nil, 55=>:occupied, 64=>:enemy}, 64, "x:c", true], [{46=>nil, 55=>nil}, 55, "x:c", false], [{46=>nil, 55=>nil, 64=>:occupied, 73=>:enemy}, 73, "x:c", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "x:c", false], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:c", false]], 38=>[[{29=>:occupied, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{29=>:occupied, 20=>:enemy}, 20, "x:c", true], [{37=>:occupied, 36=>:enemy}, 36, "x:c", true], [{39=>:occupied, 40=>nil, 41=>:enemy}, 41, "x:c", true], [{39=>:occupied, 40=>nil, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{39=>:occupied, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{39=>:occupied, 40=>:enemy}, 40, "x:c", true], [{47=>:occupied, 56=>nil, 65=>:enemy}, 65, "x:c", true], [{47=>:occupied, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{47=>:occupied, 56=>:enemy}, 56, "x:c", true], [{29=>nil}, 29, "x:c", false], [{29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{29=>nil, 20=>:occupied, 11=>:enemy}, 11, "x:c", true], [{29=>nil, 20=>nil}, 20, "x:c", false], [{29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "x:c", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "x:c", false], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:c", false], [{37=>nil}, 37, "x:c", false], [{37=>nil, 36=>nil}, 36, "x:c", false], [{39=>nil}, 39, "x:c", false], [{39=>nil, 40=>:occupied, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{39=>nil, 40=>:occupied, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{39=>nil, 40=>:occupied, 41=>:enemy}, 41, "x:c", true], [{39=>nil, 40=>nil}, 40, "x:c", false], [{39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{39=>nil, 40=>nil, 41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{39=>nil, 40=>nil, 41=>:occupied, 42=>:enemy}, 42, "x:c", true], [{39=>nil, 40=>nil, 41=>nil}, 41, "x:c", false], [{39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{39=>nil, 40=>nil, 41=>nil, 42=>:occupied, 43=>:enemy}, 43, "x:c", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "x:c", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "x:c", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "x:c", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:c", false], [{47=>nil}, 47, "x:c", false], [{47=>nil, 56=>:occupied, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{47=>nil, 56=>:occupied, 65=>:enemy}, 65, "x:c", true], [{47=>nil, 56=>nil}, 56, "x:c", false], [{47=>nil, 56=>nil, 65=>:occupied, 74=>:enemy}, 74, "x:c", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "x:c", false], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:c", false]], 39=>[[{30=>:occupied, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{30=>:occupied, 21=>:enemy}, 21, "x:c", true], [{38=>:occupied, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{38=>:occupied, 37=>:enemy}, 37, "x:c", true], [{40=>:occupied, 41=>nil, 42=>:enemy}, 42, "x:c", true], [{40=>:occupied, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{40=>:occupied, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{40=>:occupied, 41=>:enemy}, 41, "x:c", true], [{48=>:occupied, 57=>nil, 66=>:enemy}, 66, "x:c", true], [{48=>:occupied, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{48=>:occupied, 57=>:enemy}, 57, "x:c", true], [{30=>nil}, 30, "x:c", false], [{30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{30=>nil, 21=>:occupied, 12=>:enemy}, 12, "x:c", true], [{30=>nil, 21=>nil}, 21, "x:c", false], [{30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "x:c", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "x:c", false], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:c", false], [{38=>nil}, 38, "x:c", false], [{38=>nil, 37=>:occupied, 36=>:enemy}, 36, "x:c", true], [{38=>nil, 37=>nil}, 37, "x:c", false], [{38=>nil, 37=>nil, 36=>nil}, 36, "x:c", false], [{40=>nil}, 40, "x:c", false], [{40=>nil, 41=>:occupied, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{40=>nil, 41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{40=>nil, 41=>:occupied, 42=>:enemy}, 42, "x:c", true], [{40=>nil, 41=>nil}, 41, "x:c", false], [{40=>nil, 41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{40=>nil, 41=>nil, 42=>:occupied, 43=>:enemy}, 43, "x:c", true], [{40=>nil, 41=>nil, 42=>nil}, 42, "x:c", false], [{40=>nil, 41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "x:c", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "x:c", false], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:c", false], [{48=>nil}, 48, "x:c", false], [{48=>nil, 57=>:occupied, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{48=>nil, 57=>:occupied, 66=>:enemy}, 66, "x:c", true], [{48=>nil, 57=>nil}, 57, "x:c", false], [{48=>nil, 57=>nil, 66=>:occupied, 75=>:enemy}, 75, "x:c", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "x:c", false], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:c", false]], 40=>[[{31=>:occupied, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{31=>:occupied, 22=>:enemy}, 22, "x:c", true], [{39=>:occupied, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{39=>:occupied, 38=>:enemy}, 38, "x:c", true], [{41=>:occupied, 42=>nil, 43=>:enemy}, 43, "x:c", true], [{41=>:occupied, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{41=>:occupied, 42=>:enemy}, 42, "x:c", true], [{49=>:occupied, 58=>nil, 67=>:enemy}, 67, "x:c", true], [{49=>:occupied, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{49=>:occupied, 58=>:enemy}, 58, "x:c", true], [{31=>nil}, 31, "x:c", false], [{31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{31=>nil, 22=>:occupied, 13=>:enemy}, 13, "x:c", true], [{31=>nil, 22=>nil}, 22, "x:c", false], [{31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "x:c", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "x:c", false], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:c", false], [{39=>nil}, 39, "x:c", false], [{39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{39=>nil, 38=>:occupied, 37=>:enemy}, 37, "x:c", true], [{39=>nil, 38=>nil}, 38, "x:c", false], [{39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "x:c", true], [{39=>nil, 38=>nil, 37=>nil}, 37, "x:c", false], [{39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:c", false], [{41=>nil}, 41, "x:c", false], [{41=>nil, 42=>:occupied, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{41=>nil, 42=>:occupied, 43=>:enemy}, 43, "x:c", true], [{41=>nil, 42=>nil}, 42, "x:c", false], [{41=>nil, 42=>nil, 43=>:occupied, 44=>:enemy}, 44, "x:c", true], [{41=>nil, 42=>nil, 43=>nil}, 43, "x:c", false], [{41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:c", false], [{49=>nil}, 49, "x:c", false], [{49=>nil, 58=>:occupied, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{49=>nil, 58=>:occupied, 67=>:enemy}, 67, "x:c", true], [{49=>nil, 58=>nil}, 58, "x:c", false], [{49=>nil, 58=>nil, 67=>:occupied, 76=>:enemy}, 76, "x:c", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "x:c", false], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:c", false]], 41=>[[{32=>:occupied, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{32=>:occupied, 23=>:enemy}, 23, "x:c", true], [{40=>:occupied, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{40=>:occupied, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{40=>:occupied, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{40=>:occupied, 39=>:enemy}, 39, "x:c", true], [{42=>:occupied, 43=>nil, 44=>:enemy}, 44, "x:c", true], [{42=>:occupied, 43=>:enemy}, 43, "x:c", true], [{50=>:occupied, 59=>nil, 68=>:enemy}, 68, "x:c", true], [{50=>:occupied, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{50=>:occupied, 59=>:enemy}, 59, "x:c", true], [{32=>nil}, 32, "x:c", false], [{32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{32=>nil, 23=>:occupied, 14=>:enemy}, 14, "x:c", true], [{32=>nil, 23=>nil}, 23, "x:c", false], [{32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "x:c", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "x:c", false], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:c", false], [{40=>nil}, 40, "x:c", false], [{40=>nil, 39=>:occupied, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{40=>nil, 39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{40=>nil, 39=>:occupied, 38=>:enemy}, 38, "x:c", true], [{40=>nil, 39=>nil}, 39, "x:c", false], [{40=>nil, 39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{40=>nil, 39=>nil, 38=>:occupied, 37=>:enemy}, 37, "x:c", true], [{40=>nil, 39=>nil, 38=>nil}, 38, "x:c", false], [{40=>nil, 39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "x:c", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "x:c", false], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:c", false], [{42=>nil}, 42, "x:c", false], [{42=>nil, 43=>:occupied, 44=>:enemy}, 44, "x:c", true], [{42=>nil, 43=>nil}, 43, "x:c", false], [{42=>nil, 43=>nil, 44=>nil}, 44, "x:c", false], [{50=>nil}, 50, "x:c", false], [{50=>nil, 59=>:occupied, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{50=>nil, 59=>:occupied, 68=>:enemy}, 68, "x:c", true], [{50=>nil, 59=>nil}, 59, "x:c", false], [{50=>nil, 59=>nil, 68=>:occupied, 77=>:enemy}, 77, "x:c", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "x:c", false], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:c", false]], 42=>[[{33=>:occupied, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{33=>:occupied, 24=>:enemy}, 24, "x:c", true], [{41=>:occupied, 40=>nil, 39=>:enemy}, 39, "x:c", true], [{41=>:occupied, 40=>nil, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{41=>:occupied, 40=>:enemy}, 40, "x:c", true], [{43=>:occupied, 44=>:enemy}, 44, "x:c", true], [{51=>:occupied, 60=>nil, 69=>:enemy}, 69, "x:c", true], [{51=>:occupied, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{51=>:occupied, 60=>:enemy}, 60, "x:c", true], [{33=>nil}, 33, "x:c", false], [{33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{33=>nil, 24=>:occupied, 15=>:enemy}, 15, "x:c", true], [{33=>nil, 24=>nil}, 24, "x:c", false], [{33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "x:c", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "x:c", false], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:c", false], [{41=>nil}, 41, "x:c", false], [{41=>nil, 40=>:occupied, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{41=>nil, 40=>:occupied, 39=>:enemy}, 39, "x:c", true], [{41=>nil, 40=>nil}, 40, "x:c", false], [{41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{41=>nil, 40=>nil, 39=>:occupied, 38=>:enemy}, 38, "x:c", true], [{41=>nil, 40=>nil, 39=>nil}, 39, "x:c", false], [{41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>:enemy}, 37, "x:c", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "x:c", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "x:c", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "x:c", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:c", false], [{43=>nil}, 43, "x:c", false], [{43=>nil, 44=>nil}, 44, "x:c", false], [{51=>nil}, 51, "x:c", false], [{51=>nil, 60=>:occupied, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{51=>nil, 60=>:occupied, 69=>:enemy}, 69, "x:c", true], [{51=>nil, 60=>nil}, 60, "x:c", false], [{51=>nil, 60=>nil, 69=>:occupied, 78=>:enemy}, 78, "x:c", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "x:c", false], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:c", false]], 43=>[[{34=>:occupied, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{34=>:occupied, 25=>:enemy}, 25, "x:c", true], [{42=>:occupied, 41=>nil, 40=>:enemy}, 40, "x:c", true], [{42=>:occupied, 41=>nil, 40=>nil, 39=>:enemy}, 39, "x:c", true], [{42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{42=>:occupied, 41=>:enemy}, 41, "x:c", true], [{52=>:occupied, 61=>nil, 70=>:enemy}, 70, "x:c", true], [{52=>:occupied, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{52=>:occupied, 61=>:enemy}, 61, "x:c", true], [{34=>nil}, 34, "x:c", false], [{34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{34=>nil, 25=>:occupied, 16=>:enemy}, 16, "x:c", true], [{34=>nil, 25=>nil}, 25, "x:c", false], [{34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "x:c", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "x:c", false], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:c", false], [{42=>nil}, 42, "x:c", false], [{42=>nil, 41=>:occupied, 40=>nil, 39=>:enemy}, 39, "x:c", true], [{42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{42=>nil, 41=>:occupied, 40=>:enemy}, 40, "x:c", true], [{42=>nil, 41=>nil}, 41, "x:c", false], [{42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{42=>nil, 41=>nil, 40=>:occupied, 39=>:enemy}, 39, "x:c", true], [{42=>nil, 41=>nil, 40=>nil}, 40, "x:c", false], [{42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>:enemy}, 38, "x:c", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "x:c", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>:enemy}, 37, "x:c", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "x:c", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "x:c", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "x:c", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:c", false], [{44=>nil}, 44, "x:c", false], [{52=>nil}, 52, "x:c", false], [{52=>nil, 61=>:occupied, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{52=>nil, 61=>:occupied, 70=>:enemy}, 70, "x:c", true], [{52=>nil, 61=>nil}, 61, "x:c", false], [{52=>nil, 61=>nil, 70=>:occupied, 79=>:enemy}, 79, "x:c", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "x:c", false], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:c", false]], 44=>[[{35=>:occupied, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{35=>:occupied, 26=>:enemy}, 26, "x:c", true], [{43=>:occupied, 42=>nil, 41=>:enemy}, 41, "x:c", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>:enemy}, 40, "x:c", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "x:c", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{43=>:occupied, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{43=>:occupied, 42=>:enemy}, 42, "x:c", true], [{53=>:occupied, 62=>nil, 71=>:enemy}, 71, "x:c", true], [{53=>:occupied, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{53=>:occupied, 62=>:enemy}, 62, "x:c", true], [{35=>nil}, 35, "x:c", false], [{35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{35=>nil, 26=>:occupied, 17=>:enemy}, 17, "x:c", true], [{35=>nil, 26=>nil}, 26, "x:c", false], [{35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "x:c", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "x:c", false], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:c", false], [{43=>nil}, 43, "x:c", false], [{43=>nil, 42=>:occupied, 41=>nil, 40=>:enemy}, 40, "x:c", true], [{43=>nil, 42=>:occupied, 41=>nil, 40=>nil, 39=>:enemy}, 39, "x:c", true], [{43=>nil, 42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{43=>nil, 42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{43=>nil, 42=>:occupied, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{43=>nil, 42=>:occupied, 41=>:enemy}, 41, "x:c", true], [{43=>nil, 42=>nil}, 42, "x:c", false], [{43=>nil, 42=>nil, 41=>:occupied, 40=>nil, 39=>:enemy}, 39, "x:c", true], [{43=>nil, 42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{43=>nil, 42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{43=>nil, 42=>nil, 41=>:occupied, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{43=>nil, 42=>nil, 41=>:occupied, 40=>:enemy}, 40, "x:c", true], [{43=>nil, 42=>nil, 41=>nil}, 41, "x:c", false], [{43=>nil, 42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>:enemy}, 38, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>:occupied, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>:occupied, 39=>:enemy}, 39, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil}, 40, "x:c", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>:enemy}, 37, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:occupied, 38=>:enemy}, 38, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "x:c", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>nil, 36=>:enemy}, 36, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:occupied, 37=>:enemy}, 37, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "x:c", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:occupied, 36=>:enemy}, 36, "x:c", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "x:c", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:c", false], [{53=>nil}, 53, "x:c", false], [{53=>nil, 62=>:occupied, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{53=>nil, 62=>:occupied, 71=>:enemy}, 71, "x:c", true], [{53=>nil, 62=>nil}, 62, "x:c", false], [{53=>nil, 62=>nil, 71=>:occupied, 80=>:enemy}, 80, "x:c", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "x:c", false], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:c", false]], 45=>[[{36=>:occupied, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{36=>:occupied, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{36=>:occupied, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{36=>:occupied, 27=>:enemy}, 27, "x:c", true], [{46=>:occupied, 47=>nil, 48=>:enemy}, 48, "x:c", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>:enemy}, 49, "x:c", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "x:c", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{46=>:occupied, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{46=>:occupied, 47=>:enemy}, 47, "x:c", true], [{54=>:occupied, 63=>nil, 72=>:enemy}, 72, "x:c", true], [{54=>:occupied, 63=>:enemy}, 63, "x:c", true], [{36=>nil}, 36, "x:c", false], [{36=>nil, 27=>:occupied, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{36=>nil, 27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{36=>nil, 27=>:occupied, 18=>:enemy}, 18, "x:c", true], [{36=>nil, 27=>nil}, 27, "x:c", false], [{36=>nil, 27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{36=>nil, 27=>nil, 18=>:occupied, 9=>:enemy}, 9, "x:c", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "x:c", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "x:c", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "x:c", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:c", false], [{46=>nil}, 46, "x:c", false], [{46=>nil, 47=>:occupied, 48=>nil, 49=>:enemy}, 49, "x:c", true], [{46=>nil, 47=>:occupied, 48=>nil, 49=>nil, 50=>:enemy}, 50, "x:c", true], [{46=>nil, 47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{46=>nil, 47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{46=>nil, 47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{46=>nil, 47=>:occupied, 48=>:enemy}, 48, "x:c", true], [{46=>nil, 47=>nil}, 47, "x:c", false], [{46=>nil, 47=>nil, 48=>:occupied, 49=>nil, 50=>:enemy}, 50, "x:c", true], [{46=>nil, 47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{46=>nil, 47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{46=>nil, 47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{46=>nil, 47=>nil, 48=>:occupied, 49=>:enemy}, 49, "x:c", true], [{46=>nil, 47=>nil, 48=>nil}, 48, "x:c", false], [{46=>nil, 47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>:occupied, 50=>:enemy}, 50, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil}, 49, "x:c", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>:enemy}, 51, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "x:c", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>:enemy}, 52, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "x:c", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "x:c", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "x:c", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:c", false], [{54=>nil}, 54, "x:c", false], [{54=>nil, 63=>:occupied, 72=>:enemy}, 72, "x:c", true], [{54=>nil, 63=>nil}, 63, "x:c", false], [{54=>nil, 63=>nil, 72=>nil}, 72, "x:c", false]], 46=>[[{37=>:occupied, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{37=>:occupied, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{37=>:occupied, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{37=>:occupied, 28=>:enemy}, 28, "x:c", true], [{47=>:occupied, 48=>nil, 49=>:enemy}, 49, "x:c", true], [{47=>:occupied, 48=>nil, 49=>nil, 50=>:enemy}, 50, "x:c", true], [{47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{47=>:occupied, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{47=>:occupied, 48=>:enemy}, 48, "x:c", true], [{55=>:occupied, 64=>nil, 73=>:enemy}, 73, "x:c", true], [{55=>:occupied, 64=>:enemy}, 64, "x:c", true], [{37=>nil}, 37, "x:c", false], [{37=>nil, 28=>:occupied, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{37=>nil, 28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{37=>nil, 28=>:occupied, 19=>:enemy}, 19, "x:c", true], [{37=>nil, 28=>nil}, 28, "x:c", false], [{37=>nil, 28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{37=>nil, 28=>nil, 19=>:occupied, 10=>:enemy}, 10, "x:c", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "x:c", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "x:c", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "x:c", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:c", false], [{45=>nil}, 45, "x:c", false], [{47=>nil}, 47, "x:c", false], [{47=>nil, 48=>:occupied, 49=>nil, 50=>:enemy}, 50, "x:c", true], [{47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{47=>nil, 48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{47=>nil, 48=>:occupied, 49=>:enemy}, 49, "x:c", true], [{47=>nil, 48=>nil}, 48, "x:c", false], [{47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{47=>nil, 48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{47=>nil, 48=>nil, 49=>:occupied, 50=>:enemy}, 50, "x:c", true], [{47=>nil, 48=>nil, 49=>nil}, 49, "x:c", false], [{47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{47=>nil, 48=>nil, 49=>nil, 50=>:occupied, 51=>:enemy}, 51, "x:c", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "x:c", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>:enemy}, 52, "x:c", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "x:c", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "x:c", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "x:c", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:c", false], [{55=>nil}, 55, "x:c", false], [{55=>nil, 64=>:occupied, 73=>:enemy}, 73, "x:c", true], [{55=>nil, 64=>nil}, 64, "x:c", false], [{55=>nil, 64=>nil, 73=>nil}, 73, "x:c", false]], 47=>[[{38=>:occupied, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{38=>:occupied, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{38=>:occupied, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{38=>:occupied, 29=>:enemy}, 29, "x:c", true], [{46=>:occupied, 45=>:enemy}, 45, "x:c", true], [{48=>:occupied, 49=>nil, 50=>:enemy}, 50, "x:c", true], [{48=>:occupied, 49=>nil, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{48=>:occupied, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{48=>:occupied, 49=>:enemy}, 49, "x:c", true], [{56=>:occupied, 65=>nil, 74=>:enemy}, 74, "x:c", true], [{56=>:occupied, 65=>:enemy}, 65, "x:c", true], [{38=>nil}, 38, "x:c", false], [{38=>nil, 29=>:occupied, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{38=>nil, 29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{38=>nil, 29=>:occupied, 20=>:enemy}, 20, "x:c", true], [{38=>nil, 29=>nil}, 29, "x:c", false], [{38=>nil, 29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{38=>nil, 29=>nil, 20=>:occupied, 11=>:enemy}, 11, "x:c", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "x:c", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "x:c", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "x:c", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:c", false], [{46=>nil}, 46, "x:c", false], [{46=>nil, 45=>nil}, 45, "x:c", false], [{48=>nil}, 48, "x:c", false], [{48=>nil, 49=>:occupied, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{48=>nil, 49=>:occupied, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{48=>nil, 49=>:occupied, 50=>:enemy}, 50, "x:c", true], [{48=>nil, 49=>nil}, 49, "x:c", false], [{48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{48=>nil, 49=>nil, 50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{48=>nil, 49=>nil, 50=>:occupied, 51=>:enemy}, 51, "x:c", true], [{48=>nil, 49=>nil, 50=>nil}, 50, "x:c", false], [{48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{48=>nil, 49=>nil, 50=>nil, 51=>:occupied, 52=>:enemy}, 52, "x:c", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "x:c", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "x:c", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "x:c", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:c", false], [{56=>nil}, 56, "x:c", false], [{56=>nil, 65=>:occupied, 74=>:enemy}, 74, "x:c", true], [{56=>nil, 65=>nil}, 65, "x:c", false], [{56=>nil, 65=>nil, 74=>nil}, 74, "x:c", false]], 48=>[[{39=>:occupied, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{39=>:occupied, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{39=>:occupied, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{39=>:occupied, 30=>:enemy}, 30, "x:c", true], [{47=>:occupied, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{47=>:occupied, 46=>:enemy}, 46, "x:c", true], [{49=>:occupied, 50=>nil, 51=>:enemy}, 51, "x:c", true], [{49=>:occupied, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{49=>:occupied, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{49=>:occupied, 50=>:enemy}, 50, "x:c", true], [{57=>:occupied, 66=>nil, 75=>:enemy}, 75, "x:c", true], [{57=>:occupied, 66=>:enemy}, 66, "x:c", true], [{39=>nil}, 39, "x:c", false], [{39=>nil, 30=>:occupied, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{39=>nil, 30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{39=>nil, 30=>:occupied, 21=>:enemy}, 21, "x:c", true], [{39=>nil, 30=>nil}, 30, "x:c", false], [{39=>nil, 30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{39=>nil, 30=>nil, 21=>:occupied, 12=>:enemy}, 12, "x:c", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "x:c", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "x:c", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "x:c", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:c", false], [{47=>nil}, 47, "x:c", false], [{47=>nil, 46=>:occupied, 45=>:enemy}, 45, "x:c", true], [{47=>nil, 46=>nil}, 46, "x:c", false], [{47=>nil, 46=>nil, 45=>nil}, 45, "x:c", false], [{49=>nil}, 49, "x:c", false], [{49=>nil, 50=>:occupied, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{49=>nil, 50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{49=>nil, 50=>:occupied, 51=>:enemy}, 51, "x:c", true], [{49=>nil, 50=>nil}, 50, "x:c", false], [{49=>nil, 50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{49=>nil, 50=>nil, 51=>:occupied, 52=>:enemy}, 52, "x:c", true], [{49=>nil, 50=>nil, 51=>nil}, 51, "x:c", false], [{49=>nil, 50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "x:c", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "x:c", false], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:c", false], [{57=>nil}, 57, "x:c", false], [{57=>nil, 66=>:occupied, 75=>:enemy}, 75, "x:c", true], [{57=>nil, 66=>nil}, 66, "x:c", false], [{57=>nil, 66=>nil, 75=>nil}, 75, "x:c", false]], 49=>[[{40=>:occupied, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{40=>:occupied, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{40=>:occupied, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{40=>:occupied, 31=>:enemy}, 31, "x:c", true], [{48=>:occupied, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{48=>:occupied, 47=>:enemy}, 47, "x:c", true], [{50=>:occupied, 51=>nil, 52=>:enemy}, 52, "x:c", true], [{50=>:occupied, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{50=>:occupied, 51=>:enemy}, 51, "x:c", true], [{58=>:occupied, 67=>nil, 76=>:enemy}, 76, "x:c", true], [{58=>:occupied, 67=>:enemy}, 67, "x:c", true], [{40=>nil}, 40, "x:c", false], [{40=>nil, 31=>:occupied, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{40=>nil, 31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{40=>nil, 31=>:occupied, 22=>:enemy}, 22, "x:c", true], [{40=>nil, 31=>nil}, 31, "x:c", false], [{40=>nil, 31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{40=>nil, 31=>nil, 22=>:occupied, 13=>:enemy}, 13, "x:c", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "x:c", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "x:c", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "x:c", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:c", false], [{48=>nil}, 48, "x:c", false], [{48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{48=>nil, 47=>:occupied, 46=>:enemy}, 46, "x:c", true], [{48=>nil, 47=>nil}, 47, "x:c", false], [{48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "x:c", true], [{48=>nil, 47=>nil, 46=>nil}, 46, "x:c", false], [{48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:c", false], [{50=>nil}, 50, "x:c", false], [{50=>nil, 51=>:occupied, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{50=>nil, 51=>:occupied, 52=>:enemy}, 52, "x:c", true], [{50=>nil, 51=>nil}, 51, "x:c", false], [{50=>nil, 51=>nil, 52=>:occupied, 53=>:enemy}, 53, "x:c", true], [{50=>nil, 51=>nil, 52=>nil}, 52, "x:c", false], [{50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:c", false], [{58=>nil}, 58, "x:c", false], [{58=>nil, 67=>:occupied, 76=>:enemy}, 76, "x:c", true], [{58=>nil, 67=>nil}, 67, "x:c", false], [{58=>nil, 67=>nil, 76=>nil}, 76, "x:c", false]], 50=>[[{41=>:occupied, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{41=>:occupied, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{41=>:occupied, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{41=>:occupied, 32=>:enemy}, 32, "x:c", true], [{49=>:occupied, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{49=>:occupied, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{49=>:occupied, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{49=>:occupied, 48=>:enemy}, 48, "x:c", true], [{51=>:occupied, 52=>nil, 53=>:enemy}, 53, "x:c", true], [{51=>:occupied, 52=>:enemy}, 52, "x:c", true], [{59=>:occupied, 68=>nil, 77=>:enemy}, 77, "x:c", true], [{59=>:occupied, 68=>:enemy}, 68, "x:c", true], [{41=>nil}, 41, "x:c", false], [{41=>nil, 32=>:occupied, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{41=>nil, 32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{41=>nil, 32=>:occupied, 23=>:enemy}, 23, "x:c", true], [{41=>nil, 32=>nil}, 32, "x:c", false], [{41=>nil, 32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{41=>nil, 32=>nil, 23=>:occupied, 14=>:enemy}, 14, "x:c", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "x:c", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "x:c", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "x:c", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:c", false], [{49=>nil}, 49, "x:c", false], [{49=>nil, 48=>:occupied, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{49=>nil, 48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{49=>nil, 48=>:occupied, 47=>:enemy}, 47, "x:c", true], [{49=>nil, 48=>nil}, 48, "x:c", false], [{49=>nil, 48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{49=>nil, 48=>nil, 47=>:occupied, 46=>:enemy}, 46, "x:c", true], [{49=>nil, 48=>nil, 47=>nil}, 47, "x:c", false], [{49=>nil, 48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "x:c", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "x:c", false], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:c", false], [{51=>nil}, 51, "x:c", false], [{51=>nil, 52=>:occupied, 53=>:enemy}, 53, "x:c", true], [{51=>nil, 52=>nil}, 52, "x:c", false], [{51=>nil, 52=>nil, 53=>nil}, 53, "x:c", false], [{59=>nil}, 59, "x:c", false], [{59=>nil, 68=>:occupied, 77=>:enemy}, 77, "x:c", true], [{59=>nil, 68=>nil}, 68, "x:c", false], [{59=>nil, 68=>nil, 77=>nil}, 77, "x:c", false]], 51=>[[{42=>:occupied, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{42=>:occupied, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{42=>:occupied, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{42=>:occupied, 33=>:enemy}, 33, "x:c", true], [{50=>:occupied, 49=>nil, 48=>:enemy}, 48, "x:c", true], [{50=>:occupied, 49=>nil, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{50=>:occupied, 49=>:enemy}, 49, "x:c", true], [{52=>:occupied, 53=>:enemy}, 53, "x:c", true], [{60=>:occupied, 69=>nil, 78=>:enemy}, 78, "x:c", true], [{60=>:occupied, 69=>:enemy}, 69, "x:c", true], [{42=>nil}, 42, "x:c", false], [{42=>nil, 33=>:occupied, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{42=>nil, 33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{42=>nil, 33=>:occupied, 24=>:enemy}, 24, "x:c", true], [{42=>nil, 33=>nil}, 33, "x:c", false], [{42=>nil, 33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{42=>nil, 33=>nil, 24=>:occupied, 15=>:enemy}, 15, "x:c", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "x:c", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "x:c", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "x:c", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:c", false], [{50=>nil}, 50, "x:c", false], [{50=>nil, 49=>:occupied, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{50=>nil, 49=>:occupied, 48=>:enemy}, 48, "x:c", true], [{50=>nil, 49=>nil}, 49, "x:c", false], [{50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{50=>nil, 49=>nil, 48=>:occupied, 47=>:enemy}, 47, "x:c", true], [{50=>nil, 49=>nil, 48=>nil}, 48, "x:c", false], [{50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>:enemy}, 46, "x:c", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "x:c", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "x:c", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "x:c", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:c", false], [{52=>nil}, 52, "x:c", false], [{52=>nil, 53=>nil}, 53, "x:c", false], [{60=>nil}, 60, "x:c", false], [{60=>nil, 69=>:occupied, 78=>:enemy}, 78, "x:c", true], [{60=>nil, 69=>nil}, 69, "x:c", false], [{60=>nil, 69=>nil, 78=>nil}, 78, "x:c", false]], 52=>[[{43=>:occupied, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{43=>:occupied, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{43=>:occupied, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{43=>:occupied, 34=>:enemy}, 34, "x:c", true], [{51=>:occupied, 50=>nil, 49=>:enemy}, 49, "x:c", true], [{51=>:occupied, 50=>nil, 49=>nil, 48=>:enemy}, 48, "x:c", true], [{51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{51=>:occupied, 50=>:enemy}, 50, "x:c", true], [{61=>:occupied, 70=>nil, 79=>:enemy}, 79, "x:c", true], [{61=>:occupied, 70=>:enemy}, 70, "x:c", true], [{43=>nil}, 43, "x:c", false], [{43=>nil, 34=>:occupied, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{43=>nil, 34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{43=>nil, 34=>:occupied, 25=>:enemy}, 25, "x:c", true], [{43=>nil, 34=>nil}, 34, "x:c", false], [{43=>nil, 34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{43=>nil, 34=>nil, 25=>:occupied, 16=>:enemy}, 16, "x:c", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "x:c", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "x:c", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "x:c", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:c", false], [{51=>nil}, 51, "x:c", false], [{51=>nil, 50=>:occupied, 49=>nil, 48=>:enemy}, 48, "x:c", true], [{51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{51=>nil, 50=>:occupied, 49=>:enemy}, 49, "x:c", true], [{51=>nil, 50=>nil}, 50, "x:c", false], [{51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{51=>nil, 50=>nil, 49=>:occupied, 48=>:enemy}, 48, "x:c", true], [{51=>nil, 50=>nil, 49=>nil}, 49, "x:c", false], [{51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>:enemy}, 47, "x:c", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "x:c", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>:enemy}, 46, "x:c", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "x:c", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "x:c", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "x:c", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:c", false], [{53=>nil}, 53, "x:c", false], [{61=>nil}, 61, "x:c", false], [{61=>nil, 70=>:occupied, 79=>:enemy}, 79, "x:c", true], [{61=>nil, 70=>nil}, 70, "x:c", false], [{61=>nil, 70=>nil, 79=>nil}, 79, "x:c", false]], 53=>[[{44=>:occupied, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{44=>:occupied, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{44=>:occupied, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{44=>:occupied, 35=>:enemy}, 35, "x:c", true], [{52=>:occupied, 51=>nil, 50=>:enemy}, 50, "x:c", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>:enemy}, 49, "x:c", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "x:c", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{52=>:occupied, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{52=>:occupied, 51=>:enemy}, 51, "x:c", true], [{62=>:occupied, 71=>nil, 80=>:enemy}, 80, "x:c", true], [{62=>:occupied, 71=>:enemy}, 71, "x:c", true], [{44=>nil}, 44, "x:c", false], [{44=>nil, 35=>:occupied, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{44=>nil, 35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{44=>nil, 35=>:occupied, 26=>:enemy}, 26, "x:c", true], [{44=>nil, 35=>nil}, 35, "x:c", false], [{44=>nil, 35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{44=>nil, 35=>nil, 26=>:occupied, 17=>:enemy}, 17, "x:c", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "x:c", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "x:c", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "x:c", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:c", false], [{52=>nil}, 52, "x:c", false], [{52=>nil, 51=>:occupied, 50=>nil, 49=>:enemy}, 49, "x:c", true], [{52=>nil, 51=>:occupied, 50=>nil, 49=>nil, 48=>:enemy}, 48, "x:c", true], [{52=>nil, 51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{52=>nil, 51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{52=>nil, 51=>:occupied, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{52=>nil, 51=>:occupied, 50=>:enemy}, 50, "x:c", true], [{52=>nil, 51=>nil}, 51, "x:c", false], [{52=>nil, 51=>nil, 50=>:occupied, 49=>nil, 48=>:enemy}, 48, "x:c", true], [{52=>nil, 51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{52=>nil, 51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{52=>nil, 51=>nil, 50=>:occupied, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{52=>nil, 51=>nil, 50=>:occupied, 49=>:enemy}, 49, "x:c", true], [{52=>nil, 51=>nil, 50=>nil}, 50, "x:c", false], [{52=>nil, 51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>:enemy}, 47, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>:occupied, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>:occupied, 48=>:enemy}, 48, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil}, 49, "x:c", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>:enemy}, 46, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:occupied, 47=>:enemy}, 47, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "x:c", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>nil, 45=>:enemy}, 45, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:occupied, 46=>:enemy}, 46, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "x:c", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:occupied, 45=>:enemy}, 45, "x:c", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "x:c", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:c", false], [{62=>nil}, 62, "x:c", false], [{62=>nil, 71=>:occupied, 80=>:enemy}, 80, "x:c", true], [{62=>nil, 71=>nil}, 71, "x:c", false], [{62=>nil, 71=>nil, 80=>nil}, 80, "x:c", false]], 54=>[[{45=>:occupied, 36=>nil, 27=>:enemy}, 27, "x:c", true], [{45=>:occupied, 36=>nil, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{45=>:occupied, 36=>:enemy}, 36, "x:c", true], [{55=>:occupied, 56=>nil, 57=>:enemy}, 57, "x:c", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>:enemy}, 58, "x:c", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "x:c", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{55=>:occupied, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{55=>:occupied, 56=>:enemy}, 56, "x:c", true], [{63=>:occupied, 72=>:enemy}, 72, "x:c", true], [{45=>nil}, 45, "x:c", false], [{45=>nil, 36=>:occupied, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{45=>nil, 36=>:occupied, 27=>:enemy}, 27, "x:c", true], [{45=>nil, 36=>nil}, 36, "x:c", false], [{45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{45=>nil, 36=>nil, 27=>:occupied, 18=>:enemy}, 18, "x:c", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "x:c", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>:enemy}, 9, "x:c", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "x:c", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "x:c", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "x:c", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:c", false], [{55=>nil}, 55, "x:c", false], [{55=>nil, 56=>:occupied, 57=>nil, 58=>:enemy}, 58, "x:c", true], [{55=>nil, 56=>:occupied, 57=>nil, 58=>nil, 59=>:enemy}, 59, "x:c", true], [{55=>nil, 56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{55=>nil, 56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{55=>nil, 56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{55=>nil, 56=>:occupied, 57=>:enemy}, 57, "x:c", true], [{55=>nil, 56=>nil}, 56, "x:c", false], [{55=>nil, 56=>nil, 57=>:occupied, 58=>nil, 59=>:enemy}, 59, "x:c", true], [{55=>nil, 56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{55=>nil, 56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{55=>nil, 56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{55=>nil, 56=>nil, 57=>:occupied, 58=>:enemy}, 58, "x:c", true], [{55=>nil, 56=>nil, 57=>nil}, 57, "x:c", false], [{55=>nil, 56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>:occupied, 59=>:enemy}, 59, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil}, 58, "x:c", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>:enemy}, 60, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "x:c", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>:enemy}, 61, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "x:c", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "x:c", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "x:c", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:c", false], [{63=>nil}, 63, "x:c", false], [{63=>nil, 72=>nil}, 72, "x:c", false]], 55=>[[{46=>:occupied, 37=>nil, 28=>:enemy}, 28, "x:c", true], [{46=>:occupied, 37=>nil, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{46=>:occupied, 37=>:enemy}, 37, "x:c", true], [{56=>:occupied, 57=>nil, 58=>:enemy}, 58, "x:c", true], [{56=>:occupied, 57=>nil, 58=>nil, 59=>:enemy}, 59, "x:c", true], [{56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{56=>:occupied, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{56=>:occupied, 57=>:enemy}, 57, "x:c", true], [{64=>:occupied, 73=>:enemy}, 73, "x:c", true], [{46=>nil}, 46, "x:c", false], [{46=>nil, 37=>:occupied, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{46=>nil, 37=>:occupied, 28=>:enemy}, 28, "x:c", true], [{46=>nil, 37=>nil}, 37, "x:c", false], [{46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{46=>nil, 37=>nil, 28=>:occupied, 19=>:enemy}, 19, "x:c", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "x:c", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>:enemy}, 10, "x:c", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "x:c", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "x:c", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "x:c", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:c", false], [{54=>nil}, 54, "x:c", false], [{56=>nil}, 56, "x:c", false], [{56=>nil, 57=>:occupied, 58=>nil, 59=>:enemy}, 59, "x:c", true], [{56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{56=>nil, 57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{56=>nil, 57=>:occupied, 58=>:enemy}, 58, "x:c", true], [{56=>nil, 57=>nil}, 57, "x:c", false], [{56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{56=>nil, 57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{56=>nil, 57=>nil, 58=>:occupied, 59=>:enemy}, 59, "x:c", true], [{56=>nil, 57=>nil, 58=>nil}, 58, "x:c", false], [{56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{56=>nil, 57=>nil, 58=>nil, 59=>:occupied, 60=>:enemy}, 60, "x:c", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "x:c", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>:enemy}, 61, "x:c", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "x:c", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "x:c", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "x:c", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:c", false], [{64=>nil}, 64, "x:c", false], [{64=>nil, 73=>nil}, 73, "x:c", false]], 56=>[[{47=>:occupied, 38=>nil, 29=>:enemy}, 29, "x:c", true], [{47=>:occupied, 38=>nil, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{47=>:occupied, 38=>:enemy}, 38, "x:c", true], [{55=>:occupied, 54=>:enemy}, 54, "x:c", true], [{57=>:occupied, 58=>nil, 59=>:enemy}, 59, "x:c", true], [{57=>:occupied, 58=>nil, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{57=>:occupied, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{57=>:occupied, 58=>:enemy}, 58, "x:c", true], [{65=>:occupied, 74=>:enemy}, 74, "x:c", true], [{47=>nil}, 47, "x:c", false], [{47=>nil, 38=>:occupied, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{47=>nil, 38=>:occupied, 29=>:enemy}, 29, "x:c", true], [{47=>nil, 38=>nil}, 38, "x:c", false], [{47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{47=>nil, 38=>nil, 29=>:occupied, 20=>:enemy}, 20, "x:c", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "x:c", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>:enemy}, 11, "x:c", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "x:c", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "x:c", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "x:c", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:c", false], [{55=>nil}, 55, "x:c", false], [{55=>nil, 54=>nil}, 54, "x:c", false], [{57=>nil}, 57, "x:c", false], [{57=>nil, 58=>:occupied, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{57=>nil, 58=>:occupied, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{57=>nil, 58=>:occupied, 59=>:enemy}, 59, "x:c", true], [{57=>nil, 58=>nil}, 58, "x:c", false], [{57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{57=>nil, 58=>nil, 59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{57=>nil, 58=>nil, 59=>:occupied, 60=>:enemy}, 60, "x:c", true], [{57=>nil, 58=>nil, 59=>nil}, 59, "x:c", false], [{57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{57=>nil, 58=>nil, 59=>nil, 60=>:occupied, 61=>:enemy}, 61, "x:c", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "x:c", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "x:c", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "x:c", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:c", false], [{65=>nil}, 65, "x:c", false], [{65=>nil, 74=>nil}, 74, "x:c", false]], 57=>[[{48=>:occupied, 39=>nil, 30=>:enemy}, 30, "x:c", true], [{48=>:occupied, 39=>nil, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{48=>:occupied, 39=>:enemy}, 39, "x:c", true], [{56=>:occupied, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{56=>:occupied, 55=>:enemy}, 55, "x:c", true], [{58=>:occupied, 59=>nil, 60=>:enemy}, 60, "x:c", true], [{58=>:occupied, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{58=>:occupied, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{58=>:occupied, 59=>:enemy}, 59, "x:c", true], [{66=>:occupied, 75=>:enemy}, 75, "x:c", true], [{48=>nil}, 48, "x:c", false], [{48=>nil, 39=>:occupied, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{48=>nil, 39=>:occupied, 30=>:enemy}, 30, "x:c", true], [{48=>nil, 39=>nil}, 39, "x:c", false], [{48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{48=>nil, 39=>nil, 30=>:occupied, 21=>:enemy}, 21, "x:c", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "x:c", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>:enemy}, 12, "x:c", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "x:c", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "x:c", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "x:c", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:c", false], [{56=>nil}, 56, "x:c", false], [{56=>nil, 55=>:occupied, 54=>:enemy}, 54, "x:c", true], [{56=>nil, 55=>nil}, 55, "x:c", false], [{56=>nil, 55=>nil, 54=>nil}, 54, "x:c", false], [{58=>nil}, 58, "x:c", false], [{58=>nil, 59=>:occupied, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{58=>nil, 59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{58=>nil, 59=>:occupied, 60=>:enemy}, 60, "x:c", true], [{58=>nil, 59=>nil}, 59, "x:c", false], [{58=>nil, 59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{58=>nil, 59=>nil, 60=>:occupied, 61=>:enemy}, 61, "x:c", true], [{58=>nil, 59=>nil, 60=>nil}, 60, "x:c", false], [{58=>nil, 59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "x:c", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "x:c", false], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:c", false], [{66=>nil}, 66, "x:c", false], [{66=>nil, 75=>nil}, 75, "x:c", false]], 58=>[[{49=>:occupied, 40=>nil, 31=>:enemy}, 31, "x:c", true], [{49=>:occupied, 40=>nil, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{49=>:occupied, 40=>:enemy}, 40, "x:c", true], [{57=>:occupied, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{57=>:occupied, 56=>:enemy}, 56, "x:c", true], [{59=>:occupied, 60=>nil, 61=>:enemy}, 61, "x:c", true], [{59=>:occupied, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{59=>:occupied, 60=>:enemy}, 60, "x:c", true], [{67=>:occupied, 76=>:enemy}, 76, "x:c", true], [{49=>nil}, 49, "x:c", false], [{49=>nil, 40=>:occupied, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{49=>nil, 40=>:occupied, 31=>:enemy}, 31, "x:c", true], [{49=>nil, 40=>nil}, 40, "x:c", false], [{49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{49=>nil, 40=>nil, 31=>:occupied, 22=>:enemy}, 22, "x:c", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "x:c", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>:enemy}, 13, "x:c", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "x:c", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "x:c", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "x:c", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:c", false], [{57=>nil}, 57, "x:c", false], [{57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{57=>nil, 56=>:occupied, 55=>:enemy}, 55, "x:c", true], [{57=>nil, 56=>nil}, 56, "x:c", false], [{57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "x:c", true], [{57=>nil, 56=>nil, 55=>nil}, 55, "x:c", false], [{57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:c", false], [{59=>nil}, 59, "x:c", false], [{59=>nil, 60=>:occupied, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{59=>nil, 60=>:occupied, 61=>:enemy}, 61, "x:c", true], [{59=>nil, 60=>nil}, 60, "x:c", false], [{59=>nil, 60=>nil, 61=>:occupied, 62=>:enemy}, 62, "x:c", true], [{59=>nil, 60=>nil, 61=>nil}, 61, "x:c", false], [{59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:c", false], [{67=>nil}, 67, "x:c", false], [{67=>nil, 76=>nil}, 76, "x:c", false]], 59=>[[{50=>:occupied, 41=>nil, 32=>:enemy}, 32, "x:c", true], [{50=>:occupied, 41=>nil, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{50=>:occupied, 41=>:enemy}, 41, "x:c", true], [{58=>:occupied, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{58=>:occupied, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{58=>:occupied, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{58=>:occupied, 57=>:enemy}, 57, "x:c", true], [{60=>:occupied, 61=>nil, 62=>:enemy}, 62, "x:c", true], [{60=>:occupied, 61=>:enemy}, 61, "x:c", true], [{68=>:occupied, 77=>:enemy}, 77, "x:c", true], [{50=>nil}, 50, "x:c", false], [{50=>nil, 41=>:occupied, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{50=>nil, 41=>:occupied, 32=>:enemy}, 32, "x:c", true], [{50=>nil, 41=>nil}, 41, "x:c", false], [{50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{50=>nil, 41=>nil, 32=>:occupied, 23=>:enemy}, 23, "x:c", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "x:c", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>:enemy}, 14, "x:c", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "x:c", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "x:c", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "x:c", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:c", false], [{58=>nil}, 58, "x:c", false], [{58=>nil, 57=>:occupied, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{58=>nil, 57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{58=>nil, 57=>:occupied, 56=>:enemy}, 56, "x:c", true], [{58=>nil, 57=>nil}, 57, "x:c", false], [{58=>nil, 57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{58=>nil, 57=>nil, 56=>:occupied, 55=>:enemy}, 55, "x:c", true], [{58=>nil, 57=>nil, 56=>nil}, 56, "x:c", false], [{58=>nil, 57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "x:c", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "x:c", false], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:c", false], [{60=>nil}, 60, "x:c", false], [{60=>nil, 61=>:occupied, 62=>:enemy}, 62, "x:c", true], [{60=>nil, 61=>nil}, 61, "x:c", false], [{60=>nil, 61=>nil, 62=>nil}, 62, "x:c", false], [{68=>nil}, 68, "x:c", false], [{68=>nil, 77=>nil}, 77, "x:c", false]], 60=>[[{51=>:occupied, 42=>nil, 33=>:enemy}, 33, "x:c", true], [{51=>:occupied, 42=>nil, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{51=>:occupied, 42=>:enemy}, 42, "x:c", true], [{59=>:occupied, 58=>nil, 57=>:enemy}, 57, "x:c", true], [{59=>:occupied, 58=>nil, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{59=>:occupied, 58=>:enemy}, 58, "x:c", true], [{61=>:occupied, 62=>:enemy}, 62, "x:c", true], [{69=>:occupied, 78=>:enemy}, 78, "x:c", true], [{51=>nil}, 51, "x:c", false], [{51=>nil, 42=>:occupied, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{51=>nil, 42=>:occupied, 33=>:enemy}, 33, "x:c", true], [{51=>nil, 42=>nil}, 42, "x:c", false], [{51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{51=>nil, 42=>nil, 33=>:occupied, 24=>:enemy}, 24, "x:c", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "x:c", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>:enemy}, 15, "x:c", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "x:c", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "x:c", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "x:c", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:c", false], [{59=>nil}, 59, "x:c", false], [{59=>nil, 58=>:occupied, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{59=>nil, 58=>:occupied, 57=>:enemy}, 57, "x:c", true], [{59=>nil, 58=>nil}, 58, "x:c", false], [{59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{59=>nil, 58=>nil, 57=>:occupied, 56=>:enemy}, 56, "x:c", true], [{59=>nil, 58=>nil, 57=>nil}, 57, "x:c", false], [{59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>:enemy}, 55, "x:c", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "x:c", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "x:c", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "x:c", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:c", false], [{61=>nil}, 61, "x:c", false], [{61=>nil, 62=>nil}, 62, "x:c", false], [{69=>nil}, 69, "x:c", false], [{69=>nil, 78=>nil}, 78, "x:c", false]], 61=>[[{52=>:occupied, 43=>nil, 34=>:enemy}, 34, "x:c", true], [{52=>:occupied, 43=>nil, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{52=>:occupied, 43=>:enemy}, 43, "x:c", true], [{60=>:occupied, 59=>nil, 58=>:enemy}, 58, "x:c", true], [{60=>:occupied, 59=>nil, 58=>nil, 57=>:enemy}, 57, "x:c", true], [{60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{60=>:occupied, 59=>:enemy}, 59, "x:c", true], [{70=>:occupied, 79=>:enemy}, 79, "x:c", true], [{52=>nil}, 52, "x:c", false], [{52=>nil, 43=>:occupied, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{52=>nil, 43=>:occupied, 34=>:enemy}, 34, "x:c", true], [{52=>nil, 43=>nil}, 43, "x:c", false], [{52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{52=>nil, 43=>nil, 34=>:occupied, 25=>:enemy}, 25, "x:c", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "x:c", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>:enemy}, 16, "x:c", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "x:c", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "x:c", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "x:c", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:c", false], [{60=>nil}, 60, "x:c", false], [{60=>nil, 59=>:occupied, 58=>nil, 57=>:enemy}, 57, "x:c", true], [{60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{60=>nil, 59=>:occupied, 58=>:enemy}, 58, "x:c", true], [{60=>nil, 59=>nil}, 59, "x:c", false], [{60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{60=>nil, 59=>nil, 58=>:occupied, 57=>:enemy}, 57, "x:c", true], [{60=>nil, 59=>nil, 58=>nil}, 58, "x:c", false], [{60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>:enemy}, 56, "x:c", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "x:c", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>:enemy}, 55, "x:c", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "x:c", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "x:c", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "x:c", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:c", false], [{62=>nil}, 62, "x:c", false], [{70=>nil}, 70, "x:c", false], [{70=>nil, 79=>nil}, 79, "x:c", false]], 62=>[[{53=>:occupied, 44=>nil, 35=>:enemy}, 35, "x:c", true], [{53=>:occupied, 44=>nil, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{53=>:occupied, 44=>:enemy}, 44, "x:c", true], [{61=>:occupied, 60=>nil, 59=>:enemy}, 59, "x:c", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>:enemy}, 58, "x:c", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "x:c", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{61=>:occupied, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{61=>:occupied, 60=>:enemy}, 60, "x:c", true], [{71=>:occupied, 80=>:enemy}, 80, "x:c", true], [{53=>nil}, 53, "x:c", false], [{53=>nil, 44=>:occupied, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{53=>nil, 44=>:occupied, 35=>:enemy}, 35, "x:c", true], [{53=>nil, 44=>nil}, 44, "x:c", false], [{53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{53=>nil, 44=>nil, 35=>:occupied, 26=>:enemy}, 26, "x:c", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "x:c", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>:enemy}, 17, "x:c", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "x:c", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "x:c", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "x:c", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:c", false], [{61=>nil}, 61, "x:c", false], [{61=>nil, 60=>:occupied, 59=>nil, 58=>:enemy}, 58, "x:c", true], [{61=>nil, 60=>:occupied, 59=>nil, 58=>nil, 57=>:enemy}, 57, "x:c", true], [{61=>nil, 60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{61=>nil, 60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{61=>nil, 60=>:occupied, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{61=>nil, 60=>:occupied, 59=>:enemy}, 59, "x:c", true], [{61=>nil, 60=>nil}, 60, "x:c", false], [{61=>nil, 60=>nil, 59=>:occupied, 58=>nil, 57=>:enemy}, 57, "x:c", true], [{61=>nil, 60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{61=>nil, 60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{61=>nil, 60=>nil, 59=>:occupied, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{61=>nil, 60=>nil, 59=>:occupied, 58=>:enemy}, 58, "x:c", true], [{61=>nil, 60=>nil, 59=>nil}, 59, "x:c", false], [{61=>nil, 60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>:enemy}, 56, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>:occupied, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>:occupied, 57=>:enemy}, 57, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil}, 58, "x:c", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>:enemy}, 55, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:occupied, 56=>:enemy}, 56, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "x:c", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>nil, 54=>:enemy}, 54, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:occupied, 55=>:enemy}, 55, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "x:c", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:occupied, 54=>:enemy}, 54, "x:c", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "x:c", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:c", false], [{71=>nil}, 71, "x:c", false], [{71=>nil, 80=>nil}, 80, "x:c", false]], 63=>[[{54=>:occupied, 45=>nil, 36=>:enemy}, 36, "x:c", true], [{54=>:occupied, 45=>nil, 36=>nil, 27=>:enemy}, 27, "x:c", true], [{54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{54=>:occupied, 45=>:enemy}, 45, "x:c", true], [{64=>:occupied, 65=>nil, 66=>:enemy}, 66, "x:c", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>:enemy}, 67, "x:c", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "x:c", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{64=>:occupied, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{64=>:occupied, 65=>:enemy}, 65, "x:c", true], [{54=>nil}, 54, "x:c", false], [{54=>nil, 45=>:occupied, 36=>nil, 27=>:enemy}, 27, "x:c", true], [{54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{54=>nil, 45=>:occupied, 36=>:enemy}, 36, "x:c", true], [{54=>nil, 45=>nil}, 45, "x:c", false], [{54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{54=>nil, 45=>nil, 36=>:occupied, 27=>:enemy}, 27, "x:c", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "x:c", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>:enemy}, 18, "x:c", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "x:c", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>:enemy}, 9, "x:c", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "x:c", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "x:c", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "x:c", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:c", false], [{64=>nil}, 64, "x:c", false], [{64=>nil, 65=>:occupied, 66=>nil, 67=>:enemy}, 67, "x:c", true], [{64=>nil, 65=>:occupied, 66=>nil, 67=>nil, 68=>:enemy}, 68, "x:c", true], [{64=>nil, 65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{64=>nil, 65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{64=>nil, 65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{64=>nil, 65=>:occupied, 66=>:enemy}, 66, "x:c", true], [{64=>nil, 65=>nil}, 65, "x:c", false], [{64=>nil, 65=>nil, 66=>:occupied, 67=>nil, 68=>:enemy}, 68, "x:c", true], [{64=>nil, 65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{64=>nil, 65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{64=>nil, 65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{64=>nil, 65=>nil, 66=>:occupied, 67=>:enemy}, 67, "x:c", true], [{64=>nil, 65=>nil, 66=>nil}, 66, "x:c", false], [{64=>nil, 65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>:occupied, 68=>:enemy}, 68, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil}, 67, "x:c", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>:enemy}, 69, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "x:c", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>:enemy}, 70, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "x:c", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "x:c", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "x:c", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:c", false], [{72=>nil}, 72, "x:c", false]], 64=>[[{55=>:occupied, 46=>nil, 37=>:enemy}, 37, "x:c", true], [{55=>:occupied, 46=>nil, 37=>nil, 28=>:enemy}, 28, "x:c", true], [{55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{55=>:occupied, 46=>:enemy}, 46, "x:c", true], [{65=>:occupied, 66=>nil, 67=>:enemy}, 67, "x:c", true], [{65=>:occupied, 66=>nil, 67=>nil, 68=>:enemy}, 68, "x:c", true], [{65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{65=>:occupied, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{65=>:occupied, 66=>:enemy}, 66, "x:c", true], [{55=>nil}, 55, "x:c", false], [{55=>nil, 46=>:occupied, 37=>nil, 28=>:enemy}, 28, "x:c", true], [{55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{55=>nil, 46=>:occupied, 37=>:enemy}, 37, "x:c", true], [{55=>nil, 46=>nil}, 46, "x:c", false], [{55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{55=>nil, 46=>nil, 37=>:occupied, 28=>:enemy}, 28, "x:c", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "x:c", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>:enemy}, 19, "x:c", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "x:c", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>:enemy}, 10, "x:c", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "x:c", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "x:c", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "x:c", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:c", false], [{63=>nil}, 63, "x:c", false], [{65=>nil}, 65, "x:c", false], [{65=>nil, 66=>:occupied, 67=>nil, 68=>:enemy}, 68, "x:c", true], [{65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{65=>nil, 66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{65=>nil, 66=>:occupied, 67=>:enemy}, 67, "x:c", true], [{65=>nil, 66=>nil}, 66, "x:c", false], [{65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{65=>nil, 66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{65=>nil, 66=>nil, 67=>:occupied, 68=>:enemy}, 68, "x:c", true], [{65=>nil, 66=>nil, 67=>nil}, 67, "x:c", false], [{65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{65=>nil, 66=>nil, 67=>nil, 68=>:occupied, 69=>:enemy}, 69, "x:c", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "x:c", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>:enemy}, 70, "x:c", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "x:c", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "x:c", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "x:c", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:c", false], [{73=>nil}, 73, "x:c", false]], 65=>[[{56=>:occupied, 47=>nil, 38=>:enemy}, 38, "x:c", true], [{56=>:occupied, 47=>nil, 38=>nil, 29=>:enemy}, 29, "x:c", true], [{56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{56=>:occupied, 47=>:enemy}, 47, "x:c", true], [{64=>:occupied, 63=>:enemy}, 63, "x:c", true], [{66=>:occupied, 67=>nil, 68=>:enemy}, 68, "x:c", true], [{66=>:occupied, 67=>nil, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{66=>:occupied, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{66=>:occupied, 67=>:enemy}, 67, "x:c", true], [{56=>nil}, 56, "x:c", false], [{56=>nil, 47=>:occupied, 38=>nil, 29=>:enemy}, 29, "x:c", true], [{56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{56=>nil, 47=>:occupied, 38=>:enemy}, 38, "x:c", true], [{56=>nil, 47=>nil}, 47, "x:c", false], [{56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{56=>nil, 47=>nil, 38=>:occupied, 29=>:enemy}, 29, "x:c", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "x:c", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>:enemy}, 20, "x:c", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "x:c", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>:enemy}, 11, "x:c", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "x:c", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "x:c", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "x:c", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:c", false], [{64=>nil}, 64, "x:c", false], [{64=>nil, 63=>nil}, 63, "x:c", false], [{66=>nil}, 66, "x:c", false], [{66=>nil, 67=>:occupied, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{66=>nil, 67=>:occupied, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{66=>nil, 67=>:occupied, 68=>:enemy}, 68, "x:c", true], [{66=>nil, 67=>nil}, 67, "x:c", false], [{66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{66=>nil, 67=>nil, 68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{66=>nil, 67=>nil, 68=>:occupied, 69=>:enemy}, 69, "x:c", true], [{66=>nil, 67=>nil, 68=>nil}, 68, "x:c", false], [{66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{66=>nil, 67=>nil, 68=>nil, 69=>:occupied, 70=>:enemy}, 70, "x:c", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "x:c", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "x:c", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "x:c", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:c", false], [{74=>nil}, 74, "x:c", false]], 66=>[[{57=>:occupied, 48=>nil, 39=>:enemy}, 39, "x:c", true], [{57=>:occupied, 48=>nil, 39=>nil, 30=>:enemy}, 30, "x:c", true], [{57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{57=>:occupied, 48=>:enemy}, 48, "x:c", true], [{65=>:occupied, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{65=>:occupied, 64=>:enemy}, 64, "x:c", true], [{67=>:occupied, 68=>nil, 69=>:enemy}, 69, "x:c", true], [{67=>:occupied, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{67=>:occupied, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{67=>:occupied, 68=>:enemy}, 68, "x:c", true], [{57=>nil}, 57, "x:c", false], [{57=>nil, 48=>:occupied, 39=>nil, 30=>:enemy}, 30, "x:c", true], [{57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{57=>nil, 48=>:occupied, 39=>:enemy}, 39, "x:c", true], [{57=>nil, 48=>nil}, 48, "x:c", false], [{57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{57=>nil, 48=>nil, 39=>:occupied, 30=>:enemy}, 30, "x:c", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "x:c", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>:enemy}, 21, "x:c", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "x:c", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>:enemy}, 12, "x:c", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "x:c", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "x:c", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "x:c", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:c", false], [{65=>nil}, 65, "x:c", false], [{65=>nil, 64=>:occupied, 63=>:enemy}, 63, "x:c", true], [{65=>nil, 64=>nil}, 64, "x:c", false], [{65=>nil, 64=>nil, 63=>nil}, 63, "x:c", false], [{67=>nil}, 67, "x:c", false], [{67=>nil, 68=>:occupied, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{67=>nil, 68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{67=>nil, 68=>:occupied, 69=>:enemy}, 69, "x:c", true], [{67=>nil, 68=>nil}, 68, "x:c", false], [{67=>nil, 68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{67=>nil, 68=>nil, 69=>:occupied, 70=>:enemy}, 70, "x:c", true], [{67=>nil, 68=>nil, 69=>nil}, 69, "x:c", false], [{67=>nil, 68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "x:c", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "x:c", false], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:c", false], [{75=>nil}, 75, "x:c", false]], 67=>[[{58=>:occupied, 49=>nil, 40=>:enemy}, 40, "x:c", true], [{58=>:occupied, 49=>nil, 40=>nil, 31=>:enemy}, 31, "x:c", true], [{58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{58=>:occupied, 49=>:enemy}, 49, "x:c", true], [{66=>:occupied, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{66=>:occupied, 65=>:enemy}, 65, "x:c", true], [{68=>:occupied, 69=>nil, 70=>:enemy}, 70, "x:c", true], [{68=>:occupied, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{68=>:occupied, 69=>:enemy}, 69, "x:c", true], [{58=>nil}, 58, "x:c", false], [{58=>nil, 49=>:occupied, 40=>nil, 31=>:enemy}, 31, "x:c", true], [{58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{58=>nil, 49=>:occupied, 40=>:enemy}, 40, "x:c", true], [{58=>nil, 49=>nil}, 49, "x:c", false], [{58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{58=>nil, 49=>nil, 40=>:occupied, 31=>:enemy}, 31, "x:c", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "x:c", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>:enemy}, 22, "x:c", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "x:c", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>:enemy}, 13, "x:c", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "x:c", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "x:c", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "x:c", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:c", false], [{66=>nil}, 66, "x:c", false], [{66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{66=>nil, 65=>:occupied, 64=>:enemy}, 64, "x:c", true], [{66=>nil, 65=>nil}, 65, "x:c", false], [{66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "x:c", true], [{66=>nil, 65=>nil, 64=>nil}, 64, "x:c", false], [{66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:c", false], [{68=>nil}, 68, "x:c", false], [{68=>nil, 69=>:occupied, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{68=>nil, 69=>:occupied, 70=>:enemy}, 70, "x:c", true], [{68=>nil, 69=>nil}, 69, "x:c", false], [{68=>nil, 69=>nil, 70=>:occupied, 71=>:enemy}, 71, "x:c", true], [{68=>nil, 69=>nil, 70=>nil}, 70, "x:c", false], [{68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:c", false], [{76=>nil}, 76, "x:c", false]], 68=>[[{59=>:occupied, 50=>nil, 41=>:enemy}, 41, "x:c", true], [{59=>:occupied, 50=>nil, 41=>nil, 32=>:enemy}, 32, "x:c", true], [{59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{59=>:occupied, 50=>:enemy}, 50, "x:c", true], [{67=>:occupied, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{67=>:occupied, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{67=>:occupied, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{67=>:occupied, 66=>:enemy}, 66, "x:c", true], [{69=>:occupied, 70=>nil, 71=>:enemy}, 71, "x:c", true], [{69=>:occupied, 70=>:enemy}, 70, "x:c", true], [{59=>nil}, 59, "x:c", false], [{59=>nil, 50=>:occupied, 41=>nil, 32=>:enemy}, 32, "x:c", true], [{59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{59=>nil, 50=>:occupied, 41=>:enemy}, 41, "x:c", true], [{59=>nil, 50=>nil}, 50, "x:c", false], [{59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{59=>nil, 50=>nil, 41=>:occupied, 32=>:enemy}, 32, "x:c", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "x:c", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>:enemy}, 23, "x:c", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "x:c", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>:enemy}, 14, "x:c", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "x:c", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "x:c", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "x:c", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:c", false], [{67=>nil}, 67, "x:c", false], [{67=>nil, 66=>:occupied, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{67=>nil, 66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{67=>nil, 66=>:occupied, 65=>:enemy}, 65, "x:c", true], [{67=>nil, 66=>nil}, 66, "x:c", false], [{67=>nil, 66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{67=>nil, 66=>nil, 65=>:occupied, 64=>:enemy}, 64, "x:c", true], [{67=>nil, 66=>nil, 65=>nil}, 65, "x:c", false], [{67=>nil, 66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "x:c", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "x:c", false], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:c", false], [{69=>nil}, 69, "x:c", false], [{69=>nil, 70=>:occupied, 71=>:enemy}, 71, "x:c", true], [{69=>nil, 70=>nil}, 70, "x:c", false], [{69=>nil, 70=>nil, 71=>nil}, 71, "x:c", false], [{77=>nil}, 77, "x:c", false]], 69=>[[{60=>:occupied, 51=>nil, 42=>:enemy}, 42, "x:c", true], [{60=>:occupied, 51=>nil, 42=>nil, 33=>:enemy}, 33, "x:c", true], [{60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{60=>:occupied, 51=>:enemy}, 51, "x:c", true], [{68=>:occupied, 67=>nil, 66=>:enemy}, 66, "x:c", true], [{68=>:occupied, 67=>nil, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{68=>:occupied, 67=>:enemy}, 67, "x:c", true], [{70=>:occupied, 71=>:enemy}, 71, "x:c", true], [{60=>nil}, 60, "x:c", false], [{60=>nil, 51=>:occupied, 42=>nil, 33=>:enemy}, 33, "x:c", true], [{60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{60=>nil, 51=>:occupied, 42=>:enemy}, 42, "x:c", true], [{60=>nil, 51=>nil}, 51, "x:c", false], [{60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{60=>nil, 51=>nil, 42=>:occupied, 33=>:enemy}, 33, "x:c", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "x:c", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>:enemy}, 24, "x:c", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "x:c", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>:enemy}, 15, "x:c", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "x:c", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "x:c", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "x:c", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:c", false], [{68=>nil}, 68, "x:c", false], [{68=>nil, 67=>:occupied, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{68=>nil, 67=>:occupied, 66=>:enemy}, 66, "x:c", true], [{68=>nil, 67=>nil}, 67, "x:c", false], [{68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{68=>nil, 67=>nil, 66=>:occupied, 65=>:enemy}, 65, "x:c", true], [{68=>nil, 67=>nil, 66=>nil}, 66, "x:c", false], [{68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>:enemy}, 64, "x:c", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "x:c", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "x:c", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "x:c", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:c", false], [{70=>nil}, 70, "x:c", false], [{70=>nil, 71=>nil}, 71, "x:c", false], [{78=>nil}, 78, "x:c", false]], 70=>[[{61=>:occupied, 52=>nil, 43=>:enemy}, 43, "x:c", true], [{61=>:occupied, 52=>nil, 43=>nil, 34=>:enemy}, 34, "x:c", true], [{61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{61=>:occupied, 52=>:enemy}, 52, "x:c", true], [{69=>:occupied, 68=>nil, 67=>:enemy}, 67, "x:c", true], [{69=>:occupied, 68=>nil, 67=>nil, 66=>:enemy}, 66, "x:c", true], [{69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{69=>:occupied, 68=>:enemy}, 68, "x:c", true], [{61=>nil}, 61, "x:c", false], [{61=>nil, 52=>:occupied, 43=>nil, 34=>:enemy}, 34, "x:c", true], [{61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{61=>nil, 52=>:occupied, 43=>:enemy}, 43, "x:c", true], [{61=>nil, 52=>nil}, 52, "x:c", false], [{61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{61=>nil, 52=>nil, 43=>:occupied, 34=>:enemy}, 34, "x:c", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "x:c", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>:enemy}, 25, "x:c", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "x:c", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>:enemy}, 16, "x:c", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "x:c", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "x:c", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "x:c", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:c", false], [{69=>nil}, 69, "x:c", false], [{69=>nil, 68=>:occupied, 67=>nil, 66=>:enemy}, 66, "x:c", true], [{69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{69=>nil, 68=>:occupied, 67=>:enemy}, 67, "x:c", true], [{69=>nil, 68=>nil}, 68, "x:c", false], [{69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{69=>nil, 68=>nil, 67=>:occupied, 66=>:enemy}, 66, "x:c", true], [{69=>nil, 68=>nil, 67=>nil}, 67, "x:c", false], [{69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>:enemy}, 65, "x:c", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "x:c", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>:enemy}, 64, "x:c", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "x:c", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "x:c", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "x:c", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:c", false], [{71=>nil}, 71, "x:c", false], [{79=>nil}, 79, "x:c", false]], 71=>[[{62=>:occupied, 53=>nil, 44=>:enemy}, 44, "x:c", true], [{62=>:occupied, 53=>nil, 44=>nil, 35=>:enemy}, 35, "x:c", true], [{62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{62=>:occupied, 53=>:enemy}, 53, "x:c", true], [{70=>:occupied, 69=>nil, 68=>:enemy}, 68, "x:c", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>:enemy}, 67, "x:c", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "x:c", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{70=>:occupied, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{70=>:occupied, 69=>:enemy}, 69, "x:c", true], [{62=>nil}, 62, "x:c", false], [{62=>nil, 53=>:occupied, 44=>nil, 35=>:enemy}, 35, "x:c", true], [{62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{62=>nil, 53=>:occupied, 44=>:enemy}, 44, "x:c", true], [{62=>nil, 53=>nil}, 53, "x:c", false], [{62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{62=>nil, 53=>nil, 44=>:occupied, 35=>:enemy}, 35, "x:c", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "x:c", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>:enemy}, 26, "x:c", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "x:c", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>:enemy}, 17, "x:c", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "x:c", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "x:c", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "x:c", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:c", false], [{70=>nil}, 70, "x:c", false], [{70=>nil, 69=>:occupied, 68=>nil, 67=>:enemy}, 67, "x:c", true], [{70=>nil, 69=>:occupied, 68=>nil, 67=>nil, 66=>:enemy}, 66, "x:c", true], [{70=>nil, 69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{70=>nil, 69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{70=>nil, 69=>:occupied, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{70=>nil, 69=>:occupied, 68=>:enemy}, 68, "x:c", true], [{70=>nil, 69=>nil}, 69, "x:c", false], [{70=>nil, 69=>nil, 68=>:occupied, 67=>nil, 66=>:enemy}, 66, "x:c", true], [{70=>nil, 69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{70=>nil, 69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{70=>nil, 69=>nil, 68=>:occupied, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{70=>nil, 69=>nil, 68=>:occupied, 67=>:enemy}, 67, "x:c", true], [{70=>nil, 69=>nil, 68=>nil}, 68, "x:c", false], [{70=>nil, 69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>:enemy}, 65, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>:occupied, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>:occupied, 66=>:enemy}, 66, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil}, 67, "x:c", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>:enemy}, 64, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:occupied, 65=>:enemy}, 65, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "x:c", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>nil, 63=>:enemy}, 63, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:occupied, 64=>:enemy}, 64, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "x:c", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:occupied, 63=>:enemy}, 63, "x:c", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "x:c", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:c", false], [{80=>nil}, 80, "x:c", false]], 72=>[[{63=>:occupied, 54=>nil, 45=>:enemy}, 45, "x:c", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>:enemy}, 36, "x:c", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "x:c", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{63=>:occupied, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{63=>:occupied, 54=>:enemy}, 54, "x:c", true], [{73=>:occupied, 74=>nil, 75=>:enemy}, 75, "x:c", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>:enemy}, 76, "x:c", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "x:c", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{73=>:occupied, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{73=>:occupied, 74=>:enemy}, 74, "x:c", true], [{63=>nil}, 63, "x:c", false], [{63=>nil, 54=>:occupied, 45=>nil, 36=>:enemy}, 36, "x:c", true], [{63=>nil, 54=>:occupied, 45=>nil, 36=>nil, 27=>:enemy}, 27, "x:c", true], [{63=>nil, 54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{63=>nil, 54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{63=>nil, 54=>:occupied, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{63=>nil, 54=>:occupied, 45=>:enemy}, 45, "x:c", true], [{63=>nil, 54=>nil}, 54, "x:c", false], [{63=>nil, 54=>nil, 45=>:occupied, 36=>nil, 27=>:enemy}, 27, "x:c", true], [{63=>nil, 54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{63=>nil, 54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{63=>nil, 54=>nil, 45=>:occupied, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{63=>nil, 54=>nil, 45=>:occupied, 36=>:enemy}, 36, "x:c", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "x:c", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>:enemy}, 18, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>:occupied, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>:occupied, 27=>:enemy}, 27, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "x:c", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>:enemy}, 9, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:occupied, 18=>:enemy}, 18, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "x:c", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>nil, 0=>:enemy}, 0, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:occupied, 9=>:enemy}, 9, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "x:c", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:occupied, 0=>:enemy}, 0, "x:c", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "x:c", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:c", false], [{73=>nil}, 73, "x:c", false], [{73=>nil, 74=>:occupied, 75=>nil, 76=>:enemy}, 76, "x:c", true], [{73=>nil, 74=>:occupied, 75=>nil, 76=>nil, 77=>:enemy}, 77, "x:c", true], [{73=>nil, 74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{73=>nil, 74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{73=>nil, 74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{73=>nil, 74=>:occupied, 75=>:enemy}, 75, "x:c", true], [{73=>nil, 74=>nil}, 74, "x:c", false], [{73=>nil, 74=>nil, 75=>:occupied, 76=>nil, 77=>:enemy}, 77, "x:c", true], [{73=>nil, 74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{73=>nil, 74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{73=>nil, 74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{73=>nil, 74=>nil, 75=>:occupied, 76=>:enemy}, 76, "x:c", true], [{73=>nil, 74=>nil, 75=>nil}, 75, "x:c", false], [{73=>nil, 74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>:occupied, 77=>:enemy}, 77, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil}, 76, "x:c", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>:enemy}, 78, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "x:c", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>:enemy}, 79, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "x:c", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "x:c", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "x:c", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:c", false]], 73=>[[{64=>:occupied, 55=>nil, 46=>:enemy}, 46, "x:c", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>:enemy}, 37, "x:c", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "x:c", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{64=>:occupied, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{64=>:occupied, 55=>:enemy}, 55, "x:c", true], [{74=>:occupied, 75=>nil, 76=>:enemy}, 76, "x:c", true], [{74=>:occupied, 75=>nil, 76=>nil, 77=>:enemy}, 77, "x:c", true], [{74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{74=>:occupied, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{74=>:occupied, 75=>:enemy}, 75, "x:c", true], [{64=>nil}, 64, "x:c", false], [{64=>nil, 55=>:occupied, 46=>nil, 37=>:enemy}, 37, "x:c", true], [{64=>nil, 55=>:occupied, 46=>nil, 37=>nil, 28=>:enemy}, 28, "x:c", true], [{64=>nil, 55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{64=>nil, 55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{64=>nil, 55=>:occupied, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{64=>nil, 55=>:occupied, 46=>:enemy}, 46, "x:c", true], [{64=>nil, 55=>nil}, 55, "x:c", false], [{64=>nil, 55=>nil, 46=>:occupied, 37=>nil, 28=>:enemy}, 28, "x:c", true], [{64=>nil, 55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{64=>nil, 55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{64=>nil, 55=>nil, 46=>:occupied, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{64=>nil, 55=>nil, 46=>:occupied, 37=>:enemy}, 37, "x:c", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "x:c", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>:enemy}, 19, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>:occupied, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>:occupied, 28=>:enemy}, 28, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "x:c", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>:enemy}, 10, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:occupied, 19=>:enemy}, 19, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "x:c", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>nil, 1=>:enemy}, 1, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:occupied, 10=>:enemy}, 10, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "x:c", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:occupied, 1=>:enemy}, 1, "x:c", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "x:c", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:c", false], [{72=>nil}, 72, "x:c", false], [{74=>nil}, 74, "x:c", false], [{74=>nil, 75=>:occupied, 76=>nil, 77=>:enemy}, 77, "x:c", true], [{74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{74=>nil, 75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{74=>nil, 75=>:occupied, 76=>:enemy}, 76, "x:c", true], [{74=>nil, 75=>nil}, 75, "x:c", false], [{74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{74=>nil, 75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{74=>nil, 75=>nil, 76=>:occupied, 77=>:enemy}, 77, "x:c", true], [{74=>nil, 75=>nil, 76=>nil}, 76, "x:c", false], [{74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{74=>nil, 75=>nil, 76=>nil, 77=>:occupied, 78=>:enemy}, 78, "x:c", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "x:c", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>:enemy}, 79, "x:c", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "x:c", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "x:c", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "x:c", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:c", false]], 74=>[[{65=>:occupied, 56=>nil, 47=>:enemy}, 47, "x:c", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>:enemy}, 38, "x:c", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "x:c", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{65=>:occupied, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{65=>:occupied, 56=>:enemy}, 56, "x:c", true], [{73=>:occupied, 72=>:enemy}, 72, "x:c", true], [{75=>:occupied, 76=>nil, 77=>:enemy}, 77, "x:c", true], [{75=>:occupied, 76=>nil, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{75=>:occupied, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{75=>:occupied, 76=>:enemy}, 76, "x:c", true], [{65=>nil}, 65, "x:c", false], [{65=>nil, 56=>:occupied, 47=>nil, 38=>:enemy}, 38, "x:c", true], [{65=>nil, 56=>:occupied, 47=>nil, 38=>nil, 29=>:enemy}, 29, "x:c", true], [{65=>nil, 56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{65=>nil, 56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{65=>nil, 56=>:occupied, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{65=>nil, 56=>:occupied, 47=>:enemy}, 47, "x:c", true], [{65=>nil, 56=>nil}, 56, "x:c", false], [{65=>nil, 56=>nil, 47=>:occupied, 38=>nil, 29=>:enemy}, 29, "x:c", true], [{65=>nil, 56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{65=>nil, 56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{65=>nil, 56=>nil, 47=>:occupied, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{65=>nil, 56=>nil, 47=>:occupied, 38=>:enemy}, 38, "x:c", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "x:c", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>:enemy}, 20, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>:occupied, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>:occupied, 29=>:enemy}, 29, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "x:c", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>:enemy}, 11, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:occupied, 20=>:enemy}, 20, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "x:c", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>nil, 2=>:enemy}, 2, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:occupied, 11=>:enemy}, 11, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "x:c", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:occupied, 2=>:enemy}, 2, "x:c", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "x:c", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:c", false], [{73=>nil}, 73, "x:c", false], [{73=>nil, 72=>nil}, 72, "x:c", false], [{75=>nil}, 75, "x:c", false], [{75=>nil, 76=>:occupied, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{75=>nil, 76=>:occupied, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{75=>nil, 76=>:occupied, 77=>:enemy}, 77, "x:c", true], [{75=>nil, 76=>nil}, 76, "x:c", false], [{75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{75=>nil, 76=>nil, 77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{75=>nil, 76=>nil, 77=>:occupied, 78=>:enemy}, 78, "x:c", true], [{75=>nil, 76=>nil, 77=>nil}, 77, "x:c", false], [{75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{75=>nil, 76=>nil, 77=>nil, 78=>:occupied, 79=>:enemy}, 79, "x:c", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "x:c", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "x:c", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "x:c", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:c", false]], 75=>[[{66=>:occupied, 57=>nil, 48=>:enemy}, 48, "x:c", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>:enemy}, 39, "x:c", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "x:c", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{66=>:occupied, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{66=>:occupied, 57=>:enemy}, 57, "x:c", true], [{74=>:occupied, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{74=>:occupied, 73=>:enemy}, 73, "x:c", true], [{76=>:occupied, 77=>nil, 78=>:enemy}, 78, "x:c", true], [{76=>:occupied, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{76=>:occupied, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{76=>:occupied, 77=>:enemy}, 77, "x:c", true], [{66=>nil}, 66, "x:c", false], [{66=>nil, 57=>:occupied, 48=>nil, 39=>:enemy}, 39, "x:c", true], [{66=>nil, 57=>:occupied, 48=>nil, 39=>nil, 30=>:enemy}, 30, "x:c", true], [{66=>nil, 57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{66=>nil, 57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{66=>nil, 57=>:occupied, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{66=>nil, 57=>:occupied, 48=>:enemy}, 48, "x:c", true], [{66=>nil, 57=>nil}, 57, "x:c", false], [{66=>nil, 57=>nil, 48=>:occupied, 39=>nil, 30=>:enemy}, 30, "x:c", true], [{66=>nil, 57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{66=>nil, 57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{66=>nil, 57=>nil, 48=>:occupied, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{66=>nil, 57=>nil, 48=>:occupied, 39=>:enemy}, 39, "x:c", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "x:c", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>:enemy}, 21, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>:occupied, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>:occupied, 30=>:enemy}, 30, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "x:c", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>:enemy}, 12, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:occupied, 21=>:enemy}, 21, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "x:c", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>nil, 3=>:enemy}, 3, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:occupied, 12=>:enemy}, 12, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "x:c", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:occupied, 3=>:enemy}, 3, "x:c", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "x:c", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:c", false], [{74=>nil}, 74, "x:c", false], [{74=>nil, 73=>:occupied, 72=>:enemy}, 72, "x:c", true], [{74=>nil, 73=>nil}, 73, "x:c", false], [{74=>nil, 73=>nil, 72=>nil}, 72, "x:c", false], [{76=>nil}, 76, "x:c", false], [{76=>nil, 77=>:occupied, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{76=>nil, 77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{76=>nil, 77=>:occupied, 78=>:enemy}, 78, "x:c", true], [{76=>nil, 77=>nil}, 77, "x:c", false], [{76=>nil, 77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{76=>nil, 77=>nil, 78=>:occupied, 79=>:enemy}, 79, "x:c", true], [{76=>nil, 77=>nil, 78=>nil}, 78, "x:c", false], [{76=>nil, 77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "x:c", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "x:c", false], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:c", false]], 76=>[[{67=>:occupied, 58=>nil, 49=>:enemy}, 49, "x:c", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>:enemy}, 40, "x:c", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "x:c", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{67=>:occupied, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{67=>:occupied, 58=>:enemy}, 58, "x:c", true], [{75=>:occupied, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{75=>:occupied, 74=>:enemy}, 74, "x:c", true], [{77=>:occupied, 78=>nil, 79=>:enemy}, 79, "x:c", true], [{77=>:occupied, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{77=>:occupied, 78=>:enemy}, 78, "x:c", true], [{67=>nil}, 67, "x:c", false], [{67=>nil, 58=>:occupied, 49=>nil, 40=>:enemy}, 40, "x:c", true], [{67=>nil, 58=>:occupied, 49=>nil, 40=>nil, 31=>:enemy}, 31, "x:c", true], [{67=>nil, 58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{67=>nil, 58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{67=>nil, 58=>:occupied, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{67=>nil, 58=>:occupied, 49=>:enemy}, 49, "x:c", true], [{67=>nil, 58=>nil}, 58, "x:c", false], [{67=>nil, 58=>nil, 49=>:occupied, 40=>nil, 31=>:enemy}, 31, "x:c", true], [{67=>nil, 58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{67=>nil, 58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{67=>nil, 58=>nil, 49=>:occupied, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{67=>nil, 58=>nil, 49=>:occupied, 40=>:enemy}, 40, "x:c", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "x:c", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>:enemy}, 22, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>:occupied, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>:occupied, 31=>:enemy}, 31, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "x:c", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>:enemy}, 13, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:occupied, 22=>:enemy}, 22, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "x:c", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>nil, 4=>:enemy}, 4, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:occupied, 13=>:enemy}, 13, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "x:c", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:occupied, 4=>:enemy}, 4, "x:c", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "x:c", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:c", false], [{75=>nil}, 75, "x:c", false], [{75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{75=>nil, 74=>:occupied, 73=>:enemy}, 73, "x:c", true], [{75=>nil, 74=>nil}, 74, "x:c", false], [{75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "x:c", true], [{75=>nil, 74=>nil, 73=>nil}, 73, "x:c", false], [{75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:c", false], [{77=>nil}, 77, "x:c", false], [{77=>nil, 78=>:occupied, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{77=>nil, 78=>:occupied, 79=>:enemy}, 79, "x:c", true], [{77=>nil, 78=>nil}, 78, "x:c", false], [{77=>nil, 78=>nil, 79=>:occupied, 80=>:enemy}, 80, "x:c", true], [{77=>nil, 78=>nil, 79=>nil}, 79, "x:c", false], [{77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:c", false]], 77=>[[{68=>:occupied, 59=>nil, 50=>:enemy}, 50, "x:c", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>:enemy}, 41, "x:c", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "x:c", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{68=>:occupied, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{68=>:occupied, 59=>:enemy}, 59, "x:c", true], [{76=>:occupied, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{76=>:occupied, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{76=>:occupied, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{76=>:occupied, 75=>:enemy}, 75, "x:c", true], [{78=>:occupied, 79=>nil, 80=>:enemy}, 80, "x:c", true], [{78=>:occupied, 79=>:enemy}, 79, "x:c", true], [{68=>nil}, 68, "x:c", false], [{68=>nil, 59=>:occupied, 50=>nil, 41=>:enemy}, 41, "x:c", true], [{68=>nil, 59=>:occupied, 50=>nil, 41=>nil, 32=>:enemy}, 32, "x:c", true], [{68=>nil, 59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{68=>nil, 59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{68=>nil, 59=>:occupied, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{68=>nil, 59=>:occupied, 50=>:enemy}, 50, "x:c", true], [{68=>nil, 59=>nil}, 59, "x:c", false], [{68=>nil, 59=>nil, 50=>:occupied, 41=>nil, 32=>:enemy}, 32, "x:c", true], [{68=>nil, 59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{68=>nil, 59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{68=>nil, 59=>nil, 50=>:occupied, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{68=>nil, 59=>nil, 50=>:occupied, 41=>:enemy}, 41, "x:c", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "x:c", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>:enemy}, 23, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>:occupied, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>:occupied, 32=>:enemy}, 32, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "x:c", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>:enemy}, 14, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:occupied, 23=>:enemy}, 23, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "x:c", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>nil, 5=>:enemy}, 5, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:occupied, 14=>:enemy}, 14, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "x:c", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:occupied, 5=>:enemy}, 5, "x:c", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "x:c", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:c", false], [{76=>nil}, 76, "x:c", false], [{76=>nil, 75=>:occupied, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{76=>nil, 75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{76=>nil, 75=>:occupied, 74=>:enemy}, 74, "x:c", true], [{76=>nil, 75=>nil}, 75, "x:c", false], [{76=>nil, 75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{76=>nil, 75=>nil, 74=>:occupied, 73=>:enemy}, 73, "x:c", true], [{76=>nil, 75=>nil, 74=>nil}, 74, "x:c", false], [{76=>nil, 75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "x:c", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "x:c", false], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:c", false], [{78=>nil}, 78, "x:c", false], [{78=>nil, 79=>:occupied, 80=>:enemy}, 80, "x:c", true], [{78=>nil, 79=>nil}, 79, "x:c", false], [{78=>nil, 79=>nil, 80=>nil}, 80, "x:c", false]], 78=>[[{69=>:occupied, 60=>nil, 51=>:enemy}, 51, "x:c", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>:enemy}, 42, "x:c", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "x:c", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{69=>:occupied, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{69=>:occupied, 60=>:enemy}, 60, "x:c", true], [{77=>:occupied, 76=>nil, 75=>:enemy}, 75, "x:c", true], [{77=>:occupied, 76=>nil, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{77=>:occupied, 76=>:enemy}, 76, "x:c", true], [{79=>:occupied, 80=>:enemy}, 80, "x:c", true], [{69=>nil}, 69, "x:c", false], [{69=>nil, 60=>:occupied, 51=>nil, 42=>:enemy}, 42, "x:c", true], [{69=>nil, 60=>:occupied, 51=>nil, 42=>nil, 33=>:enemy}, 33, "x:c", true], [{69=>nil, 60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{69=>nil, 60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{69=>nil, 60=>:occupied, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{69=>nil, 60=>:occupied, 51=>:enemy}, 51, "x:c", true], [{69=>nil, 60=>nil}, 60, "x:c", false], [{69=>nil, 60=>nil, 51=>:occupied, 42=>nil, 33=>:enemy}, 33, "x:c", true], [{69=>nil, 60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{69=>nil, 60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{69=>nil, 60=>nil, 51=>:occupied, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{69=>nil, 60=>nil, 51=>:occupied, 42=>:enemy}, 42, "x:c", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "x:c", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>:enemy}, 24, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>:occupied, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>:occupied, 33=>:enemy}, 33, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "x:c", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>:enemy}, 15, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:occupied, 24=>:enemy}, 24, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "x:c", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>nil, 6=>:enemy}, 6, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:occupied, 15=>:enemy}, 15, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "x:c", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:occupied, 6=>:enemy}, 6, "x:c", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "x:c", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:c", false], [{77=>nil}, 77, "x:c", false], [{77=>nil, 76=>:occupied, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{77=>nil, 76=>:occupied, 75=>:enemy}, 75, "x:c", true], [{77=>nil, 76=>nil}, 76, "x:c", false], [{77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{77=>nil, 76=>nil, 75=>:occupied, 74=>:enemy}, 74, "x:c", true], [{77=>nil, 76=>nil, 75=>nil}, 75, "x:c", false], [{77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>:enemy}, 73, "x:c", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "x:c", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "x:c", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "x:c", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:c", false], [{79=>nil}, 79, "x:c", false], [{79=>nil, 80=>nil}, 80, "x:c", false]], 79=>[[{70=>:occupied, 61=>nil, 52=>:enemy}, 52, "x:c", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>:enemy}, 43, "x:c", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "x:c", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{70=>:occupied, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{70=>:occupied, 61=>:enemy}, 61, "x:c", true], [{78=>:occupied, 77=>nil, 76=>:enemy}, 76, "x:c", true], [{78=>:occupied, 77=>nil, 76=>nil, 75=>:enemy}, 75, "x:c", true], [{78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{78=>:occupied, 77=>:enemy}, 77, "x:c", true], [{70=>nil}, 70, "x:c", false], [{70=>nil, 61=>:occupied, 52=>nil, 43=>:enemy}, 43, "x:c", true], [{70=>nil, 61=>:occupied, 52=>nil, 43=>nil, 34=>:enemy}, 34, "x:c", true], [{70=>nil, 61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{70=>nil, 61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{70=>nil, 61=>:occupied, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{70=>nil, 61=>:occupied, 52=>:enemy}, 52, "x:c", true], [{70=>nil, 61=>nil}, 61, "x:c", false], [{70=>nil, 61=>nil, 52=>:occupied, 43=>nil, 34=>:enemy}, 34, "x:c", true], [{70=>nil, 61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{70=>nil, 61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{70=>nil, 61=>nil, 52=>:occupied, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{70=>nil, 61=>nil, 52=>:occupied, 43=>:enemy}, 43, "x:c", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "x:c", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>:enemy}, 25, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>:occupied, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>:occupied, 34=>:enemy}, 34, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "x:c", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>:enemy}, 16, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:occupied, 25=>:enemy}, 25, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "x:c", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>nil, 7=>:enemy}, 7, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:occupied, 16=>:enemy}, 16, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "x:c", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:occupied, 7=>:enemy}, 7, "x:c", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "x:c", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:c", false], [{78=>nil}, 78, "x:c", false], [{78=>nil, 77=>:occupied, 76=>nil, 75=>:enemy}, 75, "x:c", true], [{78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{78=>nil, 77=>:occupied, 76=>:enemy}, 76, "x:c", true], [{78=>nil, 77=>nil}, 77, "x:c", false], [{78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{78=>nil, 77=>nil, 76=>:occupied, 75=>:enemy}, 75, "x:c", true], [{78=>nil, 77=>nil, 76=>nil}, 76, "x:c", false], [{78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>:enemy}, 74, "x:c", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "x:c", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>:enemy}, 73, "x:c", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "x:c", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "x:c", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "x:c", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:c", false], [{80=>nil}, 80, "x:c", false]], 80=>[[{71=>:occupied, 62=>nil, 53=>:enemy}, 53, "x:c", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>:enemy}, 44, "x:c", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "x:c", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{71=>:occupied, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{71=>:occupied, 62=>:enemy}, 62, "x:c", true], [{79=>:occupied, 78=>nil, 77=>:enemy}, 77, "x:c", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>:enemy}, 76, "x:c", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "x:c", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{79=>:occupied, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{79=>:occupied, 78=>:enemy}, 78, "x:c", true], [{71=>nil}, 71, "x:c", false], [{71=>nil, 62=>:occupied, 53=>nil, 44=>:enemy}, 44, "x:c", true], [{71=>nil, 62=>:occupied, 53=>nil, 44=>nil, 35=>:enemy}, 35, "x:c", true], [{71=>nil, 62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{71=>nil, 62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{71=>nil, 62=>:occupied, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{71=>nil, 62=>:occupied, 53=>:enemy}, 53, "x:c", true], [{71=>nil, 62=>nil}, 62, "x:c", false], [{71=>nil, 62=>nil, 53=>:occupied, 44=>nil, 35=>:enemy}, 35, "x:c", true], [{71=>nil, 62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{71=>nil, 62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{71=>nil, 62=>nil, 53=>:occupied, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{71=>nil, 62=>nil, 53=>:occupied, 44=>:enemy}, 44, "x:c", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "x:c", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>:enemy}, 26, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>:occupied, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>:occupied, 35=>:enemy}, 35, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "x:c", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>:enemy}, 17, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:occupied, 26=>:enemy}, 26, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "x:c", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>nil, 8=>:enemy}, 8, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:occupied, 17=>:enemy}, 17, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "x:c", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:occupied, 8=>:enemy}, 8, "x:c", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "x:c", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:c", false], [{79=>nil}, 79, "x:c", false], [{79=>nil, 78=>:occupied, 77=>nil, 76=>:enemy}, 76, "x:c", true], [{79=>nil, 78=>:occupied, 77=>nil, 76=>nil, 75=>:enemy}, 75, "x:c", true], [{79=>nil, 78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{79=>nil, 78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{79=>nil, 78=>:occupied, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{79=>nil, 78=>:occupied, 77=>:enemy}, 77, "x:c", true], [{79=>nil, 78=>nil}, 78, "x:c", false], [{79=>nil, 78=>nil, 77=>:occupied, 76=>nil, 75=>:enemy}, 75, "x:c", true], [{79=>nil, 78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{79=>nil, 78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{79=>nil, 78=>nil, 77=>:occupied, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{79=>nil, 78=>nil, 77=>:occupied, 76=>:enemy}, 76, "x:c", true], [{79=>nil, 78=>nil, 77=>nil}, 77, "x:c", false], [{79=>nil, 78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>:enemy}, 74, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>:occupied, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>:occupied, 75=>:enemy}, 75, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil}, 76, "x:c", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>:enemy}, 73, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:occupied, 74=>:enemy}, 74, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "x:c", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>nil, 72=>:enemy}, 72, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:occupied, 73=>:enemy}, 73, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "x:c", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:occupied, 72=>:enemy}, 72, "x:c", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "x:c", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:c", false]], nil=>[[{0=>nil}, 0, "x:c", false], [{1=>nil}, 1, "x:c", false], [{2=>nil}, 2, "x:c", false], [{3=>nil}, 3, "x:c", false], [{4=>nil}, 4, "x:c", false], [{5=>nil}, 5, "x:c", false], [{6=>nil}, 6, "x:c", false], [{7=>nil}, 7, "x:c", false], [{8=>nil}, 8, "x:c", false], [{9=>nil}, 9, "x:c", false], [{10=>nil}, 10, "x:c", false], [{11=>nil}, 11, "x:c", false], [{12=>nil}, 12, "x:c", false], [{13=>nil}, 13, "x:c", false], [{14=>nil}, 14, "x:c", false], [{15=>nil}, 15, "x:c", false], [{16=>nil}, 16, "x:c", false], [{17=>nil}, 17, "x:c", false], [{18=>nil}, 18, "x:c", false], [{19=>nil}, 19, "x:c", false], [{20=>nil}, 20, "x:c", false], [{21=>nil}, 21, "x:c", false], [{22=>nil}, 22, "x:c", false], [{23=>nil}, 23, "x:c", false], [{24=>nil}, 24, "x:c", false], [{25=>nil}, 25, "x:c", false], [{26=>nil}, 26, "x:c", false], [{27=>nil}, 27, "x:c", false], [{28=>nil}, 28, "x:c", false], [{29=>nil}, 29, "x:c", false], [{30=>nil}, 30, "x:c", false], [{31=>nil}, 31, "x:c", false], [{32=>nil}, 32, "x:c", false], [{33=>nil}, 33, "x:c", false], [{34=>nil}, 34, "x:c", false], [{35=>nil}, 35, "x:c", false], [{36=>nil}, 36, "x:c", false], [{37=>nil}, 37, "x:c", false], [{38=>nil}, 38, "x:c", false], [{39=>nil}, 39, "x:c", false], [{40=>nil}, 40, "x:c", false], [{41=>nil}, 41, "x:c", false], [{42=>nil}, 42, "x:c", false], [{43=>nil}, 43, "x:c", false], [{44=>nil}, 44, "x:c", false], [{45=>nil}, 45, "x:c", false], [{46=>nil}, 46, "x:c", false], [{47=>nil}, 47, "x:c", false], [{48=>nil}, 48, "x:c", false], [{49=>nil}, 49, "x:c", false], [{50=>nil}, 50, "x:c", false], [{51=>nil}, 51, "x:c", false], [{52=>nil}, 52, "x:c", false], [{53=>nil}, 53, "x:c", false], [{54=>nil}, 54, "x:c", false], [{55=>nil}, 55, "x:c", false], [{56=>nil}, 56, "x:c", false], [{57=>nil}, 57, "x:c", false], [{58=>nil}, 58, "x:c", false], [{59=>nil}, 59, "x:c", false], [{60=>nil}, 60, "x:c", false], [{61=>nil}, 61, "x:c", false], [{62=>nil}, 62, "x:c", false], [{63=>nil}, 63, "x:c", false], [{64=>nil}, 64, "x:c", false], [{65=>nil}, 65, "x:c", false], [{66=>nil}, 66, "x:c", false], [{67=>nil}, 67, "x:c", false], [{68=>nil}, 68, "x:c", false], [{69=>nil}, 69, "x:c", false], [{70=>nil}, 70, "x:c", false], [{71=>nil}, 71, "x:c", false], [{72=>nil}, 72, "x:c", false], [{73=>nil}, 73, "x:c", false], [{74=>nil}, 74, "x:c", false], [{75=>nil}, 75, "x:c", false], [{76=>nil}, 76, "x:c", false], [{77=>nil}, 77, "x:c", false], [{78=>nil}, 78, "x:c", false], [{79=>nil}, 79, "x:c", false], [{80=>nil}, 80, "x:c", false]]}, "x:e"=>{0=>[[{10=>nil, 20=>:enemy}, 20, "x:e", true], [{10=>nil, 20=>nil}, 20, "x:e", false]], 1=>[[{11=>nil, 21=>:enemy}, 21, "x:e", true], [{11=>nil, 21=>nil}, 21, "x:e", false]], 2=>[[{10=>nil, 18=>:enemy}, 18, "x:e", true], [{10=>nil, 18=>nil}, 18, "x:e", false], [{12=>nil, 22=>:enemy}, 22, "x:e", true], [{12=>nil, 22=>nil}, 22, "x:e", false]], 3=>[[{11=>nil, 19=>:enemy}, 19, "x:e", true], [{11=>nil, 19=>nil}, 19, "x:e", false], [{13=>nil, 23=>:enemy}, 23, "x:e", true], [{13=>nil, 23=>nil}, 23, "x:e", false]], 4=>[[{12=>nil, 20=>:enemy}, 20, "x:e", true], [{12=>nil, 20=>nil}, 20, "x:e", false], [{14=>nil, 24=>:enemy}, 24, "x:e", true], [{14=>nil, 24=>nil}, 24, "x:e", false]], 5=>[[{13=>nil, 21=>:enemy}, 21, "x:e", true], [{13=>nil, 21=>nil}, 21, "x:e", false], [{15=>nil, 25=>:enemy}, 25, "x:e", true], [{15=>nil, 25=>nil}, 25, "x:e", false]], 6=>[[{14=>nil, 22=>:enemy}, 22, "x:e", true], [{14=>nil, 22=>nil}, 22, "x:e", false], [{16=>nil, 26=>:enemy}, 26, "x:e", true], [{16=>nil, 26=>nil}, 26, "x:e", false]], 7=>[[{15=>nil, 23=>:enemy}, 23, "x:e", true], [{15=>nil, 23=>nil}, 23, "x:e", false]], 8=>[[{16=>nil, 24=>:enemy}, 24, "x:e", true], [{16=>nil, 24=>nil}, 24, "x:e", false]], 9=>[[{19=>nil, 29=>:enemy}, 29, "x:e", true], [{19=>nil, 29=>nil}, 29, "x:e", false]], 10=>[[{20=>nil, 30=>:enemy}, 30, "x:e", true], [{20=>nil, 30=>nil}, 30, "x:e", false]], 11=>[[{19=>nil, 27=>:enemy}, 27, "x:e", true], [{19=>nil, 27=>nil}, 27, "x:e", false], [{21=>nil, 31=>:enemy}, 31, "x:e", true], [{21=>nil, 31=>nil}, 31, "x:e", false]], 12=>[[{20=>nil, 28=>:enemy}, 28, "x:e", true], [{20=>nil, 28=>nil}, 28, "x:e", false], [{22=>nil, 32=>:enemy}, 32, "x:e", true], [{22=>nil, 32=>nil}, 32, "x:e", false]], 13=>[[{21=>nil, 29=>:enemy}, 29, "x:e", true], [{21=>nil, 29=>nil}, 29, "x:e", false], [{23=>nil, 33=>:enemy}, 33, "x:e", true], [{23=>nil, 33=>nil}, 33, "x:e", false]], 14=>[[{22=>nil, 30=>:enemy}, 30, "x:e", true], [{22=>nil, 30=>nil}, 30, "x:e", false], [{24=>nil, 34=>:enemy}, 34, "x:e", true], [{24=>nil, 34=>nil}, 34, "x:e", false]], 15=>[[{23=>nil, 31=>:enemy}, 31, "x:e", true], [{23=>nil, 31=>nil}, 31, "x:e", false], [{25=>nil, 35=>:enemy}, 35, "x:e", true], [{25=>nil, 35=>nil}, 35, "x:e", false]], 16=>[[{24=>nil, 32=>:enemy}, 32, "x:e", true], [{24=>nil, 32=>nil}, 32, "x:e", false]], 17=>[[{25=>nil, 33=>:enemy}, 33, "x:e", true], [{25=>nil, 33=>nil}, 33, "x:e", false]], 18=>[[{10=>nil, 2=>:enemy}, 2, "x:e", true], [{10=>nil, 2=>nil}, 2, "x:e", false], [{28=>nil, 38=>:enemy}, 38, "x:e", true], [{28=>nil, 38=>nil}, 38, "x:e", false]], 19=>[[{11=>nil, 3=>:enemy}, 3, "x:e", true], [{11=>nil, 3=>nil}, 3, "x:e", false], [{29=>nil, 39=>:enemy}, 39, "x:e", true], [{29=>nil, 39=>nil}, 39, "x:e", false]], 20=>[[{10=>nil, 0=>:enemy}, 0, "x:e", true], [{10=>nil, 0=>nil}, 0, "x:e", false], [{12=>nil, 4=>:enemy}, 4, "x:e", true], [{12=>nil, 4=>nil}, 4, "x:e", false], [{28=>nil, 36=>:enemy}, 36, "x:e", true], [{28=>nil, 36=>nil}, 36, "x:e", false], [{30=>nil, 40=>:enemy}, 40, "x:e", true], [{30=>nil, 40=>nil}, 40, "x:e", false]], 21=>[[{11=>nil, 1=>:enemy}, 1, "x:e", true], [{11=>nil, 1=>nil}, 1, "x:e", false], [{13=>nil, 5=>:enemy}, 5, "x:e", true], [{13=>nil, 5=>nil}, 5, "x:e", false], [{29=>nil, 37=>:enemy}, 37, "x:e", true], [{29=>nil, 37=>nil}, 37, "x:e", false], [{31=>nil, 41=>:enemy}, 41, "x:e", true], [{31=>nil, 41=>nil}, 41, "x:e", false]], 22=>[[{12=>nil, 2=>:enemy}, 2, "x:e", true], [{12=>nil, 2=>nil}, 2, "x:e", false], [{14=>nil, 6=>:enemy}, 6, "x:e", true], [{14=>nil, 6=>nil}, 6, "x:e", false], [{30=>nil, 38=>:enemy}, 38, "x:e", true], [{30=>nil, 38=>nil}, 38, "x:e", false], [{32=>nil, 42=>:enemy}, 42, "x:e", true], [{32=>nil, 42=>nil}, 42, "x:e", false]], 23=>[[{13=>nil, 3=>:enemy}, 3, "x:e", true], [{13=>nil, 3=>nil}, 3, "x:e", false], [{15=>nil, 7=>:enemy}, 7, "x:e", true], [{15=>nil, 7=>nil}, 7, "x:e", false], [{31=>nil, 39=>:enemy}, 39, "x:e", true], [{31=>nil, 39=>nil}, 39, "x:e", false], [{33=>nil, 43=>:enemy}, 43, "x:e", true], [{33=>nil, 43=>nil}, 43, "x:e", false]], 24=>[[{14=>nil, 4=>:enemy}, 4, "x:e", true], [{14=>nil, 4=>nil}, 4, "x:e", false], [{16=>nil, 8=>:enemy}, 8, "x:e", true], [{16=>nil, 8=>nil}, 8, "x:e", false], [{32=>nil, 40=>:enemy}, 40, "x:e", true], [{32=>nil, 40=>nil}, 40, "x:e", false], [{34=>nil, 44=>:enemy}, 44, "x:e", true], [{34=>nil, 44=>nil}, 44, "x:e", false]], 25=>[[{15=>nil, 5=>:enemy}, 5, "x:e", true], [{15=>nil, 5=>nil}, 5, "x:e", false], [{33=>nil, 41=>:enemy}, 41, "x:e", true], [{33=>nil, 41=>nil}, 41, "x:e", false]], 26=>[[{16=>nil, 6=>:enemy}, 6, "x:e", true], [{16=>nil, 6=>nil}, 6, "x:e", false], [{34=>nil, 42=>:enemy}, 42, "x:e", true], [{34=>nil, 42=>nil}, 42, "x:e", false]], 27=>[[{19=>nil, 11=>:enemy}, 11, "x:e", true], [{19=>nil, 11=>nil}, 11, "x:e", false], [{37=>nil, 47=>:enemy}, 47, "x:e", true], [{37=>nil, 47=>nil}, 47, "x:e", false]], 28=>[[{20=>nil, 12=>:enemy}, 12, "x:e", true], [{20=>nil, 12=>nil}, 12, "x:e", false], [{38=>nil, 48=>:enemy}, 48, "x:e", true], [{38=>nil, 48=>nil}, 48, "x:e", false]], 29=>[[{19=>nil, 9=>:enemy}, 9, "x:e", true], [{19=>nil, 9=>nil}, 9, "x:e", false], [{21=>nil, 13=>:enemy}, 13, "x:e", true], [{21=>nil, 13=>nil}, 13, "x:e", false], [{37=>nil, 45=>:enemy}, 45, "x:e", true], [{37=>nil, 45=>nil}, 45, "x:e", false], [{39=>nil, 49=>:enemy}, 49, "x:e", true], [{39=>nil, 49=>nil}, 49, "x:e", false]], 30=>[[{20=>nil, 10=>:enemy}, 10, "x:e", true], [{20=>nil, 10=>nil}, 10, "x:e", false], [{22=>nil, 14=>:enemy}, 14, "x:e", true], [{22=>nil, 14=>nil}, 14, "x:e", false], [{38=>nil, 46=>:enemy}, 46, "x:e", true], [{38=>nil, 46=>nil}, 46, "x:e", false], [{40=>nil, 50=>:enemy}, 50, "x:e", true], [{40=>nil, 50=>nil}, 50, "x:e", false]], 31=>[[{21=>nil, 11=>:enemy}, 11, "x:e", true], [{21=>nil, 11=>nil}, 11, "x:e", false], [{23=>nil, 15=>:enemy}, 15, "x:e", true], [{23=>nil, 15=>nil}, 15, "x:e", false], [{39=>nil, 47=>:enemy}, 47, "x:e", true], [{39=>nil, 47=>nil}, 47, "x:e", false], [{41=>nil, 51=>:enemy}, 51, "x:e", true], [{41=>nil, 51=>nil}, 51, "x:e", false]], 32=>[[{22=>nil, 12=>:enemy}, 12, "x:e", true], [{22=>nil, 12=>nil}, 12, "x:e", false], [{24=>nil, 16=>:enemy}, 16, "x:e", true], [{24=>nil, 16=>nil}, 16, "x:e", false], [{40=>nil, 48=>:enemy}, 48, "x:e", true], [{40=>nil, 48=>nil}, 48, "x:e", false], [{42=>nil, 52=>:enemy}, 52, "x:e", true], [{42=>nil, 52=>nil}, 52, "x:e", false]], 33=>[[{23=>nil, 13=>:enemy}, 13, "x:e", true], [{23=>nil, 13=>nil}, 13, "x:e", false], [{25=>nil, 17=>:enemy}, 17, "x:e", true], [{25=>nil, 17=>nil}, 17, "x:e", false], [{41=>nil, 49=>:enemy}, 49, "x:e", true], [{41=>nil, 49=>nil}, 49, "x:e", false], [{43=>nil, 53=>:enemy}, 53, "x:e", true], [{43=>nil, 53=>nil}, 53, "x:e", false]], 34=>[[{24=>nil, 14=>:enemy}, 14, "x:e", true], [{24=>nil, 14=>nil}, 14, "x:e", false], [{42=>nil, 50=>:enemy}, 50, "x:e", true], [{42=>nil, 50=>nil}, 50, "x:e", false]], 35=>[[{25=>nil, 15=>:enemy}, 15, "x:e", true], [{25=>nil, 15=>nil}, 15, "x:e", false], [{43=>nil, 51=>:enemy}, 51, "x:e", true], [{43=>nil, 51=>nil}, 51, "x:e", false]], 36=>[[{28=>nil, 20=>:enemy}, 20, "x:e", true], [{28=>nil, 20=>nil}, 20, "x:e", false], [{46=>nil, 56=>:enemy}, 56, "x:e", true], [{46=>nil, 56=>nil}, 56, "x:e", false]], 37=>[[{29=>nil, 21=>:enemy}, 21, "x:e", true], [{29=>nil, 21=>nil}, 21, "x:e", false], [{47=>nil, 57=>:enemy}, 57, "x:e", true], [{47=>nil, 57=>nil}, 57, "x:e", false]], 38=>[[{28=>nil, 18=>:enemy}, 18, "x:e", true], [{28=>nil, 18=>nil}, 18, "x:e", false], [{30=>nil, 22=>:enemy}, 22, "x:e", true], [{30=>nil, 22=>nil}, 22, "x:e", false], [{46=>nil, 54=>:enemy}, 54, "x:e", true], [{46=>nil, 54=>nil}, 54, "x:e", false], [{48=>nil, 58=>:enemy}, 58, "x:e", true], [{48=>nil, 58=>nil}, 58, "x:e", false]], 39=>[[{29=>nil, 19=>:enemy}, 19, "x:e", true], [{29=>nil, 19=>nil}, 19, "x:e", false], [{31=>nil, 23=>:enemy}, 23, "x:e", true], [{31=>nil, 23=>nil}, 23, "x:e", false], [{47=>nil, 55=>:enemy}, 55, "x:e", true], [{47=>nil, 55=>nil}, 55, "x:e", false], [{49=>nil, 59=>:enemy}, 59, "x:e", true], [{49=>nil, 59=>nil}, 59, "x:e", false]], 40=>[[{30=>nil, 20=>:enemy}, 20, "x:e", true], [{30=>nil, 20=>nil}, 20, "x:e", false], [{32=>nil, 24=>:enemy}, 24, "x:e", true], [{32=>nil, 24=>nil}, 24, "x:e", false], [{48=>nil, 56=>:enemy}, 56, "x:e", true], [{48=>nil, 56=>nil}, 56, "x:e", false], [{50=>nil, 60=>:enemy}, 60, "x:e", true], [{50=>nil, 60=>nil}, 60, "x:e", false]], 41=>[[{31=>nil, 21=>:enemy}, 21, "x:e", true], [{31=>nil, 21=>nil}, 21, "x:e", false], [{33=>nil, 25=>:enemy}, 25, "x:e", true], [{33=>nil, 25=>nil}, 25, "x:e", false], [{49=>nil, 57=>:enemy}, 57, "x:e", true], [{49=>nil, 57=>nil}, 57, "x:e", false], [{51=>nil, 61=>:enemy}, 61, "x:e", true], [{51=>nil, 61=>nil}, 61, "x:e", false]], 42=>[[{32=>nil, 22=>:enemy}, 22, "x:e", true], [{32=>nil, 22=>nil}, 22, "x:e", false], [{34=>nil, 26=>:enemy}, 26, "x:e", true], [{34=>nil, 26=>nil}, 26, "x:e", false], [{50=>nil, 58=>:enemy}, 58, "x:e", true], [{50=>nil, 58=>nil}, 58, "x:e", false], [{52=>nil, 62=>:enemy}, 62, "x:e", true], [{52=>nil, 62=>nil}, 62, "x:e", false]], 43=>[[{33=>nil, 23=>:enemy}, 23, "x:e", true], [{33=>nil, 23=>nil}, 23, "x:e", false], [{51=>nil, 59=>:enemy}, 59, "x:e", true], [{51=>nil, 59=>nil}, 59, "x:e", false]], 44=>[[{34=>nil, 24=>:enemy}, 24, "x:e", true], [{34=>nil, 24=>nil}, 24, "x:e", false], [{52=>nil, 60=>:enemy}, 60, "x:e", true], [{52=>nil, 60=>nil}, 60, "x:e", false]], 45=>[[{37=>nil, 29=>:enemy}, 29, "x:e", true], [{37=>nil, 29=>nil}, 29, "x:e", false], [{55=>nil, 65=>:enemy}, 65, "x:e", true], [{55=>nil, 65=>nil}, 65, "x:e", false]], 46=>[[{38=>nil, 30=>:enemy}, 30, "x:e", true], [{38=>nil, 30=>nil}, 30, "x:e", false], [{56=>nil, 66=>:enemy}, 66, "x:e", true], [{56=>nil, 66=>nil}, 66, "x:e", false]], 47=>[[{37=>nil, 27=>:enemy}, 27, "x:e", true], [{37=>nil, 27=>nil}, 27, "x:e", false], [{39=>nil, 31=>:enemy}, 31, "x:e", true], [{39=>nil, 31=>nil}, 31, "x:e", false], [{55=>nil, 63=>:enemy}, 63, "x:e", true], [{55=>nil, 63=>nil}, 63, "x:e", false], [{57=>nil, 67=>:enemy}, 67, "x:e", true], [{57=>nil, 67=>nil}, 67, "x:e", false]], 48=>[[{38=>nil, 28=>:enemy}, 28, "x:e", true], [{38=>nil, 28=>nil}, 28, "x:e", false], [{40=>nil, 32=>:enemy}, 32, "x:e", true], [{40=>nil, 32=>nil}, 32, "x:e", false], [{56=>nil, 64=>:enemy}, 64, "x:e", true], [{56=>nil, 64=>nil}, 64, "x:e", false], [{58=>nil, 68=>:enemy}, 68, "x:e", true], [{58=>nil, 68=>nil}, 68, "x:e", false]], 49=>[[{39=>nil, 29=>:enemy}, 29, "x:e", true], [{39=>nil, 29=>nil}, 29, "x:e", false], [{41=>nil, 33=>:enemy}, 33, "x:e", true], [{41=>nil, 33=>nil}, 33, "x:e", false], [{57=>nil, 65=>:enemy}, 65, "x:e", true], [{57=>nil, 65=>nil}, 65, "x:e", false], [{59=>nil, 69=>:enemy}, 69, "x:e", true], [{59=>nil, 69=>nil}, 69, "x:e", false]], 50=>[[{40=>nil, 30=>:enemy}, 30, "x:e", true], [{40=>nil, 30=>nil}, 30, "x:e", false], [{42=>nil, 34=>:enemy}, 34, "x:e", true], [{42=>nil, 34=>nil}, 34, "x:e", false], [{58=>nil, 66=>:enemy}, 66, "x:e", true], [{58=>nil, 66=>nil}, 66, "x:e", false], [{60=>nil, 70=>:enemy}, 70, "x:e", true], [{60=>nil, 70=>nil}, 70, "x:e", false]], 51=>[[{41=>nil, 31=>:enemy}, 31, "x:e", true], [{41=>nil, 31=>nil}, 31, "x:e", false], [{43=>nil, 35=>:enemy}, 35, "x:e", true], [{43=>nil, 35=>nil}, 35, "x:e", false], [{59=>nil, 67=>:enemy}, 67, "x:e", true], [{59=>nil, 67=>nil}, 67, "x:e", false], [{61=>nil, 71=>:enemy}, 71, "x:e", true], [{61=>nil, 71=>nil}, 71, "x:e", false]], 52=>[[{42=>nil, 32=>:enemy}, 32, "x:e", true], [{42=>nil, 32=>nil}, 32, "x:e", false], [{60=>nil, 68=>:enemy}, 68, "x:e", true], [{60=>nil, 68=>nil}, 68, "x:e", false]], 53=>[[{43=>nil, 33=>:enemy}, 33, "x:e", true], [{43=>nil, 33=>nil}, 33, "x:e", false], [{61=>nil, 69=>:enemy}, 69, "x:e", true], [{61=>nil, 69=>nil}, 69, "x:e", false]], 54=>[[{46=>nil, 38=>:enemy}, 38, "x:e", true], [{46=>nil, 38=>nil}, 38, "x:e", false], [{64=>nil, 74=>:enemy}, 74, "x:e", true], [{64=>nil, 74=>nil}, 74, "x:e", false]], 55=>[[{47=>nil, 39=>:enemy}, 39, "x:e", true], [{47=>nil, 39=>nil}, 39, "x:e", false], [{65=>nil, 75=>:enemy}, 75, "x:e", true], [{65=>nil, 75=>nil}, 75, "x:e", false]], 56=>[[{46=>nil, 36=>:enemy}, 36, "x:e", true], [{46=>nil, 36=>nil}, 36, "x:e", false], [{48=>nil, 40=>:enemy}, 40, "x:e", true], [{48=>nil, 40=>nil}, 40, "x:e", false], [{64=>nil, 72=>:enemy}, 72, "x:e", true], [{64=>nil, 72=>nil}, 72, "x:e", false], [{66=>nil, 76=>:enemy}, 76, "x:e", true], [{66=>nil, 76=>nil}, 76, "x:e", false]], 57=>[[{47=>nil, 37=>:enemy}, 37, "x:e", true], [{47=>nil, 37=>nil}, 37, "x:e", false], [{49=>nil, 41=>:enemy}, 41, "x:e", true], [{49=>nil, 41=>nil}, 41, "x:e", false], [{65=>nil, 73=>:enemy}, 73, "x:e", true], [{65=>nil, 73=>nil}, 73, "x:e", false], [{67=>nil, 77=>:enemy}, 77, "x:e", true], [{67=>nil, 77=>nil}, 77, "x:e", false]], 58=>[[{48=>nil, 38=>:enemy}, 38, "x:e", true], [{48=>nil, 38=>nil}, 38, "x:e", false], [{50=>nil, 42=>:enemy}, 42, "x:e", true], [{50=>nil, 42=>nil}, 42, "x:e", false], [{66=>nil, 74=>:enemy}, 74, "x:e", true], [{66=>nil, 74=>nil}, 74, "x:e", false], [{68=>nil, 78=>:enemy}, 78, "x:e", true], [{68=>nil, 78=>nil}, 78, "x:e", false]], 59=>[[{49=>nil, 39=>:enemy}, 39, "x:e", true], [{49=>nil, 39=>nil}, 39, "x:e", false], [{51=>nil, 43=>:enemy}, 43, "x:e", true], [{51=>nil, 43=>nil}, 43, "x:e", false], [{67=>nil, 75=>:enemy}, 75, "x:e", true], [{67=>nil, 75=>nil}, 75, "x:e", false], [{69=>nil, 79=>:enemy}, 79, "x:e", true], [{69=>nil, 79=>nil}, 79, "x:e", false]], 60=>[[{50=>nil, 40=>:enemy}, 40, "x:e", true], [{50=>nil, 40=>nil}, 40, "x:e", false], [{52=>nil, 44=>:enemy}, 44, "x:e", true], [{52=>nil, 44=>nil}, 44, "x:e", false], [{68=>nil, 76=>:enemy}, 76, "x:e", true], [{68=>nil, 76=>nil}, 76, "x:e", false], [{70=>nil, 80=>:enemy}, 80, "x:e", true], [{70=>nil, 80=>nil}, 80, "x:e", false]], 61=>[[{51=>nil, 41=>:enemy}, 41, "x:e", true], [{51=>nil, 41=>nil}, 41, "x:e", false], [{69=>nil, 77=>:enemy}, 77, "x:e", true], [{69=>nil, 77=>nil}, 77, "x:e", false]], 62=>[[{52=>nil, 42=>:enemy}, 42, "x:e", true], [{52=>nil, 42=>nil}, 42, "x:e", false], [{70=>nil, 78=>:enemy}, 78, "x:e", true], [{70=>nil, 78=>nil}, 78, "x:e", false]], 63=>[[{55=>nil, 47=>:enemy}, 47, "x:e", true], [{55=>nil, 47=>nil}, 47, "x:e", false]], 64=>[[{56=>nil, 48=>:enemy}, 48, "x:e", true], [{56=>nil, 48=>nil}, 48, "x:e", false]], 65=>[[{55=>nil, 45=>:enemy}, 45, "x:e", true], [{55=>nil, 45=>nil}, 45, "x:e", false], [{57=>nil, 49=>:enemy}, 49, "x:e", true], [{57=>nil, 49=>nil}, 49, "x:e", false]], 66=>[[{56=>nil, 46=>:enemy}, 46, "x:e", true], [{56=>nil, 46=>nil}, 46, "x:e", false], [{58=>nil, 50=>:enemy}, 50, "x:e", true], [{58=>nil, 50=>nil}, 50, "x:e", false]], 67=>[[{57=>nil, 47=>:enemy}, 47, "x:e", true], [{57=>nil, 47=>nil}, 47, "x:e", false], [{59=>nil, 51=>:enemy}, 51, "x:e", true], [{59=>nil, 51=>nil}, 51, "x:e", false]], 68=>[[{58=>nil, 48=>:enemy}, 48, "x:e", true], [{58=>nil, 48=>nil}, 48, "x:e", false], [{60=>nil, 52=>:enemy}, 52, "x:e", true], [{60=>nil, 52=>nil}, 52, "x:e", false]], 69=>[[{59=>nil, 49=>:enemy}, 49, "x:e", true], [{59=>nil, 49=>nil}, 49, "x:e", false], [{61=>nil, 53=>:enemy}, 53, "x:e", true], [{61=>nil, 53=>nil}, 53, "x:e", false]], 70=>[[{60=>nil, 50=>:enemy}, 50, "x:e", true], [{60=>nil, 50=>nil}, 50, "x:e", false]], 71=>[[{61=>nil, 51=>:enemy}, 51, "x:e", true], [{61=>nil, 51=>nil}, 51, "x:e", false]], 72=>[[{64=>nil, 56=>:enemy}, 56, "x:e", true], [{64=>nil, 56=>nil}, 56, "x:e", false]], 73=>[[{65=>nil, 57=>:enemy}, 57, "x:e", true], [{65=>nil, 57=>nil}, 57, "x:e", false]], 74=>[[{64=>nil, 54=>:enemy}, 54, "x:e", true], [{64=>nil, 54=>nil}, 54, "x:e", false], [{66=>nil, 58=>:enemy}, 58, "x:e", true], [{66=>nil, 58=>nil}, 58, "x:e", false]], 75=>[[{65=>nil, 55=>:enemy}, 55, "x:e", true], [{65=>nil, 55=>nil}, 55, "x:e", false], [{67=>nil, 59=>:enemy}, 59, "x:e", true], [{67=>nil, 59=>nil}, 59, "x:e", false]], 76=>[[{66=>nil, 56=>:enemy}, 56, "x:e", true], [{66=>nil, 56=>nil}, 56, "x:e", false], [{68=>nil, 60=>:enemy}, 60, "x:e", true], [{68=>nil, 60=>nil}, 60, "x:e", false]], 77=>[[{67=>nil, 57=>:enemy}, 57, "x:e", true], [{67=>nil, 57=>nil}, 57, "x:e", false], [{69=>nil, 61=>:enemy}, 61, "x:e", true], [{69=>nil, 61=>nil}, 61, "x:e", false]], 78=>[[{68=>nil, 58=>:enemy}, 58, "x:e", true], [{68=>nil, 58=>nil}, 58, "x:e", false], [{70=>nil, 62=>:enemy}, 62, "x:e", true], [{70=>nil, 62=>nil}, 62, "x:e", false]], 79=>[[{69=>nil, 59=>:enemy}, 59, "x:e", true], [{69=>nil, 59=>nil}, 59, "x:e", false]], 80=>[[{70=>nil, 60=>:enemy}, 60, "x:e", true], [{70=>nil, 60=>nil}, 60, "x:e", false]], nil=>[[{0=>nil}, 0, "x:e", false], [{1=>nil}, 1, "x:e", false], [{2=>nil}, 2, "x:e", false], [{3=>nil}, 3, "x:e", false], [{4=>nil}, 4, "x:e", false], [{5=>nil}, 5, "x:e", false], [{6=>nil}, 6, "x:e", false], [{7=>nil}, 7, "x:e", false], [{8=>nil}, 8, "x:e", false], [{9=>nil}, 9, "x:e", false], [{10=>nil}, 10, "x:e", false], [{11=>nil}, 11, "x:e", false], [{12=>nil}, 12, "x:e", false], [{13=>nil}, 13, "x:e", false], [{14=>nil}, 14, "x:e", false], [{15=>nil}, 15, "x:e", false], [{16=>nil}, 16, "x:e", false], [{17=>nil}, 17, "x:e", false], [{18=>nil}, 18, "x:e", false], [{19=>nil}, 19, "x:e", false], [{20=>nil}, 20, "x:e", false], [{21=>nil}, 21, "x:e", false], [{22=>nil}, 22, "x:e", false], [{23=>nil}, 23, "x:e", false], [{24=>nil}, 24, "x:e", false], [{25=>nil}, 25, "x:e", false], [{26=>nil}, 26, "x:e", false], [{27=>nil}, 27, "x:e", false], [{28=>nil}, 28, "x:e", false], [{29=>nil}, 29, "x:e", false], [{30=>nil}, 30, "x:e", false], [{31=>nil}, 31, "x:e", false], [{32=>nil}, 32, "x:e", false], [{33=>nil}, 33, "x:e", false], [{34=>nil}, 34, "x:e", false], [{35=>nil}, 35, "x:e", false], [{36=>nil}, 36, "x:e", false], [{37=>nil}, 37, "x:e", false], [{38=>nil}, 38, "x:e", false], [{39=>nil}, 39, "x:e", false], [{40=>nil}, 40, "x:e", false], [{41=>nil}, 41, "x:e", false], [{42=>nil}, 42, "x:e", false], [{43=>nil}, 43, "x:e", false], [{44=>nil}, 44, "x:e", false], [{45=>nil}, 45, "x:e", false], [{46=>nil}, 46, "x:e", false], [{47=>nil}, 47, "x:e", false], [{48=>nil}, 48, "x:e", false], [{49=>nil}, 49, "x:e", false], [{50=>nil}, 50, "x:e", false], [{51=>nil}, 51, "x:e", false], [{52=>nil}, 52, "x:e", false], [{53=>nil}, 53, "x:e", false], [{54=>nil}, 54, "x:e", false], [{55=>nil}, 55, "x:e", false], [{56=>nil}, 56, "x:e", false], [{57=>nil}, 57, "x:e", false], [{58=>nil}, 58, "x:e", false], [{59=>nil}, 59, "x:e", false], [{60=>nil}, 60, "x:e", false], [{61=>nil}, 61, "x:e", false], [{62=>nil}, 62, "x:e", false], [{63=>nil}, 63, "x:e", false], [{64=>nil}, 64, "x:e", false], [{65=>nil}, 65, "x:e", false], [{66=>nil}, 66, "x:e", false], [{67=>nil}, 67, "x:e", false], [{68=>nil}, 68, "x:e", false], [{69=>nil}, 69, "x:e", false], [{70=>nil}, 70, "x:e", false], [{71=>nil}, 71, "x:e", false], [{72=>nil}, 72, "x:e", false], [{73=>nil}, 73, "x:e", false], [{74=>nil}, 74, "x:e", false], [{75=>nil}, 75, "x:e", false], [{76=>nil}, 76, "x:e", false], [{77=>nil}, 77, "x:e", false], [{78=>nil}, 78, "x:e", false], [{79=>nil}, 79, "x:e", false], [{80=>nil}, 80, "x:e", false]]}, "x:h"=>{0=>[[{1=>nil, 11=>:enemy}, 11, "x:h", true], [{1=>nil, 11=>nil}, 11, "x:h", false], [{9=>nil, 19=>:enemy}, 19, "x:h", true], [{9=>nil, 19=>nil}, 19, "x:h", false]], 1=>[[{2=>nil, 12=>:enemy}, 12, "x:h", true], [{2=>nil, 12=>nil}, 12, "x:h", false], [{10=>nil, 18=>:enemy}, 18, "x:h", true], [{10=>nil, 20=>:enemy}, 20, "x:h", true], [{10=>nil, 18=>nil}, 18, "x:h", false], [{10=>nil, 20=>nil}, 20, "x:h", false]], 2=>[[{1=>nil, 9=>:enemy}, 9, "x:h", true], [{1=>nil, 9=>nil}, 9, "x:h", false], [{3=>nil, 13=>:enemy}, 13, "x:h", true], [{3=>nil, 13=>nil}, 13, "x:h", false], [{11=>nil, 19=>:enemy}, 19, "x:h", true], [{11=>nil, 21=>:enemy}, 21, "x:h", true], [{11=>nil, 19=>nil}, 19, "x:h", false], [{11=>nil, 21=>nil}, 21, "x:h", false]], 3=>[[{2=>nil, 10=>:enemy}, 10, "x:h", true], [{2=>nil, 10=>nil}, 10, "x:h", false], [{4=>nil, 14=>:enemy}, 14, "x:h", true], [{4=>nil, 14=>nil}, 14, "x:h", false], [{12=>nil, 20=>:enemy}, 20, "x:h", true], [{12=>nil, 22=>:enemy}, 22, "x:h", true], [{12=>nil, 20=>nil}, 20, "x:h", false], [{12=>nil, 22=>nil}, 22, "x:h", false]], 4=>[[{3=>nil, 11=>:enemy}, 11, "x:h", true], [{3=>nil, 11=>nil}, 11, "x:h", false], [{5=>nil, 15=>:enemy}, 15, "x:h", true], [{5=>nil, 15=>nil}, 15, "x:h", false], [{13=>nil, 21=>:enemy}, 21, "x:h", true], [{13=>nil, 23=>:enemy}, 23, "x:h", true], [{13=>nil, 21=>nil}, 21, "x:h", false], [{13=>nil, 23=>nil}, 23, "x:h", false]], 5=>[[{4=>nil, 12=>:enemy}, 12, "x:h", true], [{4=>nil, 12=>nil}, 12, "x:h", false], [{6=>nil, 16=>:enemy}, 16, "x:h", true], [{6=>nil, 16=>nil}, 16, "x:h", false], [{14=>nil, 22=>:enemy}, 22, "x:h", true], [{14=>nil, 24=>:enemy}, 24, "x:h", true], [{14=>nil, 22=>nil}, 22, "x:h", false], [{14=>nil, 24=>nil}, 24, "x:h", false]], 6=>[[{5=>nil, 13=>:enemy}, 13, "x:h", true], [{5=>nil, 13=>nil}, 13, "x:h", false], [{7=>nil, 17=>:enemy}, 17, "x:h", true], [{7=>nil, 17=>nil}, 17, "x:h", false], [{15=>nil, 23=>:enemy}, 23, "x:h", true], [{15=>nil, 25=>:enemy}, 25, "x:h", true], [{15=>nil, 23=>nil}, 23, "x:h", false], [{15=>nil, 25=>nil}, 25, "x:h", false]], 7=>[[{6=>nil, 14=>:enemy}, 14, "x:h", true], [{6=>nil, 14=>nil}, 14, "x:h", false], [{16=>nil, 24=>:enemy}, 24, "x:h", true], [{16=>nil, 26=>:enemy}, 26, "x:h", true], [{16=>nil, 24=>nil}, 24, "x:h", false], [{16=>nil, 26=>nil}, 26, "x:h", false]], 8=>[[{7=>nil, 15=>:enemy}, 15, "x:h", true], [{7=>nil, 15=>nil}, 15, "x:h", false], [{17=>nil, 25=>:enemy}, 25, "x:h", true], [{17=>nil, 25=>nil}, 25, "x:h", false]], 9=>[[{10=>nil, 2=>:enemy}, 2, "x:h", true], [{10=>nil, 20=>:enemy}, 20, "x:h", true], [{10=>nil, 2=>nil}, 2, "x:h", false], [{10=>nil, 20=>nil}, 20, "x:h", false], [{18=>nil, 28=>:enemy}, 28, "x:h", true], [{18=>nil, 28=>nil}, 28, "x:h", false]], 10=>[[{11=>nil, 3=>:enemy}, 3, "x:h", true], [{11=>nil, 21=>:enemy}, 21, "x:h", true], [{11=>nil, 3=>nil}, 3, "x:h", false], [{11=>nil, 21=>nil}, 21, "x:h", false], [{19=>nil, 27=>:enemy}, 27, "x:h", true], [{19=>nil, 29=>:enemy}, 29, "x:h", true], [{19=>nil, 27=>nil}, 27, "x:h", false], [{19=>nil, 29=>nil}, 29, "x:h", false]], 11=>[[{10=>nil, 0=>:enemy}, 0, "x:h", true], [{10=>nil, 18=>:enemy}, 18, "x:h", true], [{10=>nil, 0=>nil}, 0, "x:h", false], [{10=>nil, 18=>nil}, 18, "x:h", false], [{12=>nil, 4=>:enemy}, 4, "x:h", true], [{12=>nil, 22=>:enemy}, 22, "x:h", true], [{12=>nil, 4=>nil}, 4, "x:h", false], [{12=>nil, 22=>nil}, 22, "x:h", false], [{20=>nil, 28=>:enemy}, 28, "x:h", true], [{20=>nil, 30=>:enemy}, 30, "x:h", true], [{20=>nil, 28=>nil}, 28, "x:h", false], [{20=>nil, 30=>nil}, 30, "x:h", false]], 12=>[[{11=>nil, 1=>:enemy}, 1, "x:h", true], [{11=>nil, 19=>:enemy}, 19, "x:h", true], [{11=>nil, 1=>nil}, 1, "x:h", false], [{11=>nil, 19=>nil}, 19, "x:h", false], [{13=>nil, 5=>:enemy}, 5, "x:h", true], [{13=>nil, 23=>:enemy}, 23, "x:h", true], [{13=>nil, 5=>nil}, 5, "x:h", false], [{13=>nil, 23=>nil}, 23, "x:h", false], [{21=>nil, 29=>:enemy}, 29, "x:h", true], [{21=>nil, 31=>:enemy}, 31, "x:h", true], [{21=>nil, 29=>nil}, 29, "x:h", false], [{21=>nil, 31=>nil}, 31, "x:h", false]], 13=>[[{12=>nil, 2=>:enemy}, 2, "x:h", true], [{12=>nil, 20=>:enemy}, 20, "x:h", true], [{12=>nil, 2=>nil}, 2, "x:h", false], [{12=>nil, 20=>nil}, 20, "x:h", false], [{14=>nil, 6=>:enemy}, 6, "x:h", true], [{14=>nil, 24=>:enemy}, 24, "x:h", true], [{14=>nil, 6=>nil}, 6, "x:h", false], [{14=>nil, 24=>nil}, 24, "x:h", false], [{22=>nil, 30=>:enemy}, 30, "x:h", true], [{22=>nil, 32=>:enemy}, 32, "x:h", true], [{22=>nil, 30=>nil}, 30, "x:h", false], [{22=>nil, 32=>nil}, 32, "x:h", false]], 14=>[[{13=>nil, 3=>:enemy}, 3, "x:h", true], [{13=>nil, 21=>:enemy}, 21, "x:h", true], [{13=>nil, 3=>nil}, 3, "x:h", false], [{13=>nil, 21=>nil}, 21, "x:h", false], [{15=>nil, 7=>:enemy}, 7, "x:h", true], [{15=>nil, 25=>:enemy}, 25, "x:h", true], [{15=>nil, 7=>nil}, 7, "x:h", false], [{15=>nil, 25=>nil}, 25, "x:h", false], [{23=>nil, 31=>:enemy}, 31, "x:h", true], [{23=>nil, 33=>:enemy}, 33, "x:h", true], [{23=>nil, 31=>nil}, 31, "x:h", false], [{23=>nil, 33=>nil}, 33, "x:h", false]], 15=>[[{14=>nil, 4=>:enemy}, 4, "x:h", true], [{14=>nil, 22=>:enemy}, 22, "x:h", true], [{14=>nil, 4=>nil}, 4, "x:h", false], [{14=>nil, 22=>nil}, 22, "x:h", false], [{16=>nil, 8=>:enemy}, 8, "x:h", true], [{16=>nil, 26=>:enemy}, 26, "x:h", true], [{16=>nil, 8=>nil}, 8, "x:h", false], [{16=>nil, 26=>nil}, 26, "x:h", false], [{24=>nil, 32=>:enemy}, 32, "x:h", true], [{24=>nil, 34=>:enemy}, 34, "x:h", true], [{24=>nil, 32=>nil}, 32, "x:h", false], [{24=>nil, 34=>nil}, 34, "x:h", false]], 16=>[[{15=>nil, 5=>:enemy}, 5, "x:h", true], [{15=>nil, 23=>:enemy}, 23, "x:h", true], [{15=>nil, 5=>nil}, 5, "x:h", false], [{15=>nil, 23=>nil}, 23, "x:h", false], [{25=>nil, 33=>:enemy}, 33, "x:h", true], [{25=>nil, 35=>:enemy}, 35, "x:h", true], [{25=>nil, 33=>nil}, 33, "x:h", false], [{25=>nil, 35=>nil}, 35, "x:h", false]], 17=>[[{16=>nil, 6=>:enemy}, 6, "x:h", true], [{16=>nil, 24=>:enemy}, 24, "x:h", true], [{16=>nil, 6=>nil}, 6, "x:h", false], [{16=>nil, 24=>nil}, 24, "x:h", false], [{26=>nil, 34=>:enemy}, 34, "x:h", true], [{26=>nil, 34=>nil}, 34, "x:h", false]], 18=>[[{9=>nil, 1=>:enemy}, 1, "x:h", true], [{9=>nil, 1=>nil}, 1, "x:h", false], [{19=>nil, 11=>:enemy}, 11, "x:h", true], [{19=>nil, 29=>:enemy}, 29, "x:h", true], [{19=>nil, 11=>nil}, 11, "x:h", false], [{19=>nil, 29=>nil}, 29, "x:h", false], [{27=>nil, 37=>:enemy}, 37, "x:h", true], [{27=>nil, 37=>nil}, 37, "x:h", false]], 19=>[[{10=>nil, 0=>:enemy}, 0, "x:h", true], [{10=>nil, 2=>:enemy}, 2, "x:h", true], [{10=>nil, 0=>nil}, 0, "x:h", false], [{10=>nil, 2=>nil}, 2, "x:h", false], [{20=>nil, 12=>:enemy}, 12, "x:h", true], [{20=>nil, 30=>:enemy}, 30, "x:h", true], [{20=>nil, 12=>nil}, 12, "x:h", false], [{20=>nil, 30=>nil}, 30, "x:h", false], [{28=>nil, 36=>:enemy}, 36, "x:h", true], [{28=>nil, 38=>:enemy}, 38, "x:h", true], [{28=>nil, 36=>nil}, 36, "x:h", false], [{28=>nil, 38=>nil}, 38, "x:h", false]], 20=>[[{11=>nil, 1=>:enemy}, 1, "x:h", true], [{11=>nil, 3=>:enemy}, 3, "x:h", true], [{11=>nil, 1=>nil}, 1, "x:h", false], [{11=>nil, 3=>nil}, 3, "x:h", false], [{19=>nil, 9=>:enemy}, 9, "x:h", true], [{19=>nil, 27=>:enemy}, 27, "x:h", true], [{19=>nil, 9=>nil}, 9, "x:h", false], [{19=>nil, 27=>nil}, 27, "x:h", false], [{21=>nil, 13=>:enemy}, 13, "x:h", true], [{21=>nil, 31=>:enemy}, 31, "x:h", true], [{21=>nil, 13=>nil}, 13, "x:h", false], [{21=>nil, 31=>nil}, 31, "x:h", false], [{29=>nil, 37=>:enemy}, 37, "x:h", true], [{29=>nil, 39=>:enemy}, 39, "x:h", true], [{29=>nil, 37=>nil}, 37, "x:h", false], [{29=>nil, 39=>nil}, 39, "x:h", false]], 21=>[[{12=>nil, 2=>:enemy}, 2, "x:h", true], [{12=>nil, 4=>:enemy}, 4, "x:h", true], [{12=>nil, 2=>nil}, 2, "x:h", false], [{12=>nil, 4=>nil}, 4, "x:h", false], [{20=>nil, 10=>:enemy}, 10, "x:h", true], [{20=>nil, 28=>:enemy}, 28, "x:h", true], [{20=>nil, 10=>nil}, 10, "x:h", false], [{20=>nil, 28=>nil}, 28, "x:h", false], [{22=>nil, 14=>:enemy}, 14, "x:h", true], [{22=>nil, 32=>:enemy}, 32, "x:h", true], [{22=>nil, 14=>nil}, 14, "x:h", false], [{22=>nil, 32=>nil}, 32, "x:h", false], [{30=>nil, 38=>:enemy}, 38, "x:h", true], [{30=>nil, 40=>:enemy}, 40, "x:h", true], [{30=>nil, 38=>nil}, 38, "x:h", false], [{30=>nil, 40=>nil}, 40, "x:h", false]], 22=>[[{13=>nil, 3=>:enemy}, 3, "x:h", true], [{13=>nil, 5=>:enemy}, 5, "x:h", true], [{13=>nil, 3=>nil}, 3, "x:h", false], [{13=>nil, 5=>nil}, 5, "x:h", false], [{21=>nil, 11=>:enemy}, 11, "x:h", true], [{21=>nil, 29=>:enemy}, 29, "x:h", true], [{21=>nil, 11=>nil}, 11, "x:h", false], [{21=>nil, 29=>nil}, 29, "x:h", false], [{23=>nil, 15=>:enemy}, 15, "x:h", true], [{23=>nil, 33=>:enemy}, 33, "x:h", true], [{23=>nil, 15=>nil}, 15, "x:h", false], [{23=>nil, 33=>nil}, 33, "x:h", false], [{31=>nil, 39=>:enemy}, 39, "x:h", true], [{31=>nil, 41=>:enemy}, 41, "x:h", true], [{31=>nil, 39=>nil}, 39, "x:h", false], [{31=>nil, 41=>nil}, 41, "x:h", false]], 23=>[[{14=>nil, 4=>:enemy}, 4, "x:h", true], [{14=>nil, 6=>:enemy}, 6, "x:h", true], [{14=>nil, 4=>nil}, 4, "x:h", false], [{14=>nil, 6=>nil}, 6, "x:h", false], [{22=>nil, 12=>:enemy}, 12, "x:h", true], [{22=>nil, 30=>:enemy}, 30, "x:h", true], [{22=>nil, 12=>nil}, 12, "x:h", false], [{22=>nil, 30=>nil}, 30, "x:h", false], [{24=>nil, 16=>:enemy}, 16, "x:h", true], [{24=>nil, 34=>:enemy}, 34, "x:h", true], [{24=>nil, 16=>nil}, 16, "x:h", false], [{24=>nil, 34=>nil}, 34, "x:h", false], [{32=>nil, 40=>:enemy}, 40, "x:h", true], [{32=>nil, 42=>:enemy}, 42, "x:h", true], [{32=>nil, 40=>nil}, 40, "x:h", false], [{32=>nil, 42=>nil}, 42, "x:h", false]], 24=>[[{15=>nil, 5=>:enemy}, 5, "x:h", true], [{15=>nil, 7=>:enemy}, 7, "x:h", true], [{15=>nil, 5=>nil}, 5, "x:h", false], [{15=>nil, 7=>nil}, 7, "x:h", false], [{23=>nil, 13=>:enemy}, 13, "x:h", true], [{23=>nil, 31=>:enemy}, 31, "x:h", true], [{23=>nil, 13=>nil}, 13, "x:h", false], [{23=>nil, 31=>nil}, 31, "x:h", false], [{25=>nil, 17=>:enemy}, 17, "x:h", true], [{25=>nil, 35=>:enemy}, 35, "x:h", true], [{25=>nil, 17=>nil}, 17, "x:h", false], [{25=>nil, 35=>nil}, 35, "x:h", false], [{33=>nil, 41=>:enemy}, 41, "x:h", true], [{33=>nil, 43=>:enemy}, 43, "x:h", true], [{33=>nil, 41=>nil}, 41, "x:h", false], [{33=>nil, 43=>nil}, 43, "x:h", false]], 25=>[[{16=>nil, 6=>:enemy}, 6, "x:h", true], [{16=>nil, 8=>:enemy}, 8, "x:h", true], [{16=>nil, 6=>nil}, 6, "x:h", false], [{16=>nil, 8=>nil}, 8, "x:h", false], [{24=>nil, 14=>:enemy}, 14, "x:h", true], [{24=>nil, 32=>:enemy}, 32, "x:h", true], [{24=>nil, 14=>nil}, 14, "x:h", false], [{24=>nil, 32=>nil}, 32, "x:h", false], [{34=>nil, 42=>:enemy}, 42, "x:h", true], [{34=>nil, 44=>:enemy}, 44, "x:h", true], [{34=>nil, 42=>nil}, 42, "x:h", false], [{34=>nil, 44=>nil}, 44, "x:h", false]], 26=>[[{17=>nil, 7=>:enemy}, 7, "x:h", true], [{17=>nil, 7=>nil}, 7, "x:h", false], [{25=>nil, 15=>:enemy}, 15, "x:h", true], [{25=>nil, 33=>:enemy}, 33, "x:h", true], [{25=>nil, 15=>nil}, 15, "x:h", false], [{25=>nil, 33=>nil}, 33, "x:h", false], [{35=>nil, 43=>:enemy}, 43, "x:h", true], [{35=>nil, 43=>nil}, 43, "x:h", false]], 27=>[[{18=>nil, 10=>:enemy}, 10, "x:h", true], [{18=>nil, 10=>nil}, 10, "x:h", false], [{28=>nil, 20=>:enemy}, 20, "x:h", true], [{28=>nil, 38=>:enemy}, 38, "x:h", true], [{28=>nil, 20=>nil}, 20, "x:h", false], [{28=>nil, 38=>nil}, 38, "x:h", false], [{36=>nil, 46=>:enemy}, 46, "x:h", true], [{36=>nil, 46=>nil}, 46, "x:h", false]], 28=>[[{19=>nil, 9=>:enemy}, 9, "x:h", true], [{19=>nil, 11=>:enemy}, 11, "x:h", true], [{19=>nil, 9=>nil}, 9, "x:h", false], [{19=>nil, 11=>nil}, 11, "x:h", false], [{29=>nil, 21=>:enemy}, 21, "x:h", true], [{29=>nil, 39=>:enemy}, 39, "x:h", true], [{29=>nil, 21=>nil}, 21, "x:h", false], [{29=>nil, 39=>nil}, 39, "x:h", false], [{37=>nil, 45=>:enemy}, 45, "x:h", true], [{37=>nil, 47=>:enemy}, 47, "x:h", true], [{37=>nil, 45=>nil}, 45, "x:h", false], [{37=>nil, 47=>nil}, 47, "x:h", false]], 29=>[[{20=>nil, 10=>:enemy}, 10, "x:h", true], [{20=>nil, 12=>:enemy}, 12, "x:h", true], [{20=>nil, 10=>nil}, 10, "x:h", false], [{20=>nil, 12=>nil}, 12, "x:h", false], [{28=>nil, 18=>:enemy}, 18, "x:h", true], [{28=>nil, 36=>:enemy}, 36, "x:h", true], [{28=>nil, 18=>nil}, 18, "x:h", false], [{28=>nil, 36=>nil}, 36, "x:h", false], [{30=>nil, 22=>:enemy}, 22, "x:h", true], [{30=>nil, 40=>:enemy}, 40, "x:h", true], [{30=>nil, 22=>nil}, 22, "x:h", false], [{30=>nil, 40=>nil}, 40, "x:h", false], [{38=>nil, 46=>:enemy}, 46, "x:h", true], [{38=>nil, 48=>:enemy}, 48, "x:h", true], [{38=>nil, 46=>nil}, 46, "x:h", false], [{38=>nil, 48=>nil}, 48, "x:h", false]], 30=>[[{21=>nil, 11=>:enemy}, 11, "x:h", true], [{21=>nil, 13=>:enemy}, 13, "x:h", true], [{21=>nil, 11=>nil}, 11, "x:h", false], [{21=>nil, 13=>nil}, 13, "x:h", false], [{29=>nil, 19=>:enemy}, 19, "x:h", true], [{29=>nil, 37=>:enemy}, 37, "x:h", true], [{29=>nil, 19=>nil}, 19, "x:h", false], [{29=>nil, 37=>nil}, 37, "x:h", false], [{31=>nil, 23=>:enemy}, 23, "x:h", true], [{31=>nil, 41=>:enemy}, 41, "x:h", true], [{31=>nil, 23=>nil}, 23, "x:h", false], [{31=>nil, 41=>nil}, 41, "x:h", false], [{39=>nil, 47=>:enemy}, 47, "x:h", true], [{39=>nil, 49=>:enemy}, 49, "x:h", true], [{39=>nil, 47=>nil}, 47, "x:h", false], [{39=>nil, 49=>nil}, 49, "x:h", false]], 31=>[[{22=>nil, 12=>:enemy}, 12, "x:h", true], [{22=>nil, 14=>:enemy}, 14, "x:h", true], [{22=>nil, 12=>nil}, 12, "x:h", false], [{22=>nil, 14=>nil}, 14, "x:h", false], [{30=>nil, 20=>:enemy}, 20, "x:h", true], [{30=>nil, 38=>:enemy}, 38, "x:h", true], [{30=>nil, 20=>nil}, 20, "x:h", false], [{30=>nil, 38=>nil}, 38, "x:h", false], [{32=>nil, 24=>:enemy}, 24, "x:h", true], [{32=>nil, 42=>:enemy}, 42, "x:h", true], [{32=>nil, 24=>nil}, 24, "x:h", false], [{32=>nil, 42=>nil}, 42, "x:h", false], [{40=>nil, 48=>:enemy}, 48, "x:h", true], [{40=>nil, 50=>:enemy}, 50, "x:h", true], [{40=>nil, 48=>nil}, 48, "x:h", false], [{40=>nil, 50=>nil}, 50, "x:h", false]], 32=>[[{23=>nil, 13=>:enemy}, 13, "x:h", true], [{23=>nil, 15=>:enemy}, 15, "x:h", true], [{23=>nil, 13=>nil}, 13, "x:h", false], [{23=>nil, 15=>nil}, 15, "x:h", false], [{31=>nil, 21=>:enemy}, 21, "x:h", true], [{31=>nil, 39=>:enemy}, 39, "x:h", true], [{31=>nil, 21=>nil}, 21, "x:h", false], [{31=>nil, 39=>nil}, 39, "x:h", false], [{33=>nil, 25=>:enemy}, 25, "x:h", true], [{33=>nil, 43=>:enemy}, 43, "x:h", true], [{33=>nil, 25=>nil}, 25, "x:h", false], [{33=>nil, 43=>nil}, 43, "x:h", false], [{41=>nil, 49=>:enemy}, 49, "x:h", true], [{41=>nil, 51=>:enemy}, 51, "x:h", true], [{41=>nil, 49=>nil}, 49, "x:h", false], [{41=>nil, 51=>nil}, 51, "x:h", false]], 33=>[[{24=>nil, 14=>:enemy}, 14, "x:h", true], [{24=>nil, 16=>:enemy}, 16, "x:h", true], [{24=>nil, 14=>nil}, 14, "x:h", false], [{24=>nil, 16=>nil}, 16, "x:h", false], [{32=>nil, 22=>:enemy}, 22, "x:h", true], [{32=>nil, 40=>:enemy}, 40, "x:h", true], [{32=>nil, 22=>nil}, 22, "x:h", false], [{32=>nil, 40=>nil}, 40, "x:h", false], [{34=>nil, 26=>:enemy}, 26, "x:h", true], [{34=>nil, 44=>:enemy}, 44, "x:h", true], [{34=>nil, 26=>nil}, 26, "x:h", false], [{34=>nil, 44=>nil}, 44, "x:h", false], [{42=>nil, 50=>:enemy}, 50, "x:h", true], [{42=>nil, 52=>:enemy}, 52, "x:h", true], [{42=>nil, 50=>nil}, 50, "x:h", false], [{42=>nil, 52=>nil}, 52, "x:h", false]], 34=>[[{25=>nil, 15=>:enemy}, 15, "x:h", true], [{25=>nil, 17=>:enemy}, 17, "x:h", true], [{25=>nil, 15=>nil}, 15, "x:h", false], [{25=>nil, 17=>nil}, 17, "x:h", false], [{33=>nil, 23=>:enemy}, 23, "x:h", true], [{33=>nil, 41=>:enemy}, 41, "x:h", true], [{33=>nil, 23=>nil}, 23, "x:h", false], [{33=>nil, 41=>nil}, 41, "x:h", false], [{43=>nil, 51=>:enemy}, 51, "x:h", true], [{43=>nil, 53=>:enemy}, 53, "x:h", true], [{43=>nil, 51=>nil}, 51, "x:h", false], [{43=>nil, 53=>nil}, 53, "x:h", false]], 35=>[[{26=>nil, 16=>:enemy}, 16, "x:h", true], [{26=>nil, 16=>nil}, 16, "x:h", false], [{34=>nil, 24=>:enemy}, 24, "x:h", true], [{34=>nil, 42=>:enemy}, 42, "x:h", true], [{34=>nil, 24=>nil}, 24, "x:h", false], [{34=>nil, 42=>nil}, 42, "x:h", false], [{44=>nil, 52=>:enemy}, 52, "x:h", true], [{44=>nil, 52=>nil}, 52, "x:h", false]], 36=>[[{27=>nil, 19=>:enemy}, 19, "x:h", true], [{27=>nil, 19=>nil}, 19, "x:h", false], [{37=>nil, 29=>:enemy}, 29, "x:h", true], [{37=>nil, 47=>:enemy}, 47, "x:h", true], [{37=>nil, 29=>nil}, 29, "x:h", false], [{37=>nil, 47=>nil}, 47, "x:h", false], [{45=>nil, 55=>:enemy}, 55, "x:h", true], [{45=>nil, 55=>nil}, 55, "x:h", false]], 37=>[[{28=>nil, 18=>:enemy}, 18, "x:h", true], [{28=>nil, 20=>:enemy}, 20, "x:h", true], [{28=>nil, 18=>nil}, 18, "x:h", false], [{28=>nil, 20=>nil}, 20, "x:h", false], [{38=>nil, 30=>:enemy}, 30, "x:h", true], [{38=>nil, 48=>:enemy}, 48, "x:h", true], [{38=>nil, 30=>nil}, 30, "x:h", false], [{38=>nil, 48=>nil}, 48, "x:h", false], [{46=>nil, 54=>:enemy}, 54, "x:h", true], [{46=>nil, 56=>:enemy}, 56, "x:h", true], [{46=>nil, 54=>nil}, 54, "x:h", false], [{46=>nil, 56=>nil}, 56, "x:h", false]], 38=>[[{29=>nil, 19=>:enemy}, 19, "x:h", true], [{29=>nil, 21=>:enemy}, 21, "x:h", true], [{29=>nil, 19=>nil}, 19, "x:h", false], [{29=>nil, 21=>nil}, 21, "x:h", false], [{37=>nil, 27=>:enemy}, 27, "x:h", true], [{37=>nil, 45=>:enemy}, 45, "x:h", true], [{37=>nil, 27=>nil}, 27, "x:h", false], [{37=>nil, 45=>nil}, 45, "x:h", false], [{39=>nil, 31=>:enemy}, 31, "x:h", true], [{39=>nil, 49=>:enemy}, 49, "x:h", true], [{39=>nil, 31=>nil}, 31, "x:h", false], [{39=>nil, 49=>nil}, 49, "x:h", false], [{47=>nil, 55=>:enemy}, 55, "x:h", true], [{47=>nil, 57=>:enemy}, 57, "x:h", true], [{47=>nil, 55=>nil}, 55, "x:h", false], [{47=>nil, 57=>nil}, 57, "x:h", false]], 39=>[[{30=>nil, 20=>:enemy}, 20, "x:h", true], [{30=>nil, 22=>:enemy}, 22, "x:h", true], [{30=>nil, 20=>nil}, 20, "x:h", false], [{30=>nil, 22=>nil}, 22, "x:h", false], [{38=>nil, 28=>:enemy}, 28, "x:h", true], [{38=>nil, 46=>:enemy}, 46, "x:h", true], [{38=>nil, 28=>nil}, 28, "x:h", false], [{38=>nil, 46=>nil}, 46, "x:h", false], [{40=>nil, 32=>:enemy}, 32, "x:h", true], [{40=>nil, 50=>:enemy}, 50, "x:h", true], [{40=>nil, 32=>nil}, 32, "x:h", false], [{40=>nil, 50=>nil}, 50, "x:h", false], [{48=>nil, 56=>:enemy}, 56, "x:h", true], [{48=>nil, 58=>:enemy}, 58, "x:h", true], [{48=>nil, 56=>nil}, 56, "x:h", false], [{48=>nil, 58=>nil}, 58, "x:h", false]], 40=>[[{31=>nil, 21=>:enemy}, 21, "x:h", true], [{31=>nil, 23=>:enemy}, 23, "x:h", true], [{31=>nil, 21=>nil}, 21, "x:h", false], [{31=>nil, 23=>nil}, 23, "x:h", false], [{39=>nil, 29=>:enemy}, 29, "x:h", true], [{39=>nil, 47=>:enemy}, 47, "x:h", true], [{39=>nil, 29=>nil}, 29, "x:h", false], [{39=>nil, 47=>nil}, 47, "x:h", false], [{41=>nil, 33=>:enemy}, 33, "x:h", true], [{41=>nil, 51=>:enemy}, 51, "x:h", true], [{41=>nil, 33=>nil}, 33, "x:h", false], [{41=>nil, 51=>nil}, 51, "x:h", false], [{49=>nil, 57=>:enemy}, 57, "x:h", true], [{49=>nil, 59=>:enemy}, 59, "x:h", true], [{49=>nil, 57=>nil}, 57, "x:h", false], [{49=>nil, 59=>nil}, 59, "x:h", false]], 41=>[[{32=>nil, 22=>:enemy}, 22, "x:h", true], [{32=>nil, 24=>:enemy}, 24, "x:h", true], [{32=>nil, 22=>nil}, 22, "x:h", false], [{32=>nil, 24=>nil}, 24, "x:h", false], [{40=>nil, 30=>:enemy}, 30, "x:h", true], [{40=>nil, 48=>:enemy}, 48, "x:h", true], [{40=>nil, 30=>nil}, 30, "x:h", false], [{40=>nil, 48=>nil}, 48, "x:h", false], [{42=>nil, 34=>:enemy}, 34, "x:h", true], [{42=>nil, 52=>:enemy}, 52, "x:h", true], [{42=>nil, 34=>nil}, 34, "x:h", false], [{42=>nil, 52=>nil}, 52, "x:h", false], [{50=>nil, 58=>:enemy}, 58, "x:h", true], [{50=>nil, 60=>:enemy}, 60, "x:h", true], [{50=>nil, 58=>nil}, 58, "x:h", false], [{50=>nil, 60=>nil}, 60, "x:h", false]], 42=>[[{33=>nil, 23=>:enemy}, 23, "x:h", true], [{33=>nil, 25=>:enemy}, 25, "x:h", true], [{33=>nil, 23=>nil}, 23, "x:h", false], [{33=>nil, 25=>nil}, 25, "x:h", false], [{41=>nil, 31=>:enemy}, 31, "x:h", true], [{41=>nil, 49=>:enemy}, 49, "x:h", true], [{41=>nil, 31=>nil}, 31, "x:h", false], [{41=>nil, 49=>nil}, 49, "x:h", false], [{43=>nil, 35=>:enemy}, 35, "x:h", true], [{43=>nil, 53=>:enemy}, 53, "x:h", true], [{43=>nil, 35=>nil}, 35, "x:h", false], [{43=>nil, 53=>nil}, 53, "x:h", false], [{51=>nil, 59=>:enemy}, 59, "x:h", true], [{51=>nil, 61=>:enemy}, 61, "x:h", true], [{51=>nil, 59=>nil}, 59, "x:h", false], [{51=>nil, 61=>nil}, 61, "x:h", false]], 43=>[[{34=>nil, 24=>:enemy}, 24, "x:h", true], [{34=>nil, 26=>:enemy}, 26, "x:h", true], [{34=>nil, 24=>nil}, 24, "x:h", false], [{34=>nil, 26=>nil}, 26, "x:h", false], [{42=>nil, 32=>:enemy}, 32, "x:h", true], [{42=>nil, 50=>:enemy}, 50, "x:h", true], [{42=>nil, 32=>nil}, 32, "x:h", false], [{42=>nil, 50=>nil}, 50, "x:h", false], [{52=>nil, 60=>:enemy}, 60, "x:h", true], [{52=>nil, 62=>:enemy}, 62, "x:h", true], [{52=>nil, 60=>nil}, 60, "x:h", false], [{52=>nil, 62=>nil}, 62, "x:h", false]], 44=>[[{35=>nil, 25=>:enemy}, 25, "x:h", true], [{35=>nil, 25=>nil}, 25, "x:h", false], [{43=>nil, 33=>:enemy}, 33, "x:h", true], [{43=>nil, 51=>:enemy}, 51, "x:h", true], [{43=>nil, 33=>nil}, 33, "x:h", false], [{43=>nil, 51=>nil}, 51, "x:h", false], [{53=>nil, 61=>:enemy}, 61, "x:h", true], [{53=>nil, 61=>nil}, 61, "x:h", false]], 45=>[[{36=>nil, 28=>:enemy}, 28, "x:h", true], [{36=>nil, 28=>nil}, 28, "x:h", false], [{46=>nil, 38=>:enemy}, 38, "x:h", true], [{46=>nil, 56=>:enemy}, 56, "x:h", true], [{46=>nil, 38=>nil}, 38, "x:h", false], [{46=>nil, 56=>nil}, 56, "x:h", false], [{54=>nil, 64=>:enemy}, 64, "x:h", true], [{54=>nil, 64=>nil}, 64, "x:h", false]], 46=>[[{37=>nil, 27=>:enemy}, 27, "x:h", true], [{37=>nil, 29=>:enemy}, 29, "x:h", true], [{37=>nil, 27=>nil}, 27, "x:h", false], [{37=>nil, 29=>nil}, 29, "x:h", false], [{47=>nil, 39=>:enemy}, 39, "x:h", true], [{47=>nil, 57=>:enemy}, 57, "x:h", true], [{47=>nil, 39=>nil}, 39, "x:h", false], [{47=>nil, 57=>nil}, 57, "x:h", false], [{55=>nil, 63=>:enemy}, 63, "x:h", true], [{55=>nil, 65=>:enemy}, 65, "x:h", true], [{55=>nil, 63=>nil}, 63, "x:h", false], [{55=>nil, 65=>nil}, 65, "x:h", false]], 47=>[[{38=>nil, 28=>:enemy}, 28, "x:h", true], [{38=>nil, 30=>:enemy}, 30, "x:h", true], [{38=>nil, 28=>nil}, 28, "x:h", false], [{38=>nil, 30=>nil}, 30, "x:h", false], [{46=>nil, 36=>:enemy}, 36, "x:h", true], [{46=>nil, 54=>:enemy}, 54, "x:h", true], [{46=>nil, 36=>nil}, 36, "x:h", false], [{46=>nil, 54=>nil}, 54, "x:h", false], [{48=>nil, 40=>:enemy}, 40, "x:h", true], [{48=>nil, 58=>:enemy}, 58, "x:h", true], [{48=>nil, 40=>nil}, 40, "x:h", false], [{48=>nil, 58=>nil}, 58, "x:h", false], [{56=>nil, 64=>:enemy}, 64, "x:h", true], [{56=>nil, 66=>:enemy}, 66, "x:h", true], [{56=>nil, 64=>nil}, 64, "x:h", false], [{56=>nil, 66=>nil}, 66, "x:h", false]], 48=>[[{39=>nil, 29=>:enemy}, 29, "x:h", true], [{39=>nil, 31=>:enemy}, 31, "x:h", true], [{39=>nil, 29=>nil}, 29, "x:h", false], [{39=>nil, 31=>nil}, 31, "x:h", false], [{47=>nil, 37=>:enemy}, 37, "x:h", true], [{47=>nil, 55=>:enemy}, 55, "x:h", true], [{47=>nil, 37=>nil}, 37, "x:h", false], [{47=>nil, 55=>nil}, 55, "x:h", false], [{49=>nil, 41=>:enemy}, 41, "x:h", true], [{49=>nil, 59=>:enemy}, 59, "x:h", true], [{49=>nil, 41=>nil}, 41, "x:h", false], [{49=>nil, 59=>nil}, 59, "x:h", false], [{57=>nil, 65=>:enemy}, 65, "x:h", true], [{57=>nil, 67=>:enemy}, 67, "x:h", true], [{57=>nil, 65=>nil}, 65, "x:h", false], [{57=>nil, 67=>nil}, 67, "x:h", false]], 49=>[[{40=>nil, 30=>:enemy}, 30, "x:h", true], [{40=>nil, 32=>:enemy}, 32, "x:h", true], [{40=>nil, 30=>nil}, 30, "x:h", false], [{40=>nil, 32=>nil}, 32, "x:h", false], [{48=>nil, 38=>:enemy}, 38, "x:h", true], [{48=>nil, 56=>:enemy}, 56, "x:h", true], [{48=>nil, 38=>nil}, 38, "x:h", false], [{48=>nil, 56=>nil}, 56, "x:h", false], [{50=>nil, 42=>:enemy}, 42, "x:h", true], [{50=>nil, 60=>:enemy}, 60, "x:h", true], [{50=>nil, 42=>nil}, 42, "x:h", false], [{50=>nil, 60=>nil}, 60, "x:h", false], [{58=>nil, 66=>:enemy}, 66, "x:h", true], [{58=>nil, 68=>:enemy}, 68, "x:h", true], [{58=>nil, 66=>nil}, 66, "x:h", false], [{58=>nil, 68=>nil}, 68, "x:h", false]], 50=>[[{41=>nil, 31=>:enemy}, 31, "x:h", true], [{41=>nil, 33=>:enemy}, 33, "x:h", true], [{41=>nil, 31=>nil}, 31, "x:h", false], [{41=>nil, 33=>nil}, 33, "x:h", false], [{49=>nil, 39=>:enemy}, 39, "x:h", true], [{49=>nil, 57=>:enemy}, 57, "x:h", true], [{49=>nil, 39=>nil}, 39, "x:h", false], [{49=>nil, 57=>nil}, 57, "x:h", false], [{51=>nil, 43=>:enemy}, 43, "x:h", true], [{51=>nil, 61=>:enemy}, 61, "x:h", true], [{51=>nil, 43=>nil}, 43, "x:h", false], [{51=>nil, 61=>nil}, 61, "x:h", false], [{59=>nil, 67=>:enemy}, 67, "x:h", true], [{59=>nil, 69=>:enemy}, 69, "x:h", true], [{59=>nil, 67=>nil}, 67, "x:h", false], [{59=>nil, 69=>nil}, 69, "x:h", false]], 51=>[[{42=>nil, 32=>:enemy}, 32, "x:h", true], [{42=>nil, 34=>:enemy}, 34, "x:h", true], [{42=>nil, 32=>nil}, 32, "x:h", false], [{42=>nil, 34=>nil}, 34, "x:h", false], [{50=>nil, 40=>:enemy}, 40, "x:h", true], [{50=>nil, 58=>:enemy}, 58, "x:h", true], [{50=>nil, 40=>nil}, 40, "x:h", false], [{50=>nil, 58=>nil}, 58, "x:h", false], [{52=>nil, 44=>:enemy}, 44, "x:h", true], [{52=>nil, 62=>:enemy}, 62, "x:h", true], [{52=>nil, 44=>nil}, 44, "x:h", false], [{52=>nil, 62=>nil}, 62, "x:h", false], [{60=>nil, 68=>:enemy}, 68, "x:h", true], [{60=>nil, 70=>:enemy}, 70, "x:h", true], [{60=>nil, 68=>nil}, 68, "x:h", false], [{60=>nil, 70=>nil}, 70, "x:h", false]], 52=>[[{43=>nil, 33=>:enemy}, 33, "x:h", true], [{43=>nil, 35=>:enemy}, 35, "x:h", true], [{43=>nil, 33=>nil}, 33, "x:h", false], [{43=>nil, 35=>nil}, 35, "x:h", false], [{51=>nil, 41=>:enemy}, 41, "x:h", true], [{51=>nil, 59=>:enemy}, 59, "x:h", true], [{51=>nil, 41=>nil}, 41, "x:h", false], [{51=>nil, 59=>nil}, 59, "x:h", false], [{61=>nil, 69=>:enemy}, 69, "x:h", true], [{61=>nil, 71=>:enemy}, 71, "x:h", true], [{61=>nil, 69=>nil}, 69, "x:h", false], [{61=>nil, 71=>nil}, 71, "x:h", false]], 53=>[[{44=>nil, 34=>:enemy}, 34, "x:h", true], [{44=>nil, 34=>nil}, 34, "x:h", false], [{52=>nil, 42=>:enemy}, 42, "x:h", true], [{52=>nil, 60=>:enemy}, 60, "x:h", true], [{52=>nil, 42=>nil}, 42, "x:h", false], [{52=>nil, 60=>nil}, 60, "x:h", false], [{62=>nil, 70=>:enemy}, 70, "x:h", true], [{62=>nil, 70=>nil}, 70, "x:h", false]], 54=>[[{45=>nil, 37=>:enemy}, 37, "x:h", true], [{45=>nil, 37=>nil}, 37, "x:h", false], [{55=>nil, 47=>:enemy}, 47, "x:h", true], [{55=>nil, 65=>:enemy}, 65, "x:h", true], [{55=>nil, 47=>nil}, 47, "x:h", false], [{55=>nil, 65=>nil}, 65, "x:h", false], [{63=>nil, 73=>:enemy}, 73, "x:h", true], [{63=>nil, 73=>nil}, 73, "x:h", false]], 55=>[[{46=>nil, 36=>:enemy}, 36, "x:h", true], [{46=>nil, 38=>:enemy}, 38, "x:h", true], [{46=>nil, 36=>nil}, 36, "x:h", false], [{46=>nil, 38=>nil}, 38, "x:h", false], [{56=>nil, 48=>:enemy}, 48, "x:h", true], [{56=>nil, 66=>:enemy}, 66, "x:h", true], [{56=>nil, 48=>nil}, 48, "x:h", false], [{56=>nil, 66=>nil}, 66, "x:h", false], [{64=>nil, 72=>:enemy}, 72, "x:h", true], [{64=>nil, 74=>:enemy}, 74, "x:h", true], [{64=>nil, 72=>nil}, 72, "x:h", false], [{64=>nil, 74=>nil}, 74, "x:h", false]], 56=>[[{47=>nil, 37=>:enemy}, 37, "x:h", true], [{47=>nil, 39=>:enemy}, 39, "x:h", true], [{47=>nil, 37=>nil}, 37, "x:h", false], [{47=>nil, 39=>nil}, 39, "x:h", false], [{55=>nil, 45=>:enemy}, 45, "x:h", true], [{55=>nil, 63=>:enemy}, 63, "x:h", true], [{55=>nil, 45=>nil}, 45, "x:h", false], [{55=>nil, 63=>nil}, 63, "x:h", false], [{57=>nil, 49=>:enemy}, 49, "x:h", true], [{57=>nil, 67=>:enemy}, 67, "x:h", true], [{57=>nil, 49=>nil}, 49, "x:h", false], [{57=>nil, 67=>nil}, 67, "x:h", false], [{65=>nil, 73=>:enemy}, 73, "x:h", true], [{65=>nil, 75=>:enemy}, 75, "x:h", true], [{65=>nil, 73=>nil}, 73, "x:h", false], [{65=>nil, 75=>nil}, 75, "x:h", false]], 57=>[[{48=>nil, 38=>:enemy}, 38, "x:h", true], [{48=>nil, 40=>:enemy}, 40, "x:h", true], [{48=>nil, 38=>nil}, 38, "x:h", false], [{48=>nil, 40=>nil}, 40, "x:h", false], [{56=>nil, 46=>:enemy}, 46, "x:h", true], [{56=>nil, 64=>:enemy}, 64, "x:h", true], [{56=>nil, 46=>nil}, 46, "x:h", false], [{56=>nil, 64=>nil}, 64, "x:h", false], [{58=>nil, 50=>:enemy}, 50, "x:h", true], [{58=>nil, 68=>:enemy}, 68, "x:h", true], [{58=>nil, 50=>nil}, 50, "x:h", false], [{58=>nil, 68=>nil}, 68, "x:h", false], [{66=>nil, 74=>:enemy}, 74, "x:h", true], [{66=>nil, 76=>:enemy}, 76, "x:h", true], [{66=>nil, 74=>nil}, 74, "x:h", false], [{66=>nil, 76=>nil}, 76, "x:h", false]], 58=>[[{49=>nil, 39=>:enemy}, 39, "x:h", true], [{49=>nil, 41=>:enemy}, 41, "x:h", true], [{49=>nil, 39=>nil}, 39, "x:h", false], [{49=>nil, 41=>nil}, 41, "x:h", false], [{57=>nil, 47=>:enemy}, 47, "x:h", true], [{57=>nil, 65=>:enemy}, 65, "x:h", true], [{57=>nil, 47=>nil}, 47, "x:h", false], [{57=>nil, 65=>nil}, 65, "x:h", false], [{59=>nil, 51=>:enemy}, 51, "x:h", true], [{59=>nil, 69=>:enemy}, 69, "x:h", true], [{59=>nil, 51=>nil}, 51, "x:h", false], [{59=>nil, 69=>nil}, 69, "x:h", false], [{67=>nil, 75=>:enemy}, 75, "x:h", true], [{67=>nil, 77=>:enemy}, 77, "x:h", true], [{67=>nil, 75=>nil}, 75, "x:h", false], [{67=>nil, 77=>nil}, 77, "x:h", false]], 59=>[[{50=>nil, 40=>:enemy}, 40, "x:h", true], [{50=>nil, 42=>:enemy}, 42, "x:h", true], [{50=>nil, 40=>nil}, 40, "x:h", false], [{50=>nil, 42=>nil}, 42, "x:h", false], [{58=>nil, 48=>:enemy}, 48, "x:h", true], [{58=>nil, 66=>:enemy}, 66, "x:h", true], [{58=>nil, 48=>nil}, 48, "x:h", false], [{58=>nil, 66=>nil}, 66, "x:h", false], [{60=>nil, 52=>:enemy}, 52, "x:h", true], [{60=>nil, 70=>:enemy}, 70, "x:h", true], [{60=>nil, 52=>nil}, 52, "x:h", false], [{60=>nil, 70=>nil}, 70, "x:h", false], [{68=>nil, 76=>:enemy}, 76, "x:h", true], [{68=>nil, 78=>:enemy}, 78, "x:h", true], [{68=>nil, 76=>nil}, 76, "x:h", false], [{68=>nil, 78=>nil}, 78, "x:h", false]], 60=>[[{51=>nil, 41=>:enemy}, 41, "x:h", true], [{51=>nil, 43=>:enemy}, 43, "x:h", true], [{51=>nil, 41=>nil}, 41, "x:h", false], [{51=>nil, 43=>nil}, 43, "x:h", false], [{59=>nil, 49=>:enemy}, 49, "x:h", true], [{59=>nil, 67=>:enemy}, 67, "x:h", true], [{59=>nil, 49=>nil}, 49, "x:h", false], [{59=>nil, 67=>nil}, 67, "x:h", false], [{61=>nil, 53=>:enemy}, 53, "x:h", true], [{61=>nil, 71=>:enemy}, 71, "x:h", true], [{61=>nil, 53=>nil}, 53, "x:h", false], [{61=>nil, 71=>nil}, 71, "x:h", false], [{69=>nil, 77=>:enemy}, 77, "x:h", true], [{69=>nil, 79=>:enemy}, 79, "x:h", true], [{69=>nil, 77=>nil}, 77, "x:h", false], [{69=>nil, 79=>nil}, 79, "x:h", false]], 61=>[[{52=>nil, 42=>:enemy}, 42, "x:h", true], [{52=>nil, 44=>:enemy}, 44, "x:h", true], [{52=>nil, 42=>nil}, 42, "x:h", false], [{52=>nil, 44=>nil}, 44, "x:h", false], [{60=>nil, 50=>:enemy}, 50, "x:h", true], [{60=>nil, 68=>:enemy}, 68, "x:h", true], [{60=>nil, 50=>nil}, 50, "x:h", false], [{60=>nil, 68=>nil}, 68, "x:h", false], [{70=>nil, 78=>:enemy}, 78, "x:h", true], [{70=>nil, 80=>:enemy}, 80, "x:h", true], [{70=>nil, 78=>nil}, 78, "x:h", false], [{70=>nil, 80=>nil}, 80, "x:h", false]], 62=>[[{53=>nil, 43=>:enemy}, 43, "x:h", true], [{53=>nil, 43=>nil}, 43, "x:h", false], [{61=>nil, 51=>:enemy}, 51, "x:h", true], [{61=>nil, 69=>:enemy}, 69, "x:h", true], [{61=>nil, 51=>nil}, 51, "x:h", false], [{61=>nil, 69=>nil}, 69, "x:h", false], [{71=>nil, 79=>:enemy}, 79, "x:h", true], [{71=>nil, 79=>nil}, 79, "x:h", false]], 63=>[[{54=>nil, 46=>:enemy}, 46, "x:h", true], [{54=>nil, 46=>nil}, 46, "x:h", false], [{64=>nil, 56=>:enemy}, 56, "x:h", true], [{64=>nil, 74=>:enemy}, 74, "x:h", true], [{64=>nil, 56=>nil}, 56, "x:h", false], [{64=>nil, 74=>nil}, 74, "x:h", false]], 64=>[[{55=>nil, 45=>:enemy}, 45, "x:h", true], [{55=>nil, 47=>:enemy}, 47, "x:h", true], [{55=>nil, 45=>nil}, 45, "x:h", false], [{55=>nil, 47=>nil}, 47, "x:h", false], [{65=>nil, 57=>:enemy}, 57, "x:h", true], [{65=>nil, 75=>:enemy}, 75, "x:h", true], [{65=>nil, 57=>nil}, 57, "x:h", false], [{65=>nil, 75=>nil}, 75, "x:h", false]], 65=>[[{56=>nil, 46=>:enemy}, 46, "x:h", true], [{56=>nil, 48=>:enemy}, 48, "x:h", true], [{56=>nil, 46=>nil}, 46, "x:h", false], [{56=>nil, 48=>nil}, 48, "x:h", false], [{64=>nil, 54=>:enemy}, 54, "x:h", true], [{64=>nil, 72=>:enemy}, 72, "x:h", true], [{64=>nil, 54=>nil}, 54, "x:h", false], [{64=>nil, 72=>nil}, 72, "x:h", false], [{66=>nil, 58=>:enemy}, 58, "x:h", true], [{66=>nil, 76=>:enemy}, 76, "x:h", true], [{66=>nil, 58=>nil}, 58, "x:h", false], [{66=>nil, 76=>nil}, 76, "x:h", false]], 66=>[[{57=>nil, 47=>:enemy}, 47, "x:h", true], [{57=>nil, 49=>:enemy}, 49, "x:h", true], [{57=>nil, 47=>nil}, 47, "x:h", false], [{57=>nil, 49=>nil}, 49, "x:h", false], [{65=>nil, 55=>:enemy}, 55, "x:h", true], [{65=>nil, 73=>:enemy}, 73, "x:h", true], [{65=>nil, 55=>nil}, 55, "x:h", false], [{65=>nil, 73=>nil}, 73, "x:h", false], [{67=>nil, 59=>:enemy}, 59, "x:h", true], [{67=>nil, 77=>:enemy}, 77, "x:h", true], [{67=>nil, 59=>nil}, 59, "x:h", false], [{67=>nil, 77=>nil}, 77, "x:h", false]], 67=>[[{58=>nil, 48=>:enemy}, 48, "x:h", true], [{58=>nil, 50=>:enemy}, 50, "x:h", true], [{58=>nil, 48=>nil}, 48, "x:h", false], [{58=>nil, 50=>nil}, 50, "x:h", false], [{66=>nil, 56=>:enemy}, 56, "x:h", true], [{66=>nil, 74=>:enemy}, 74, "x:h", true], [{66=>nil, 56=>nil}, 56, "x:h", false], [{66=>nil, 74=>nil}, 74, "x:h", false], [{68=>nil, 60=>:enemy}, 60, "x:h", true], [{68=>nil, 78=>:enemy}, 78, "x:h", true], [{68=>nil, 60=>nil}, 60, "x:h", false], [{68=>nil, 78=>nil}, 78, "x:h", false]], 68=>[[{59=>nil, 49=>:enemy}, 49, "x:h", true], [{59=>nil, 51=>:enemy}, 51, "x:h", true], [{59=>nil, 49=>nil}, 49, "x:h", false], [{59=>nil, 51=>nil}, 51, "x:h", false], [{67=>nil, 57=>:enemy}, 57, "x:h", true], [{67=>nil, 75=>:enemy}, 75, "x:h", true], [{67=>nil, 57=>nil}, 57, "x:h", false], [{67=>nil, 75=>nil}, 75, "x:h", false], [{69=>nil, 61=>:enemy}, 61, "x:h", true], [{69=>nil, 79=>:enemy}, 79, "x:h", true], [{69=>nil, 61=>nil}, 61, "x:h", false], [{69=>nil, 79=>nil}, 79, "x:h", false]], 69=>[[{60=>nil, 50=>:enemy}, 50, "x:h", true], [{60=>nil, 52=>:enemy}, 52, "x:h", true], [{60=>nil, 50=>nil}, 50, "x:h", false], [{60=>nil, 52=>nil}, 52, "x:h", false], [{68=>nil, 58=>:enemy}, 58, "x:h", true], [{68=>nil, 76=>:enemy}, 76, "x:h", true], [{68=>nil, 58=>nil}, 58, "x:h", false], [{68=>nil, 76=>nil}, 76, "x:h", false], [{70=>nil, 62=>:enemy}, 62, "x:h", true], [{70=>nil, 80=>:enemy}, 80, "x:h", true], [{70=>nil, 62=>nil}, 62, "x:h", false], [{70=>nil, 80=>nil}, 80, "x:h", false]], 70=>[[{61=>nil, 51=>:enemy}, 51, "x:h", true], [{61=>nil, 53=>:enemy}, 53, "x:h", true], [{61=>nil, 51=>nil}, 51, "x:h", false], [{61=>nil, 53=>nil}, 53, "x:h", false], [{69=>nil, 59=>:enemy}, 59, "x:h", true], [{69=>nil, 77=>:enemy}, 77, "x:h", true], [{69=>nil, 59=>nil}, 59, "x:h", false], [{69=>nil, 77=>nil}, 77, "x:h", false]], 71=>[[{62=>nil, 52=>:enemy}, 52, "x:h", true], [{62=>nil, 52=>nil}, 52, "x:h", false], [{70=>nil, 60=>:enemy}, 60, "x:h", true], [{70=>nil, 78=>:enemy}, 78, "x:h", true], [{70=>nil, 60=>nil}, 60, "x:h", false], [{70=>nil, 78=>nil}, 78, "x:h", false]], 72=>[[{63=>nil, 55=>:enemy}, 55, "x:h", true], [{63=>nil, 55=>nil}, 55, "x:h", false], [{73=>nil, 65=>:enemy}, 65, "x:h", true], [{73=>nil, 65=>nil}, 65, "x:h", false]], 73=>[[{64=>nil, 54=>:enemy}, 54, "x:h", true], [{64=>nil, 56=>:enemy}, 56, "x:h", true], [{64=>nil, 54=>nil}, 54, "x:h", false], [{64=>nil, 56=>nil}, 56, "x:h", false], [{74=>nil, 66=>:enemy}, 66, "x:h", true], [{74=>nil, 66=>nil}, 66, "x:h", false]], 74=>[[{65=>nil, 55=>:enemy}, 55, "x:h", true], [{65=>nil, 57=>:enemy}, 57, "x:h", true], [{65=>nil, 55=>nil}, 55, "x:h", false], [{65=>nil, 57=>nil}, 57, "x:h", false], [{73=>nil, 63=>:enemy}, 63, "x:h", true], [{73=>nil, 63=>nil}, 63, "x:h", false], [{75=>nil, 67=>:enemy}, 67, "x:h", true], [{75=>nil, 67=>nil}, 67, "x:h", false]], 75=>[[{66=>nil, 56=>:enemy}, 56, "x:h", true], [{66=>nil, 58=>:enemy}, 58, "x:h", true], [{66=>nil, 56=>nil}, 56, "x:h", false], [{66=>nil, 58=>nil}, 58, "x:h", false], [{74=>nil, 64=>:enemy}, 64, "x:h", true], [{74=>nil, 64=>nil}, 64, "x:h", false], [{76=>nil, 68=>:enemy}, 68, "x:h", true], [{76=>nil, 68=>nil}, 68, "x:h", false]], 76=>[[{67=>nil, 57=>:enemy}, 57, "x:h", true], [{67=>nil, 59=>:enemy}, 59, "x:h", true], [{67=>nil, 57=>nil}, 57, "x:h", false], [{67=>nil, 59=>nil}, 59, "x:h", false], [{75=>nil, 65=>:enemy}, 65, "x:h", true], [{75=>nil, 65=>nil}, 65, "x:h", false], [{77=>nil, 69=>:enemy}, 69, "x:h", true], [{77=>nil, 69=>nil}, 69, "x:h", false]], 77=>[[{68=>nil, 58=>:enemy}, 58, "x:h", true], [{68=>nil, 60=>:enemy}, 60, "x:h", true], [{68=>nil, 58=>nil}, 58, "x:h", false], [{68=>nil, 60=>nil}, 60, "x:h", false], [{76=>nil, 66=>:enemy}, 66, "x:h", true], [{76=>nil, 66=>nil}, 66, "x:h", false], [{78=>nil, 70=>:enemy}, 70, "x:h", true], [{78=>nil, 70=>nil}, 70, "x:h", false]], 78=>[[{69=>nil, 59=>:enemy}, 59, "x:h", true], [{69=>nil, 61=>:enemy}, 61, "x:h", true], [{69=>nil, 59=>nil}, 59, "x:h", false], [{69=>nil, 61=>nil}, 61, "x:h", false], [{77=>nil, 67=>:enemy}, 67, "x:h", true], [{77=>nil, 67=>nil}, 67, "x:h", false], [{79=>nil, 71=>:enemy}, 71, "x:h", true], [{79=>nil, 71=>nil}, 71, "x:h", false]], 79=>[[{70=>nil, 60=>:enemy}, 60, "x:h", true], [{70=>nil, 62=>:enemy}, 62, "x:h", true], [{70=>nil, 60=>nil}, 60, "x:h", false], [{70=>nil, 62=>nil}, 62, "x:h", false], [{78=>nil, 68=>:enemy}, 68, "x:h", true], [{78=>nil, 68=>nil}, 68, "x:h", false]], 80=>[[{71=>nil, 61=>:enemy}, 61, "x:h", true], [{71=>nil, 61=>nil}, 61, "x:h", false], [{79=>nil, 69=>:enemy}, 69, "x:h", true], [{79=>nil, 69=>nil}, 69, "x:h", false]], nil=>[[{0=>nil}, 0, "x:h", false], [{1=>nil}, 1, "x:h", false], [{2=>nil}, 2, "x:h", false], [{3=>nil}, 3, "x:h", false], [{4=>nil}, 4, "x:h", false], [{5=>nil}, 5, "x:h", false], [{6=>nil}, 6, "x:h", false], [{7=>nil}, 7, "x:h", false], [{8=>nil}, 8, "x:h", false], [{9=>nil}, 9, "x:h", false], [{10=>nil}, 10, "x:h", false], [{11=>nil}, 11, "x:h", false], [{12=>nil}, 12, "x:h", false], [{13=>nil}, 13, "x:h", false], [{14=>nil}, 14, "x:h", false], [{15=>nil}, 15, "x:h", false], [{16=>nil}, 16, "x:h", false], [{17=>nil}, 17, "x:h", false], [{18=>nil}, 18, "x:h", false], [{19=>nil}, 19, "x:h", false], [{20=>nil}, 20, "x:h", false], [{21=>nil}, 21, "x:h", false], [{22=>nil}, 22, "x:h", false], [{23=>nil}, 23, "x:h", false], [{24=>nil}, 24, "x:h", false], [{25=>nil}, 25, "x:h", false], [{26=>nil}, 26, "x:h", false], [{27=>nil}, 27, "x:h", false], [{28=>nil}, 28, "x:h", false], [{29=>nil}, 29, "x:h", false], [{30=>nil}, 30, "x:h", false], [{31=>nil}, 31, "x:h", false], [{32=>nil}, 32, "x:h", false], [{33=>nil}, 33, "x:h", false], [{34=>nil}, 34, "x:h", false], [{35=>nil}, 35, "x:h", false], [{36=>nil}, 36, "x:h", false], [{37=>nil}, 37, "x:h", false], [{38=>nil}, 38, "x:h", false], [{39=>nil}, 39, "x:h", false], [{40=>nil}, 40, "x:h", false], [{41=>nil}, 41, "x:h", false], [{42=>nil}, 42, "x:h", false], [{43=>nil}, 43, "x:h", false], [{44=>nil}, 44, "x:h", false], [{45=>nil}, 45, "x:h", false], [{46=>nil}, 46, "x:h", false], [{47=>nil}, 47, "x:h", false], [{48=>nil}, 48, "x:h", false], [{49=>nil}, 49, "x:h", false], [{50=>nil}, 50, "x:h", false], [{51=>nil}, 51, "x:h", false], [{52=>nil}, 52, "x:h", false], [{53=>nil}, 53, "x:h", false], [{54=>nil}, 54, "x:h", false], [{55=>nil}, 55, "x:h", false], [{56=>nil}, 56, "x:h", false], [{57=>nil}, 57, "x:h", false], [{58=>nil}, 58, "x:h", false], [{59=>nil}, 59, "x:h", false], [{60=>nil}, 60, "x:h", false], [{61=>nil}, 61, "x:h", false], [{62=>nil}, 62, "x:h", false], [{63=>nil}, 63, "x:h", false], [{64=>nil}, 64, "x:h", false], [{65=>nil}, 65, "x:h", false], [{66=>nil}, 66, "x:h", false], [{67=>nil}, 67, "x:h", false], [{68=>nil}, 68, "x:h", false], [{69=>nil}, 69, "x:h", false], [{70=>nil}, 70, "x:h", false], [{71=>nil}, 71, "x:h", false], [{72=>nil}, 72, "x:h", false], [{73=>nil}, 73, "x:h", false], [{74=>nil}, 74, "x:h", false], [{75=>nil}, 75, "x:h", false], [{76=>nil}, 76, "x:h", false], [{77=>nil}, 77, "x:h", false], [{78=>nil}, 78, "x:h", false], [{79=>nil}, 79, "x:h", false], [{80=>nil}, 80, "x:h", false]]}, "x:r"=>{0=>[[{1=>:enemy}, 1, "x:r", true], [{9=>:enemy}, 9, "x:r", true], [{1=>nil}, 1, "x:r", false], [{1=>nil, 2=>:enemy}, 2, "x:r", true], [{1=>nil, 2=>nil}, 2, "x:r", false], [{1=>nil, 2=>nil, 3=>:enemy}, 3, "x:r", true], [{1=>nil, 2=>nil, 3=>nil}, 3, "x:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, 4, "x:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil}, 4, "x:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "x:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "x:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "x:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "x:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "x:r", false], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:r", true], [{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:r", false], [{9=>nil}, 9, "x:r", false], [{9=>nil, 18=>:enemy}, 18, "x:r", true], [{9=>nil, 18=>nil}, 18, "x:r", false], [{9=>nil, 18=>nil, 27=>:enemy}, 27, "x:r", true], [{9=>nil, 18=>nil, 27=>nil}, 27, "x:r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, 36, "x:r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil}, 36, "x:r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "x:r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "x:r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "x:r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "x:r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "x:r", false], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:r", true], [{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:r", false]], 1=>[[{0=>:enemy}, 0, "x:r", true], [{2=>:enemy}, 2, "x:r", true], [{10=>:enemy}, 10, "x:r", true], [{0=>nil}, 0, "x:r", false], [{2=>nil}, 2, "x:r", false], [{2=>nil, 3=>:enemy}, 3, "x:r", true], [{2=>nil, 3=>nil}, 3, "x:r", false], [{2=>nil, 3=>nil, 4=>:enemy}, 4, "x:r", true], [{2=>nil, 3=>nil, 4=>nil}, 4, "x:r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, 5, "x:r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil}, 5, "x:r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "x:r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "x:r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "x:r", false], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:r", true], [{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:r", false], [{10=>nil}, 10, "x:r", false], [{10=>nil, 19=>:enemy}, 19, "x:r", true], [{10=>nil, 19=>nil}, 19, "x:r", false], [{10=>nil, 19=>nil, 28=>:enemy}, 28, "x:r", true], [{10=>nil, 19=>nil, 28=>nil}, 28, "x:r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, 37, "x:r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil}, 37, "x:r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "x:r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "x:r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "x:r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "x:r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "x:r", false], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:r", true], [{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:r", false]], 2=>[[{1=>:enemy}, 1, "x:r", true], [{3=>:enemy}, 3, "x:r", true], [{11=>:enemy}, 11, "x:r", true], [{1=>nil}, 1, "x:r", false], [{1=>nil, 0=>:enemy}, 0, "x:r", true], [{1=>nil, 0=>nil}, 0, "x:r", false], [{3=>nil}, 3, "x:r", false], [{3=>nil, 4=>:enemy}, 4, "x:r", true], [{3=>nil, 4=>nil}, 4, "x:r", false], [{3=>nil, 4=>nil, 5=>:enemy}, 5, "x:r", true], [{3=>nil, 4=>nil, 5=>nil}, 5, "x:r", false], [{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, 6, "x:r", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil}, 6, "x:r", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:r", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "x:r", false], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:r", true], [{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:r", false], [{11=>nil}, 11, "x:r", false], [{11=>nil, 20=>:enemy}, 20, "x:r", true], [{11=>nil, 20=>nil}, 20, "x:r", false], [{11=>nil, 20=>nil, 29=>:enemy}, 29, "x:r", true], [{11=>nil, 20=>nil, 29=>nil}, 29, "x:r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, 38, "x:r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil}, 38, "x:r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "x:r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "x:r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "x:r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "x:r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "x:r", false], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:r", true], [{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:r", false]], 3=>[[{2=>:enemy}, 2, "x:r", true], [{4=>:enemy}, 4, "x:r", true], [{12=>:enemy}, 12, "x:r", true], [{2=>nil}, 2, "x:r", false], [{2=>nil, 1=>:enemy}, 1, "x:r", true], [{2=>nil, 1=>nil}, 1, "x:r", false], [{2=>nil, 1=>nil, 0=>:enemy}, 0, "x:r", true], [{2=>nil, 1=>nil, 0=>nil}, 0, "x:r", false], [{4=>nil}, 4, "x:r", false], [{4=>nil, 5=>:enemy}, 5, "x:r", true], [{4=>nil, 5=>nil}, 5, "x:r", false], [{4=>nil, 5=>nil, 6=>:enemy}, 6, "x:r", true], [{4=>nil, 5=>nil, 6=>nil}, 6, "x:r", false], [{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, 7, "x:r", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil}, 7, "x:r", false], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:r", true], [{4=>nil, 5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:r", false], [{12=>nil}, 12, "x:r", false], [{12=>nil, 21=>:enemy}, 21, "x:r", true], [{12=>nil, 21=>nil}, 21, "x:r", false], [{12=>nil, 21=>nil, 30=>:enemy}, 30, "x:r", true], [{12=>nil, 21=>nil, 30=>nil}, 30, "x:r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, 39, "x:r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil}, 39, "x:r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "x:r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "x:r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "x:r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "x:r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "x:r", false], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:r", true], [{12=>nil, 21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:r", false]], 4=>[[{3=>:enemy}, 3, "x:r", true], [{5=>:enemy}, 5, "x:r", true], [{13=>:enemy}, 13, "x:r", true], [{3=>nil}, 3, "x:r", false], [{3=>nil, 2=>:enemy}, 2, "x:r", true], [{3=>nil, 2=>nil}, 2, "x:r", false], [{3=>nil, 2=>nil, 1=>:enemy}, 1, "x:r", true], [{3=>nil, 2=>nil, 1=>nil}, 1, "x:r", false], [{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:r", true], [{3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:r", false], [{5=>nil}, 5, "x:r", false], [{5=>nil, 6=>:enemy}, 6, "x:r", true], [{5=>nil, 6=>nil}, 6, "x:r", false], [{5=>nil, 6=>nil, 7=>:enemy}, 7, "x:r", true], [{5=>nil, 6=>nil, 7=>nil}, 7, "x:r", false], [{5=>nil, 6=>nil, 7=>nil, 8=>:enemy}, 8, "x:r", true], [{5=>nil, 6=>nil, 7=>nil, 8=>nil}, 8, "x:r", false], [{13=>nil}, 13, "x:r", false], [{13=>nil, 22=>:enemy}, 22, "x:r", true], [{13=>nil, 22=>nil}, 22, "x:r", false], [{13=>nil, 22=>nil, 31=>:enemy}, 31, "x:r", true], [{13=>nil, 22=>nil, 31=>nil}, 31, "x:r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>:enemy}, 40, "x:r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil}, 40, "x:r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "x:r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "x:r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "x:r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "x:r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "x:r", false], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:r", true], [{13=>nil, 22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:r", false]], 5=>[[{4=>:enemy}, 4, "x:r", true], [{6=>:enemy}, 6, "x:r", true], [{14=>:enemy}, 14, "x:r", true], [{4=>nil}, 4, "x:r", false], [{4=>nil, 3=>:enemy}, 3, "x:r", true], [{4=>nil, 3=>nil}, 3, "x:r", false], [{4=>nil, 3=>nil, 2=>:enemy}, 2, "x:r", true], [{4=>nil, 3=>nil, 2=>nil}, 2, "x:r", false], [{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:r", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "x:r", false], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:r", true], [{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:r", false], [{6=>nil}, 6, "x:r", false], [{6=>nil, 7=>:enemy}, 7, "x:r", true], [{6=>nil, 7=>nil}, 7, "x:r", false], [{6=>nil, 7=>nil, 8=>:enemy}, 8, "x:r", true], [{6=>nil, 7=>nil, 8=>nil}, 8, "x:r", false], [{14=>nil}, 14, "x:r", false], [{14=>nil, 23=>:enemy}, 23, "x:r", true], [{14=>nil, 23=>nil}, 23, "x:r", false], [{14=>nil, 23=>nil, 32=>:enemy}, 32, "x:r", true], [{14=>nil, 23=>nil, 32=>nil}, 32, "x:r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>:enemy}, 41, "x:r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil}, 41, "x:r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "x:r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "x:r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "x:r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "x:r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "x:r", false], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:r", true], [{14=>nil, 23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:r", false]], 6=>[[{5=>:enemy}, 5, "x:r", true], [{7=>:enemy}, 7, "x:r", true], [{15=>:enemy}, 15, "x:r", true], [{5=>nil}, 5, "x:r", false], [{5=>nil, 4=>:enemy}, 4, "x:r", true], [{5=>nil, 4=>nil}, 4, "x:r", false], [{5=>nil, 4=>nil, 3=>:enemy}, 3, "x:r", true], [{5=>nil, 4=>nil, 3=>nil}, 3, "x:r", false], [{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "x:r", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "x:r", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:r", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "x:r", false], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:r", true], [{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:r", false], [{7=>nil}, 7, "x:r", false], [{7=>nil, 8=>:enemy}, 8, "x:r", true], [{7=>nil, 8=>nil}, 8, "x:r", false], [{15=>nil}, 15, "x:r", false], [{15=>nil, 24=>:enemy}, 24, "x:r", true], [{15=>nil, 24=>nil}, 24, "x:r", false], [{15=>nil, 24=>nil, 33=>:enemy}, 33, "x:r", true], [{15=>nil, 24=>nil, 33=>nil}, 33, "x:r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>:enemy}, 42, "x:r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil}, 42, "x:r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "x:r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "x:r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "x:r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "x:r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "x:r", false], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:r", true], [{15=>nil, 24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:r", false]], 7=>[[{6=>:enemy}, 6, "x:r", true], [{8=>:enemy}, 8, "x:r", true], [{16=>:enemy}, 16, "x:r", true], [{6=>nil}, 6, "x:r", false], [{6=>nil, 5=>:enemy}, 5, "x:r", true], [{6=>nil, 5=>nil}, 5, "x:r", false], [{6=>nil, 5=>nil, 4=>:enemy}, 4, "x:r", true], [{6=>nil, 5=>nil, 4=>nil}, 4, "x:r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "x:r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "x:r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "x:r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "x:r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "x:r", false], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:r", true], [{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:r", false], [{8=>nil}, 8, "x:r", false], [{16=>nil}, 16, "x:r", false], [{16=>nil, 25=>:enemy}, 25, "x:r", true], [{16=>nil, 25=>nil}, 25, "x:r", false], [{16=>nil, 25=>nil, 34=>:enemy}, 34, "x:r", true], [{16=>nil, 25=>nil, 34=>nil}, 34, "x:r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>:enemy}, 43, "x:r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil}, 43, "x:r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "x:r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "x:r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "x:r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "x:r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "x:r", false], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:r", true], [{16=>nil, 25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:r", false]], 8=>[[{7=>:enemy}, 7, "x:r", true], [{17=>:enemy}, 17, "x:r", true], [{7=>nil}, 7, "x:r", false], [{7=>nil, 6=>:enemy}, 6, "x:r", true], [{7=>nil, 6=>nil}, 6, "x:r", false], [{7=>nil, 6=>nil, 5=>:enemy}, 5, "x:r", true], [{7=>nil, 6=>nil, 5=>nil}, 5, "x:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>:enemy}, 4, "x:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil}, 4, "x:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, 3, "x:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil}, 3, "x:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, 2, "x:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}, 2, "x:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, 1, "x:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}, 1, "x:r", false], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, 0, "x:r", true], [{7=>nil, 6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}, 0, "x:r", false], [{17=>nil}, 17, "x:r", false], [{17=>nil, 26=>:enemy}, 26, "x:r", true], [{17=>nil, 26=>nil}, 26, "x:r", false], [{17=>nil, 26=>nil, 35=>:enemy}, 35, "x:r", true], [{17=>nil, 26=>nil, 35=>nil}, 35, "x:r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, 44, "x:r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil}, 44, "x:r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "x:r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "x:r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "x:r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "x:r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "x:r", false], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:r", true], [{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:r", false]], 9=>[[{0=>:enemy}, 0, "x:r", true], [{10=>:enemy}, 10, "x:r", true], [{18=>:enemy}, 18, "x:r", true], [{0=>nil}, 0, "x:r", false], [{10=>nil}, 10, "x:r", false], [{10=>nil, 11=>:enemy}, 11, "x:r", true], [{10=>nil, 11=>nil}, 11, "x:r", false], [{10=>nil, 11=>nil, 12=>:enemy}, 12, "x:r", true], [{10=>nil, 11=>nil, 12=>nil}, 12, "x:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, 13, "x:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil}, 13, "x:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "x:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "x:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "x:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "x:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "x:r", false], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:r", true], [{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:r", false], [{18=>nil}, 18, "x:r", false], [{18=>nil, 27=>:enemy}, 27, "x:r", true], [{18=>nil, 27=>nil}, 27, "x:r", false], [{18=>nil, 27=>nil, 36=>:enemy}, 36, "x:r", true], [{18=>nil, 27=>nil, 36=>nil}, 36, "x:r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, 45, "x:r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil}, 45, "x:r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "x:r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "x:r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "x:r", false], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:r", true], [{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:r", false]], 10=>[[{1=>:enemy}, 1, "x:r", true], [{9=>:enemy}, 9, "x:r", true], [{11=>:enemy}, 11, "x:r", true], [{19=>:enemy}, 19, "x:r", true], [{1=>nil}, 1, "x:r", false], [{9=>nil}, 9, "x:r", false], [{11=>nil}, 11, "x:r", false], [{11=>nil, 12=>:enemy}, 12, "x:r", true], [{11=>nil, 12=>nil}, 12, "x:r", false], [{11=>nil, 12=>nil, 13=>:enemy}, 13, "x:r", true], [{11=>nil, 12=>nil, 13=>nil}, 13, "x:r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, 14, "x:r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil}, 14, "x:r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "x:r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "x:r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "x:r", false], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:r", true], [{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:r", false], [{19=>nil}, 19, "x:r", false], [{19=>nil, 28=>:enemy}, 28, "x:r", true], [{19=>nil, 28=>nil}, 28, "x:r", false], [{19=>nil, 28=>nil, 37=>:enemy}, 37, "x:r", true], [{19=>nil, 28=>nil, 37=>nil}, 37, "x:r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, 46, "x:r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil}, 46, "x:r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "x:r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "x:r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "x:r", false], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:r", true], [{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:r", false]], 11=>[[{2=>:enemy}, 2, "x:r", true], [{10=>:enemy}, 10, "x:r", true], [{12=>:enemy}, 12, "x:r", true], [{20=>:enemy}, 20, "x:r", true], [{2=>nil}, 2, "x:r", false], [{10=>nil}, 10, "x:r", false], [{10=>nil, 9=>:enemy}, 9, "x:r", true], [{10=>nil, 9=>nil}, 9, "x:r", false], [{12=>nil}, 12, "x:r", false], [{12=>nil, 13=>:enemy}, 13, "x:r", true], [{12=>nil, 13=>nil}, 13, "x:r", false], [{12=>nil, 13=>nil, 14=>:enemy}, 14, "x:r", true], [{12=>nil, 13=>nil, 14=>nil}, 14, "x:r", false], [{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, 15, "x:r", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil}, 15, "x:r", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:r", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "x:r", false], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:r", true], [{12=>nil, 13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:r", false], [{20=>nil}, 20, "x:r", false], [{20=>nil, 29=>:enemy}, 29, "x:r", true], [{20=>nil, 29=>nil}, 29, "x:r", false], [{20=>nil, 29=>nil, 38=>:enemy}, 38, "x:r", true], [{20=>nil, 29=>nil, 38=>nil}, 38, "x:r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, 47, "x:r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil}, 47, "x:r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "x:r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "x:r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "x:r", false], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:r", true], [{20=>nil, 29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:r", false]], 12=>[[{3=>:enemy}, 3, "x:r", true], [{11=>:enemy}, 11, "x:r", true], [{13=>:enemy}, 13, "x:r", true], [{21=>:enemy}, 21, "x:r", true], [{3=>nil}, 3, "x:r", false], [{11=>nil}, 11, "x:r", false], [{11=>nil, 10=>:enemy}, 10, "x:r", true], [{11=>nil, 10=>nil}, 10, "x:r", false], [{11=>nil, 10=>nil, 9=>:enemy}, 9, "x:r", true], [{11=>nil, 10=>nil, 9=>nil}, 9, "x:r", false], [{13=>nil}, 13, "x:r", false], [{13=>nil, 14=>:enemy}, 14, "x:r", true], [{13=>nil, 14=>nil}, 14, "x:r", false], [{13=>nil, 14=>nil, 15=>:enemy}, 15, "x:r", true], [{13=>nil, 14=>nil, 15=>nil}, 15, "x:r", false], [{13=>nil, 14=>nil, 15=>nil, 16=>:enemy}, 16, "x:r", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil}, 16, "x:r", false], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:r", true], [{13=>nil, 14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:r", false], [{21=>nil}, 21, "x:r", false], [{21=>nil, 30=>:enemy}, 30, "x:r", true], [{21=>nil, 30=>nil}, 30, "x:r", false], [{21=>nil, 30=>nil, 39=>:enemy}, 39, "x:r", true], [{21=>nil, 30=>nil, 39=>nil}, 39, "x:r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>:enemy}, 48, "x:r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil}, 48, "x:r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "x:r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "x:r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "x:r", false], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:r", true], [{21=>nil, 30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:r", false]], 13=>[[{4=>:enemy}, 4, "x:r", true], [{12=>:enemy}, 12, "x:r", true], [{14=>:enemy}, 14, "x:r", true], [{22=>:enemy}, 22, "x:r", true], [{4=>nil}, 4, "x:r", false], [{12=>nil}, 12, "x:r", false], [{12=>nil, 11=>:enemy}, 11, "x:r", true], [{12=>nil, 11=>nil}, 11, "x:r", false], [{12=>nil, 11=>nil, 10=>:enemy}, 10, "x:r", true], [{12=>nil, 11=>nil, 10=>nil}, 10, "x:r", false], [{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:r", true], [{12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:r", false], [{14=>nil}, 14, "x:r", false], [{14=>nil, 15=>:enemy}, 15, "x:r", true], [{14=>nil, 15=>nil}, 15, "x:r", false], [{14=>nil, 15=>nil, 16=>:enemy}, 16, "x:r", true], [{14=>nil, 15=>nil, 16=>nil}, 16, "x:r", false], [{14=>nil, 15=>nil, 16=>nil, 17=>:enemy}, 17, "x:r", true], [{14=>nil, 15=>nil, 16=>nil, 17=>nil}, 17, "x:r", false], [{22=>nil}, 22, "x:r", false], [{22=>nil, 31=>:enemy}, 31, "x:r", true], [{22=>nil, 31=>nil}, 31, "x:r", false], [{22=>nil, 31=>nil, 40=>:enemy}, 40, "x:r", true], [{22=>nil, 31=>nil, 40=>nil}, 40, "x:r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>:enemy}, 49, "x:r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil}, 49, "x:r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "x:r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "x:r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "x:r", false], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:r", true], [{22=>nil, 31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:r", false]], 14=>[[{5=>:enemy}, 5, "x:r", true], [{13=>:enemy}, 13, "x:r", true], [{15=>:enemy}, 15, "x:r", true], [{23=>:enemy}, 23, "x:r", true], [{5=>nil}, 5, "x:r", false], [{13=>nil}, 13, "x:r", false], [{13=>nil, 12=>:enemy}, 12, "x:r", true], [{13=>nil, 12=>nil}, 12, "x:r", false], [{13=>nil, 12=>nil, 11=>:enemy}, 11, "x:r", true], [{13=>nil, 12=>nil, 11=>nil}, 11, "x:r", false], [{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:r", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "x:r", false], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:r", true], [{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:r", false], [{15=>nil}, 15, "x:r", false], [{15=>nil, 16=>:enemy}, 16, "x:r", true], [{15=>nil, 16=>nil}, 16, "x:r", false], [{15=>nil, 16=>nil, 17=>:enemy}, 17, "x:r", true], [{15=>nil, 16=>nil, 17=>nil}, 17, "x:r", false], [{23=>nil}, 23, "x:r", false], [{23=>nil, 32=>:enemy}, 32, "x:r", true], [{23=>nil, 32=>nil}, 32, "x:r", false], [{23=>nil, 32=>nil, 41=>:enemy}, 41, "x:r", true], [{23=>nil, 32=>nil, 41=>nil}, 41, "x:r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>:enemy}, 50, "x:r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil}, 50, "x:r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "x:r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "x:r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "x:r", false], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:r", true], [{23=>nil, 32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:r", false]], 15=>[[{6=>:enemy}, 6, "x:r", true], [{14=>:enemy}, 14, "x:r", true], [{16=>:enemy}, 16, "x:r", true], [{24=>:enemy}, 24, "x:r", true], [{6=>nil}, 6, "x:r", false], [{14=>nil}, 14, "x:r", false], [{14=>nil, 13=>:enemy}, 13, "x:r", true], [{14=>nil, 13=>nil}, 13, "x:r", false], [{14=>nil, 13=>nil, 12=>:enemy}, 12, "x:r", true], [{14=>nil, 13=>nil, 12=>nil}, 12, "x:r", false], [{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "x:r", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "x:r", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:r", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "x:r", false], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:r", true], [{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:r", false], [{16=>nil}, 16, "x:r", false], [{16=>nil, 17=>:enemy}, 17, "x:r", true], [{16=>nil, 17=>nil}, 17, "x:r", false], [{24=>nil}, 24, "x:r", false], [{24=>nil, 33=>:enemy}, 33, "x:r", true], [{24=>nil, 33=>nil}, 33, "x:r", false], [{24=>nil, 33=>nil, 42=>:enemy}, 42, "x:r", true], [{24=>nil, 33=>nil, 42=>nil}, 42, "x:r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>:enemy}, 51, "x:r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil}, 51, "x:r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "x:r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "x:r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "x:r", false], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:r", true], [{24=>nil, 33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:r", false]], 16=>[[{7=>:enemy}, 7, "x:r", true], [{15=>:enemy}, 15, "x:r", true], [{17=>:enemy}, 17, "x:r", true], [{25=>:enemy}, 25, "x:r", true], [{7=>nil}, 7, "x:r", false], [{15=>nil}, 15, "x:r", false], [{15=>nil, 14=>:enemy}, 14, "x:r", true], [{15=>nil, 14=>nil}, 14, "x:r", false], [{15=>nil, 14=>nil, 13=>:enemy}, 13, "x:r", true], [{15=>nil, 14=>nil, 13=>nil}, 13, "x:r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "x:r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "x:r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "x:r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "x:r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "x:r", false], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:r", true], [{15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:r", false], [{17=>nil}, 17, "x:r", false], [{25=>nil}, 25, "x:r", false], [{25=>nil, 34=>:enemy}, 34, "x:r", true], [{25=>nil, 34=>nil}, 34, "x:r", false], [{25=>nil, 34=>nil, 43=>:enemy}, 43, "x:r", true], [{25=>nil, 34=>nil, 43=>nil}, 43, "x:r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, 52, "x:r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil}, 52, "x:r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "x:r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "x:r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "x:r", false], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:r", true], [{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:r", false]], 17=>[[{8=>:enemy}, 8, "x:r", true], [{16=>:enemy}, 16, "x:r", true], [{26=>:enemy}, 26, "x:r", true], [{8=>nil}, 8, "x:r", false], [{16=>nil}, 16, "x:r", false], [{16=>nil, 15=>:enemy}, 15, "x:r", true], [{16=>nil, 15=>nil}, 15, "x:r", false], [{16=>nil, 15=>nil, 14=>:enemy}, 14, "x:r", true], [{16=>nil, 15=>nil, 14=>nil}, 14, "x:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>:enemy}, 13, "x:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil}, 13, "x:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>:enemy}, 12, "x:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil}, 12, "x:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, 11, "x:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil}, 11, "x:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, 10, "x:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}, 10, "x:r", false], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, 9, "x:r", true], [{16=>nil, 15=>nil, 14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}, 9, "x:r", false], [{26=>nil}, 26, "x:r", false], [{26=>nil, 35=>:enemy}, 35, "x:r", true], [{26=>nil, 35=>nil}, 35, "x:r", false], [{26=>nil, 35=>nil, 44=>:enemy}, 44, "x:r", true], [{26=>nil, 35=>nil, 44=>nil}, 44, "x:r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, 53, "x:r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil}, 53, "x:r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "x:r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "x:r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "x:r", false], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:r", true], [{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:r", false]], 18=>[[{9=>:enemy}, 9, "x:r", true], [{19=>:enemy}, 19, "x:r", true], [{27=>:enemy}, 27, "x:r", true], [{9=>nil}, 9, "x:r", false], [{9=>nil, 0=>:enemy}, 0, "x:r", true], [{9=>nil, 0=>nil}, 0, "x:r", false], [{19=>nil}, 19, "x:r", false], [{19=>nil, 20=>:enemy}, 20, "x:r", true], [{19=>nil, 20=>nil}, 20, "x:r", false], [{19=>nil, 20=>nil, 21=>:enemy}, 21, "x:r", true], [{19=>nil, 20=>nil, 21=>nil}, 21, "x:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, 22, "x:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil}, 22, "x:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "x:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "x:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "x:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "x:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "x:r", false], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:r", true], [{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:r", false], [{27=>nil}, 27, "x:r", false], [{27=>nil, 36=>:enemy}, 36, "x:r", true], [{27=>nil, 36=>nil}, 36, "x:r", false], [{27=>nil, 36=>nil, 45=>:enemy}, 45, "x:r", true], [{27=>nil, 36=>nil, 45=>nil}, 45, "x:r", false], [{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, 54, "x:r", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil}, 54, "x:r", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:r", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "x:r", false], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:r", true], [{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:r", false]], 19=>[[{10=>:enemy}, 10, "x:r", true], [{18=>:enemy}, 18, "x:r", true], [{20=>:enemy}, 20, "x:r", true], [{28=>:enemy}, 28, "x:r", true], [{10=>nil}, 10, "x:r", false], [{10=>nil, 1=>:enemy}, 1, "x:r", true], [{10=>nil, 1=>nil}, 1, "x:r", false], [{18=>nil}, 18, "x:r", false], [{20=>nil}, 20, "x:r", false], [{20=>nil, 21=>:enemy}, 21, "x:r", true], [{20=>nil, 21=>nil}, 21, "x:r", false], [{20=>nil, 21=>nil, 22=>:enemy}, 22, "x:r", true], [{20=>nil, 21=>nil, 22=>nil}, 22, "x:r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, 23, "x:r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil}, 23, "x:r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "x:r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "x:r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "x:r", false], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:r", true], [{20=>nil, 21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:r", false], [{28=>nil}, 28, "x:r", false], [{28=>nil, 37=>:enemy}, 37, "x:r", true], [{28=>nil, 37=>nil}, 37, "x:r", false], [{28=>nil, 37=>nil, 46=>:enemy}, 46, "x:r", true], [{28=>nil, 37=>nil, 46=>nil}, 46, "x:r", false], [{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, 55, "x:r", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil}, 55, "x:r", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:r", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "x:r", false], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:r", true], [{28=>nil, 37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:r", false]], 20=>[[{11=>:enemy}, 11, "x:r", true], [{19=>:enemy}, 19, "x:r", true], [{21=>:enemy}, 21, "x:r", true], [{29=>:enemy}, 29, "x:r", true], [{11=>nil}, 11, "x:r", false], [{11=>nil, 2=>:enemy}, 2, "x:r", true], [{11=>nil, 2=>nil}, 2, "x:r", false], [{19=>nil}, 19, "x:r", false], [{19=>nil, 18=>:enemy}, 18, "x:r", true], [{19=>nil, 18=>nil}, 18, "x:r", false], [{21=>nil}, 21, "x:r", false], [{21=>nil, 22=>:enemy}, 22, "x:r", true], [{21=>nil, 22=>nil}, 22, "x:r", false], [{21=>nil, 22=>nil, 23=>:enemy}, 23, "x:r", true], [{21=>nil, 22=>nil, 23=>nil}, 23, "x:r", false], [{21=>nil, 22=>nil, 23=>nil, 24=>:enemy}, 24, "x:r", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil}, 24, "x:r", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:r", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "x:r", false], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:r", true], [{21=>nil, 22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:r", false], [{29=>nil}, 29, "x:r", false], [{29=>nil, 38=>:enemy}, 38, "x:r", true], [{29=>nil, 38=>nil}, 38, "x:r", false], [{29=>nil, 38=>nil, 47=>:enemy}, 47, "x:r", true], [{29=>nil, 38=>nil, 47=>nil}, 47, "x:r", false], [{29=>nil, 38=>nil, 47=>nil, 56=>:enemy}, 56, "x:r", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil}, 56, "x:r", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:r", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "x:r", false], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:r", true], [{29=>nil, 38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:r", false]], 21=>[[{12=>:enemy}, 12, "x:r", true], [{20=>:enemy}, 20, "x:r", true], [{22=>:enemy}, 22, "x:r", true], [{30=>:enemy}, 30, "x:r", true], [{12=>nil}, 12, "x:r", false], [{12=>nil, 3=>:enemy}, 3, "x:r", true], [{12=>nil, 3=>nil}, 3, "x:r", false], [{20=>nil}, 20, "x:r", false], [{20=>nil, 19=>:enemy}, 19, "x:r", true], [{20=>nil, 19=>nil}, 19, "x:r", false], [{20=>nil, 19=>nil, 18=>:enemy}, 18, "x:r", true], [{20=>nil, 19=>nil, 18=>nil}, 18, "x:r", false], [{22=>nil}, 22, "x:r", false], [{22=>nil, 23=>:enemy}, 23, "x:r", true], [{22=>nil, 23=>nil}, 23, "x:r", false], [{22=>nil, 23=>nil, 24=>:enemy}, 24, "x:r", true], [{22=>nil, 23=>nil, 24=>nil}, 24, "x:r", false], [{22=>nil, 23=>nil, 24=>nil, 25=>:enemy}, 25, "x:r", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil}, 25, "x:r", false], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:r", true], [{22=>nil, 23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:r", false], [{30=>nil}, 30, "x:r", false], [{30=>nil, 39=>:enemy}, 39, "x:r", true], [{30=>nil, 39=>nil}, 39, "x:r", false], [{30=>nil, 39=>nil, 48=>:enemy}, 48, "x:r", true], [{30=>nil, 39=>nil, 48=>nil}, 48, "x:r", false], [{30=>nil, 39=>nil, 48=>nil, 57=>:enemy}, 57, "x:r", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil}, 57, "x:r", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:r", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "x:r", false], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:r", true], [{30=>nil, 39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:r", false]], 22=>[[{13=>:enemy}, 13, "x:r", true], [{21=>:enemy}, 21, "x:r", true], [{23=>:enemy}, 23, "x:r", true], [{31=>:enemy}, 31, "x:r", true], [{13=>nil}, 13, "x:r", false], [{13=>nil, 4=>:enemy}, 4, "x:r", true], [{13=>nil, 4=>nil}, 4, "x:r", false], [{21=>nil}, 21, "x:r", false], [{21=>nil, 20=>:enemy}, 20, "x:r", true], [{21=>nil, 20=>nil}, 20, "x:r", false], [{21=>nil, 20=>nil, 19=>:enemy}, 19, "x:r", true], [{21=>nil, 20=>nil, 19=>nil}, 19, "x:r", false], [{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:r", true], [{21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:r", false], [{23=>nil}, 23, "x:r", false], [{23=>nil, 24=>:enemy}, 24, "x:r", true], [{23=>nil, 24=>nil}, 24, "x:r", false], [{23=>nil, 24=>nil, 25=>:enemy}, 25, "x:r", true], [{23=>nil, 24=>nil, 25=>nil}, 25, "x:r", false], [{23=>nil, 24=>nil, 25=>nil, 26=>:enemy}, 26, "x:r", true], [{23=>nil, 24=>nil, 25=>nil, 26=>nil}, 26, "x:r", false], [{31=>nil}, 31, "x:r", false], [{31=>nil, 40=>:enemy}, 40, "x:r", true], [{31=>nil, 40=>nil}, 40, "x:r", false], [{31=>nil, 40=>nil, 49=>:enemy}, 49, "x:r", true], [{31=>nil, 40=>nil, 49=>nil}, 49, "x:r", false], [{31=>nil, 40=>nil, 49=>nil, 58=>:enemy}, 58, "x:r", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil}, 58, "x:r", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:r", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "x:r", false], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:r", true], [{31=>nil, 40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:r", false]], 23=>[[{14=>:enemy}, 14, "x:r", true], [{22=>:enemy}, 22, "x:r", true], [{24=>:enemy}, 24, "x:r", true], [{32=>:enemy}, 32, "x:r", true], [{14=>nil}, 14, "x:r", false], [{14=>nil, 5=>:enemy}, 5, "x:r", true], [{14=>nil, 5=>nil}, 5, "x:r", false], [{22=>nil}, 22, "x:r", false], [{22=>nil, 21=>:enemy}, 21, "x:r", true], [{22=>nil, 21=>nil}, 21, "x:r", false], [{22=>nil, 21=>nil, 20=>:enemy}, 20, "x:r", true], [{22=>nil, 21=>nil, 20=>nil}, 20, "x:r", false], [{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:r", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "x:r", false], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:r", true], [{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:r", false], [{24=>nil}, 24, "x:r", false], [{24=>nil, 25=>:enemy}, 25, "x:r", true], [{24=>nil, 25=>nil}, 25, "x:r", false], [{24=>nil, 25=>nil, 26=>:enemy}, 26, "x:r", true], [{24=>nil, 25=>nil, 26=>nil}, 26, "x:r", false], [{32=>nil}, 32, "x:r", false], [{32=>nil, 41=>:enemy}, 41, "x:r", true], [{32=>nil, 41=>nil}, 41, "x:r", false], [{32=>nil, 41=>nil, 50=>:enemy}, 50, "x:r", true], [{32=>nil, 41=>nil, 50=>nil}, 50, "x:r", false], [{32=>nil, 41=>nil, 50=>nil, 59=>:enemy}, 59, "x:r", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil}, 59, "x:r", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:r", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "x:r", false], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:r", true], [{32=>nil, 41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:r", false]], 24=>[[{15=>:enemy}, 15, "x:r", true], [{23=>:enemy}, 23, "x:r", true], [{25=>:enemy}, 25, "x:r", true], [{33=>:enemy}, 33, "x:r", true], [{15=>nil}, 15, "x:r", false], [{15=>nil, 6=>:enemy}, 6, "x:r", true], [{15=>nil, 6=>nil}, 6, "x:r", false], [{23=>nil}, 23, "x:r", false], [{23=>nil, 22=>:enemy}, 22, "x:r", true], [{23=>nil, 22=>nil}, 22, "x:r", false], [{23=>nil, 22=>nil, 21=>:enemy}, 21, "x:r", true], [{23=>nil, 22=>nil, 21=>nil}, 21, "x:r", false], [{23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "x:r", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "x:r", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:r", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "x:r", false], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:r", true], [{23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:r", false], [{25=>nil}, 25, "x:r", false], [{25=>nil, 26=>:enemy}, 26, "x:r", true], [{25=>nil, 26=>nil}, 26, "x:r", false], [{33=>nil}, 33, "x:r", false], [{33=>nil, 42=>:enemy}, 42, "x:r", true], [{33=>nil, 42=>nil}, 42, "x:r", false], [{33=>nil, 42=>nil, 51=>:enemy}, 51, "x:r", true], [{33=>nil, 42=>nil, 51=>nil}, 51, "x:r", false], [{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, 60, "x:r", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil}, 60, "x:r", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:r", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "x:r", false], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:r", true], [{33=>nil, 42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:r", false]], 25=>[[{16=>:enemy}, 16, "x:r", true], [{24=>:enemy}, 24, "x:r", true], [{26=>:enemy}, 26, "x:r", true], [{34=>:enemy}, 34, "x:r", true], [{16=>nil}, 16, "x:r", false], [{16=>nil, 7=>:enemy}, 7, "x:r", true], [{16=>nil, 7=>nil}, 7, "x:r", false], [{24=>nil}, 24, "x:r", false], [{24=>nil, 23=>:enemy}, 23, "x:r", true], [{24=>nil, 23=>nil}, 23, "x:r", false], [{24=>nil, 23=>nil, 22=>:enemy}, 22, "x:r", true], [{24=>nil, 23=>nil, 22=>nil}, 22, "x:r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "x:r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "x:r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "x:r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "x:r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "x:r", false], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:r", true], [{24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:r", false], [{26=>nil}, 26, "x:r", false], [{34=>nil}, 34, "x:r", false], [{34=>nil, 43=>:enemy}, 43, "x:r", true], [{34=>nil, 43=>nil}, 43, "x:r", false], [{34=>nil, 43=>nil, 52=>:enemy}, 52, "x:r", true], [{34=>nil, 43=>nil, 52=>nil}, 52, "x:r", false], [{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, 61, "x:r", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil}, 61, "x:r", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:r", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "x:r", false], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:r", true], [{34=>nil, 43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:r", false]], 26=>[[{17=>:enemy}, 17, "x:r", true], [{25=>:enemy}, 25, "x:r", true], [{35=>:enemy}, 35, "x:r", true], [{17=>nil}, 17, "x:r", false], [{17=>nil, 8=>:enemy}, 8, "x:r", true], [{17=>nil, 8=>nil}, 8, "x:r", false], [{25=>nil}, 25, "x:r", false], [{25=>nil, 24=>:enemy}, 24, "x:r", true], [{25=>nil, 24=>nil}, 24, "x:r", false], [{25=>nil, 24=>nil, 23=>:enemy}, 23, "x:r", true], [{25=>nil, 24=>nil, 23=>nil}, 23, "x:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>:enemy}, 22, "x:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil}, 22, "x:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>:enemy}, 21, "x:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil}, 21, "x:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>:enemy}, 20, "x:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil}, 20, "x:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, 19, "x:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil}, 19, "x:r", false], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, 18, "x:r", true], [{25=>nil, 24=>nil, 23=>nil, 22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}, 18, "x:r", false], [{35=>nil}, 35, "x:r", false], [{35=>nil, 44=>:enemy}, 44, "x:r", true], [{35=>nil, 44=>nil}, 44, "x:r", false], [{35=>nil, 44=>nil, 53=>:enemy}, 53, "x:r", true], [{35=>nil, 44=>nil, 53=>nil}, 53, "x:r", false], [{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, 62, "x:r", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil}, 62, "x:r", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:r", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "x:r", false], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:r", true], [{35=>nil, 44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:r", false]], 27=>[[{18=>:enemy}, 18, "x:r", true], [{28=>:enemy}, 28, "x:r", true], [{36=>:enemy}, 36, "x:r", true], [{18=>nil}, 18, "x:r", false], [{18=>nil, 9=>:enemy}, 9, "x:r", true], [{18=>nil, 9=>nil}, 9, "x:r", false], [{18=>nil, 9=>nil, 0=>:enemy}, 0, "x:r", true], [{18=>nil, 9=>nil, 0=>nil}, 0, "x:r", false], [{28=>nil}, 28, "x:r", false], [{28=>nil, 29=>:enemy}, 29, "x:r", true], [{28=>nil, 29=>nil}, 29, "x:r", false], [{28=>nil, 29=>nil, 30=>:enemy}, 30, "x:r", true], [{28=>nil, 29=>nil, 30=>nil}, 30, "x:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, 31, "x:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil}, 31, "x:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "x:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "x:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "x:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "x:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "x:r", false], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:r", true], [{28=>nil, 29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:r", false], [{36=>nil}, 36, "x:r", false], [{36=>nil, 45=>:enemy}, 45, "x:r", true], [{36=>nil, 45=>nil}, 45, "x:r", false], [{36=>nil, 45=>nil, 54=>:enemy}, 54, "x:r", true], [{36=>nil, 45=>nil, 54=>nil}, 54, "x:r", false], [{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, 63, "x:r", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil}, 63, "x:r", false], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:r", true], [{36=>nil, 45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:r", false]], 28=>[[{19=>:enemy}, 19, "x:r", true], [{27=>:enemy}, 27, "x:r", true], [{29=>:enemy}, 29, "x:r", true], [{37=>:enemy}, 37, "x:r", true], [{19=>nil}, 19, "x:r", false], [{19=>nil, 10=>:enemy}, 10, "x:r", true], [{19=>nil, 10=>nil}, 10, "x:r", false], [{19=>nil, 10=>nil, 1=>:enemy}, 1, "x:r", true], [{19=>nil, 10=>nil, 1=>nil}, 1, "x:r", false], [{27=>nil}, 27, "x:r", false], [{29=>nil}, 29, "x:r", false], [{29=>nil, 30=>:enemy}, 30, "x:r", true], [{29=>nil, 30=>nil}, 30, "x:r", false], [{29=>nil, 30=>nil, 31=>:enemy}, 31, "x:r", true], [{29=>nil, 30=>nil, 31=>nil}, 31, "x:r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>:enemy}, 32, "x:r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil}, 32, "x:r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "x:r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "x:r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "x:r", false], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:r", true], [{29=>nil, 30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:r", false], [{37=>nil}, 37, "x:r", false], [{37=>nil, 46=>:enemy}, 46, "x:r", true], [{37=>nil, 46=>nil}, 46, "x:r", false], [{37=>nil, 46=>nil, 55=>:enemy}, 55, "x:r", true], [{37=>nil, 46=>nil, 55=>nil}, 55, "x:r", false], [{37=>nil, 46=>nil, 55=>nil, 64=>:enemy}, 64, "x:r", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil}, 64, "x:r", false], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:r", true], [{37=>nil, 46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:r", false]], 29=>[[{20=>:enemy}, 20, "x:r", true], [{28=>:enemy}, 28, "x:r", true], [{30=>:enemy}, 30, "x:r", true], [{38=>:enemy}, 38, "x:r", true], [{20=>nil}, 20, "x:r", false], [{20=>nil, 11=>:enemy}, 11, "x:r", true], [{20=>nil, 11=>nil}, 11, "x:r", false], [{20=>nil, 11=>nil, 2=>:enemy}, 2, "x:r", true], [{20=>nil, 11=>nil, 2=>nil}, 2, "x:r", false], [{28=>nil}, 28, "x:r", false], [{28=>nil, 27=>:enemy}, 27, "x:r", true], [{28=>nil, 27=>nil}, 27, "x:r", false], [{30=>nil}, 30, "x:r", false], [{30=>nil, 31=>:enemy}, 31, "x:r", true], [{30=>nil, 31=>nil}, 31, "x:r", false], [{30=>nil, 31=>nil, 32=>:enemy}, 32, "x:r", true], [{30=>nil, 31=>nil, 32=>nil}, 32, "x:r", false], [{30=>nil, 31=>nil, 32=>nil, 33=>:enemy}, 33, "x:r", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil}, 33, "x:r", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:r", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "x:r", false], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:r", true], [{30=>nil, 31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:r", false], [{38=>nil}, 38, "x:r", false], [{38=>nil, 47=>:enemy}, 47, "x:r", true], [{38=>nil, 47=>nil}, 47, "x:r", false], [{38=>nil, 47=>nil, 56=>:enemy}, 56, "x:r", true], [{38=>nil, 47=>nil, 56=>nil}, 56, "x:r", false], [{38=>nil, 47=>nil, 56=>nil, 65=>:enemy}, 65, "x:r", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil}, 65, "x:r", false], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:r", true], [{38=>nil, 47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:r", false]], 30=>[[{21=>:enemy}, 21, "x:r", true], [{29=>:enemy}, 29, "x:r", true], [{31=>:enemy}, 31, "x:r", true], [{39=>:enemy}, 39, "x:r", true], [{21=>nil}, 21, "x:r", false], [{21=>nil, 12=>:enemy}, 12, "x:r", true], [{21=>nil, 12=>nil}, 12, "x:r", false], [{21=>nil, 12=>nil, 3=>:enemy}, 3, "x:r", true], [{21=>nil, 12=>nil, 3=>nil}, 3, "x:r", false], [{29=>nil}, 29, "x:r", false], [{29=>nil, 28=>:enemy}, 28, "x:r", true], [{29=>nil, 28=>nil}, 28, "x:r", false], [{29=>nil, 28=>nil, 27=>:enemy}, 27, "x:r", true], [{29=>nil, 28=>nil, 27=>nil}, 27, "x:r", false], [{31=>nil}, 31, "x:r", false], [{31=>nil, 32=>:enemy}, 32, "x:r", true], [{31=>nil, 32=>nil}, 32, "x:r", false], [{31=>nil, 32=>nil, 33=>:enemy}, 33, "x:r", true], [{31=>nil, 32=>nil, 33=>nil}, 33, "x:r", false], [{31=>nil, 32=>nil, 33=>nil, 34=>:enemy}, 34, "x:r", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil}, 34, "x:r", false], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:r", true], [{31=>nil, 32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:r", false], [{39=>nil}, 39, "x:r", false], [{39=>nil, 48=>:enemy}, 48, "x:r", true], [{39=>nil, 48=>nil}, 48, "x:r", false], [{39=>nil, 48=>nil, 57=>:enemy}, 57, "x:r", true], [{39=>nil, 48=>nil, 57=>nil}, 57, "x:r", false], [{39=>nil, 48=>nil, 57=>nil, 66=>:enemy}, 66, "x:r", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil}, 66, "x:r", false], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:r", true], [{39=>nil, 48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:r", false]], 31=>[[{22=>:enemy}, 22, "x:r", true], [{30=>:enemy}, 30, "x:r", true], [{32=>:enemy}, 32, "x:r", true], [{40=>:enemy}, 40, "x:r", true], [{22=>nil}, 22, "x:r", false], [{22=>nil, 13=>:enemy}, 13, "x:r", true], [{22=>nil, 13=>nil}, 13, "x:r", false], [{22=>nil, 13=>nil, 4=>:enemy}, 4, "x:r", true], [{22=>nil, 13=>nil, 4=>nil}, 4, "x:r", false], [{30=>nil}, 30, "x:r", false], [{30=>nil, 29=>:enemy}, 29, "x:r", true], [{30=>nil, 29=>nil}, 29, "x:r", false], [{30=>nil, 29=>nil, 28=>:enemy}, 28, "x:r", true], [{30=>nil, 29=>nil, 28=>nil}, 28, "x:r", false], [{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:r", true], [{30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:r", false], [{32=>nil}, 32, "x:r", false], [{32=>nil, 33=>:enemy}, 33, "x:r", true], [{32=>nil, 33=>nil}, 33, "x:r", false], [{32=>nil, 33=>nil, 34=>:enemy}, 34, "x:r", true], [{32=>nil, 33=>nil, 34=>nil}, 34, "x:r", false], [{32=>nil, 33=>nil, 34=>nil, 35=>:enemy}, 35, "x:r", true], [{32=>nil, 33=>nil, 34=>nil, 35=>nil}, 35, "x:r", false], [{40=>nil}, 40, "x:r", false], [{40=>nil, 49=>:enemy}, 49, "x:r", true], [{40=>nil, 49=>nil}, 49, "x:r", false], [{40=>nil, 49=>nil, 58=>:enemy}, 58, "x:r", true], [{40=>nil, 49=>nil, 58=>nil}, 58, "x:r", false], [{40=>nil, 49=>nil, 58=>nil, 67=>:enemy}, 67, "x:r", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil}, 67, "x:r", false], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:r", true], [{40=>nil, 49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:r", false]], 32=>[[{23=>:enemy}, 23, "x:r", true], [{31=>:enemy}, 31, "x:r", true], [{33=>:enemy}, 33, "x:r", true], [{41=>:enemy}, 41, "x:r", true], [{23=>nil}, 23, "x:r", false], [{23=>nil, 14=>:enemy}, 14, "x:r", true], [{23=>nil, 14=>nil}, 14, "x:r", false], [{23=>nil, 14=>nil, 5=>:enemy}, 5, "x:r", true], [{23=>nil, 14=>nil, 5=>nil}, 5, "x:r", false], [{31=>nil}, 31, "x:r", false], [{31=>nil, 30=>:enemy}, 30, "x:r", true], [{31=>nil, 30=>nil}, 30, "x:r", false], [{31=>nil, 30=>nil, 29=>:enemy}, 29, "x:r", true], [{31=>nil, 30=>nil, 29=>nil}, 29, "x:r", false], [{31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:r", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "x:r", false], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:r", true], [{31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:r", false], [{33=>nil}, 33, "x:r", false], [{33=>nil, 34=>:enemy}, 34, "x:r", true], [{33=>nil, 34=>nil}, 34, "x:r", false], [{33=>nil, 34=>nil, 35=>:enemy}, 35, "x:r", true], [{33=>nil, 34=>nil, 35=>nil}, 35, "x:r", false], [{41=>nil}, 41, "x:r", false], [{41=>nil, 50=>:enemy}, 50, "x:r", true], [{41=>nil, 50=>nil}, 50, "x:r", false], [{41=>nil, 50=>nil, 59=>:enemy}, 59, "x:r", true], [{41=>nil, 50=>nil, 59=>nil}, 59, "x:r", false], [{41=>nil, 50=>nil, 59=>nil, 68=>:enemy}, 68, "x:r", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil}, 68, "x:r", false], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:r", true], [{41=>nil, 50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:r", false]], 33=>[[{24=>:enemy}, 24, "x:r", true], [{32=>:enemy}, 32, "x:r", true], [{34=>:enemy}, 34, "x:r", true], [{42=>:enemy}, 42, "x:r", true], [{24=>nil}, 24, "x:r", false], [{24=>nil, 15=>:enemy}, 15, "x:r", true], [{24=>nil, 15=>nil}, 15, "x:r", false], [{24=>nil, 15=>nil, 6=>:enemy}, 6, "x:r", true], [{24=>nil, 15=>nil, 6=>nil}, 6, "x:r", false], [{32=>nil}, 32, "x:r", false], [{32=>nil, 31=>:enemy}, 31, "x:r", true], [{32=>nil, 31=>nil}, 31, "x:r", false], [{32=>nil, 31=>nil, 30=>:enemy}, 30, "x:r", true], [{32=>nil, 31=>nil, 30=>nil}, 30, "x:r", false], [{32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "x:r", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "x:r", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:r", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "x:r", false], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:r", true], [{32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:r", false], [{34=>nil}, 34, "x:r", false], [{34=>nil, 35=>:enemy}, 35, "x:r", true], [{34=>nil, 35=>nil}, 35, "x:r", false], [{42=>nil}, 42, "x:r", false], [{42=>nil, 51=>:enemy}, 51, "x:r", true], [{42=>nil, 51=>nil}, 51, "x:r", false], [{42=>nil, 51=>nil, 60=>:enemy}, 60, "x:r", true], [{42=>nil, 51=>nil, 60=>nil}, 60, "x:r", false], [{42=>nil, 51=>nil, 60=>nil, 69=>:enemy}, 69, "x:r", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil}, 69, "x:r", false], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:r", true], [{42=>nil, 51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:r", false]], 34=>[[{25=>:enemy}, 25, "x:r", true], [{33=>:enemy}, 33, "x:r", true], [{35=>:enemy}, 35, "x:r", true], [{43=>:enemy}, 43, "x:r", true], [{25=>nil}, 25, "x:r", false], [{25=>nil, 16=>:enemy}, 16, "x:r", true], [{25=>nil, 16=>nil}, 16, "x:r", false], [{25=>nil, 16=>nil, 7=>:enemy}, 7, "x:r", true], [{25=>nil, 16=>nil, 7=>nil}, 7, "x:r", false], [{33=>nil}, 33, "x:r", false], [{33=>nil, 32=>:enemy}, 32, "x:r", true], [{33=>nil, 32=>nil}, 32, "x:r", false], [{33=>nil, 32=>nil, 31=>:enemy}, 31, "x:r", true], [{33=>nil, 32=>nil, 31=>nil}, 31, "x:r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "x:r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "x:r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "x:r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "x:r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "x:r", false], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:r", true], [{33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:r", false], [{35=>nil}, 35, "x:r", false], [{43=>nil}, 43, "x:r", false], [{43=>nil, 52=>:enemy}, 52, "x:r", true], [{43=>nil, 52=>nil}, 52, "x:r", false], [{43=>nil, 52=>nil, 61=>:enemy}, 61, "x:r", true], [{43=>nil, 52=>nil, 61=>nil}, 61, "x:r", false], [{43=>nil, 52=>nil, 61=>nil, 70=>:enemy}, 70, "x:r", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil}, 70, "x:r", false], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:r", true], [{43=>nil, 52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:r", false]], 35=>[[{26=>:enemy}, 26, "x:r", true], [{34=>:enemy}, 34, "x:r", true], [{44=>:enemy}, 44, "x:r", true], [{26=>nil}, 26, "x:r", false], [{26=>nil, 17=>:enemy}, 17, "x:r", true], [{26=>nil, 17=>nil}, 17, "x:r", false], [{26=>nil, 17=>nil, 8=>:enemy}, 8, "x:r", true], [{26=>nil, 17=>nil, 8=>nil}, 8, "x:r", false], [{34=>nil}, 34, "x:r", false], [{34=>nil, 33=>:enemy}, 33, "x:r", true], [{34=>nil, 33=>nil}, 33, "x:r", false], [{34=>nil, 33=>nil, 32=>:enemy}, 32, "x:r", true], [{34=>nil, 33=>nil, 32=>nil}, 32, "x:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>:enemy}, 31, "x:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil}, 31, "x:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>:enemy}, 30, "x:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil}, 30, "x:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>:enemy}, 29, "x:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil}, 29, "x:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>:enemy}, 28, "x:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil}, 28, "x:r", false], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, 27, "x:r", true], [{34=>nil, 33=>nil, 32=>nil, 31=>nil, 30=>nil, 29=>nil, 28=>nil, 27=>nil}, 27, "x:r", false], [{44=>nil}, 44, "x:r", false], [{44=>nil, 53=>:enemy}, 53, "x:r", true], [{44=>nil, 53=>nil}, 53, "x:r", false], [{44=>nil, 53=>nil, 62=>:enemy}, 62, "x:r", true], [{44=>nil, 53=>nil, 62=>nil}, 62, "x:r", false], [{44=>nil, 53=>nil, 62=>nil, 71=>:enemy}, 71, "x:r", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil}, 71, "x:r", false], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:r", true], [{44=>nil, 53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:r", false]], 36=>[[{27=>:enemy}, 27, "x:r", true], [{37=>:enemy}, 37, "x:r", true], [{45=>:enemy}, 45, "x:r", true], [{27=>nil}, 27, "x:r", false], [{27=>nil, 18=>:enemy}, 18, "x:r", true], [{27=>nil, 18=>nil}, 18, "x:r", false], [{27=>nil, 18=>nil, 9=>:enemy}, 9, "x:r", true], [{27=>nil, 18=>nil, 9=>nil}, 9, "x:r", false], [{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:r", true], [{27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:r", false], [{37=>nil}, 37, "x:r", false], [{37=>nil, 38=>:enemy}, 38, "x:r", true], [{37=>nil, 38=>nil}, 38, "x:r", false], [{37=>nil, 38=>nil, 39=>:enemy}, 39, "x:r", true], [{37=>nil, 38=>nil, 39=>nil}, 39, "x:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>:enemy}, 40, "x:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil}, 40, "x:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "x:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "x:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "x:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "x:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "x:r", false], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:r", true], [{37=>nil, 38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:r", false], [{45=>nil}, 45, "x:r", false], [{45=>nil, 54=>:enemy}, 54, "x:r", true], [{45=>nil, 54=>nil}, 54, "x:r", false], [{45=>nil, 54=>nil, 63=>:enemy}, 63, "x:r", true], [{45=>nil, 54=>nil, 63=>nil}, 63, "x:r", false], [{45=>nil, 54=>nil, 63=>nil, 72=>:enemy}, 72, "x:r", true], [{45=>nil, 54=>nil, 63=>nil, 72=>nil}, 72, "x:r", false]], 37=>[[{28=>:enemy}, 28, "x:r", true], [{36=>:enemy}, 36, "x:r", true], [{38=>:enemy}, 38, "x:r", true], [{46=>:enemy}, 46, "x:r", true], [{28=>nil}, 28, "x:r", false], [{28=>nil, 19=>:enemy}, 19, "x:r", true], [{28=>nil, 19=>nil}, 19, "x:r", false], [{28=>nil, 19=>nil, 10=>:enemy}, 10, "x:r", true], [{28=>nil, 19=>nil, 10=>nil}, 10, "x:r", false], [{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:r", true], [{28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:r", false], [{36=>nil}, 36, "x:r", false], [{38=>nil}, 38, "x:r", false], [{38=>nil, 39=>:enemy}, 39, "x:r", true], [{38=>nil, 39=>nil}, 39, "x:r", false], [{38=>nil, 39=>nil, 40=>:enemy}, 40, "x:r", true], [{38=>nil, 39=>nil, 40=>nil}, 40, "x:r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>:enemy}, 41, "x:r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil}, 41, "x:r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "x:r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "x:r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "x:r", false], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:r", true], [{38=>nil, 39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:r", false], [{46=>nil}, 46, "x:r", false], [{46=>nil, 55=>:enemy}, 55, "x:r", true], [{46=>nil, 55=>nil}, 55, "x:r", false], [{46=>nil, 55=>nil, 64=>:enemy}, 64, "x:r", true], [{46=>nil, 55=>nil, 64=>nil}, 64, "x:r", false], [{46=>nil, 55=>nil, 64=>nil, 73=>:enemy}, 73, "x:r", true], [{46=>nil, 55=>nil, 64=>nil, 73=>nil}, 73, "x:r", false]], 38=>[[{29=>:enemy}, 29, "x:r", true], [{37=>:enemy}, 37, "x:r", true], [{39=>:enemy}, 39, "x:r", true], [{47=>:enemy}, 47, "x:r", true], [{29=>nil}, 29, "x:r", false], [{29=>nil, 20=>:enemy}, 20, "x:r", true], [{29=>nil, 20=>nil}, 20, "x:r", false], [{29=>nil, 20=>nil, 11=>:enemy}, 11, "x:r", true], [{29=>nil, 20=>nil, 11=>nil}, 11, "x:r", false], [{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:r", true], [{29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:r", false], [{37=>nil}, 37, "x:r", false], [{37=>nil, 36=>:enemy}, 36, "x:r", true], [{37=>nil, 36=>nil}, 36, "x:r", false], [{39=>nil}, 39, "x:r", false], [{39=>nil, 40=>:enemy}, 40, "x:r", true], [{39=>nil, 40=>nil}, 40, "x:r", false], [{39=>nil, 40=>nil, 41=>:enemy}, 41, "x:r", true], [{39=>nil, 40=>nil, 41=>nil}, 41, "x:r", false], [{39=>nil, 40=>nil, 41=>nil, 42=>:enemy}, 42, "x:r", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil}, 42, "x:r", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:r", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "x:r", false], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:r", true], [{39=>nil, 40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:r", false], [{47=>nil}, 47, "x:r", false], [{47=>nil, 56=>:enemy}, 56, "x:r", true], [{47=>nil, 56=>nil}, 56, "x:r", false], [{47=>nil, 56=>nil, 65=>:enemy}, 65, "x:r", true], [{47=>nil, 56=>nil, 65=>nil}, 65, "x:r", false], [{47=>nil, 56=>nil, 65=>nil, 74=>:enemy}, 74, "x:r", true], [{47=>nil, 56=>nil, 65=>nil, 74=>nil}, 74, "x:r", false]], 39=>[[{30=>:enemy}, 30, "x:r", true], [{38=>:enemy}, 38, "x:r", true], [{40=>:enemy}, 40, "x:r", true], [{48=>:enemy}, 48, "x:r", true], [{30=>nil}, 30, "x:r", false], [{30=>nil, 21=>:enemy}, 21, "x:r", true], [{30=>nil, 21=>nil}, 21, "x:r", false], [{30=>nil, 21=>nil, 12=>:enemy}, 12, "x:r", true], [{30=>nil, 21=>nil, 12=>nil}, 12, "x:r", false], [{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:r", true], [{30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:r", false], [{38=>nil}, 38, "x:r", false], [{38=>nil, 37=>:enemy}, 37, "x:r", true], [{38=>nil, 37=>nil}, 37, "x:r", false], [{38=>nil, 37=>nil, 36=>:enemy}, 36, "x:r", true], [{38=>nil, 37=>nil, 36=>nil}, 36, "x:r", false], [{40=>nil}, 40, "x:r", false], [{40=>nil, 41=>:enemy}, 41, "x:r", true], [{40=>nil, 41=>nil}, 41, "x:r", false], [{40=>nil, 41=>nil, 42=>:enemy}, 42, "x:r", true], [{40=>nil, 41=>nil, 42=>nil}, 42, "x:r", false], [{40=>nil, 41=>nil, 42=>nil, 43=>:enemy}, 43, "x:r", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil}, 43, "x:r", false], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:r", true], [{40=>nil, 41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:r", false], [{48=>nil}, 48, "x:r", false], [{48=>nil, 57=>:enemy}, 57, "x:r", true], [{48=>nil, 57=>nil}, 57, "x:r", false], [{48=>nil, 57=>nil, 66=>:enemy}, 66, "x:r", true], [{48=>nil, 57=>nil, 66=>nil}, 66, "x:r", false], [{48=>nil, 57=>nil, 66=>nil, 75=>:enemy}, 75, "x:r", true], [{48=>nil, 57=>nil, 66=>nil, 75=>nil}, 75, "x:r", false]], 40=>[[{31=>:enemy}, 31, "x:r", true], [{39=>:enemy}, 39, "x:r", true], [{41=>:enemy}, 41, "x:r", true], [{49=>:enemy}, 49, "x:r", true], [{31=>nil}, 31, "x:r", false], [{31=>nil, 22=>:enemy}, 22, "x:r", true], [{31=>nil, 22=>nil}, 22, "x:r", false], [{31=>nil, 22=>nil, 13=>:enemy}, 13, "x:r", true], [{31=>nil, 22=>nil, 13=>nil}, 13, "x:r", false], [{31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:r", true], [{31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:r", false], [{39=>nil}, 39, "x:r", false], [{39=>nil, 38=>:enemy}, 38, "x:r", true], [{39=>nil, 38=>nil}, 38, "x:r", false], [{39=>nil, 38=>nil, 37=>:enemy}, 37, "x:r", true], [{39=>nil, 38=>nil, 37=>nil}, 37, "x:r", false], [{39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:r", true], [{39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:r", false], [{41=>nil}, 41, "x:r", false], [{41=>nil, 42=>:enemy}, 42, "x:r", true], [{41=>nil, 42=>nil}, 42, "x:r", false], [{41=>nil, 42=>nil, 43=>:enemy}, 43, "x:r", true], [{41=>nil, 42=>nil, 43=>nil}, 43, "x:r", false], [{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, 44, "x:r", true], [{41=>nil, 42=>nil, 43=>nil, 44=>nil}, 44, "x:r", false], [{49=>nil}, 49, "x:r", false], [{49=>nil, 58=>:enemy}, 58, "x:r", true], [{49=>nil, 58=>nil}, 58, "x:r", false], [{49=>nil, 58=>nil, 67=>:enemy}, 67, "x:r", true], [{49=>nil, 58=>nil, 67=>nil}, 67, "x:r", false], [{49=>nil, 58=>nil, 67=>nil, 76=>:enemy}, 76, "x:r", true], [{49=>nil, 58=>nil, 67=>nil, 76=>nil}, 76, "x:r", false]], 41=>[[{32=>:enemy}, 32, "x:r", true], [{40=>:enemy}, 40, "x:r", true], [{42=>:enemy}, 42, "x:r", true], [{50=>:enemy}, 50, "x:r", true], [{32=>nil}, 32, "x:r", false], [{32=>nil, 23=>:enemy}, 23, "x:r", true], [{32=>nil, 23=>nil}, 23, "x:r", false], [{32=>nil, 23=>nil, 14=>:enemy}, 14, "x:r", true], [{32=>nil, 23=>nil, 14=>nil}, 14, "x:r", false], [{32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:r", true], [{32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:r", false], [{40=>nil}, 40, "x:r", false], [{40=>nil, 39=>:enemy}, 39, "x:r", true], [{40=>nil, 39=>nil}, 39, "x:r", false], [{40=>nil, 39=>nil, 38=>:enemy}, 38, "x:r", true], [{40=>nil, 39=>nil, 38=>nil}, 38, "x:r", false], [{40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:r", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "x:r", false], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:r", true], [{40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:r", false], [{42=>nil}, 42, "x:r", false], [{42=>nil, 43=>:enemy}, 43, "x:r", true], [{42=>nil, 43=>nil}, 43, "x:r", false], [{42=>nil, 43=>nil, 44=>:enemy}, 44, "x:r", true], [{42=>nil, 43=>nil, 44=>nil}, 44, "x:r", false], [{50=>nil}, 50, "x:r", false], [{50=>nil, 59=>:enemy}, 59, "x:r", true], [{50=>nil, 59=>nil}, 59, "x:r", false], [{50=>nil, 59=>nil, 68=>:enemy}, 68, "x:r", true], [{50=>nil, 59=>nil, 68=>nil}, 68, "x:r", false], [{50=>nil, 59=>nil, 68=>nil, 77=>:enemy}, 77, "x:r", true], [{50=>nil, 59=>nil, 68=>nil, 77=>nil}, 77, "x:r", false]], 42=>[[{33=>:enemy}, 33, "x:r", true], [{41=>:enemy}, 41, "x:r", true], [{43=>:enemy}, 43, "x:r", true], [{51=>:enemy}, 51, "x:r", true], [{33=>nil}, 33, "x:r", false], [{33=>nil, 24=>:enemy}, 24, "x:r", true], [{33=>nil, 24=>nil}, 24, "x:r", false], [{33=>nil, 24=>nil, 15=>:enemy}, 15, "x:r", true], [{33=>nil, 24=>nil, 15=>nil}, 15, "x:r", false], [{33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:r", true], [{33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:r", false], [{41=>nil}, 41, "x:r", false], [{41=>nil, 40=>:enemy}, 40, "x:r", true], [{41=>nil, 40=>nil}, 40, "x:r", false], [{41=>nil, 40=>nil, 39=>:enemy}, 39, "x:r", true], [{41=>nil, 40=>nil, 39=>nil}, 39, "x:r", false], [{41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "x:r", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "x:r", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:r", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "x:r", false], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:r", true], [{41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:r", false], [{43=>nil}, 43, "x:r", false], [{43=>nil, 44=>:enemy}, 44, "x:r", true], [{43=>nil, 44=>nil}, 44, "x:r", false], [{51=>nil}, 51, "x:r", false], [{51=>nil, 60=>:enemy}, 60, "x:r", true], [{51=>nil, 60=>nil}, 60, "x:r", false], [{51=>nil, 60=>nil, 69=>:enemy}, 69, "x:r", true], [{51=>nil, 60=>nil, 69=>nil}, 69, "x:r", false], [{51=>nil, 60=>nil, 69=>nil, 78=>:enemy}, 78, "x:r", true], [{51=>nil, 60=>nil, 69=>nil, 78=>nil}, 78, "x:r", false]], 43=>[[{34=>:enemy}, 34, "x:r", true], [{42=>:enemy}, 42, "x:r", true], [{44=>:enemy}, 44, "x:r", true], [{52=>:enemy}, 52, "x:r", true], [{34=>nil}, 34, "x:r", false], [{34=>nil, 25=>:enemy}, 25, "x:r", true], [{34=>nil, 25=>nil}, 25, "x:r", false], [{34=>nil, 25=>nil, 16=>:enemy}, 16, "x:r", true], [{34=>nil, 25=>nil, 16=>nil}, 16, "x:r", false], [{34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:r", true], [{34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:r", false], [{42=>nil}, 42, "x:r", false], [{42=>nil, 41=>:enemy}, 41, "x:r", true], [{42=>nil, 41=>nil}, 41, "x:r", false], [{42=>nil, 41=>nil, 40=>:enemy}, 40, "x:r", true], [{42=>nil, 41=>nil, 40=>nil}, 40, "x:r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "x:r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "x:r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "x:r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "x:r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "x:r", false], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:r", true], [{42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:r", false], [{44=>nil}, 44, "x:r", false], [{52=>nil}, 52, "x:r", false], [{52=>nil, 61=>:enemy}, 61, "x:r", true], [{52=>nil, 61=>nil}, 61, "x:r", false], [{52=>nil, 61=>nil, 70=>:enemy}, 70, "x:r", true], [{52=>nil, 61=>nil, 70=>nil}, 70, "x:r", false], [{52=>nil, 61=>nil, 70=>nil, 79=>:enemy}, 79, "x:r", true], [{52=>nil, 61=>nil, 70=>nil, 79=>nil}, 79, "x:r", false]], 44=>[[{35=>:enemy}, 35, "x:r", true], [{43=>:enemy}, 43, "x:r", true], [{53=>:enemy}, 53, "x:r", true], [{35=>nil}, 35, "x:r", false], [{35=>nil, 26=>:enemy}, 26, "x:r", true], [{35=>nil, 26=>nil}, 26, "x:r", false], [{35=>nil, 26=>nil, 17=>:enemy}, 17, "x:r", true], [{35=>nil, 26=>nil, 17=>nil}, 17, "x:r", false], [{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:r", true], [{35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:r", false], [{43=>nil}, 43, "x:r", false], [{43=>nil, 42=>:enemy}, 42, "x:r", true], [{43=>nil, 42=>nil}, 42, "x:r", false], [{43=>nil, 42=>nil, 41=>:enemy}, 41, "x:r", true], [{43=>nil, 42=>nil, 41=>nil}, 41, "x:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, 40, "x:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil}, 40, "x:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>:enemy}, 39, "x:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil}, 39, "x:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>:enemy}, 38, "x:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil}, 38, "x:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>:enemy}, 37, "x:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil}, 37, "x:r", false], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>:enemy}, 36, "x:r", true], [{43=>nil, 42=>nil, 41=>nil, 40=>nil, 39=>nil, 38=>nil, 37=>nil, 36=>nil}, 36, "x:r", false], [{53=>nil}, 53, "x:r", false], [{53=>nil, 62=>:enemy}, 62, "x:r", true], [{53=>nil, 62=>nil}, 62, "x:r", false], [{53=>nil, 62=>nil, 71=>:enemy}, 71, "x:r", true], [{53=>nil, 62=>nil, 71=>nil}, 71, "x:r", false], [{53=>nil, 62=>nil, 71=>nil, 80=>:enemy}, 80, "x:r", true], [{53=>nil, 62=>nil, 71=>nil, 80=>nil}, 80, "x:r", false]], 45=>[[{36=>:enemy}, 36, "x:r", true], [{46=>:enemy}, 46, "x:r", true], [{54=>:enemy}, 54, "x:r", true], [{36=>nil}, 36, "x:r", false], [{36=>nil, 27=>:enemy}, 27, "x:r", true], [{36=>nil, 27=>nil}, 27, "x:r", false], [{36=>nil, 27=>nil, 18=>:enemy}, 18, "x:r", true], [{36=>nil, 27=>nil, 18=>nil}, 18, "x:r", false], [{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:r", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "x:r", false], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:r", true], [{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:r", false], [{46=>nil}, 46, "x:r", false], [{46=>nil, 47=>:enemy}, 47, "x:r", true], [{46=>nil, 47=>nil}, 47, "x:r", false], [{46=>nil, 47=>nil, 48=>:enemy}, 48, "x:r", true], [{46=>nil, 47=>nil, 48=>nil}, 48, "x:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>:enemy}, 49, "x:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil}, 49, "x:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "x:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "x:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "x:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "x:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "x:r", false], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:r", true], [{46=>nil, 47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:r", false], [{54=>nil}, 54, "x:r", false], [{54=>nil, 63=>:enemy}, 63, "x:r", true], [{54=>nil, 63=>nil}, 63, "x:r", false], [{54=>nil, 63=>nil, 72=>:enemy}, 72, "x:r", true], [{54=>nil, 63=>nil, 72=>nil}, 72, "x:r", false]], 46=>[[{37=>:enemy}, 37, "x:r", true], [{45=>:enemy}, 45, "x:r", true], [{47=>:enemy}, 47, "x:r", true], [{55=>:enemy}, 55, "x:r", true], [{37=>nil}, 37, "x:r", false], [{37=>nil, 28=>:enemy}, 28, "x:r", true], [{37=>nil, 28=>nil}, 28, "x:r", false], [{37=>nil, 28=>nil, 19=>:enemy}, 19, "x:r", true], [{37=>nil, 28=>nil, 19=>nil}, 19, "x:r", false], [{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:r", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "x:r", false], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:r", true], [{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:r", false], [{45=>nil}, 45, "x:r", false], [{47=>nil}, 47, "x:r", false], [{47=>nil, 48=>:enemy}, 48, "x:r", true], [{47=>nil, 48=>nil}, 48, "x:r", false], [{47=>nil, 48=>nil, 49=>:enemy}, 49, "x:r", true], [{47=>nil, 48=>nil, 49=>nil}, 49, "x:r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>:enemy}, 50, "x:r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil}, 50, "x:r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "x:r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "x:r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "x:r", false], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:r", true], [{47=>nil, 48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:r", false], [{55=>nil}, 55, "x:r", false], [{55=>nil, 64=>:enemy}, 64, "x:r", true], [{55=>nil, 64=>nil}, 64, "x:r", false], [{55=>nil, 64=>nil, 73=>:enemy}, 73, "x:r", true], [{55=>nil, 64=>nil, 73=>nil}, 73, "x:r", false]], 47=>[[{38=>:enemy}, 38, "x:r", true], [{46=>:enemy}, 46, "x:r", true], [{48=>:enemy}, 48, "x:r", true], [{56=>:enemy}, 56, "x:r", true], [{38=>nil}, 38, "x:r", false], [{38=>nil, 29=>:enemy}, 29, "x:r", true], [{38=>nil, 29=>nil}, 29, "x:r", false], [{38=>nil, 29=>nil, 20=>:enemy}, 20, "x:r", true], [{38=>nil, 29=>nil, 20=>nil}, 20, "x:r", false], [{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:r", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "x:r", false], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:r", true], [{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:r", false], [{46=>nil}, 46, "x:r", false], [{46=>nil, 45=>:enemy}, 45, "x:r", true], [{46=>nil, 45=>nil}, 45, "x:r", false], [{48=>nil}, 48, "x:r", false], [{48=>nil, 49=>:enemy}, 49, "x:r", true], [{48=>nil, 49=>nil}, 49, "x:r", false], [{48=>nil, 49=>nil, 50=>:enemy}, 50, "x:r", true], [{48=>nil, 49=>nil, 50=>nil}, 50, "x:r", false], [{48=>nil, 49=>nil, 50=>nil, 51=>:enemy}, 51, "x:r", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil}, 51, "x:r", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:r", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "x:r", false], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:r", true], [{48=>nil, 49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:r", false], [{56=>nil}, 56, "x:r", false], [{56=>nil, 65=>:enemy}, 65, "x:r", true], [{56=>nil, 65=>nil}, 65, "x:r", false], [{56=>nil, 65=>nil, 74=>:enemy}, 74, "x:r", true], [{56=>nil, 65=>nil, 74=>nil}, 74, "x:r", false]], 48=>[[{39=>:enemy}, 39, "x:r", true], [{47=>:enemy}, 47, "x:r", true], [{49=>:enemy}, 49, "x:r", true], [{57=>:enemy}, 57, "x:r", true], [{39=>nil}, 39, "x:r", false], [{39=>nil, 30=>:enemy}, 30, "x:r", true], [{39=>nil, 30=>nil}, 30, "x:r", false], [{39=>nil, 30=>nil, 21=>:enemy}, 21, "x:r", true], [{39=>nil, 30=>nil, 21=>nil}, 21, "x:r", false], [{39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:r", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "x:r", false], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:r", true], [{39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:r", false], [{47=>nil}, 47, "x:r", false], [{47=>nil, 46=>:enemy}, 46, "x:r", true], [{47=>nil, 46=>nil}, 46, "x:r", false], [{47=>nil, 46=>nil, 45=>:enemy}, 45, "x:r", true], [{47=>nil, 46=>nil, 45=>nil}, 45, "x:r", false], [{49=>nil}, 49, "x:r", false], [{49=>nil, 50=>:enemy}, 50, "x:r", true], [{49=>nil, 50=>nil}, 50, "x:r", false], [{49=>nil, 50=>nil, 51=>:enemy}, 51, "x:r", true], [{49=>nil, 50=>nil, 51=>nil}, 51, "x:r", false], [{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, 52, "x:r", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil}, 52, "x:r", false], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:r", true], [{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:r", false], [{57=>nil}, 57, "x:r", false], [{57=>nil, 66=>:enemy}, 66, "x:r", true], [{57=>nil, 66=>nil}, 66, "x:r", false], [{57=>nil, 66=>nil, 75=>:enemy}, 75, "x:r", true], [{57=>nil, 66=>nil, 75=>nil}, 75, "x:r", false]], 49=>[[{40=>:enemy}, 40, "x:r", true], [{48=>:enemy}, 48, "x:r", true], [{50=>:enemy}, 50, "x:r", true], [{58=>:enemy}, 58, "x:r", true], [{40=>nil}, 40, "x:r", false], [{40=>nil, 31=>:enemy}, 31, "x:r", true], [{40=>nil, 31=>nil}, 31, "x:r", false], [{40=>nil, 31=>nil, 22=>:enemy}, 22, "x:r", true], [{40=>nil, 31=>nil, 22=>nil}, 22, "x:r", false], [{40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:r", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "x:r", false], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:r", true], [{40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:r", false], [{48=>nil}, 48, "x:r", false], [{48=>nil, 47=>:enemy}, 47, "x:r", true], [{48=>nil, 47=>nil}, 47, "x:r", false], [{48=>nil, 47=>nil, 46=>:enemy}, 46, "x:r", true], [{48=>nil, 47=>nil, 46=>nil}, 46, "x:r", false], [{48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:r", true], [{48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:r", false], [{50=>nil}, 50, "x:r", false], [{50=>nil, 51=>:enemy}, 51, "x:r", true], [{50=>nil, 51=>nil}, 51, "x:r", false], [{50=>nil, 51=>nil, 52=>:enemy}, 52, "x:r", true], [{50=>nil, 51=>nil, 52=>nil}, 52, "x:r", false], [{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, 53, "x:r", true], [{50=>nil, 51=>nil, 52=>nil, 53=>nil}, 53, "x:r", false], [{58=>nil}, 58, "x:r", false], [{58=>nil, 67=>:enemy}, 67, "x:r", true], [{58=>nil, 67=>nil}, 67, "x:r", false], [{58=>nil, 67=>nil, 76=>:enemy}, 76, "x:r", true], [{58=>nil, 67=>nil, 76=>nil}, 76, "x:r", false]], 50=>[[{41=>:enemy}, 41, "x:r", true], [{49=>:enemy}, 49, "x:r", true], [{51=>:enemy}, 51, "x:r", true], [{59=>:enemy}, 59, "x:r", true], [{41=>nil}, 41, "x:r", false], [{41=>nil, 32=>:enemy}, 32, "x:r", true], [{41=>nil, 32=>nil}, 32, "x:r", false], [{41=>nil, 32=>nil, 23=>:enemy}, 23, "x:r", true], [{41=>nil, 32=>nil, 23=>nil}, 23, "x:r", false], [{41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:r", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "x:r", false], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:r", true], [{41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:r", false], [{49=>nil}, 49, "x:r", false], [{49=>nil, 48=>:enemy}, 48, "x:r", true], [{49=>nil, 48=>nil}, 48, "x:r", false], [{49=>nil, 48=>nil, 47=>:enemy}, 47, "x:r", true], [{49=>nil, 48=>nil, 47=>nil}, 47, "x:r", false], [{49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:r", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "x:r", false], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:r", true], [{49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:r", false], [{51=>nil}, 51, "x:r", false], [{51=>nil, 52=>:enemy}, 52, "x:r", true], [{51=>nil, 52=>nil}, 52, "x:r", false], [{51=>nil, 52=>nil, 53=>:enemy}, 53, "x:r", true], [{51=>nil, 52=>nil, 53=>nil}, 53, "x:r", false], [{59=>nil}, 59, "x:r", false], [{59=>nil, 68=>:enemy}, 68, "x:r", true], [{59=>nil, 68=>nil}, 68, "x:r", false], [{59=>nil, 68=>nil, 77=>:enemy}, 77, "x:r", true], [{59=>nil, 68=>nil, 77=>nil}, 77, "x:r", false]], 51=>[[{42=>:enemy}, 42, "x:r", true], [{50=>:enemy}, 50, "x:r", true], [{52=>:enemy}, 52, "x:r", true], [{60=>:enemy}, 60, "x:r", true], [{42=>nil}, 42, "x:r", false], [{42=>nil, 33=>:enemy}, 33, "x:r", true], [{42=>nil, 33=>nil}, 33, "x:r", false], [{42=>nil, 33=>nil, 24=>:enemy}, 24, "x:r", true], [{42=>nil, 33=>nil, 24=>nil}, 24, "x:r", false], [{42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:r", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "x:r", false], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:r", true], [{42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:r", false], [{50=>nil}, 50, "x:r", false], [{50=>nil, 49=>:enemy}, 49, "x:r", true], [{50=>nil, 49=>nil}, 49, "x:r", false], [{50=>nil, 49=>nil, 48=>:enemy}, 48, "x:r", true], [{50=>nil, 49=>nil, 48=>nil}, 48, "x:r", false], [{50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "x:r", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "x:r", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:r", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "x:r", false], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:r", true], [{50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:r", false], [{52=>nil}, 52, "x:r", false], [{52=>nil, 53=>:enemy}, 53, "x:r", true], [{52=>nil, 53=>nil}, 53, "x:r", false], [{60=>nil}, 60, "x:r", false], [{60=>nil, 69=>:enemy}, 69, "x:r", true], [{60=>nil, 69=>nil}, 69, "x:r", false], [{60=>nil, 69=>nil, 78=>:enemy}, 78, "x:r", true], [{60=>nil, 69=>nil, 78=>nil}, 78, "x:r", false]], 52=>[[{43=>:enemy}, 43, "x:r", true], [{51=>:enemy}, 51, "x:r", true], [{53=>:enemy}, 53, "x:r", true], [{61=>:enemy}, 61, "x:r", true], [{43=>nil}, 43, "x:r", false], [{43=>nil, 34=>:enemy}, 34, "x:r", true], [{43=>nil, 34=>nil}, 34, "x:r", false], [{43=>nil, 34=>nil, 25=>:enemy}, 25, "x:r", true], [{43=>nil, 34=>nil, 25=>nil}, 25, "x:r", false], [{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:r", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "x:r", false], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:r", true], [{43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:r", false], [{51=>nil}, 51, "x:r", false], [{51=>nil, 50=>:enemy}, 50, "x:r", true], [{51=>nil, 50=>nil}, 50, "x:r", false], [{51=>nil, 50=>nil, 49=>:enemy}, 49, "x:r", true], [{51=>nil, 50=>nil, 49=>nil}, 49, "x:r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "x:r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "x:r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "x:r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "x:r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "x:r", false], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:r", true], [{51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:r", false], [{53=>nil}, 53, "x:r", false], [{61=>nil}, 61, "x:r", false], [{61=>nil, 70=>:enemy}, 70, "x:r", true], [{61=>nil, 70=>nil}, 70, "x:r", false], [{61=>nil, 70=>nil, 79=>:enemy}, 79, "x:r", true], [{61=>nil, 70=>nil, 79=>nil}, 79, "x:r", false]], 53=>[[{44=>:enemy}, 44, "x:r", true], [{52=>:enemy}, 52, "x:r", true], [{62=>:enemy}, 62, "x:r", true], [{44=>nil}, 44, "x:r", false], [{44=>nil, 35=>:enemy}, 35, "x:r", true], [{44=>nil, 35=>nil}, 35, "x:r", false], [{44=>nil, 35=>nil, 26=>:enemy}, 26, "x:r", true], [{44=>nil, 35=>nil, 26=>nil}, 26, "x:r", false], [{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:r", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "x:r", false], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:r", true], [{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:r", false], [{52=>nil}, 52, "x:r", false], [{52=>nil, 51=>:enemy}, 51, "x:r", true], [{52=>nil, 51=>nil}, 51, "x:r", false], [{52=>nil, 51=>nil, 50=>:enemy}, 50, "x:r", true], [{52=>nil, 51=>nil, 50=>nil}, 50, "x:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, 49, "x:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil}, 49, "x:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, 48, "x:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}, 48, "x:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>:enemy}, 47, "x:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil}, 47, "x:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>:enemy}, 46, "x:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil}, 46, "x:r", false], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>:enemy}, 45, "x:r", true], [{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil, 47=>nil, 46=>nil, 45=>nil}, 45, "x:r", false], [{62=>nil}, 62, "x:r", false], [{62=>nil, 71=>:enemy}, 71, "x:r", true], [{62=>nil, 71=>nil}, 71, "x:r", false], [{62=>nil, 71=>nil, 80=>:enemy}, 80, "x:r", true], [{62=>nil, 71=>nil, 80=>nil}, 80, "x:r", false]], 54=>[[{45=>:enemy}, 45, "x:r", true], [{55=>:enemy}, 55, "x:r", true], [{63=>:enemy}, 63, "x:r", true], [{45=>nil}, 45, "x:r", false], [{45=>nil, 36=>:enemy}, 36, "x:r", true], [{45=>nil, 36=>nil}, 36, "x:r", false], [{45=>nil, 36=>nil, 27=>:enemy}, 27, "x:r", true], [{45=>nil, 36=>nil, 27=>nil}, 27, "x:r", false], [{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "x:r", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "x:r", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:r", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "x:r", false], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:r", true], [{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:r", false], [{55=>nil}, 55, "x:r", false], [{55=>nil, 56=>:enemy}, 56, "x:r", true], [{55=>nil, 56=>nil}, 56, "x:r", false], [{55=>nil, 56=>nil, 57=>:enemy}, 57, "x:r", true], [{55=>nil, 56=>nil, 57=>nil}, 57, "x:r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>:enemy}, 58, "x:r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil}, 58, "x:r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "x:r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "x:r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "x:r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "x:r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "x:r", false], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:r", true], [{55=>nil, 56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:r", false], [{63=>nil}, 63, "x:r", false], [{63=>nil, 72=>:enemy}, 72, "x:r", true], [{63=>nil, 72=>nil}, 72, "x:r", false]], 55=>[[{46=>:enemy}, 46, "x:r", true], [{54=>:enemy}, 54, "x:r", true], [{56=>:enemy}, 56, "x:r", true], [{64=>:enemy}, 64, "x:r", true], [{46=>nil}, 46, "x:r", false], [{46=>nil, 37=>:enemy}, 37, "x:r", true], [{46=>nil, 37=>nil}, 37, "x:r", false], [{46=>nil, 37=>nil, 28=>:enemy}, 28, "x:r", true], [{46=>nil, 37=>nil, 28=>nil}, 28, "x:r", false], [{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "x:r", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "x:r", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:r", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "x:r", false], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:r", true], [{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:r", false], [{54=>nil}, 54, "x:r", false], [{56=>nil}, 56, "x:r", false], [{56=>nil, 57=>:enemy}, 57, "x:r", true], [{56=>nil, 57=>nil}, 57, "x:r", false], [{56=>nil, 57=>nil, 58=>:enemy}, 58, "x:r", true], [{56=>nil, 57=>nil, 58=>nil}, 58, "x:r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>:enemy}, 59, "x:r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil}, 59, "x:r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "x:r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "x:r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "x:r", false], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:r", true], [{56=>nil, 57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:r", false], [{64=>nil}, 64, "x:r", false], [{64=>nil, 73=>:enemy}, 73, "x:r", true], [{64=>nil, 73=>nil}, 73, "x:r", false]], 56=>[[{47=>:enemy}, 47, "x:r", true], [{55=>:enemy}, 55, "x:r", true], [{57=>:enemy}, 57, "x:r", true], [{65=>:enemy}, 65, "x:r", true], [{47=>nil}, 47, "x:r", false], [{47=>nil, 38=>:enemy}, 38, "x:r", true], [{47=>nil, 38=>nil}, 38, "x:r", false], [{47=>nil, 38=>nil, 29=>:enemy}, 29, "x:r", true], [{47=>nil, 38=>nil, 29=>nil}, 29, "x:r", false], [{47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "x:r", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "x:r", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:r", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "x:r", false], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:r", true], [{47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:r", false], [{55=>nil}, 55, "x:r", false], [{55=>nil, 54=>:enemy}, 54, "x:r", true], [{55=>nil, 54=>nil}, 54, "x:r", false], [{57=>nil}, 57, "x:r", false], [{57=>nil, 58=>:enemy}, 58, "x:r", true], [{57=>nil, 58=>nil}, 58, "x:r", false], [{57=>nil, 58=>nil, 59=>:enemy}, 59, "x:r", true], [{57=>nil, 58=>nil, 59=>nil}, 59, "x:r", false], [{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, 60, "x:r", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil}, 60, "x:r", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:r", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "x:r", false], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:r", true], [{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:r", false], [{65=>nil}, 65, "x:r", false], [{65=>nil, 74=>:enemy}, 74, "x:r", true], [{65=>nil, 74=>nil}, 74, "x:r", false]], 57=>[[{48=>:enemy}, 48, "x:r", true], [{56=>:enemy}, 56, "x:r", true], [{58=>:enemy}, 58, "x:r", true], [{66=>:enemy}, 66, "x:r", true], [{48=>nil}, 48, "x:r", false], [{48=>nil, 39=>:enemy}, 39, "x:r", true], [{48=>nil, 39=>nil}, 39, "x:r", false], [{48=>nil, 39=>nil, 30=>:enemy}, 30, "x:r", true], [{48=>nil, 39=>nil, 30=>nil}, 30, "x:r", false], [{48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "x:r", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "x:r", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:r", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "x:r", false], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:r", true], [{48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:r", false], [{56=>nil}, 56, "x:r", false], [{56=>nil, 55=>:enemy}, 55, "x:r", true], [{56=>nil, 55=>nil}, 55, "x:r", false], [{56=>nil, 55=>nil, 54=>:enemy}, 54, "x:r", true], [{56=>nil, 55=>nil, 54=>nil}, 54, "x:r", false], [{58=>nil}, 58, "x:r", false], [{58=>nil, 59=>:enemy}, 59, "x:r", true], [{58=>nil, 59=>nil}, 59, "x:r", false], [{58=>nil, 59=>nil, 60=>:enemy}, 60, "x:r", true], [{58=>nil, 59=>nil, 60=>nil}, 60, "x:r", false], [{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, 61, "x:r", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil}, 61, "x:r", false], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:r", true], [{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:r", false], [{66=>nil}, 66, "x:r", false], [{66=>nil, 75=>:enemy}, 75, "x:r", true], [{66=>nil, 75=>nil}, 75, "x:r", false]], 58=>[[{49=>:enemy}, 49, "x:r", true], [{57=>:enemy}, 57, "x:r", true], [{59=>:enemy}, 59, "x:r", true], [{67=>:enemy}, 67, "x:r", true], [{49=>nil}, 49, "x:r", false], [{49=>nil, 40=>:enemy}, 40, "x:r", true], [{49=>nil, 40=>nil}, 40, "x:r", false], [{49=>nil, 40=>nil, 31=>:enemy}, 31, "x:r", true], [{49=>nil, 40=>nil, 31=>nil}, 31, "x:r", false], [{49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "x:r", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "x:r", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:r", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "x:r", false], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:r", true], [{49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:r", false], [{57=>nil}, 57, "x:r", false], [{57=>nil, 56=>:enemy}, 56, "x:r", true], [{57=>nil, 56=>nil}, 56, "x:r", false], [{57=>nil, 56=>nil, 55=>:enemy}, 55, "x:r", true], [{57=>nil, 56=>nil, 55=>nil}, 55, "x:r", false], [{57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:r", true], [{57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:r", false], [{59=>nil}, 59, "x:r", false], [{59=>nil, 60=>:enemy}, 60, "x:r", true], [{59=>nil, 60=>nil}, 60, "x:r", false], [{59=>nil, 60=>nil, 61=>:enemy}, 61, "x:r", true], [{59=>nil, 60=>nil, 61=>nil}, 61, "x:r", false], [{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, 62, "x:r", true], [{59=>nil, 60=>nil, 61=>nil, 62=>nil}, 62, "x:r", false], [{67=>nil}, 67, "x:r", false], [{67=>nil, 76=>:enemy}, 76, "x:r", true], [{67=>nil, 76=>nil}, 76, "x:r", false]], 59=>[[{50=>:enemy}, 50, "x:r", true], [{58=>:enemy}, 58, "x:r", true], [{60=>:enemy}, 60, "x:r", true], [{68=>:enemy}, 68, "x:r", true], [{50=>nil}, 50, "x:r", false], [{50=>nil, 41=>:enemy}, 41, "x:r", true], [{50=>nil, 41=>nil}, 41, "x:r", false], [{50=>nil, 41=>nil, 32=>:enemy}, 32, "x:r", true], [{50=>nil, 41=>nil, 32=>nil}, 32, "x:r", false], [{50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "x:r", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "x:r", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:r", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "x:r", false], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:r", true], [{50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:r", false], [{58=>nil}, 58, "x:r", false], [{58=>nil, 57=>:enemy}, 57, "x:r", true], [{58=>nil, 57=>nil}, 57, "x:r", false], [{58=>nil, 57=>nil, 56=>:enemy}, 56, "x:r", true], [{58=>nil, 57=>nil, 56=>nil}, 56, "x:r", false], [{58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:r", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "x:r", false], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:r", true], [{58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:r", false], [{60=>nil}, 60, "x:r", false], [{60=>nil, 61=>:enemy}, 61, "x:r", true], [{60=>nil, 61=>nil}, 61, "x:r", false], [{60=>nil, 61=>nil, 62=>:enemy}, 62, "x:r", true], [{60=>nil, 61=>nil, 62=>nil}, 62, "x:r", false], [{68=>nil}, 68, "x:r", false], [{68=>nil, 77=>:enemy}, 77, "x:r", true], [{68=>nil, 77=>nil}, 77, "x:r", false]], 60=>[[{51=>:enemy}, 51, "x:r", true], [{59=>:enemy}, 59, "x:r", true], [{61=>:enemy}, 61, "x:r", true], [{69=>:enemy}, 69, "x:r", true], [{51=>nil}, 51, "x:r", false], [{51=>nil, 42=>:enemy}, 42, "x:r", true], [{51=>nil, 42=>nil}, 42, "x:r", false], [{51=>nil, 42=>nil, 33=>:enemy}, 33, "x:r", true], [{51=>nil, 42=>nil, 33=>nil}, 33, "x:r", false], [{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "x:r", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "x:r", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:r", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "x:r", false], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:r", true], [{51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:r", false], [{59=>nil}, 59, "x:r", false], [{59=>nil, 58=>:enemy}, 58, "x:r", true], [{59=>nil, 58=>nil}, 58, "x:r", false], [{59=>nil, 58=>nil, 57=>:enemy}, 57, "x:r", true], [{59=>nil, 58=>nil, 57=>nil}, 57, "x:r", false], [{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "x:r", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "x:r", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:r", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "x:r", false], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:r", true], [{59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:r", false], [{61=>nil}, 61, "x:r", false], [{61=>nil, 62=>:enemy}, 62, "x:r", true], [{61=>nil, 62=>nil}, 62, "x:r", false], [{69=>nil}, 69, "x:r", false], [{69=>nil, 78=>:enemy}, 78, "x:r", true], [{69=>nil, 78=>nil}, 78, "x:r", false]], 61=>[[{52=>:enemy}, 52, "x:r", true], [{60=>:enemy}, 60, "x:r", true], [{62=>:enemy}, 62, "x:r", true], [{70=>:enemy}, 70, "x:r", true], [{52=>nil}, 52, "x:r", false], [{52=>nil, 43=>:enemy}, 43, "x:r", true], [{52=>nil, 43=>nil}, 43, "x:r", false], [{52=>nil, 43=>nil, 34=>:enemy}, 34, "x:r", true], [{52=>nil, 43=>nil, 34=>nil}, 34, "x:r", false], [{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "x:r", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "x:r", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:r", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "x:r", false], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:r", true], [{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:r", false], [{60=>nil}, 60, "x:r", false], [{60=>nil, 59=>:enemy}, 59, "x:r", true], [{60=>nil, 59=>nil}, 59, "x:r", false], [{60=>nil, 59=>nil, 58=>:enemy}, 58, "x:r", true], [{60=>nil, 59=>nil, 58=>nil}, 58, "x:r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "x:r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "x:r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "x:r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "x:r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "x:r", false], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:r", true], [{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:r", false], [{62=>nil}, 62, "x:r", false], [{70=>nil}, 70, "x:r", false], [{70=>nil, 79=>:enemy}, 79, "x:r", true], [{70=>nil, 79=>nil}, 79, "x:r", false]], 62=>[[{53=>:enemy}, 53, "x:r", true], [{61=>:enemy}, 61, "x:r", true], [{71=>:enemy}, 71, "x:r", true], [{53=>nil}, 53, "x:r", false], [{53=>nil, 44=>:enemy}, 44, "x:r", true], [{53=>nil, 44=>nil}, 44, "x:r", false], [{53=>nil, 44=>nil, 35=>:enemy}, 35, "x:r", true], [{53=>nil, 44=>nil, 35=>nil}, 35, "x:r", false], [{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "x:r", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "x:r", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:r", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "x:r", false], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:r", true], [{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:r", false], [{61=>nil}, 61, "x:r", false], [{61=>nil, 60=>:enemy}, 60, "x:r", true], [{61=>nil, 60=>nil}, 60, "x:r", false], [{61=>nil, 60=>nil, 59=>:enemy}, 59, "x:r", true], [{61=>nil, 60=>nil, 59=>nil}, 59, "x:r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, 58, "x:r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil}, 58, "x:r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, 57, "x:r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}, 57, "x:r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, 56, "x:r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}, 56, "x:r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>:enemy}, 55, "x:r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil}, 55, "x:r", false], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>:enemy}, 54, "x:r", true], [{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil, 55=>nil, 54=>nil}, 54, "x:r", false], [{71=>nil}, 71, "x:r", false], [{71=>nil, 80=>:enemy}, 80, "x:r", true], [{71=>nil, 80=>nil}, 80, "x:r", false]], 63=>[[{54=>:enemy}, 54, "x:r", true], [{64=>:enemy}, 64, "x:r", true], [{72=>:enemy}, 72, "x:r", true], [{54=>nil}, 54, "x:r", false], [{54=>nil, 45=>:enemy}, 45, "x:r", true], [{54=>nil, 45=>nil}, 45, "x:r", false], [{54=>nil, 45=>nil, 36=>:enemy}, 36, "x:r", true], [{54=>nil, 45=>nil, 36=>nil}, 36, "x:r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "x:r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "x:r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "x:r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "x:r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "x:r", false], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:r", true], [{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:r", false], [{64=>nil}, 64, "x:r", false], [{64=>nil, 65=>:enemy}, 65, "x:r", true], [{64=>nil, 65=>nil}, 65, "x:r", false], [{64=>nil, 65=>nil, 66=>:enemy}, 66, "x:r", true], [{64=>nil, 65=>nil, 66=>nil}, 66, "x:r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>:enemy}, 67, "x:r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil}, 67, "x:r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "x:r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "x:r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "x:r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "x:r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "x:r", false], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:r", true], [{64=>nil, 65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:r", false], [{72=>nil}, 72, "x:r", false]], 64=>[[{55=>:enemy}, 55, "x:r", true], [{63=>:enemy}, 63, "x:r", true], [{65=>:enemy}, 65, "x:r", true], [{73=>:enemy}, 73, "x:r", true], [{55=>nil}, 55, "x:r", false], [{55=>nil, 46=>:enemy}, 46, "x:r", true], [{55=>nil, 46=>nil}, 46, "x:r", false], [{55=>nil, 46=>nil, 37=>:enemy}, 37, "x:r", true], [{55=>nil, 46=>nil, 37=>nil}, 37, "x:r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "x:r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "x:r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "x:r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "x:r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "x:r", false], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:r", true], [{55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:r", false], [{63=>nil}, 63, "x:r", false], [{65=>nil}, 65, "x:r", false], [{65=>nil, 66=>:enemy}, 66, "x:r", true], [{65=>nil, 66=>nil}, 66, "x:r", false], [{65=>nil, 66=>nil, 67=>:enemy}, 67, "x:r", true], [{65=>nil, 66=>nil, 67=>nil}, 67, "x:r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>:enemy}, 68, "x:r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil}, 68, "x:r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "x:r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "x:r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "x:r", false], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:r", true], [{65=>nil, 66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:r", false], [{73=>nil}, 73, "x:r", false]], 65=>[[{56=>:enemy}, 56, "x:r", true], [{64=>:enemy}, 64, "x:r", true], [{66=>:enemy}, 66, "x:r", true], [{74=>:enemy}, 74, "x:r", true], [{56=>nil}, 56, "x:r", false], [{56=>nil, 47=>:enemy}, 47, "x:r", true], [{56=>nil, 47=>nil}, 47, "x:r", false], [{56=>nil, 47=>nil, 38=>:enemy}, 38, "x:r", true], [{56=>nil, 47=>nil, 38=>nil}, 38, "x:r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "x:r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "x:r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "x:r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "x:r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "x:r", false], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:r", true], [{56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:r", false], [{64=>nil}, 64, "x:r", false], [{64=>nil, 63=>:enemy}, 63, "x:r", true], [{64=>nil, 63=>nil}, 63, "x:r", false], [{66=>nil}, 66, "x:r", false], [{66=>nil, 67=>:enemy}, 67, "x:r", true], [{66=>nil, 67=>nil}, 67, "x:r", false], [{66=>nil, 67=>nil, 68=>:enemy}, 68, "x:r", true], [{66=>nil, 67=>nil, 68=>nil}, 68, "x:r", false], [{66=>nil, 67=>nil, 68=>nil, 69=>:enemy}, 69, "x:r", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil}, 69, "x:r", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:r", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "x:r", false], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:r", true], [{66=>nil, 67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:r", false], [{74=>nil}, 74, "x:r", false]], 66=>[[{57=>:enemy}, 57, "x:r", true], [{65=>:enemy}, 65, "x:r", true], [{67=>:enemy}, 67, "x:r", true], [{75=>:enemy}, 75, "x:r", true], [{57=>nil}, 57, "x:r", false], [{57=>nil, 48=>:enemy}, 48, "x:r", true], [{57=>nil, 48=>nil}, 48, "x:r", false], [{57=>nil, 48=>nil, 39=>:enemy}, 39, "x:r", true], [{57=>nil, 48=>nil, 39=>nil}, 39, "x:r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "x:r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "x:r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "x:r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "x:r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "x:r", false], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:r", true], [{57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:r", false], [{65=>nil}, 65, "x:r", false], [{65=>nil, 64=>:enemy}, 64, "x:r", true], [{65=>nil, 64=>nil}, 64, "x:r", false], [{65=>nil, 64=>nil, 63=>:enemy}, 63, "x:r", true], [{65=>nil, 64=>nil, 63=>nil}, 63, "x:r", false], [{67=>nil}, 67, "x:r", false], [{67=>nil, 68=>:enemy}, 68, "x:r", true], [{67=>nil, 68=>nil}, 68, "x:r", false], [{67=>nil, 68=>nil, 69=>:enemy}, 69, "x:r", true], [{67=>nil, 68=>nil, 69=>nil}, 69, "x:r", false], [{67=>nil, 68=>nil, 69=>nil, 70=>:enemy}, 70, "x:r", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil}, 70, "x:r", false], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:r", true], [{67=>nil, 68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:r", false], [{75=>nil}, 75, "x:r", false]], 67=>[[{58=>:enemy}, 58, "x:r", true], [{66=>:enemy}, 66, "x:r", true], [{68=>:enemy}, 68, "x:r", true], [{76=>:enemy}, 76, "x:r", true], [{58=>nil}, 58, "x:r", false], [{58=>nil, 49=>:enemy}, 49, "x:r", true], [{58=>nil, 49=>nil}, 49, "x:r", false], [{58=>nil, 49=>nil, 40=>:enemy}, 40, "x:r", true], [{58=>nil, 49=>nil, 40=>nil}, 40, "x:r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "x:r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "x:r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "x:r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "x:r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "x:r", false], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:r", true], [{58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:r", false], [{66=>nil}, 66, "x:r", false], [{66=>nil, 65=>:enemy}, 65, "x:r", true], [{66=>nil, 65=>nil}, 65, "x:r", false], [{66=>nil, 65=>nil, 64=>:enemy}, 64, "x:r", true], [{66=>nil, 65=>nil, 64=>nil}, 64, "x:r", false], [{66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:r", true], [{66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:r", false], [{68=>nil}, 68, "x:r", false], [{68=>nil, 69=>:enemy}, 69, "x:r", true], [{68=>nil, 69=>nil}, 69, "x:r", false], [{68=>nil, 69=>nil, 70=>:enemy}, 70, "x:r", true], [{68=>nil, 69=>nil, 70=>nil}, 70, "x:r", false], [{68=>nil, 69=>nil, 70=>nil, 71=>:enemy}, 71, "x:r", true], [{68=>nil, 69=>nil, 70=>nil, 71=>nil}, 71, "x:r", false], [{76=>nil}, 76, "x:r", false]], 68=>[[{59=>:enemy}, 59, "x:r", true], [{67=>:enemy}, 67, "x:r", true], [{69=>:enemy}, 69, "x:r", true], [{77=>:enemy}, 77, "x:r", true], [{59=>nil}, 59, "x:r", false], [{59=>nil, 50=>:enemy}, 50, "x:r", true], [{59=>nil, 50=>nil}, 50, "x:r", false], [{59=>nil, 50=>nil, 41=>:enemy}, 41, "x:r", true], [{59=>nil, 50=>nil, 41=>nil}, 41, "x:r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "x:r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "x:r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "x:r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "x:r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "x:r", false], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:r", true], [{59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:r", false], [{67=>nil}, 67, "x:r", false], [{67=>nil, 66=>:enemy}, 66, "x:r", true], [{67=>nil, 66=>nil}, 66, "x:r", false], [{67=>nil, 66=>nil, 65=>:enemy}, 65, "x:r", true], [{67=>nil, 66=>nil, 65=>nil}, 65, "x:r", false], [{67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:r", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "x:r", false], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:r", true], [{67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:r", false], [{69=>nil}, 69, "x:r", false], [{69=>nil, 70=>:enemy}, 70, "x:r", true], [{69=>nil, 70=>nil}, 70, "x:r", false], [{69=>nil, 70=>nil, 71=>:enemy}, 71, "x:r", true], [{69=>nil, 70=>nil, 71=>nil}, 71, "x:r", false], [{77=>nil}, 77, "x:r", false]], 69=>[[{60=>:enemy}, 60, "x:r", true], [{68=>:enemy}, 68, "x:r", true], [{70=>:enemy}, 70, "x:r", true], [{78=>:enemy}, 78, "x:r", true], [{60=>nil}, 60, "x:r", false], [{60=>nil, 51=>:enemy}, 51, "x:r", true], [{60=>nil, 51=>nil}, 51, "x:r", false], [{60=>nil, 51=>nil, 42=>:enemy}, 42, "x:r", true], [{60=>nil, 51=>nil, 42=>nil}, 42, "x:r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "x:r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "x:r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "x:r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "x:r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "x:r", false], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:r", true], [{60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:r", false], [{68=>nil}, 68, "x:r", false], [{68=>nil, 67=>:enemy}, 67, "x:r", true], [{68=>nil, 67=>nil}, 67, "x:r", false], [{68=>nil, 67=>nil, 66=>:enemy}, 66, "x:r", true], [{68=>nil, 67=>nil, 66=>nil}, 66, "x:r", false], [{68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "x:r", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "x:r", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:r", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "x:r", false], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:r", true], [{68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:r", false], [{70=>nil}, 70, "x:r", false], [{70=>nil, 71=>:enemy}, 71, "x:r", true], [{70=>nil, 71=>nil}, 71, "x:r", false], [{78=>nil}, 78, "x:r", false]], 70=>[[{61=>:enemy}, 61, "x:r", true], [{69=>:enemy}, 69, "x:r", true], [{71=>:enemy}, 71, "x:r", true], [{79=>:enemy}, 79, "x:r", true], [{61=>nil}, 61, "x:r", false], [{61=>nil, 52=>:enemy}, 52, "x:r", true], [{61=>nil, 52=>nil}, 52, "x:r", false], [{61=>nil, 52=>nil, 43=>:enemy}, 43, "x:r", true], [{61=>nil, 52=>nil, 43=>nil}, 43, "x:r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "x:r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "x:r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "x:r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "x:r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "x:r", false], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:r", true], [{61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:r", false], [{69=>nil}, 69, "x:r", false], [{69=>nil, 68=>:enemy}, 68, "x:r", true], [{69=>nil, 68=>nil}, 68, "x:r", false], [{69=>nil, 68=>nil, 67=>:enemy}, 67, "x:r", true], [{69=>nil, 68=>nil, 67=>nil}, 67, "x:r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "x:r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "x:r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "x:r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "x:r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "x:r", false], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:r", true], [{69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:r", false], [{71=>nil}, 71, "x:r", false], [{79=>nil}, 79, "x:r", false]], 71=>[[{62=>:enemy}, 62, "x:r", true], [{70=>:enemy}, 70, "x:r", true], [{80=>:enemy}, 80, "x:r", true], [{62=>nil}, 62, "x:r", false], [{62=>nil, 53=>:enemy}, 53, "x:r", true], [{62=>nil, 53=>nil}, 53, "x:r", false], [{62=>nil, 53=>nil, 44=>:enemy}, 44, "x:r", true], [{62=>nil, 53=>nil, 44=>nil}, 44, "x:r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "x:r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "x:r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "x:r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "x:r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "x:r", false], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:r", true], [{62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:r", false], [{70=>nil}, 70, "x:r", false], [{70=>nil, 69=>:enemy}, 69, "x:r", true], [{70=>nil, 69=>nil}, 69, "x:r", false], [{70=>nil, 69=>nil, 68=>:enemy}, 68, "x:r", true], [{70=>nil, 69=>nil, 68=>nil}, 68, "x:r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>:enemy}, 67, "x:r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil}, 67, "x:r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>:enemy}, 66, "x:r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil}, 66, "x:r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>:enemy}, 65, "x:r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil}, 65, "x:r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>:enemy}, 64, "x:r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil}, 64, "x:r", false], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>:enemy}, 63, "x:r", true], [{70=>nil, 69=>nil, 68=>nil, 67=>nil, 66=>nil, 65=>nil, 64=>nil, 63=>nil}, 63, "x:r", false], [{80=>nil}, 80, "x:r", false]], 72=>[[{63=>:enemy}, 63, "x:r", true], [{73=>:enemy}, 73, "x:r", true], [{63=>nil}, 63, "x:r", false], [{63=>nil, 54=>:enemy}, 54, "x:r", true], [{63=>nil, 54=>nil}, 54, "x:r", false], [{63=>nil, 54=>nil, 45=>:enemy}, 45, "x:r", true], [{63=>nil, 54=>nil, 45=>nil}, 45, "x:r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>:enemy}, 36, "x:r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil}, 36, "x:r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, 27, "x:r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil}, 27, "x:r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, 18, "x:r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}, 18, "x:r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, 9, "x:r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}, 9, "x:r", false], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, 0, "x:r", true], [{63=>nil, 54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}, 0, "x:r", false], [{73=>nil}, 73, "x:r", false], [{73=>nil, 74=>:enemy}, 74, "x:r", true], [{73=>nil, 74=>nil}, 74, "x:r", false], [{73=>nil, 74=>nil, 75=>:enemy}, 75, "x:r", true], [{73=>nil, 74=>nil, 75=>nil}, 75, "x:r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>:enemy}, 76, "x:r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil}, 76, "x:r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "x:r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "x:r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "x:r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "x:r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "x:r", false], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:r", true], [{73=>nil, 74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:r", false]], 73=>[[{64=>:enemy}, 64, "x:r", true], [{72=>:enemy}, 72, "x:r", true], [{74=>:enemy}, 74, "x:r", true], [{64=>nil}, 64, "x:r", false], [{64=>nil, 55=>:enemy}, 55, "x:r", true], [{64=>nil, 55=>nil}, 55, "x:r", false], [{64=>nil, 55=>nil, 46=>:enemy}, 46, "x:r", true], [{64=>nil, 55=>nil, 46=>nil}, 46, "x:r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>:enemy}, 37, "x:r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil}, 37, "x:r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>:enemy}, 28, "x:r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil}, 28, "x:r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, 19, "x:r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil}, 19, "x:r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, 10, "x:r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}, 10, "x:r", false], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, 1, "x:r", true], [{64=>nil, 55=>nil, 46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}, 1, "x:r", false], [{72=>nil}, 72, "x:r", false], [{74=>nil}, 74, "x:r", false], [{74=>nil, 75=>:enemy}, 75, "x:r", true], [{74=>nil, 75=>nil}, 75, "x:r", false], [{74=>nil, 75=>nil, 76=>:enemy}, 76, "x:r", true], [{74=>nil, 75=>nil, 76=>nil}, 76, "x:r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>:enemy}, 77, "x:r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil}, 77, "x:r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "x:r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "x:r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "x:r", false], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:r", true], [{74=>nil, 75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:r", false]], 74=>[[{65=>:enemy}, 65, "x:r", true], [{73=>:enemy}, 73, "x:r", true], [{75=>:enemy}, 75, "x:r", true], [{65=>nil}, 65, "x:r", false], [{65=>nil, 56=>:enemy}, 56, "x:r", true], [{65=>nil, 56=>nil}, 56, "x:r", false], [{65=>nil, 56=>nil, 47=>:enemy}, 47, "x:r", true], [{65=>nil, 56=>nil, 47=>nil}, 47, "x:r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>:enemy}, 38, "x:r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil}, 38, "x:r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>:enemy}, 29, "x:r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil}, 29, "x:r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>:enemy}, 20, "x:r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil}, 20, "x:r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, 11, "x:r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil}, 11, "x:r", false], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, 2, "x:r", true], [{65=>nil, 56=>nil, 47=>nil, 38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}, 2, "x:r", false], [{73=>nil}, 73, "x:r", false], [{73=>nil, 72=>:enemy}, 72, "x:r", true], [{73=>nil, 72=>nil}, 72, "x:r", false], [{75=>nil}, 75, "x:r", false], [{75=>nil, 76=>:enemy}, 76, "x:r", true], [{75=>nil, 76=>nil}, 76, "x:r", false], [{75=>nil, 76=>nil, 77=>:enemy}, 77, "x:r", true], [{75=>nil, 76=>nil, 77=>nil}, 77, "x:r", false], [{75=>nil, 76=>nil, 77=>nil, 78=>:enemy}, 78, "x:r", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil}, 78, "x:r", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:r", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "x:r", false], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:r", true], [{75=>nil, 76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:r", false]], 75=>[[{66=>:enemy}, 66, "x:r", true], [{74=>:enemy}, 74, "x:r", true], [{76=>:enemy}, 76, "x:r", true], [{66=>nil}, 66, "x:r", false], [{66=>nil, 57=>:enemy}, 57, "x:r", true], [{66=>nil, 57=>nil}, 57, "x:r", false], [{66=>nil, 57=>nil, 48=>:enemy}, 48, "x:r", true], [{66=>nil, 57=>nil, 48=>nil}, 48, "x:r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>:enemy}, 39, "x:r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil}, 39, "x:r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>:enemy}, 30, "x:r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil}, 30, "x:r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>:enemy}, 21, "x:r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil}, 21, "x:r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>:enemy}, 12, "x:r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil}, 12, "x:r", false], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, 3, "x:r", true], [{66=>nil, 57=>nil, 48=>nil, 39=>nil, 30=>nil, 21=>nil, 12=>nil, 3=>nil}, 3, "x:r", false], [{74=>nil}, 74, "x:r", false], [{74=>nil, 73=>:enemy}, 73, "x:r", true], [{74=>nil, 73=>nil}, 73, "x:r", false], [{74=>nil, 73=>nil, 72=>:enemy}, 72, "x:r", true], [{74=>nil, 73=>nil, 72=>nil}, 72, "x:r", false], [{76=>nil}, 76, "x:r", false], [{76=>nil, 77=>:enemy}, 77, "x:r", true], [{76=>nil, 77=>nil}, 77, "x:r", false], [{76=>nil, 77=>nil, 78=>:enemy}, 78, "x:r", true], [{76=>nil, 77=>nil, 78=>nil}, 78, "x:r", false], [{76=>nil, 77=>nil, 78=>nil, 79=>:enemy}, 79, "x:r", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil}, 79, "x:r", false], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:r", true], [{76=>nil, 77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:r", false]], 76=>[[{67=>:enemy}, 67, "x:r", true], [{75=>:enemy}, 75, "x:r", true], [{77=>:enemy}, 77, "x:r", true], [{67=>nil}, 67, "x:r", false], [{67=>nil, 58=>:enemy}, 58, "x:r", true], [{67=>nil, 58=>nil}, 58, "x:r", false], [{67=>nil, 58=>nil, 49=>:enemy}, 49, "x:r", true], [{67=>nil, 58=>nil, 49=>nil}, 49, "x:r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>:enemy}, 40, "x:r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil}, 40, "x:r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>:enemy}, 31, "x:r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil}, 31, "x:r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>:enemy}, 22, "x:r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil}, 22, "x:r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>:enemy}, 13, "x:r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil}, 13, "x:r", false], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>:enemy}, 4, "x:r", true], [{67=>nil, 58=>nil, 49=>nil, 40=>nil, 31=>nil, 22=>nil, 13=>nil, 4=>nil}, 4, "x:r", false], [{75=>nil}, 75, "x:r", false], [{75=>nil, 74=>:enemy}, 74, "x:r", true], [{75=>nil, 74=>nil}, 74, "x:r", false], [{75=>nil, 74=>nil, 73=>:enemy}, 73, "x:r", true], [{75=>nil, 74=>nil, 73=>nil}, 73, "x:r", false], [{75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:r", true], [{75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:r", false], [{77=>nil}, 77, "x:r", false], [{77=>nil, 78=>:enemy}, 78, "x:r", true], [{77=>nil, 78=>nil}, 78, "x:r", false], [{77=>nil, 78=>nil, 79=>:enemy}, 79, "x:r", true], [{77=>nil, 78=>nil, 79=>nil}, 79, "x:r", false], [{77=>nil, 78=>nil, 79=>nil, 80=>:enemy}, 80, "x:r", true], [{77=>nil, 78=>nil, 79=>nil, 80=>nil}, 80, "x:r", false]], 77=>[[{68=>:enemy}, 68, "x:r", true], [{76=>:enemy}, 76, "x:r", true], [{78=>:enemy}, 78, "x:r", true], [{68=>nil}, 68, "x:r", false], [{68=>nil, 59=>:enemy}, 59, "x:r", true], [{68=>nil, 59=>nil}, 59, "x:r", false], [{68=>nil, 59=>nil, 50=>:enemy}, 50, "x:r", true], [{68=>nil, 59=>nil, 50=>nil}, 50, "x:r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>:enemy}, 41, "x:r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil}, 41, "x:r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>:enemy}, 32, "x:r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil}, 32, "x:r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>:enemy}, 23, "x:r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil}, 23, "x:r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>:enemy}, 14, "x:r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil}, 14, "x:r", false], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>:enemy}, 5, "x:r", true], [{68=>nil, 59=>nil, 50=>nil, 41=>nil, 32=>nil, 23=>nil, 14=>nil, 5=>nil}, 5, "x:r", false], [{76=>nil}, 76, "x:r", false], [{76=>nil, 75=>:enemy}, 75, "x:r", true], [{76=>nil, 75=>nil}, 75, "x:r", false], [{76=>nil, 75=>nil, 74=>:enemy}, 74, "x:r", true], [{76=>nil, 75=>nil, 74=>nil}, 74, "x:r", false], [{76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:r", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "x:r", false], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:r", true], [{76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:r", false], [{78=>nil}, 78, "x:r", false], [{78=>nil, 79=>:enemy}, 79, "x:r", true], [{78=>nil, 79=>nil}, 79, "x:r", false], [{78=>nil, 79=>nil, 80=>:enemy}, 80, "x:r", true], [{78=>nil, 79=>nil, 80=>nil}, 80, "x:r", false]], 78=>[[{69=>:enemy}, 69, "x:r", true], [{77=>:enemy}, 77, "x:r", true], [{79=>:enemy}, 79, "x:r", true], [{69=>nil}, 69, "x:r", false], [{69=>nil, 60=>:enemy}, 60, "x:r", true], [{69=>nil, 60=>nil}, 60, "x:r", false], [{69=>nil, 60=>nil, 51=>:enemy}, 51, "x:r", true], [{69=>nil, 60=>nil, 51=>nil}, 51, "x:r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>:enemy}, 42, "x:r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil}, 42, "x:r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>:enemy}, 33, "x:r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil}, 33, "x:r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, 24, "x:r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil}, 24, "x:r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>:enemy}, 15, "x:r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil}, 15, "x:r", false], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>:enemy}, 6, "x:r", true], [{69=>nil, 60=>nil, 51=>nil, 42=>nil, 33=>nil, 24=>nil, 15=>nil, 6=>nil}, 6, "x:r", false], [{77=>nil}, 77, "x:r", false], [{77=>nil, 76=>:enemy}, 76, "x:r", true], [{77=>nil, 76=>nil}, 76, "x:r", false], [{77=>nil, 76=>nil, 75=>:enemy}, 75, "x:r", true], [{77=>nil, 76=>nil, 75=>nil}, 75, "x:r", false], [{77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "x:r", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "x:r", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:r", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "x:r", false], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:r", true], [{77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:r", false], [{79=>nil}, 79, "x:r", false], [{79=>nil, 80=>:enemy}, 80, "x:r", true], [{79=>nil, 80=>nil}, 80, "x:r", false]], 79=>[[{70=>:enemy}, 70, "x:r", true], [{78=>:enemy}, 78, "x:r", true], [{80=>:enemy}, 80, "x:r", true], [{70=>nil}, 70, "x:r", false], [{70=>nil, 61=>:enemy}, 61, "x:r", true], [{70=>nil, 61=>nil}, 61, "x:r", false], [{70=>nil, 61=>nil, 52=>:enemy}, 52, "x:r", true], [{70=>nil, 61=>nil, 52=>nil}, 52, "x:r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>:enemy}, 43, "x:r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil}, 43, "x:r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>:enemy}, 34, "x:r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil}, 34, "x:r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, 25, "x:r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil}, 25, "x:r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, 16, "x:r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}, 16, "x:r", false], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>:enemy}, 7, "x:r", true], [{70=>nil, 61=>nil, 52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil, 7=>nil}, 7, "x:r", false], [{78=>nil}, 78, "x:r", false], [{78=>nil, 77=>:enemy}, 77, "x:r", true], [{78=>nil, 77=>nil}, 77, "x:r", false], [{78=>nil, 77=>nil, 76=>:enemy}, 76, "x:r", true], [{78=>nil, 77=>nil, 76=>nil}, 76, "x:r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "x:r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "x:r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "x:r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "x:r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "x:r", false], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:r", true], [{78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:r", false], [{80=>nil}, 80, "x:r", false]], 80=>[[{71=>:enemy}, 71, "x:r", true], [{79=>:enemy}, 79, "x:r", true], [{71=>nil}, 71, "x:r", false], [{71=>nil, 62=>:enemy}, 62, "x:r", true], [{71=>nil, 62=>nil}, 62, "x:r", false], [{71=>nil, 62=>nil, 53=>:enemy}, 53, "x:r", true], [{71=>nil, 62=>nil, 53=>nil}, 53, "x:r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>:enemy}, 44, "x:r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil}, 44, "x:r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>:enemy}, 35, "x:r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil}, 35, "x:r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, 26, "x:r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil}, 26, "x:r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, 17, "x:r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}, 17, "x:r", false], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, 8, "x:r", true], [{71=>nil, 62=>nil, 53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}, 8, "x:r", false], [{79=>nil}, 79, "x:r", false], [{79=>nil, 78=>:enemy}, 78, "x:r", true], [{79=>nil, 78=>nil}, 78, "x:r", false], [{79=>nil, 78=>nil, 77=>:enemy}, 77, "x:r", true], [{79=>nil, 78=>nil, 77=>nil}, 77, "x:r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>:enemy}, 76, "x:r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil}, 76, "x:r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>:enemy}, 75, "x:r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil}, 75, "x:r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>:enemy}, 74, "x:r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil}, 74, "x:r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>:enemy}, 73, "x:r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil}, 73, "x:r", false], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>:enemy}, 72, "x:r", true], [{79=>nil, 78=>nil, 77=>nil, 76=>nil, 75=>nil, 74=>nil, 73=>nil, 72=>nil}, 72, "x:r", false]], nil=>[[{0=>nil}, 0, "x:r", false], [{1=>nil}, 1, "x:r", false], [{2=>nil}, 2, "x:r", false], [{3=>nil}, 3, "x:r", false], [{4=>nil}, 4, "x:r", false], [{5=>nil}, 5, "x:r", false], [{6=>nil}, 6, "x:r", false], [{7=>nil}, 7, "x:r", false], [{8=>nil}, 8, "x:r", false], [{9=>nil}, 9, "x:r", false], [{10=>nil}, 10, "x:r", false], [{11=>nil}, 11, "x:r", false], [{12=>nil}, 12, "x:r", false], [{13=>nil}, 13, "x:r", false], [{14=>nil}, 14, "x:r", false], [{15=>nil}, 15, "x:r", false], [{16=>nil}, 16, "x:r", false], [{17=>nil}, 17, "x:r", false], [{18=>nil}, 18, "x:r", false], [{19=>nil}, 19, "x:r", false], [{20=>nil}, 20, "x:r", false], [{21=>nil}, 21, "x:r", false], [{22=>nil}, 22, "x:r", false], [{23=>nil}, 23, "x:r", false], [{24=>nil}, 24, "x:r", false], [{25=>nil}, 25, "x:r", false], [{26=>nil}, 26, "x:r", false], [{27=>nil}, 27, "x:r", false], [{28=>nil}, 28, "x:r", false], [{29=>nil}, 29, "x:r", false], [{30=>nil}, 30, "x:r", false], [{31=>nil}, 31, "x:r", false], [{32=>nil}, 32, "x:r", false], [{33=>nil}, 33, "x:r", false], [{34=>nil}, 34, "x:r", false], [{35=>nil}, 35, "x:r", false], [{36=>nil}, 36, "x:r", false], [{37=>nil}, 37, "x:r", false], [{38=>nil}, 38, "x:r", false], [{39=>nil}, 39, "x:r", false], [{40=>nil}, 40, "x:r", false], [{41=>nil}, 41, "x:r", false], [{42=>nil}, 42, "x:r", false], [{43=>nil}, 43, "x:r", false], [{44=>nil}, 44, "x:r", false], [{45=>nil}, 45, "x:r", false], [{46=>nil}, 46, "x:r", false], [{47=>nil}, 47, "x:r", false], [{48=>nil}, 48, "x:r", false], [{49=>nil}, 49, "x:r", false], [{50=>nil}, 50, "x:r", false], [{51=>nil}, 51, "x:r", false], [{52=>nil}, 52, "x:r", false], [{53=>nil}, 53, "x:r", false], [{54=>nil}, 54, "x:r", false], [{55=>nil}, 55, "x:r", false], [{56=>nil}, 56, "x:r", false], [{57=>nil}, 57, "x:r", false], [{58=>nil}, 58, "x:r", false], [{59=>nil}, 59, "x:r", false], [{60=>nil}, 60, "x:r", false], [{61=>nil}, 61, "x:r", false], [{62=>nil}, 62, "x:r", false], [{63=>nil}, 63, "x:r", false], [{64=>nil}, 64, "x:r", false], [{65=>nil}, 65, "x:r", false], [{66=>nil}, 66, "x:r", false], [{67=>nil}, 67, "x:r", false], [{68=>nil}, 68, "x:r", false], [{69=>nil}, 69, "x:r", false], [{70=>nil}, 70, "x:r", false], [{71=>nil}, 71, "x:r", false], [{72=>nil}, 72, "x:r", false], [{73=>nil}, 73, "x:r", false], [{74=>nil}, 74, "x:r", false], [{75=>nil}, 75, "x:r", false], [{76=>nil}, 76, "x:r", false], [{77=>nil}, 77, "x:r", false], [{78=>nil}, 78, "x:r", false], [{79=>nil}, 79, "x:r", false], [{80=>nil}, 80, "x:r", false]]}, "x:s"=>{0=>[[{1=>:enemy}, 1, "x:s", true], [{9=>:enemy}, 9, "x:s", true], [{1=>nil}, 1, "x:s", false], [{9=>nil}, 9, "x:s", false]], 1=>[[{0=>:enemy}, 0, "x:s", true], [{2=>:enemy}, 2, "x:s", true], [{10=>:enemy}, 10, "x:s", true], [{0=>nil}, 0, "x:s", false], [{2=>nil}, 2, "x:s", false], [{10=>nil}, 10, "x:s", false]], 2=>[[{1=>:enemy}, 1, "x:s", true], [{3=>:enemy}, 3, "x:s", true], [{11=>:enemy}, 11, "x:s", true], [{1=>nil}, 1, "x:s", false], [{3=>nil}, 3, "x:s", false], [{11=>nil}, 11, "x:s", false]], 3=>[[{2=>:enemy}, 2, "x:s", true], [{4=>:enemy}, 4, "x:s", true], [{12=>:enemy}, 12, "x:s", true], [{2=>nil}, 2, "x:s", false], [{4=>nil}, 4, "x:s", false], [{12=>nil}, 12, "x:s", false]], 4=>[[{3=>:enemy}, 3, "x:s", true], [{5=>:enemy}, 5, "x:s", true], [{13=>:enemy}, 13, "x:s", true], [{3=>nil}, 3, "x:s", false], [{5=>nil}, 5, "x:s", false], [{13=>nil}, 13, "x:s", false]], 5=>[[{4=>:enemy}, 4, "x:s", true], [{6=>:enemy}, 6, "x:s", true], [{14=>:enemy}, 14, "x:s", true], [{4=>nil}, 4, "x:s", false], [{6=>nil}, 6, "x:s", false], [{14=>nil}, 14, "x:s", false]], 6=>[[{5=>:enemy}, 5, "x:s", true], [{7=>:enemy}, 7, "x:s", true], [{15=>:enemy}, 15, "x:s", true], [{5=>nil}, 5, "x:s", false], [{7=>nil}, 7, "x:s", false], [{15=>nil}, 15, "x:s", false]], 7=>[[{6=>:enemy}, 6, "x:s", true], [{8=>:enemy}, 8, "x:s", true], [{16=>:enemy}, 16, "x:s", true], [{6=>nil}, 6, "x:s", false], [{8=>nil}, 8, "x:s", false], [{16=>nil}, 16, "x:s", false]], 8=>[[{7=>:enemy}, 7, "x:s", true], [{17=>:enemy}, 17, "x:s", true], [{7=>nil}, 7, "x:s", false], [{17=>nil}, 17, "x:s", false]], 9=>[[{10=>:enemy}, 10, "x:s", true], [{18=>:enemy}, 18, "x:s", true], [{10=>nil}, 10, "x:s", false], [{18=>nil}, 18, "x:s", false]], 10=>[[{9=>:enemy}, 9, "x:s", true], [{11=>:enemy}, 11, "x:s", true], [{19=>:enemy}, 19, "x:s", true], [{9=>nil}, 9, "x:s", false], [{11=>nil}, 11, "x:s", false], [{19=>nil}, 19, "x:s", false]], 11=>[[{10=>:enemy}, 10, "x:s", true], [{12=>:enemy}, 12, "x:s", true], [{20=>:enemy}, 20, "x:s", true], [{10=>nil}, 10, "x:s", false], [{12=>nil}, 12, "x:s", false], [{20=>nil}, 20, "x:s", false]], 12=>[[{11=>:enemy}, 11, "x:s", true], [{13=>:enemy}, 13, "x:s", true], [{21=>:enemy}, 21, "x:s", true], [{11=>nil}, 11, "x:s", false], [{13=>nil}, 13, "x:s", false], [{21=>nil}, 21, "x:s", false]], 13=>[[{12=>:enemy}, 12, "x:s", true], [{14=>:enemy}, 14, "x:s", true], [{22=>:enemy}, 22, "x:s", true], [{12=>nil}, 12, "x:s", false], [{14=>nil}, 14, "x:s", false], [{22=>nil}, 22, "x:s", false]], 14=>[[{13=>:enemy}, 13, "x:s", true], [{15=>:enemy}, 15, "x:s", true], [{23=>:enemy}, 23, "x:s", true], [{13=>nil}, 13, "x:s", false], [{15=>nil}, 15, "x:s", false], [{23=>nil}, 23, "x:s", false]], 15=>[[{14=>:enemy}, 14, "x:s", true], [{16=>:enemy}, 16, "x:s", true], [{24=>:enemy}, 24, "x:s", true], [{14=>nil}, 14, "x:s", false], [{16=>nil}, 16, "x:s", false], [{24=>nil}, 24, "x:s", false]], 16=>[[{15=>:enemy}, 15, "x:s", true], [{17=>:enemy}, 17, "x:s", true], [{25=>:enemy}, 25, "x:s", true], [{15=>nil}, 15, "x:s", false], [{17=>nil}, 17, "x:s", false], [{25=>nil}, 25, "x:s", false]], 17=>[[{16=>:enemy}, 16, "x:s", true], [{26=>:enemy}, 26, "x:s", true], [{16=>nil}, 16, "x:s", false], [{26=>nil}, 26, "x:s", false]], 18=>[[{19=>:enemy}, 19, "x:s", true], [{27=>:enemy}, 27, "x:s", true], [{19=>nil}, 19, "x:s", false], [{27=>nil}, 27, "x:s", false]], 19=>[[{18=>:enemy}, 18, "x:s", true], [{20=>:enemy}, 20, "x:s", true], [{28=>:enemy}, 28, "x:s", true], [{18=>nil}, 18, "x:s", false], [{20=>nil}, 20, "x:s", false], [{28=>nil}, 28, "x:s", false]], 20=>[[{19=>:enemy}, 19, "x:s", true], [{21=>:enemy}, 21, "x:s", true], [{29=>:enemy}, 29, "x:s", true], [{19=>nil}, 19, "x:s", false], [{21=>nil}, 21, "x:s", false], [{29=>nil}, 29, "x:s", false]], 21=>[[{20=>:enemy}, 20, "x:s", true], [{22=>:enemy}, 22, "x:s", true], [{30=>:enemy}, 30, "x:s", true], [{20=>nil}, 20, "x:s", false], [{22=>nil}, 22, "x:s", false], [{30=>nil}, 30, "x:s", false]], 22=>[[{21=>:enemy}, 21, "x:s", true], [{23=>:enemy}, 23, "x:s", true], [{31=>:enemy}, 31, "x:s", true], [{21=>nil}, 21, "x:s", false], [{23=>nil}, 23, "x:s", false], [{31=>nil}, 31, "x:s", false]], 23=>[[{22=>:enemy}, 22, "x:s", true], [{24=>:enemy}, 24, "x:s", true], [{32=>:enemy}, 32, "x:s", true], [{22=>nil}, 22, "x:s", false], [{24=>nil}, 24, "x:s", false], [{32=>nil}, 32, "x:s", false]], 24=>[[{23=>:enemy}, 23, "x:s", true], [{25=>:enemy}, 25, "x:s", true], [{33=>:enemy}, 33, "x:s", true], [{23=>nil}, 23, "x:s", false], [{25=>nil}, 25, "x:s", false], [{33=>nil}, 33, "x:s", false]], 25=>[[{24=>:enemy}, 24, "x:s", true], [{26=>:enemy}, 26, "x:s", true], [{34=>:enemy}, 34, "x:s", true], [{24=>nil}, 24, "x:s", false], [{26=>nil}, 26, "x:s", false], [{34=>nil}, 34, "x:s", false]], 26=>[[{25=>:enemy}, 25, "x:s", true], [{35=>:enemy}, 35, "x:s", true], [{25=>nil}, 25, "x:s", false], [{35=>nil}, 35, "x:s", false]], 27=>[[{28=>:enemy}, 28, "x:s", true], [{36=>:enemy}, 36, "x:s", true], [{28=>nil}, 28, "x:s", false], [{36=>nil}, 36, "x:s", false]], 28=>[[{27=>:enemy}, 27, "x:s", true], [{29=>:enemy}, 29, "x:s", true], [{37=>:enemy}, 37, "x:s", true], [{27=>nil}, 27, "x:s", false], [{29=>nil}, 29, "x:s", false], [{37=>nil}, 37, "x:s", false]], 29=>[[{28=>:enemy}, 28, "x:s", true], [{30=>:enemy}, 30, "x:s", true], [{38=>:enemy}, 38, "x:s", true], [{28=>nil}, 28, "x:s", false], [{30=>nil}, 30, "x:s", false], [{38=>nil}, 38, "x:s", false]], 30=>[[{29=>:enemy}, 29, "x:s", true], [{31=>:enemy}, 31, "x:s", true], [{39=>:enemy}, 39, "x:s", true], [{29=>nil}, 29, "x:s", false], [{31=>nil}, 31, "x:s", false], [{39=>nil}, 39, "x:s", false]], 31=>[[{30=>:enemy}, 30, "x:s", true], [{32=>:enemy}, 32, "x:s", true], [{40=>:enemy}, 40, "x:s", true], [{30=>nil}, 30, "x:s", false], [{32=>nil}, 32, "x:s", false], [{40=>nil}, 40, "x:s", false]], 32=>[[{31=>:enemy}, 31, "x:s", true], [{33=>:enemy}, 33, "x:s", true], [{41=>:enemy}, 41, "x:s", true], [{31=>nil}, 31, "x:s", false], [{33=>nil}, 33, "x:s", false], [{41=>nil}, 41, "x:s", false]], 33=>[[{32=>:enemy}, 32, "x:s", true], [{34=>:enemy}, 34, "x:s", true], [{42=>:enemy}, 42, "x:s", true], [{32=>nil}, 32, "x:s", false], [{34=>nil}, 34, "x:s", false], [{42=>nil}, 42, "x:s", false]], 34=>[[{33=>:enemy}, 33, "x:s", true], [{35=>:enemy}, 35, "x:s", true], [{43=>:enemy}, 43, "x:s", true], [{33=>nil}, 33, "x:s", false], [{35=>nil}, 35, "x:s", false], [{43=>nil}, 43, "x:s", false]], 35=>[[{34=>:enemy}, 34, "x:s", true], [{44=>:enemy}, 44, "x:s", true], [{34=>nil}, 34, "x:s", false], [{44=>nil}, 44, "x:s", false]], 36=>[[{37=>:enemy}, 37, "x:s", true], [{45=>:enemy}, 45, "x:s", true], [{37=>nil}, 37, "x:s", false], [{45=>nil}, 45, "x:s", false]], 37=>[[{36=>:enemy}, 36, "x:s", true], [{38=>:enemy}, 38, "x:s", true], [{46=>:enemy}, 46, "x:s", true], [{36=>nil}, 36, "x:s", false], [{38=>nil}, 38, "x:s", false], [{46=>nil}, 46, "x:s", false]], 38=>[[{37=>:enemy}, 37, "x:s", true], [{39=>:enemy}, 39, "x:s", true], [{47=>:enemy}, 47, "x:s", true], [{37=>nil}, 37, "x:s", false], [{39=>nil}, 39, "x:s", false], [{47=>nil}, 47, "x:s", false]], 39=>[[{38=>:enemy}, 38, "x:s", true], [{40=>:enemy}, 40, "x:s", true], [{48=>:enemy}, 48, "x:s", true], [{38=>nil}, 38, "x:s", false], [{40=>nil}, 40, "x:s", false], [{48=>nil}, 48, "x:s", false]], 40=>[[{39=>:enemy}, 39, "x:s", true], [{41=>:enemy}, 41, "x:s", true], [{49=>:enemy}, 49, "x:s", true], [{39=>nil}, 39, "x:s", false], [{41=>nil}, 41, "x:s", false], [{49=>nil}, 49, "x:s", false]], 41=>[[{40=>:enemy}, 40, "x:s", true], [{42=>:enemy}, 42, "x:s", true], [{50=>:enemy}, 50, "x:s", true], [{40=>nil}, 40, "x:s", false], [{42=>nil}, 42, "x:s", false], [{50=>nil}, 50, "x:s", false]], 42=>[[{41=>:enemy}, 41, "x:s", true], [{43=>:enemy}, 43, "x:s", true], [{51=>:enemy}, 51, "x:s", true], [{41=>nil}, 41, "x:s", false], [{43=>nil}, 43, "x:s", false], [{51=>nil}, 51, "x:s", false]], 43=>[[{42=>:enemy}, 42, "x:s", true], [{44=>:enemy}, 44, "x:s", true], [{52=>:enemy}, 52, "x:s", true], [{42=>nil}, 42, "x:s", false], [{44=>nil}, 44, "x:s", false], [{52=>nil}, 52, "x:s", false]], 44=>[[{43=>:enemy}, 43, "x:s", true], [{53=>:enemy}, 53, "x:s", true], [{43=>nil}, 43, "x:s", false], [{53=>nil}, 53, "x:s", false]], 45=>[[{46=>:enemy}, 46, "x:s", true], [{54=>:enemy}, 54, "x:s", true], [{46=>nil}, 46, "x:s", false], [{54=>nil}, 54, "x:s", false]], 46=>[[{45=>:enemy}, 45, "x:s", true], [{47=>:enemy}, 47, "x:s", true], [{55=>:enemy}, 55, "x:s", true], [{45=>nil}, 45, "x:s", false], [{47=>nil}, 47, "x:s", false], [{55=>nil}, 55, "x:s", false]], 47=>[[{46=>:enemy}, 46, "x:s", true], [{48=>:enemy}, 48, "x:s", true], [{56=>:enemy}, 56, "x:s", true], [{46=>nil}, 46, "x:s", false], [{48=>nil}, 48, "x:s", false], [{56=>nil}, 56, "x:s", false]], 48=>[[{47=>:enemy}, 47, "x:s", true], [{49=>:enemy}, 49, "x:s", true], [{57=>:enemy}, 57, "x:s", true], [{47=>nil}, 47, "x:s", false], [{49=>nil}, 49, "x:s", false], [{57=>nil}, 57, "x:s", false]], 49=>[[{48=>:enemy}, 48, "x:s", true], [{50=>:enemy}, 50, "x:s", true], [{58=>:enemy}, 58, "x:s", true], [{48=>nil}, 48, "x:s", false], [{50=>nil}, 50, "x:s", false], [{58=>nil}, 58, "x:s", false]], 50=>[[{49=>:enemy}, 49, "x:s", true], [{51=>:enemy}, 51, "x:s", true], [{59=>:enemy}, 59, "x:s", true], [{49=>nil}, 49, "x:s", false], [{51=>nil}, 51, "x:s", false], [{59=>nil}, 59, "x:s", false]], 51=>[[{50=>:enemy}, 50, "x:s", true], [{52=>:enemy}, 52, "x:s", true], [{60=>:enemy}, 60, "x:s", true], [{50=>nil}, 50, "x:s", false], [{52=>nil}, 52, "x:s", false], [{60=>nil}, 60, "x:s", false]], 52=>[[{51=>:enemy}, 51, "x:s", true], [{53=>:enemy}, 53, "x:s", true], [{61=>:enemy}, 61, "x:s", true], [{51=>nil}, 51, "x:s", false], [{53=>nil}, 53, "x:s", false], [{61=>nil}, 61, "x:s", false]], 53=>[[{52=>:enemy}, 52, "x:s", true], [{62=>:enemy}, 62, "x:s", true], [{52=>nil}, 52, "x:s", false], [{62=>nil}, 62, "x:s", false]], 54=>[[{55=>:enemy}, 55, "x:s", true], [{63=>:enemy}, 63, "x:s", true], [{55=>nil}, 55, "x:s", false], [{63=>nil}, 63, "x:s", false]], 55=>[[{54=>:enemy}, 54, "x:s", true], [{56=>:enemy}, 56, "x:s", true], [{64=>:enemy}, 64, "x:s", true], [{54=>nil}, 54, "x:s", false], [{56=>nil}, 56, "x:s", false], [{64=>nil}, 64, "x:s", false]], 56=>[[{55=>:enemy}, 55, "x:s", true], [{57=>:enemy}, 57, "x:s", true], [{65=>:enemy}, 65, "x:s", true], [{55=>nil}, 55, "x:s", false], [{57=>nil}, 57, "x:s", false], [{65=>nil}, 65, "x:s", false]], 57=>[[{56=>:enemy}, 56, "x:s", true], [{58=>:enemy}, 58, "x:s", true], [{66=>:enemy}, 66, "x:s", true], [{56=>nil}, 56, "x:s", false], [{58=>nil}, 58, "x:s", false], [{66=>nil}, 66, "x:s", false]], 58=>[[{57=>:enemy}, 57, "x:s", true], [{59=>:enemy}, 59, "x:s", true], [{67=>:enemy}, 67, "x:s", true], [{57=>nil}, 57, "x:s", false], [{59=>nil}, 59, "x:s", false], [{67=>nil}, 67, "x:s", false]], 59=>[[{58=>:enemy}, 58, "x:s", true], [{60=>:enemy}, 60, "x:s", true], [{68=>:enemy}, 68, "x:s", true], [{58=>nil}, 58, "x:s", false], [{60=>nil}, 60, "x:s", false], [{68=>nil}, 68, "x:s", false]], 60=>[[{59=>:enemy}, 59, "x:s", true], [{61=>:enemy}, 61, "x:s", true], [{69=>:enemy}, 69, "x:s", true], [{59=>nil}, 59, "x:s", false], [{61=>nil}, 61, "x:s", false], [{69=>nil}, 69, "x:s", false]], 61=>[[{60=>:enemy}, 60, "x:s", true], [{62=>:enemy}, 62, "x:s", true], [{70=>:enemy}, 70, "x:s", true], [{60=>nil}, 60, "x:s", false], [{62=>nil}, 62, "x:s", false], [{70=>nil}, 70, "x:s", false]], 62=>[[{61=>:enemy}, 61, "x:s", true], [{71=>:enemy}, 71, "x:s", true], [{61=>nil}, 61, "x:s", false], [{71=>nil}, 71, "x:s", false]], 63=>[[{64=>:enemy}, 64, "x:s", true], [{72=>:enemy}, 72, "x:s", true], [{64=>nil}, 64, "x:s", false], [{72=>nil}, 72, "x:s", false]], 64=>[[{63=>:enemy}, 63, "x:s", true], [{65=>:enemy}, 65, "x:s", true], [{73=>:enemy}, 73, "x:s", true], [{63=>nil}, 63, "x:s", false], [{65=>nil}, 65, "x:s", false], [{73=>nil}, 73, "x:s", false]], 65=>[[{64=>:enemy}, 64, "x:s", true], [{66=>:enemy}, 66, "x:s", true], [{74=>:enemy}, 74, "x:s", true], [{64=>nil}, 64, "x:s", false], [{66=>nil}, 66, "x:s", false], [{74=>nil}, 74, "x:s", false]], 66=>[[{65=>:enemy}, 65, "x:s", true], [{67=>:enemy}, 67, "x:s", true], [{75=>:enemy}, 75, "x:s", true], [{65=>nil}, 65, "x:s", false], [{67=>nil}, 67, "x:s", false], [{75=>nil}, 75, "x:s", false]], 67=>[[{66=>:enemy}, 66, "x:s", true], [{68=>:enemy}, 68, "x:s", true], [{76=>:enemy}, 76, "x:s", true], [{66=>nil}, 66, "x:s", false], [{68=>nil}, 68, "x:s", false], [{76=>nil}, 76, "x:s", false]], 68=>[[{67=>:enemy}, 67, "x:s", true], [{69=>:enemy}, 69, "x:s", true], [{77=>:enemy}, 77, "x:s", true], [{67=>nil}, 67, "x:s", false], [{69=>nil}, 69, "x:s", false], [{77=>nil}, 77, "x:s", false]], 69=>[[{68=>:enemy}, 68, "x:s", true], [{70=>:enemy}, 70, "x:s", true], [{78=>:enemy}, 78, "x:s", true], [{68=>nil}, 68, "x:s", false], [{70=>nil}, 70, "x:s", false], [{78=>nil}, 78, "x:s", false]], 70=>[[{69=>:enemy}, 69, "x:s", true], [{71=>:enemy}, 71, "x:s", true], [{79=>:enemy}, 79, "x:s", true], [{69=>nil}, 69, "x:s", false], [{71=>nil}, 71, "x:s", false], [{79=>nil}, 79, "x:s", false]], 71=>[[{70=>:enemy}, 70, "x:s", true], [{80=>:enemy}, 80, "x:s", true], [{70=>nil}, 70, "x:s", false], [{80=>nil}, 80, "x:s", false]], 72=>[[{73=>:enemy}, 73, "x:s", true], [{73=>nil}, 73, "x:s", false]], 73=>[[{72=>:enemy}, 72, "x:s", true], [{74=>:enemy}, 74, "x:s", true], [{72=>nil}, 72, "x:s", false], [{74=>nil}, 74, "x:s", false]], 74=>[[{73=>:enemy}, 73, "x:s", true], [{75=>:enemy}, 75, "x:s", true], [{73=>nil}, 73, "x:s", false], [{75=>nil}, 75, "x:s", false]], 75=>[[{74=>:enemy}, 74, "x:s", true], [{76=>:enemy}, 76, "x:s", true], [{74=>nil}, 74, "x:s", false], [{76=>nil}, 76, "x:s", false]], 76=>[[{75=>:enemy}, 75, "x:s", true], [{77=>:enemy}, 77, "x:s", true], [{75=>nil}, 75, "x:s", false], [{77=>nil}, 77, "x:s", false]], 77=>[[{76=>:enemy}, 76, "x:s", true], [{78=>:enemy}, 78, "x:s", true], [{76=>nil}, 76, "x:s", false], [{78=>nil}, 78, "x:s", false]], 78=>[[{77=>:enemy}, 77, "x:s", true], [{79=>:enemy}, 79, "x:s", true], [{77=>nil}, 77, "x:s", false], [{79=>nil}, 79, "x:s", false]], 79=>[[{78=>:enemy}, 78, "x:s", true], [{80=>:enemy}, 80, "x:s", true], [{78=>nil}, 78, "x:s", false], [{80=>nil}, 80, "x:s", false]], 80=>[[{79=>:enemy}, 79, "x:s", true], [{79=>nil}, 79, "x:s", false]], nil=>[[{0=>nil}, 0, "x:s", false], [{1=>nil}, 1, "x:s", false], [{2=>nil}, 2, "x:s", false], [{3=>nil}, 3, "x:s", false], [{4=>nil}, 4, "x:s", false], [{5=>nil}, 5, "x:s", false], [{6=>nil}, 6, "x:s", false], [{7=>nil}, 7, "x:s", false], [{8=>nil}, 8, "x:s", false], [{9=>nil}, 9, "x:s", false], [{10=>nil}, 10, "x:s", false], [{11=>nil}, 11, "x:s", false], [{12=>nil}, 12, "x:s", false], [{13=>nil}, 13, "x:s", false], [{14=>nil}, 14, "x:s", false], [{15=>nil}, 15, "x:s", false], [{16=>nil}, 16, "x:s", false], [{17=>nil}, 17, "x:s", false], [{18=>nil}, 18, "x:s", false], [{19=>nil}, 19, "x:s", false], [{20=>nil}, 20, "x:s", false], [{21=>nil}, 21, "x:s", false], [{22=>nil}, 22, "x:s", false], [{23=>nil}, 23, "x:s", false], [{24=>nil}, 24, "x:s", false], [{25=>nil}, 25, "x:s", false], [{26=>nil}, 26, "x:s", false], [{27=>nil}, 27, "x:s", false], [{28=>nil}, 28, "x:s", false], [{29=>nil}, 29, "x:s", false], [{30=>nil}, 30, "x:s", false], [{31=>nil}, 31, "x:s", false], [{32=>nil}, 32, "x:s", false], [{33=>nil}, 33, "x:s", false], [{34=>nil}, 34, "x:s", false], [{35=>nil}, 35, "x:s", false], [{36=>nil}, 36, "x:s", false], [{37=>nil}, 37, "x:s", false], [{38=>nil}, 38, "x:s", false], [{39=>nil}, 39, "x:s", false], [{40=>nil}, 40, "x:s", false], [{41=>nil}, 41, "x:s", false], [{42=>nil}, 42, "x:s", false], [{43=>nil}, 43, "x:s", false], [{44=>nil}, 44, "x:s", false], [{45=>nil}, 45, "x:s", false], [{46=>nil}, 46, "x:s", false], [{47=>nil}, 47, "x:s", false], [{48=>nil}, 48, "x:s", false], [{49=>nil}, 49, "x:s", false], [{50=>nil}, 50, "x:s", false], [{51=>nil}, 51, "x:s", false], [{52=>nil}, 52, "x:s", false], [{53=>nil}, 53, "x:s", false], [{54=>nil}, 54, "x:s", false], [{55=>nil}, 55, "x:s", false], [{56=>nil}, 56, "x:s", false], [{57=>nil}, 57, "x:s", false], [{58=>nil}, 58, "x:s", false], [{59=>nil}, 59, "x:s", false], [{60=>nil}, 60, "x:s", false], [{61=>nil}, 61, "x:s", false], [{62=>nil}, 62, "x:s", false], [{63=>nil}, 63, "x:s", false], [{64=>nil}, 64, "x:s", false], [{65=>nil}, 65, "x:s", false], [{66=>nil}, 66, "x:s", false], [{67=>nil}, 67, "x:s", false], [{68=>nil}, 68, "x:s", false], [{69=>nil}, 69, "x:s", false], [{70=>nil}, 70, "x:s", false], [{71=>nil}, 71, "x:s", false], [{72=>nil}, 72, "x:s", false], [{73=>nil}, 73, "x:s", false], [{74=>nil}, 74, "x:s", false], [{75=>nil}, 75, "x:s", false], [{76=>nil}, 76, "x:s", false], [{77=>nil}, 77, "x:s", false], [{78=>nil}, 78, "x:s", false], [{79=>nil}, 79, "x:s", false], [{80=>nil}, 80, "x:s", false]]}}
  end
end
